@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Day.php 5286 2011-10-12 07:14:38Z EZdesign $
+ * @version $Id: Day.php 6353 2012-05-28 17:29:23Z SteveG $
  *
  * @category Piwik
  * @package Piwik
@@ -22,6 +22,9 @@
  */
 class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 {
+	/**
+	 * Constructor
+	 */
 	function __construct()
 	{
 		parent::__construct();
@@ -49,7 +52,9 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 *   (for example when a Segment is defined and the Keywords report is requested)
 	 * Then the function will create the Archive for the Core metrics 'VisitsSummary' which will in turn process the number of visits
 	 *
-	 *  If there is no specified segment, the SQL query will always run.
+	 * If there is no specified segment, the SQL query will always run.
+	 *
+	 * @return bool|null
 	 */
 	public function isThereSomeVisits()
 	{
@@ -80,7 +85,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 				sum(log_visit.visit_total_actions) as nb_actions,
 				max(log_visit.visit_total_actions) as max_actions,
 				sum(log_visit.visit_total_time) as sum_visit_length,
-				sum(case log_visit.visit_total_actions when 1 then 1 else 0 end) as bounce_count,
+				sum(case log_visit.visit_total_actions when 1 then 1 when 0 then 1 else 0 end) as bounce_count,
 				sum(case log_visit.visit_goal_converted when 1 then 1 else 0 end) as nb_visits_converted
 			";
 			$from = "log_visit";
@@ -122,6 +127,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * If a segment is specified but a plugin other than 'VisitsSummary' is being requested,
 	 * we create an archive for processing VisitsSummary Core Metrics, which will in turn
 	 * execute the query above (in isThereSomeVisits)
+	 *
+	 * @return bool|null
 	 */
 	private function redirectRequestToVisitsSummary()
 	{
@@ -143,6 +150,129 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		
 		return $this->isThereSomeVisits;
 	}
+
+	/**
+	 * Creates and returns an array of SQL SELECT expressions that will summarize
+	 * the data in a column of a specified table, over a set of ranges.
+	 *
+	 * The SELECT expressions will count the number of column values that are
+	 * within each range.
+	 *
+	 * @param string       $column              The column of the log_conversion table to reduce.
+	 * @param array        $ranges              The ranges to reduce data over.
+	 * @param string       $table               The table the SELECTs should use.
+	 * @param string       $selectColumnPrefix  The prefix when specifying what a SELECT
+	 *                                          expression will be selected AS.
+	 * @param bool|string  $extraCondition      An extra condition to be appended to 'case when'
+	 *                                          expressions. Must start with the logical operator,
+	 *                                          ie (AND, OR, etc.).
+	 * @return array  An array of SQL SELECT expressions.
+	 */
+	public static function buildReduceByRangeSelect(
+		$column, $ranges, $table, $selectColumnPrefix = '', $extraCondition = false)
+	{
+		$selects = array();
+
+		foreach($ranges as $gap)
+		{
+			if (count($gap) == 2)
+			{
+				$lowerBound = $gap[0];
+				$upperBound = $gap[1];
+				
+				$selectAs = "$selectColumnPrefix$lowerBound-$upperBound";
+
+				$selects[] = "sum(case when $table.$column between $lowerBound and $upperBound $extraCondition".
+									 " then 1 else 0 end) as `$selectAs`";
+			}
+			else
+			{
+				$lowerBound = $gap[0];
+				
+				$selectAs = $selectColumnPrefix.($lowerBound + 1).urlencode('+');
+
+				$selects[] = "sum(case when $table.$column > $lowerBound $extraCondition then 1 else 0 end) as `$selectAs`";
+			}
+		}
+
+		return $selects;
+	}
+
+	/**
+	 * Converts a database SELECT result into a whole DataTable with two columns and as many
+	 * rows as elements in $row.
+	 * 
+	 * The key of each element in $row is used as the value of the first column, and the
+	 * value of each element is used as the second column.
+	 * 
+	 * NOTE: $selectAsPrefix can be used to make sure only SOME of the data in $row is used.
+	 * 
+	 * @param array   $row             The database row to convert.
+	 * @param mixed   $labelCount      The label to use for the second column of the DataTable result.
+	 * @param string  $selectAsPrefix  A string that identifies which elements of $row to use
+	 *                                 in the result. Every key of $row that starts with this
+	 *                                 value is used.
+	 * @return Piwik_DataTable
+	 */
+	public function getSimpleDataTableFromRow($row, $labelCount, $selectAsPrefix = '')
+	{
+		// the labels in $row can have prefixes that need to be removed before creating a table
+		$cleanRow = array();
+
+		foreach($row as $label => $count)
+		{
+			if (empty($selectAsPrefix) || strpos($label, $selectAsPrefix) === 0)
+			{
+				$cleanLabel = substr($label, strlen($selectAsPrefix));
+
+				$cleanRow[$cleanLabel] = array($labelCount => $count);
+			}
+		}
+
+		$table = new Piwik_DataTable();
+		$table->addRowsFromArrayWithIndexLabel($cleanRow);
+		return $table;
+	}
+
+	/**
+	 * Performs a simple query on the log_visit table within the time range this archive
+	 * represents.
+	 *
+	 * @param string      $select        The SELECT clause.
+	 * @param string|bool $orderBy       The ORDER BY clause (without the 'ORDER BY' part). Set to
+	 *                                   false to specify no ORDER BY.
+	 * @param array|bool  $groupByCols   An array of column names to group by. Set to false to
+	 *                                   specify no GROUP BY.
+	 * @param bool        $oneResultRow  Whether only one row is expected or not. If set to true,
+	 *                                   this function returns one row, if false, an array of rows.
+	 * @return array
+	 */
+	public function queryVisitsSimple($select, $orderBy = false, $groupByCols = false, $oneResultRow = true)
+	{
+		$from = "log_visit";
+		$where = "log_visit.visit_last_action_time >= ?
+				AND log_visit.visit_last_action_time <= ?
+	 			AND log_visit.idsite = ?";
+		
+		$groupBy = false;
+		if ($groupByCols and !empty($groupByCols))
+		{
+			$groupBy = implode(',', $groupByCols);
+		}
+		
+		$bind = array($this->getStartDatetimeUTC(), $this->getEndDatetimeUTC(), $this->idsite);
+		
+		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind, $orderBy, $groupBy);
+		
+		if ($oneResultRow)
+		{
+			return $this->db->fetchRow($query['sql'], $query['bind']);
+		}
+		else
+		{
+			return $this->db->fetchAll($query['sql'], $query['bind']);
+		}
+	}
 	
 	/**
 	 * Helper function that returns a DataTable containing the $select fields / value pairs.
@@ -157,32 +287,23 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * 		PercentFlash 		0.5676
 	 *
 	 *
-	 * @param string $select
-	 * @param string $labelCount
+	 * @param string  $select
+	 * @param string  $labelCount
 	 * @return Piwik_DataTable
 	 */
 	public function getSimpleDataTableFromSelect($select, $labelCount)
 	{
-		$from = "log_visit";
-		$where = "log_visit.visit_last_action_time >= ?
-				AND log_visit.visit_last_action_time <= ?
-	 			AND log_visit.idsite = ?";
-		
-		$bind = array($this->getStartDatetimeUTC(), $this->getEndDatetimeUTC(), $this->idsite);
-		
-		$query = $this->getSegment()->getSelectQuery($select, $from, $where, $bind);
-		
-		$data = $this->db->fetchRow($query['sql'], $query['bind']);
-		
-		foreach($data as $label => &$count)
-		{
-			$count = array($labelCount => $count);
-		}
-		$table = new Piwik_DataTable();
-		$table->addRowsFromArrayWithIndexLabel($data);
-		return $table;
+		$data = $this->queryVisitsSimple($select);
+		return $this->getSimpleDataTableFromRow($data, $labelCount);
 	}
 
+	/**
+	 * Returns the actions by the given dimension
+	 *
+	 * @param array|string  $label
+	 * @param string        $where
+	 * @return mixed
+	 */
 	public function queryActionsByDimension($label, $where = '')
 	{
 	    if(is_array($label))
@@ -237,9 +358,9 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	/**
 	 * Query visits by dimension
 	 *
-	 * @param string $label mixed Can be a string, eg. "referer_name", will be aliased as 'label' in the returned rows
-	 * 				Can also be an array of strings, when the dimension spans multiple fields, eg. array("referer_name", "referer_keyword")
-	 * @param string $where Additional condition for WHERE clause
+	 * @param array|string  $label  mixed Can be a string, eg. "referer_name", will be aliased as 'label' in the returned rows
+	 * 				                Can also be an array of strings, when the dimension spans multiple fields, eg. array("referer_name", "referer_keyword")
+	 * @param string        $where  Additional condition for WHERE clause
 	 */
 	public function queryVisitsByDimension($label, $where = '')
 	{
@@ -270,7 +391,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 				sum(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_NB_ACTIONS ."`,
 				max(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_MAX_ACTIONS ."`,
 				sum(log_visit.visit_total_time) as `". Piwik_Archive::INDEX_SUM_VISIT_LENGTH ."`,
-				sum(case log_visit.visit_total_actions when 1 then 1 else 0 end) as `". Piwik_Archive::INDEX_BOUNCE_COUNT ."`,
+				sum(case log_visit.visit_total_actions when 1 then 1 when 0 then 1 else 0 end) as `". Piwik_Archive::INDEX_BOUNCE_COUNT ."`,
 				sum(case log_visit.visit_goal_converted when 1 then 1 else 0 end) as `". Piwik_Archive::INDEX_NB_VISITS_CONVERTED ."`";
 	    
 	    $from = "log_visit";
@@ -286,13 +407,18 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		
 		return $this->db->query($query['sql'], $query['bind']);
 	}
-	
+
 	/**
 	 * @see queryVisitsByDimension() Similar to this function,
 	 * but queries metrics for the requested dimensions,
 	 * for each Goal conversion
+	 *
+	 * @param string|array  $label
+	 * @param string        $where
+	 * @param array         $aggregateLabels
+	 * @return
 	 */
-	public function queryConversionsByDimension($label, $where = '')
+	public function queryConversionsByDimension($label, $where = '', $aggregateLabels = array())
 	{
 		if(empty($label))
 		{
@@ -313,6 +439,10 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	        $select = $label . " AS label, ";
 	        $groupBy = 'label';
 	    }
+	    if(!empty($aggregateLabels))
+	    {
+	    	$select .= implode(", ", $aggregateLabels) . ", ";
+	    }
 	    if(!empty($where))
 	    {
 	    	$where = sprintf($where, "log_conversion", "log_conversion");
@@ -348,7 +478,13 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
         
         return $this->db->query($query['sql'], $query['bind']);
 	}
-	
+
+	/**
+	 * Returns the ecommerce items
+	 *
+	 * @param string  $field
+	 * @return string
+	 */
 	public function queryEcommerceItems($field)
 	{
 		$query = "SELECT
@@ -376,12 +512,21 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		$query = $this->db->query($query, $bind);
 		return $query;
 	}
-	
+
+	/**
+	 * @param string  $field
+	 * @return string
+	 */
 	static public function getSqlRevenue($field)
 	{
 		return "ROUND(".$field.",".Piwik_Tracker_GoalManager::REVENUE_PRECISION.")";
 	}
-	
+
+	/**
+	 * Converts the given array to a datatable
+	 * @param array $array
+	 * @return Piwik_DataTable
+	 */
 	public function getDataTableFromArray( $array )
 	{
 		$table = new Piwik_DataTable();
@@ -420,7 +565,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * Windows XP	12	...
 	 * Mac OS	15	36	...
 	 *
-	 * @param string $label Table log_visit field name to be use to compute common stats
+	 * @param string  $label  Table log_visit field name to be use to compute common stats
 	 * @return array
 	 */
 	public function getArrayInterestForLabel($label)
@@ -434,13 +579,14 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		}
 		return $interest;
 	}
-	
+
 	/**
 	 * Generates a dataTable given a multidimensional PHP array that associates LABELS to Piwik_DataTableRows
 	 * This is used for the "Actions" DataTable, where a line is the aggregate of all the subtables
 	 * Example: the category /blog has 3 visits because it has /blog/index (2 visits) + /blog/about (1 visit)
 	 *
-	 * @param array $table
+	 * @param array  $table
+	 * @param array  $parents
 	 * @return Piwik_DataTable
 	 */
 	static public function generateDataTable( $table, $parents=array() )
@@ -483,8 +629,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * 	 				LABEL2 => array(col1 => X, col2 => Y),
 	 * 				)
 	 *
-	 * @param array $array at the given format
-	 * @return array Array with one element: the serialized data table string
+	 * @param array  $array  at the given format
+	 * @return array  Array with one element: the serialized data table string
 	 */
 	public function getDataTableSerialized( $array )
 	{
@@ -516,9 +662,9 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * 				)
 	 *
 	 *
-	 * @param array $arrayLevel0
-	 * @param array $subArrayLevel1ByKey Array of Piwik_DataTable
-	 * @return array Array with N elements: the strings of the datatable serialized
+	 * @param array  $arrayLevel0
+	 * @param array  $subArrayLevel1ByKey  Array of Piwik_DataTable
+	 * @return array  Array with N elements: the strings of the datatable serialized
 	 */
 	public function getDataTableWithSubtablesFromArraysIndexedByLabel( $arrayLevel0, $subArrayLevel1ByKey )
 	{
@@ -535,10 +681,12 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 
 		return $parentTableLevel0;
 	}
-	
+
 	/**
 	 * Returns an empty row containing default values for the common stat
 	 *
+	 * @param bool  $onlyMetricsAvailableInActionsTable
+	 * @param bool  $doNotSumVisits
 	 * @return array
 	 */
 	public function getNewInterestRow($onlyMetricsAvailableInActionsTable = false, $doNotSumVisits = false)
@@ -569,7 +717,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * Returns a Piwik_DataTable_Row containing default values for common stat,
 	 * plus a column 'label' with the value $label
 	 *
-	 * @param string $label
+	 * @param string  $label
 	 * @return Piwik_DataTable_Row
 	 */
 	public function getNewInterestRowLabeled( $label )
@@ -581,14 +729,17 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 					)
 				);
 	}
-	
+
 	/**
 	 * Adds the given row $newRowToAdd to the existing  $oldRowToUpdate passed by reference
 	 *
 	 * The rows are php arrays Name => value
 	 *
-	 * @param array $newRowToAdd
-	 * @param array $oldRowToUpdate
+	 * @param array  $newRowToAdd
+	 * @param array  $oldRowToUpdate
+	 * @param bool   $onlyMetricsAvailableInActionsTable
+	 * @param bool   $doNotSumVisits
+	 * @return
 	 */
 	public function updateInterestStats( $newRowToAdd, &$oldRowToUpdate, $onlyMetricsAvailableInActionsTable = false, $doNotSumVisits = false)
 	{
@@ -669,7 +820,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * 			);
 	 * 		)
 	 *
-	 * @param array $interestByLabel Passed by reference, will be modified
+	 * @param array  $interestByLabel  Passed by reference, will be modified
 	 */
 	function enrichConversionsByLabelArray(&$interestByLabel)
 	{
@@ -703,7 +854,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	}
 
 	/**
-	 * @param array $interestByLabelAndSubLabel Passed by reference, will be modified
+	 *
+	 * @param array  $interestByLabelAndSubLabel  Passed by reference, will be modified
 	 */
 	function enrichConversionsByLabelArrayHasTwoLevels(&$interestByLabelAndSubLabel)
 	{
@@ -713,6 +865,11 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		}
 	}
 
+	/**
+	 *
+	 * @param $newRowToAdd
+	 * @param $oldRowToUpdate
+	 */
 	function updateGoalStats($newRowToAdd, &$oldRowToUpdate)
 	{
 		$oldRowToUpdate[Piwik_Archive::INDEX_GOAL_NB_CONVERSIONS]	+= $newRowToAdd[Piwik_Archive::INDEX_GOAL_NB_CONVERSIONS];
@@ -734,7 +891,12 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 			}
 		}
 	}
-	
+
+	/**
+	 *
+	 * @param $idGoal
+	 * @return array
+	 */
 	function getNewGoalRow($idGoal)
 	{
 		if($idGoal > Piwik_Tracker_GoalManager::IDGOAL_ORDER)
@@ -763,4 +925,4 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 						Piwik_Archive::INDEX_GOAL_ECOMMERCE_ITEMS => 0,
 		);
 	}
-}
+}
\ No newline at end of file
