@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Common.php 5223 2011-09-25 01:17:39Z vipsoft $
+ * @version $Id: Common.php 6412 2012-05-31 03:24:39Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -62,21 +62,46 @@ class Piwik_Common
 		static $prefixTable = null;
 		if(is_null($prefixTable))
 		{
-			if(!empty($GLOBALS['PIWIK_TRACKER_MODE']))
-			{
-				$prefixTable = Piwik_Tracker_Config::getInstance()->database['tables_prefix'];
-			}
-			else
-			{
-				$config = Zend_Registry::get('config');
-				if($config !== false)
-				{
-					$prefixTable = $config->database->tables_prefix;
-				}
-			}
+			$prefixTable = Piwik_Config::getInstance()->database['tables_prefix'];
 		}
 		return $prefixTable . $table;
 	}
+	
+	/**
+	 * Returns an array containing the prefixed table names of every passed argument.
+	 * 
+	 * @param string ... The table names to prefix, ie "log_visit"
+	 * @return array The prefixed names in an array.
+	 */
+	static public function prefixTables()
+	{
+		$result = array();
+		foreach (func_get_args() as $table)
+		{
+			$result[] = self::prefixTable($table);
+		}
+		return $result;
+	}
+
+	/**
+	 * Returns the table name, after removing the table prefix
+	 * @param string $table
+	 * @return string
+	 */
+	static public function unprefixTable($table)
+	{
+		static $prefixTable = null;
+		if(is_null($prefixTable))
+		{
+			$prefixTable = Piwik_Config::getInstance()->database['tables_prefix'];
+		}
+		if(empty($prefixTable)
+			|| strpos($table, $prefixTable) !== 0)
+		{
+			return $table;
+		}
+		return str_replace($prefixTable, '', $table, $count = 1);
+	}
 
 /*
  * Tracker
@@ -98,7 +123,7 @@ class Piwik_Common
 				Piwik::createAccessObject();
 			}
 			try {
-				$config = Zend_Registry::get('config');
+				$config = Piwik_Config::getInstance();
 			} catch (Exception $e) {
 				Piwik::createConfigObject();
 			}
@@ -109,7 +134,7 @@ class Piwik_Common
 			}
 
 			$pluginsManager = Piwik_PluginsManager::getInstance();
-			$pluginsToLoad = Zend_Registry::get('config')->Plugins->Plugins->toArray();
+			$pluginsToLoad = Piwik_Config::getInstance()->Plugins['Plugins'];
 			$pluginsForcedNotToLoad = Piwik_Tracker::getPluginsNotToLoad();
 			$pluginsToLoad = array_diff($pluginsToLoad, $pluginsForcedNotToLoad);
 			$pluginsManager->loadPlugins( $pluginsToLoad );
@@ -146,6 +171,8 @@ class Piwik_Common
 	 */
 	static function getCacheWebsiteAttributes( $idSite )
 	{
+		$idSite = (int)$idSite;
+		
 		$cache = self::getTrackerCache();
 		if(($cacheContent = $cache->get($idSite)) !== false)
 		{
@@ -207,6 +234,7 @@ class Piwik_Common
 	 * Store data in general (global cache)
 	 *
 	 * @param mixed $value
+	 * @return bool
 	 */
 	static protected function setCacheGeneral($value)
 	{
@@ -240,6 +268,7 @@ class Piwik_Common
 	 */
 	static public function deleteCacheWebsiteAttributes( $idSite )
 	{
+		$idSite = (int)$idSite;
 		$cache = new Piwik_CacheFile('tracker');
 		$cache->delete($idSite);
 	}
@@ -266,7 +295,7 @@ class Piwik_Common
 	{
 		// Currently, there is no hourly tasks. When there are some,
 		// this could be too agressive minimum interval (some hours would be skipped in case of low traffic)
-		$minimumInterval = Piwik_Tracker_Config::getInstance()->Tracker['scheduled_tasks_min_interval'];
+		$minimumInterval = Piwik_Config::getInstance()->Tracker['scheduled_tasks_min_interval'];
 
 		// If the user disabled browser archiving, he has already setup a cron
 		// To avoid parallel requests triggering the Scheduled Tasks,
@@ -386,17 +415,29 @@ class Piwik_Common
 
 		foreach($values as $value)
 		{
-			if( false !== strpos($value, '='))
+			$pos = strpos($value, '=');
+			if($pos !== false)
 			{
-				$exploded = explode('=',$value);
-				$name = $exploded[0];
-				$value = $exploded[1];
+				$name = substr($value, 0, $pos);
+				$value = substr($value, $pos+1);
+				if ($value === false)
+				{
+					$value = '';
+				}
 			}
 			else
 			{
 				$name = $value;
 				$value = false;
 			}
+			if(!empty($name))
+			{
+				$name = Piwik_Common::sanitizeInputValue($name);
+			}
+			if(!empty($value))
+			{
+				$value = Piwik_Common::sanitizeInputValue($value);
+			}
 
 			// if array without indexes
 			$count = 0;
@@ -421,7 +462,8 @@ class Piwik_Common
 	/**
 	 * Builds a URL from the result of parse_url function
 	 * Copied from the PHP comments at http://php.net/parse_url
-	 * @param array
+	 * @param array $parsed
+	 * @return bool|string
 	 */
 	static public function getParseUrlReverse($parsed)
 	{
@@ -514,7 +556,7 @@ class Piwik_Common
 	 * @param string $path without trailing slash
 	 * @param string $content
 	 */
-	static public function createHtAccess( $path, $content = "<Files \"*\">\nDeny from all\n</Files>\n" )
+	static public function createHtAccess( $path, $content = "<Files \"*\">\n<IfModule mod_access.c>\nDeny from all\n</IfModule>\n<IfModule !mod_access_compat>\n<IfModule mod_authz_host.c>\nDeny from all\n</IfModule>\n</IfModule>\n<IfModule mod_access_compat>\nDeny from all\n</IfModule>\n</Files>\n" )
 	{
 		if(self::isApache())
 		{
@@ -553,6 +595,97 @@ class Piwik_Common
 		return (0 !== preg_match('/(^[a-zA-Z0-9]+([a-zA-Z_0-9.-]*))$/D', $filename));
 	}
 
+/*
+ * String operations
+ */
+
+	/**
+	 * byte-oriented substr() - ASCII
+	 *
+	 * @param string $string
+	 * @param int $start
+	 * @param int $length optional length
+	 * @return string
+	 */
+	static public function substr($string, $start)
+	{
+		// in case mbstring overloads substr function
+		$substr = function_exists('mb_orig_substr') ? 'mb_orig_substr' : 'substr';
+
+		$length = func_num_args() > 2
+			? func_get_arg(2)
+			: self::strlen($string);
+
+		return $substr($string, $start, $length);
+	}
+
+	/**
+	 * byte-oriented strlen() - ASCII
+	 *
+	 * @param string $string
+	 * @return int
+	 */
+	static public function strlen($string)
+	{
+		// in case mbstring overloads strlen function
+		$strlen = function_exists('mb_orig_strlen') ? 'mb_orig_strlen' : 'strlen';
+		return $strlen($string);
+	}
+
+	/**
+	 * multi-byte substr() - UTF-8
+	 *
+	 * @param string $string
+	 * @param int $start
+	 * @param int $length optional length
+	 * @return string
+	 */
+	static public function mb_substr($string, $start)
+	{
+		$length = func_num_args() > 2
+			? func_get_arg(2)
+			: self::mb_strlen($string);
+
+		if (function_exists('mb_substr'))
+		{
+			return mb_substr($string, $start, $length, 'UTF-8');
+		}
+
+		return substr($string, $start, $length);
+	}
+
+	/**
+	 * multi-byte strlen() - UTF-8
+	 *
+	 * @param string $string
+	 * @return int
+	 */
+	static public function mb_strlen($string)
+	{
+		if (function_exists('mb_strlen'))
+		{
+			return mb_strlen($string, 'UTF-8');
+		}
+
+		return strlen($string);
+	}
+
+	/**
+	 * multi-byte strtolower() - UTF-8
+	 *
+	 * @param string $string
+	 * @return string
+	 */
+	static public function mb_strtolower($string)
+	{
+		if (function_exists('mb_strtolower'))
+		{
+			return mb_strtolower($string, 'UTF-8');
+		}
+
+		return strtolower($string);
+	}
+
 /*
  * Escaping input
  */
@@ -569,17 +702,18 @@ class Piwik_Common
 	 * - The single quotes are not protected so "Piwik's amazing" will still be "Piwik's amazing".
 	 *
 	 * - Transformations are:
-	 * 		- '&' (ampersand) becomes '&amp;'
-	 *  	- '"'(double quote) becomes '&quot;'
-	 * 		- '<' (less than) becomes '&lt;'
-	 * 		- '>' (greater than) becomes '&gt;'
+	 *         - '&' (ampersand) becomes '&amp;'
+	 *         - '"'(double quote) becomes '&quot;'
+	 *         - '<' (less than) becomes '&lt;'
+	 *         - '>' (greater than) becomes '&gt;'
 	 * - It handles the magic_quotes setting.
 	 * - A non string value is returned without modification
 	 *
-	 * @param mixed The variable to be cleaned
+	 * @param mixed $value The variable to be cleaned
+	 * @throws Exception
 	 * @return mixed The variable after cleaning
 	 */
-	static public function sanitizeInputValues($value)
+	static public function sanitizeInputValues($value, $alreadyStripslashed = false)
 	{
 		if(is_numeric($value))
 		{
@@ -589,11 +723,9 @@ class Piwik_Common
 		{
 			$value = self::sanitizeInputValue($value);
 
-			// Undo the damage caused by magic_quotes; deprecated in php 5.3 but not removed until php 6
-			if ( version_compare(PHP_VERSION, '6') === -1
-				&& get_magic_quotes_gpc())
+			if(!$alreadyStripslashed) // a JSON array was already stripslashed, don't do it again for each value
 			{
-				$value = stripslashes($value);
+				$value = self::undoMagicQuotes($value);
 			}
 		}
 		elseif (is_array($value))
@@ -601,14 +733,14 @@ class Piwik_Common
 			foreach (array_keys($value) as $key)
 			{
 				$newKey = $key;
-				$newKey = self::sanitizeInputValues($newKey);
+				$newKey = self::sanitizeInputValues($newKey, $alreadyStripslashed);
 				if ($key != $newKey)
 				{
 					$value[$newKey] = $value[$key];
 					unset($value[$key]);
 				}
 
-				$value[$newKey] = self::sanitizeInputValues($value[$newKey]);
+				$value[$newKey] = self::sanitizeInputValues($value[$newKey], $alreadyStripslashed);
 			}
 		}
 		elseif( !is_null($value)
@@ -659,7 +791,44 @@ class Piwik_Common
 	{
 		return htmlspecialchars_decode($value, self::HTML_ENCODING_QUOTE_STYLE);
 	}
-
+	
+	/**
+	 * Unsanitize one or more values.
+	 * 
+	 * @param string|array $value
+	 * @return string|array unsanitized input
+	 */
+	static public function unsanitizeInputValues($value)
+	{
+		if (is_array($value))
+		{
+			$result = array();
+			foreach ($value as $key => $arrayValue)
+			{
+				$result[$key] = self::unsanitizeInputValues($arrayValue);
+			}
+			return $result;
+		}
+		else
+		{
+			return self::unsanitizeInputValue($value);
+		}
+	}
+	
+	/**
+	 * Undo the damage caused by magic_quotes; deprecated in php 5.3 but not removed until php 5.4
+	 * 
+	 * @param string
+	 * @return string modified or not
+	 */
+	static public function undoMagicQuotes($value)
+	{
+		return version_compare(PHP_VERSION, '5.4', '<')
+				&& get_magic_quotes_gpc()
+				? stripslashes($value)
+				: $value;
+	}
+	
 	/**
 	 * Returns a sanitized variable value from the $_GET and $_POST superglobal.
 	 * If the variable doesn't have a value or an empty value, returns the defaultValue if specified.
@@ -669,11 +838,11 @@ class Piwik_Common
 	 *
 	 * @param string $varName name of the variable
 	 * @param string $varDefault default value. If '', and if the type doesn't match, exit() !
-	 * @param string $varType Expected type, the value must be one of the following: array, int, integer, string
+	 * @param string $varType Expected type, the value must be one of the following: array, int, integer, string, json
 	 * @param array $requestArrayToUse
 	 *
-	 * @exception if the variable type is not known
-	 * @exception if the variable we want to read doesn't have neither a value nor a default value specified
+	 * @throws Exception  if the variable type is not known
+	 *                    or if the variable we want to read doesn't have neither a value nor a default value specified
 	 *
 	 * @return mixed The variable after cleaning
 	 */
@@ -715,7 +884,16 @@ class Piwik_Common
 			}
 		}
 
-		// Normal case, there is a value available in REQUEST for the requested varName
+		// Normal case, there is a value available in REQUEST for the requested varName:
+		
+		// we deal w/ json differently
+		if ($varType == 'json')
+		{
+			$value = self::undoMagicQuotes($requestArrayToUse[$varName]);
+			$value = Piwik_Common::json_decode($value, $assoc = true);
+			return self::sanitizeInputValues($value, $alreadyStripslashed = true);
+		}
+		
 		$value = self::sanitizeInputValues( $requestArrayToUse[$varName] );
 		if( !is_null($varType))
 		{
@@ -785,18 +963,7 @@ class Piwik_Common
 		static $salt = null;
 		if(is_null($salt))
 		{
-			if(!empty($GLOBALS['PIWIK_TRACKER_MODE']))
-			{
-				$salt = @Piwik_Tracker_Config::getInstance()->superuser['salt'];
-			}
-			else
-			{
-				$config = Zend_Registry::get('config');
-				if($config !== false)
-				{
-					$salt = @$config->superuser->salt;
-				}
-			}
+			$salt = @Piwik_Config::getInstance()->superuser['salt'];
 		}
 		return $salt;
 	}
@@ -813,18 +980,7 @@ class Piwik_Common
 		static $hashAlgorithm = null;
 		if(is_null($hashAlgorithm))
 		{
-			if(!empty($GLOBALS['PIWIK_TRACKER_MODE']))
-			{
-				$hashAlgorithm = @Piwik_Tracker_Config::getInstance()->General['hash_algorithm'];
-			}
-			else
-			{
-				$config = Zend_Registry::get('config');
-				if($config !== false)
-				{
-					$hashAlgorithm = @$config->General->hash_algorithm;
-				}
-			}
+			$hashAlgorithm = @Piwik_Config::getInstance()->General['hash_algorithm'];
 		}
 
 		if($hashAlgorithm)
@@ -837,46 +993,6 @@ class Piwik_Common
 		return md5($str, $raw_output);
 	}
 
-	/**
-	 * Returns the list of Campaign parameter names that will be read to classify 
-	 * a visit as coming from a Campaign
-	 * 
-	 * @return array array( 
-	 * 			0 => array( ... ) // campaign names parameters
-	 * 			1 => array( ... ) // campaign keyword parameters
-	 * ); 
-	 */
-	static public function getCampaignParameters()
-	{
-		if(!empty($GLOBALS['PIWIK_TRACKER_MODE']))
-		{
-			$return = array(
-				Piwik_Tracker_Config::getInstance()->Tracker['campaign_var_name'],
-				Piwik_Tracker_Config::getInstance()->Tracker['campaign_keyword_var_name'],
-			);
-		}
-		else
-		{
-			$return = array(
-				Zend_Registry::get('config')->Tracker->campaign_var_name,
-				Zend_Registry::get('config')->Tracker->campaign_keyword_var_name,
-			);
-		}
-		foreach($return as &$list) 
-		{
-			if(strpos($list, ',') !== false)
-			{
-				$list = explode(',', $list);
-			}
-			else
-			{
-				$list = array($list);
-			}
-		}
-		array_walk_recursive($return, 'trim');
-		return $return;
-	}
-	
 	/**
 	 * Generate random string
 	 *
@@ -907,6 +1023,7 @@ class Piwik_Common
 
 	/**
 	 * Convert hexadecimal representation into binary data.
+	 * !! Will emit warning if input string is not hex!!
 	 *
 	 * @see http://php.net/bin2hex
 	 *
@@ -921,13 +1038,14 @@ class Piwik_Common
 	/**
 	 * This function will convert the input string to the binary representation of the ID
 	 * but it will throw an Exception if the specified input ID is not correct
-	 * 
+	 *
 	 * This is used when building segments containing visitorId which could be an invalid string
 	 * therefore throwing Unexpected PHP error [pack(): Type H: illegal hex digit i] severity [E_WARNING]
-	 * 
-	 * It would be simply to silent fail the pack() call above but in all other cases, we don't expect an error, 
+	 *
+	 * It would be simply to silent fail the pack() call above but in all other cases, we don't expect an error,
 	 * so better be safe and get the php error when something unexpected is happening
 	 * @param string $id
+	 * @throws Exception
 	 * @return binary string
 	 */
 	static public function convertVisitorIdToBin($id)
@@ -960,16 +1078,85 @@ class Piwik_Common
 		return Piwik_IP::long2ip($ip);
 	}
 
+	/**
+	 * Should we use the replacement json_encode/json_decode functions?
+	 *
+	 * @return bool True if broken; false otherwise
+	 */
+	static private function useJsonLibrary()
+	{
+		static $useLib;
+
+		if (!isset($useLib))
+		{
+			/*
+			 * 5.1.x - doesn't have json extension; we use lib/upgradephp instead
+			 * 5.2 to 5.2.4 - broken in various ways, including:
+			 *
+			 * @see https://bugs.php.net/bug.php?id=38680 'json_decode cannot decode basic types'
+			 * @see https://bugs.php.net/bug.php?id=41403 'json_decode cannot decode floats'
+			 * @see https://bugs.php.net/bug.php?id=42785 'json_encode outputs numbers according to locale'
+			 */
+			$useLib = false;
+			if (version_compare(PHP_VERSION, '5.2.1') < 0)
+			{
+				$useLib = true;
+			}
+			else if (version_compare(PHP_VERSION, '5.2.5') < 0)
+			{
+				$info = localeconv();
+				$useLib = $info['decimal_point'] != '.';
+			}
+		}
+
+		return $useLib;
+	}
+
+	/**
+	 * JSON encode wrapper
+	 * - missing or broken in some php 5.x versions
+	 *
+	 * @param mixed $value
+	 * @return string
+	 */
+	static public function json_encode($value)
+	{
+		if (self::useJsonLibrary())
+		{
+			return _json_encode($value);
+		}
+
+		return json_encode($value);
+	}
+
+	/**
+	 * JSON decode wrapper
+	 * - missing or broken in some php 5.x versions
+	 *
+	 * @param string $json
+	 * @param bool $assoc
+	 * @return mixed
+	 */
+	static public function json_decode($json, $assoc = false)
+	{
+		if (self::useJsonLibrary())
+		{
+			return _json_decode($json, $assoc);
+		}
+
+		return json_decode($json, $assoc);
+	}
+
 /*
  * DataFiles
  */
 
 	/**
-	 * Returns list of valid country codes
+	 * Returns list of continent codes
 	 *
 	 * @see core/DataFiles/Countries.php
 	 *
-	 * @return array Array of 2 letter ISO codes
+	 * @return array Array of 3 letter continent codes
 	 */
 	static public function getContinentsList()
 	{
@@ -1186,8 +1373,8 @@ class Piwik_Common
 	/**
 	 * Returns the visitor language based only on the Browser 'accepted language' information
 	 *
-	 * @param string $browserLang Browser's accepted langauge header
-	 * @param array Array of valid language codes
+	 * @param $browserLanguage Browser's accepted langauge header
+	 * @param $validLanguages  array of valid language codes
 	 * @return string 2 letter ISO 639 code
 	 */
 	static public function extractLanguageCodeFromBrowserLanguage($browserLanguage, $validLanguages)
@@ -1233,6 +1420,42 @@ class Piwik_Common
 		return 'unk';
 	}
 
+/*
+ * Campaign
+ */
+
+	/**
+	 * Returns the list of Campaign parameter names that will be read to classify 
+	 * a visit as coming from a Campaign
+	 * 
+	 * @return array array( 
+	 * 			0 => array( ... ) // campaign names parameters
+	 * 			1 => array( ... ) // campaign keyword parameters
+	 * ); 
+	 */
+	static public function getCampaignParameters()
+	{
+		$return = array(
+			Piwik_Config::getInstance()->Tracker['campaign_var_name'],
+			Piwik_Config::getInstance()->Tracker['campaign_keyword_var_name'],
+		);
+
+		foreach($return as &$list) 
+		{
+			if(strpos($list, ',') !== false)
+			{
+				$list = explode(',', $list);
+			}
+			else
+			{
+				$list = array($list);
+			}
+		}
+
+		array_walk_recursive($return, 'trim');
+		return $return;
+	}
+	
 /*
  * Referrer
  */
@@ -1348,7 +1571,7 @@ class Piwik_Common
 			elseif(!strncmp($refererPath, '/pemonitorhosted/ws/results/', 28))
 			{
 				// private-label search powered by InfoSpace Metasearch
-				$refererHost = 'infospace.com';
+				$refererHost = 'wsdsold.infospace.com';
 			}
 			elseif(strpos($refererHost, '.images.search.yahoo.com') != false)
 			{
@@ -1382,6 +1605,7 @@ class Piwik_Common
 			$variableNames = array($variableNames);
 		}
 
+		$key = null;
 		if($searchEngineName === 'Google Images'
 			|| ($searchEngineName === 'Google' && strpos($referrerUrl, '/imgres') !== false) )
 		{
@@ -1392,7 +1616,8 @@ class Piwik_Common
 			}
 			$searchEngineName = 'Google Images';
 		}
-		else if($searchEngineName === 'Google' && (strpos($query, '&as_') !== false || strpos($query, 'as_') === 0))
+		else if($searchEngineName === 'Google' 
+				&& (strpos($query, '&as_') !== false || strpos($query, 'as_') === 0))
 		{
 			$keys = array();
 			$key = self::getParameterFromQueryString($query, 'as_q');
@@ -1451,33 +1676,79 @@ class Piwik_Common
 					// search for keywords now &vname=keyword
 					$key = self::getParameterFromQueryString($query, $variableName);
 					$key = trim(urldecode($key));
-					if(!empty($key))
+					
+					// Special case: Google & empty q parameter
+					if(empty($key)
+						&& $variableName == 'q'
+						
+						&& (
+							// Google search with no keyword
+							($searchEngineName == 'Google'
+							&& (	// First, they started putting an empty q= parameter
+									strpos($query, '&q=') !== false 
+								|| 	strpos($query, '?q=') !== false
+									// then they started sending the full host only (no path/query string)
+								||  (empty($query) && (empty($refererPath) || $refererPath == '/') && empty($refererParsed['fragment']))
+								)
+						) 
+							// search engines with no keyword
+							|| $searchEngineName == 'Google Images'
+							|| $searchEngineName == 'DuckDuckGo')
+					)
+					{
+						$key = false;
+					}
+					if(!empty($key)
+						|| $key === false)
 					{
 						break;
 					}
 				}
 			}
 		}
-		if(empty($key))
+		
+		// $key === false is the special case "No keyword provided" which is a Search engine match
+		if($key === null
+			|| $key === '')
 		{
 			return false;
 		}
 
-		if(function_exists('iconv')
-			&& isset($searchEngines[$refererHost][3]))
+		if(!empty($key))
 		{
-			$charset = trim($searchEngines[$refererHost][3]);
-			if(!empty($charset))
+			if(function_exists('iconv')
+				&& isset($searchEngines[$refererHost][3]))
 			{
-				$newkey = @iconv($charset, 'UTF-8//IGNORE', $key);
-				if(!empty($newkey))
+				// accepts string, array, or comma-separated list string in preferred order
+				$charsets = $searchEngines[$refererHost][3];
+				if (!is_array($charsets))
 				{
-					$key = $newkey;
+					$charsets = explode(',', $charsets);
+				}
+
+				if(!empty($charsets))
+				{
+					$charset = $charsets[0];
+					if (count($charsets) > 1
+						&& function_exists('mb_detect_encoding'))
+					{
+						$charset = mb_detect_encoding($key, $charsets);
+						if ($charset === false)
+						{
+							$charset = $charsets[0];
+						}
+					}
+
+					$newkey = @iconv($charset, 'UTF-8//IGNORE', $key);
+					if(!empty($newkey))
+					{
+						$key = $newkey;
+					}
 				}
 			}
-		}
 
-		$key = mb_strtolower($key, 'UTF-8');
+			$key = self::mb_strtolower($key);
+		}
 
 		return array(
 			'name' => $searchEngineName,
@@ -1506,6 +1777,7 @@ class Piwik_Common
 	 * Is the current script execution triggered by misc/cron/archive.php ?
 	 * 
 	 * Helpful for error handling: directly throw error without HTML (eg. when DB is down)
+	 * @return bool
 	 */
 	static public function isArchivePhpTriggered()
 	{
@@ -1539,7 +1811,17 @@ class Piwik_Common
 	 */
 	static public function isWindows()
 	{
-		return DIRECTORY_SEPARATOR == '\\';
+		return DIRECTORY_SEPARATOR === '\\';
+	}
+
+	/** 
+	 * Returns true if running on MacOS 
+	 * 
+	 * @return bool true if PHP detects it is running on MacOS; else false 
+	 */ 
+	static public function isMacOS() 
+	{ 
+		return PHP_OS === 'Darwin'; 
 	}
 
 	/**
@@ -1595,6 +1877,7 @@ class Piwik_Common
  * Mark orphaned object for garbage collection
  *
  * For more information: @link http://dev.piwik.org/trac/ticket/374
+ * @param $var
  */
 function destroy(&$var)
 {
@@ -1602,11 +1885,3 @@ function destroy(&$var)
 	unset($var);
 	$var = null;
 }
-
-
-// http://bugs.php.net/bug.php?id=53632
-if (strpos(str_replace('.','',serialize($_REQUEST)), '22250738585072011') !== false)
-{
-  header('Status: 422 Unprocessable Entity');
-  die('Exit');
-}
