@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 5296 2011-10-14 02:52:44Z matt $
+ * @version $Id: Controller.php 6400 2012-05-30 09:50:00Z matt $
  * 
  * @category Piwik
  * @package Piwik
@@ -37,6 +37,10 @@ abstract class Piwik_Controller
 	 * @var Piwik_Date|null 
 	 */
 	protected $date;
+
+	/**
+	 * @var int
+	 */
 	protected $idSite;
 	
 	/**
@@ -71,8 +75,9 @@ abstract class Piwik_Controller
 	/**
 	 * Helper method to convert "today" or "yesterday" to the default timezone specified.
 	 * If the date is absolute, ie. YYYY-MM-DD, it will not be converted to the timezone
-	 * @param string $date today, yesterday, YYYY-MM-DD
-	 * @param string $defaultTimezone
+	 *
+	 * @param string  $date             today, yesterday, YYYY-MM-DD
+	 * @param string  $defaultTimezone  default timezone to use
 	 * @return Piwik_Date
 	 */
 	protected function getDateParameterInTimezone($date, $defaultTimezone )
@@ -101,7 +106,8 @@ abstract class Piwik_Controller
 	/**
 	 * Sets the date to be used by all other methods in the controller.
 	 * If the date has to be modified, it should be called just after the controller construct
-	 * @param Piwik_Date $date
+	 *
+	 * @param Piwik_Date  $date
 	 * @return void
 	 */
 	protected function setDate(Piwik_Date $date)
@@ -123,12 +129,12 @@ abstract class Piwik_Controller
 	}
 
 	/**
-	 * Given an Object implementing Piwik_iView interface, we either:
+	 * Given an Object implementing Piwik_View_Interface, we either:
 	 * - echo the output of the rendering if fetch = false
 	 * - returns the output of the rendering if fetch = true
 	 *
-	 * @param Piwik_ViewDataTable $view
-	 * @param bool $fetch
+	 * @param Piwik_ViewDataTable  $view   view object to use
+	 * @param bool                 $fetch  indicates whether to output or return the content
 	 * @return string|void
 	 */
 	protected function renderView( Piwik_ViewDataTable $view, $fetch = false)
@@ -156,9 +162,9 @@ abstract class Piwik_Controller
 	 * Returns a ViewDataTable object of an Evolution graph 
 	 * for the last30 days/weeks/etc. of the current period, relative to the current date.
 	 *
-	 * @param string $currentModuleName
-	 * @param string $currentControllerAction
-	 * @param string $apiMethod
+	 * @param string  $currentModuleName
+	 * @param string  $currentControllerAction
+	 * @param string  $apiMethod
 	 * @return Piwik_ViewDataTable_GenerateGraphHTML_ChartEvolution
 	 */
 	protected function getLastUnitGraph($currentModuleName, $currentControllerAction, $apiMethod)
@@ -179,17 +185,93 @@ abstract class Piwik_Controller
 		return $view;
 	}
 
+	/**
+	 * This method is similar to self::getLastUnitGraph. It works with API.get to combine metrics
+	 * of different *.get reports. The returned ViewDataTable is configured with column
+	 * translations and selectable metrics.
+	 *
+	 * @param string       $currentModuleName
+	 * @param string       $currentControllerAction
+	 * @param array        $columnsToDisplay
+	 * @param array        $selectableColumns
+	 * @param bool|string  $reportDocumentation
+	 * @param string       $apiMethod The method to request the report from
+	 *                                (by default, this is API.get but it can be changed for custom stuff)
+	 * @return Piwik_ViewDataTable_GenerateGraphHTML_ChartEvolution
+	 */
+	protected function getLastUnitGraphAcrossPlugins($currentModuleName, $currentControllerAction,
+			$columnsToDisplay, $selectableColumns=array(), $reportDocumentation=false, $apiMethod='API.get')
+	{
+		// back up and manipulate the columns parameter
+		$backupColumns = false;
+		if (isset($_GET['columns']))
+		{
+			$backupColumns = $_GET['columns'];
+		}
+		
+		$_GET['columns'] = implode(',', $columnsToDisplay);
+		
+		// load translations from meta data
+		$idSite = Piwik_Common::getRequestVar('idSite');
+		$period = Piwik_Common::getRequestVar('period');
+		$date = Piwik_Common::getRequestVar('date');
+		$meta = Piwik_API_API::getInstance()->getReportMetadata($idSite, $period, $date);
+		
+		$columns = array_merge($columnsToDisplay, $selectableColumns);
+		$translations = array();
+		foreach ($meta as $reportMeta)
+		{
+			if ($reportMeta['action'] == 'get' && !isset($reportMeta['parameters']))
+			{
+				foreach ($columns as $column)
+				{
+					if (isset($reportMeta['metrics'][$column]))
+					{
+						$translations[$column] = $reportMeta['metrics'][$column];
+					}
+				}
+			}
+		}
+		
+		// initialize the graph and load the data
+		$view = $this->getLastUnitGraph($currentModuleName, $currentControllerAction, $apiMethod);
+		$view->setColumnsToDisplay($columnsToDisplay);
+		$view->setSelectableColumns($selectableColumns);
+		$view->setColumnsTranslations($translations);
+		
+		if ($reportDocumentation)
+		{
+			$view->setReportDocumentation($reportDocumentation);
+		}
+		
+		$view->main();
+		
+		// restore the columns parameter
+		if ($backupColumns !== false)
+		{
+			 $_GET['columns'] = $backupColumns;
+		}
+		else
+		{
+			unset($_GET['columns']);
+		}
+		
+		return $view;
+	}
+
 	/**
 	 * Returns the array of new processed parameters once the parameters are applied.
-	 * For example: if you set range=last30 and date=2008-03-10, 
+	 * For example: if you set range=last30 and date=2008-03-10,
 	 *  the date element of the returned array will be "2008-02-10,2008-03-10"
-	 * 
+	 *
 	 * Parameters you can set:
 	 * - range: last30, previous10, etc.
 	 * - date: YYYY-MM-DD, today, yesterday
 	 * - period: day, week, month, year
-	 * 
-	 * @param array  paramsToSet = array( 'date' => 'last50', 'viewDataTable' =>'sparkline' )
+	 *
+	 * @param array  $paramsToSet  array( 'date' => 'last50', 'viewDataTable' =>'sparkline' )
+	 * @throws Piwik_Access_NoAccessException
+	 * @return array
 	 */
 	protected function getGraphParamsModified($paramsToSet = array())
 	{
@@ -237,10 +319,11 @@ abstract class Piwik_Controller
 	 * Given for example, $period = month, $lastN = 'last6', $endDate = '2011-07-01', 
 	 * It will return the $date = '2011-01-01,2011-07-01' which is useful to draw graphs for the last N periods
 	 * 
-	 * @param string $period
-	 * @param string $lastN
-	 * @param string $endDate
-	 * @param Piwik_Site $site
+	 * @param string      $period
+	 * @param string      $lastN
+	 * @param string      $endDate
+	 * @param Piwik_Site  $site
+	 * @return string
 	 */
 	static public function getDateRangeRelativeToEndDate($period, $lastN, $endDate, $site )
 	{
@@ -254,7 +337,7 @@ abstract class Piwik_Controller
 	 * Returns a numeric value from the API.
 	 * Works only for API methods that originally returns numeric values (there is no cast here)
 	 *
-	 * @param string $methodToCall Name of method to call, eg. Referers.getNumberOfDistinctSearchEngines
+	 * @param string  $methodToCall  Name of method to call, eg. Referers.getNumberOfDistinctSearchEngines
 	 * @return int|float
 	 */
 	protected function getNumericValue( $methodToCall )
@@ -270,8 +353,8 @@ abstract class Piwik_Controller
 	 * It will automatically build a sparkline by setting the viewDataTable=sparkline parameter in the URL.
 	 * It will also computes automatically the 'date' for the 'last30' days/weeks/etc. 
 	 *
-	 * @param string $action Method name of the controller to call in the img src
-	 * @param array Array of name => value of parameters to set in the generated GET url 
+	 * @param string  $action            Method name of the controller to call in the img src
+	 * @param array   $customParameters  Array of name => value of parameters to set in the generated GET url
 	 * @return string The generated URL
 	 */
 	protected function getUrlSparkline( $action, $customParameters = array() )
@@ -296,8 +379,9 @@ abstract class Piwik_Controller
 	
 	/**
 	 * Sets the first date available in the calendar
-	 * @param Piwik_Date $minDate
-	 * @param Piwik_View $view
+	 *
+	 * @param Piwik_Date  $minDate
+	 * @param Piwik_View  $view
 	 * @return void
 	 */
 	protected function setMinDateView(Piwik_Date $minDate, $view)
@@ -309,8 +393,9 @@ abstract class Piwik_Controller
 	
 	/**
 	 * Sets "today" in the calendar. Today does not always mean "UTC" today, eg. for websites in UTC+12.
-	 * @param Piwik_Date $maxDate
-	 * @param Piwik_View $view
+	 *
+	 * @param Piwik_Date  $maxDate
+	 * @param Piwik_View  $view
 	 * @return void
 	 */
 	protected function setMaxDateView(Piwik_Date $maxDate, $view)
@@ -319,11 +404,14 @@ abstract class Piwik_Controller
 		$view->maxDateMonth = $maxDate->toString('m');
 		$view->maxDateDay = $maxDate->toString('d');
 	}
-	
+
 	/**
-	 * Sets general variables to the view that are used by various templates and Javascript.
+	 * Sets general variables to the view that are used by
+	 * various templates and Javascript.
 	 * If any error happens, displays the login screen
-	 * @param Piwik_View $view
+	 *
+	 * @param Piwik_View  $view
+	 * @throws Exception
 	 * @return void
 	 */
 	protected function setGeneralVariablesView($view)
@@ -351,7 +439,16 @@ abstract class Piwik_Controller
 				$period = new Piwik_Period_Range($periodStr, $rawDate, $this->site->getTimezone());
 			}
 			$view->rawDate = $rawDate;
-			$view->prettyDate = $period->getPrettyString();
+			
+			if ($period instanceof Piwik_Period_Month) // show month name when period is for a month
+			{
+				$view->prettyDate = $period->getLocalizedLongString();
+			}
+			else
+			{
+				$view->prettyDate = $period->getPrettyString();
+			}
+			
 			$view->siteName = $this->site->getName();
 			$view->siteMainUrl = $this->site->getMainUrl();
 			
@@ -371,6 +468,9 @@ abstract class Piwik_Controller
 			$view->startDate = $dateStart;
 			$view->endDate = $dateEnd;
 			
+			$language = Piwik_LanguagesManager::getLanguageForSession();
+			$view->language = !empty($language) ? $language : Piwik_LanguagesManager::getLanguageCodeForCurrentUser();
+			
 			$this->setBasicVariablesView($view);
 		} catch(Exception $e) {
 			Piwik_ExitWithMessage($e->getMessage());
@@ -380,22 +480,30 @@ abstract class Piwik_Controller
 	/**
 	 * Set the minimal variables in the view object
 	 * 
-	 * @param Piwik_View $view
+	 * @param Piwik_View  $view
 	 */
 	protected function setBasicVariablesView($view)
 	{
 		$view->topMenu = Piwik_GetTopMenu();
-		$view->debugTrackVisitsInsidePiwikUI = Zend_Registry::get('config')->Debug->track_visits_inside_piwik_ui;
+		$view->debugTrackVisitsInsidePiwikUI = Piwik_Config::getInstance()->Debug['track_visits_inside_piwik_ui'];
 		$view->isSuperUser = Zend_Registry::get('access')->isSuperUser();
-		$view->isCustomLogo = Zend_Registry::get('config')->branding->use_custom_logo;
+		$view->isCustomLogo = Piwik_Config::getInstance()->branding['use_custom_logo'];
 		$view->logoHeader = Piwik_API_API::getInstance()->getHeaderLogoUrl();
 		$view->logoLarge = Piwik_API_API::getInstance()->getLogoUrl();
-		$view->piwikUrl = Piwik::getPiwikUrl();
+		
+		$view->enableFrames = Piwik_Config::getInstance()->General['enable_framed_pages']
+			|| @Piwik_Config::getInstance()->General['enable_framed_logins'];
+		if(!$view->enableFrames)
+		{
+			$view->setXFrameOptions('sameorigin');
+		}
 	}
-	
+
 	/**
-	 * Sets general period variables (available periods, current period, period labels) used by templates 
-	 * @param Piwik_View $view
+	 * Sets general period variables (available periods, current period, period labels) used by templates
+	 *
+	 * @param Piwik_View  $view
+	 * @throws Exception
 	 * @return void
 	 */
 	public static function setPeriodVariablesView($view)
@@ -430,16 +538,77 @@ abstract class Piwik_Controller
 		$view->otherPeriods = $availablePeriods;
 		$view->periodsNames = $periodNames;
 	}
-	
+
+	/**
+	 * Set metrics variables (displayed metrics, available metrics) used by template
+	 * Handles the server-side of the metrics picker
+	 *
+	 * @param Piwik_View|Piwik_ViewDataTable  $view
+	 * @param string                          $defaultMetricDay      name of the default metric for period=day
+	 * @param string                          $defaultMetric         name of the default metric for other periods
+	 * @param array                           $metricsForDay         metrics that are only available for period=day
+	 * @param array                           $metricsForAllPeriods  metrics that are available for all periods
+	 * @param bool                            $labelDisplayed        add 'label' to columns to display?
+	 * @return void
+	 */
+	protected function setMetricsVariablesView(Piwik_ViewDataTable $view, $defaultMetricDay='nb_uniq_visitors',
+			$defaultMetric='nb_visits', $metricsForDay=array('nb_uniq_visitors'),
+			$metricsForAllPeriods=array('nb_visits', 'nb_actions'), $labelDisplayed=true)
+	{
+		// columns is set in the request if metrics picker has been used
+		$columns = Piwik_Common::getRequestVar('columns', false);
+		if ($columns !== false)
+		{
+			$columns = Piwik::getArrayFromApiParameter($columns);
+			$firstColumn = $columns[0];
+		}
+		else
+		{
+			// default columns
+			$firstColumn = isset($view->period) && $view->period == 'day' ? $defaultMetricDay : $defaultMetric;
+			$columns = array($firstColumn);
+		}
+		// displayed columns
+		if ($labelDisplayed 
+			&& !($view instanceof Piwik_ViewDataTable_GenerateGraphData))
+		{
+			array_unshift($columns, 'label');
+		}
+		$view->setColumnsToDisplay($columns);
+		
+		
+		// Continue only for graphs
+		if(!($view instanceof Piwik_ViewDataTable_GenerateGraphData))
+		{
+			return;
+		}
+		// do not sort if sorted column was initially "label" or eg. it would make "Visits by Server time" not pretty
+		if($view->getSortedColumn() != 'label')
+		{
+			$view->setSortedColumn($firstColumn);
+		}
+		// selectable columns
+		if (isset($view->period) && $view->period == 'day')
+		{
+			$selectableColumns = array_merge($metricsForDay, $metricsForAllPeriods);
+		}
+		else
+		{
+			$selectableColumns = $metricsForAllPeriods;
+		}
+		$view->setSelectableColumns($selectableColumns);
+	}
+
 	/**
 	 * Helper method used to redirect the current http request to another module/action
 	 * If specified, will also redirect to a given website, period and /or date
-	 * 
-	 * @param string $moduleToRedirect Module, eg. "MultiSites"
-	 * @param string $actionToRedirect Action, eg. "index"
-	 * @param string $websiteId Website ID, eg. 1
-	 * @param string $defaultPeriod Default period, eg. "day"
-	 * @param string $defaultDate Default date, eg. "today"
+	 *
+	 * @param string  $moduleToRedirect  Module, eg. "MultiSites"
+	 * @param string  $actionToRedirect  Action, eg. "index"
+	 * @param string  $websiteId         Website ID, eg. 1
+	 * @param string  $defaultPeriod     Default period, eg. "day"
+	 * @param string  $defaultDate       Default date, eg. "today"
+	 * @param array   $parameters        Parameters to append to url
 	 */
 	function redirectToIndex($moduleToRedirect, $actionToRedirect, $websiteId = null, $defaultPeriod = null, $defaultDate = null, $parameters = array())
 	{
@@ -493,7 +662,8 @@ abstract class Piwik_Controller
 	
 
 	/**
-	 * Returns default website that Piwik should load 
+	 * Returns default website that Piwik should load
+	 *
 	 * @return Piwik_Site
 	 */
 	protected function getDefaultWebsiteId()
@@ -524,7 +694,8 @@ abstract class Piwik_Controller
 
 	/**
 	 * Returns default date for Piwik reports
-	 * @return string today, 2010-01-01, etc.
+	 *
+	 * @return string  today, 2010-01-01, etc.
 	 */
 	protected function getDefaultDate()
 	{
@@ -532,7 +703,7 @@ abstract class Piwik_Controller
 		$userSettingsDate = Piwik_UsersManager_API::getInstance()->getUserPreference(Piwik::getCurrentUserLogin(), Piwik_UsersManager_API::PREFERENCE_DEFAULT_REPORT_DATE);
 		if($userSettingsDate === false)
 		{
-			return Zend_Registry::get('config')->General->default_day;
+			return Piwik_Config::getInstance()->General['default_day'];
 		}
 		if($userSettingsDate == 'yesterday')
 		{
@@ -549,14 +720,15 @@ abstract class Piwik_Controller
 	
 	/**
 	 * Returns default date for Piwik reports
-	 * @return string today, 2010-01-01, etc.
+	 *
+	 * @return string  today, 2010-01-01, etc.
 	 */
 	protected function getDefaultPeriod()
 	{
 		$userSettingsDate = Piwik_UsersManager_API::getInstance()->getUserPreference(Piwik::getCurrentUserLogin(), Piwik_UsersManager_API::PREFERENCE_DEFAULT_REPORT_DATE);
 		if($userSettingsDate === false)
 		{
-			return Zend_Registry::get('config')->General->default_period;
+			return Piwik_Config::getInstance()->General['default_period'];
 		}
 		if(in_array($userSettingsDate, array('today','yesterday')))
 		{
@@ -576,8 +748,9 @@ abstract class Piwik_Controller
 	 * actions that are either invoked via AJAX or redirect to a page
 	 * within the site.  The token should never appear in the browser's
 	 * address bar.
-	 * 
-	 * @return throws exception if token doesn't match
+	 *
+	 * @throws Piwik_Access_NoAccessException  if token doesn't match
+	 * @return void
 	 */
 	protected function checkTokenInUrl()
 	{
@@ -586,29 +759,3 @@ abstract class Piwik_Controller
 		}
 	}
 }
-
-/**
- * Parent class of all plugins Controllers with admin functions
- * 
- * @package Piwik
- */
-abstract class Piwik_Controller_Admin extends Piwik_Controller
-{
-	/**
-	 * Used by Admin screens
-	 * 
-	 * @param Piwik_View $view
-	 */
-	protected function setBasicVariablesView($view)
-	{
-		parent::setBasicVariablesView($view);
-
-		$view->currentAdminMenuName = Piwik_GetCurrentAdminMenuName();
-
-		$view->enableFrames = Zend_Registry::get('config')->General->enable_framed_settings;
-		if(!$view->enableFrames)
-		{
-			$view->setXFrameOptions('sameorigin');
-		}
-	}
-}
