@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: AddSummaryRow.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: AddSummaryRow.php 6439 2012-06-01 14:12:57Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -28,37 +28,57 @@
  */
 class Piwik_DataTable_Filter_AddSummaryRow extends Piwik_DataTable_Filter
 {
-	public function __construct(	$table, 
-									$startRowToSummarize, 
-									$labelSummaryRow = Piwik_DataTable::LABEL_SUMMARY_ROW, 
-									$columnToSortByBeforeTruncating = null )
+	/**
+	 * Creates a new filter and set all required parameters
+	 *
+	 * @param Piwik_DataTable  $table
+	 * @param int              $startRowToSummarize
+	 * @param int              $labelSummaryRow
+	 * @param null             $columnToSortByBeforeTruncating
+	 * @param bool             $deleteRows
+	 */
+	public function __construct($table,
+								$startRowToSummarize,
+								$labelSummaryRow = Piwik_DataTable::LABEL_SUMMARY_ROW,
+								$columnToSortByBeforeTruncating = null,
+								$deleteRows = true )
 	{
 		parent::__construct($table);
 		$this->startRowToSummarize = $startRowToSummarize;
 		$this->labelSummaryRow = $labelSummaryRow;
 		$this->columnToSortByBeforeTruncating = $columnToSortByBeforeTruncating;
-
-		if($table->getRowsCount() > $startRowToSummarize + 1)
-		{
-			$this->filter();
-		}
+		$this->deleteRows = $deleteRows;
 	}
 
-	protected function filter()
+	/**
+	 * Adds a summary row to the given data table
+	 *
+	 * @param Piwik_DataTable  $table
+	 */
+	public function filter($table)
 	{
-		$this->table->filter('Sort', 
+		if($table->getRowsCount() <= $this->startRowToSummarize + 1)
+		{
+			return;
+		}
+		$table->filter('Sort', 
 							array( $this->columnToSortByBeforeTruncating, 'desc'));
 		
-		$rows = $this->table->getRows();
-		$count = $this->table->getRowsCount();
+		$rows = $table->getRows();
+		$count = $table->getRowsCount();
 		$newRow = new Piwik_DataTable_Row();
 		for($i = $this->startRowToSummarize; $i < $count; $i++)
 		{
 			if(!isset($rows[$i]))
 			{
 				// case when the last row is a summary row, it is not indexed by $cout but by Piwik_DataTable::ID_SUMMARY_ROW
-				$summaryRow = $this->table->getRowFromId(Piwik_DataTable::ID_SUMMARY_ROW);
-				$newRow->sumRow($summaryRow);
+				$summaryRow = $table->getRowFromId(Piwik_DataTable::ID_SUMMARY_ROW);
+				
+				//FIXME: I'm not sure why it could return false, but it was reported in: http://forum.piwik.org/read.php?2,89324,page=1#msg-89442
+				if($summaryRow)
+				{
+					$newRow->sumRow($summaryRow);
+				}
 			}
 			else
 			{
@@ -67,8 +87,11 @@ class Piwik_DataTable_Filter_AddSummaryRow extends Piwik_DataTable_Filter
 		}
 		
 		$newRow->setColumns(array('label' => $this->labelSummaryRow) + $newRow->getColumns());
-		$this->table->filter('Limit', array(0, $this->startRowToSummarize));
-		$this->table->addSummaryRow($newRow);
+		if ($this->deleteRows)
+		{
+			$table->filter('Limit', array(0, $this->startRowToSummarize));
+		}
+		$table->addSummaryRow($newRow);
 		unset($rows);
 	}
 }
