@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Limit.php 4169 2011-03-23 01:59:57Z matt $
+ * @version $Id: Limit.php 6353 2012-05-28 17:29:23Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -21,11 +21,12 @@ class Piwik_DataTable_Filter_Limit extends Piwik_DataTable_Filter
 	/**
 	 * Filter constructor.
 	 * 
-	 * @param Piwik_DataTable $table
-	 * @param int $offset Starting row (indexed from 0)
-	 * @param int $limit Number of rows to keep (specify -1 to keep all rows)
+	 * @param Piwik_DataTable  $table
+	 * @param int              $offset          Starting row (indexed from 0)
+	 * @param int              $limit           Number of rows to keep (specify -1 to keep all rows)
+	 * @param bool             $keepSummaryRow  Whether to keep the summary row or not.
 	 */
-	public function __construct( $table, $offset, $limit = null )
+	public function __construct( $table, $offset, $limit = null, $keepSummaryRow = false )
 	{
 		parent::__construct($table);
 		$this->offset = $offset;
@@ -35,14 +36,22 @@ class Piwik_DataTable_Filter_Limit extends Piwik_DataTable_Filter
 			$limit = -1;
 		}
 		$this->limit = $limit;
-	}	
-	
+		$this->keepSummaryRow = $keepSummaryRow;
+	}
+
+	/**
+	 * Limits the given data table
+	 *
+	 * @param Piwik_DataTable  $table
+	 */
 	public function filter($table)
 	{
-		$table = $table;
 		$table->setRowsCountBeforeLimitFilter();
 		
-		$rowsCount = $table->getRowsCount();
+		if ($this->keepSummaryRow)
+		{
+			$summaryRow = $table->getRowFromId(Piwik_DataTable::ID_SUMMARY_ROW);
+		}
 		
 		// we delete from 0 to offset
 		if($this->offset > 0) 
@@ -54,5 +63,10 @@ class Piwik_DataTable_Filter_Limit extends Piwik_DataTable_Filter
 		{
 			$table->deleteRowsOffset( $this->limit );
 		}
+		
+		if ($this->keepSummaryRow && $summaryRow)
+		{
+			$table->addSummaryRow($summaryRow);
+		}
 	}
 }
