@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: MetadataCallbackAddMetadata.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: MetadataCallbackAddMetadata.php 6353 2012-05-28 17:29:23Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -26,19 +26,27 @@ class Piwik_DataTable_Filter_MetadataCallbackAddMetadata extends Piwik_DataTable
 	private $metadataToRead;
 	private $functionToApply;
 	private $metadataToAdd;
-	
+
+	/**
+	 * @param Piwik_DataTable  $table
+	 * @param string           $metadataToRead
+	 * @param string           $metadataToAdd
+	 * @param callback         $functionToApply
+	 */
 	public function __construct( $table, $metadataToRead, $metadataToAdd, $functionToApply )
 	{
 		parent::__construct($table);
 		$this->functionToApply = $functionToApply;
 		$this->metadataToRead = $metadataToRead;
 		$this->metadataToAdd = $metadataToAdd;
-		$this->filter();
 	}
-	
-	protected function filter()
+
+	/**
+	 * @param Piwik_DataTable  $table
+	 */
+	public function filter($table)
 	{
-		foreach($this->table->getRows() as $key => $row)
+		foreach($table->getRows() as $key => $row)
 		{
 			$oldValue = $row->getMetadata($this->metadataToRead);
 			$newValue = call_user_func( $this->functionToApply, $oldValue);
