@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: SafeDecodeLabel.php 4169 2011-03-23 01:59:57Z matt $
+ * @version $Id: SafeDecodeLabel.php 6353 2012-05-28 17:29:23Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -17,14 +17,38 @@
 class Piwik_DataTable_Filter_SafeDecodeLabel extends Piwik_DataTable_Filter
 {
 	private $columnToDecode;
-	private $outputHtml;
+	static private $outputHtml = true;
+
+	/**
+	 * @param Piwik_DataTable $table
+	 */
 	public function __construct( $table )
 	{
 		parent::__construct($table);
 		$this->columnToDecode = 'label';
-		$this->outputHtml = true;
 	}
-	
+
+	/**
+	 * Decodes the given value
+	 *
+	 * @param string  $value
+	 * @return mixed|string
+	 */
+	static public function filterValue($value)
+	{
+		$value = htmlspecialchars_decode( urldecode($value), ENT_QUOTES);
+		if(self::$outputHtml)
+		{
+			$value = htmlspecialchars($value, ENT_QUOTES);
+		}
+		return $value;
+	}
+
+	/**
+	 * Decodes all columns of the given data table
+	 *
+	 * @param Piwik_DataTable  $table
+	 */
 	public function filter($table)
 	{
 		foreach($table->getRows() as $row)
@@ -32,17 +56,12 @@ class Piwik_DataTable_Filter_SafeDecodeLabel extends Piwik_DataTable_Filter
 			$value = $row->getColumn($this->columnToDecode);
 			if($value !== false)
 			{
-				$value = htmlspecialchars_decode(
-										urldecode($value),
-										ENT_QUOTES);
-				if($this->outputHtml)
-				{
-					$value = htmlspecialchars($value, ENT_QUOTES);
-				}
+				$value = self::filterValue($value);
 				$row->setColumn($this->columnToDecode,$value);
-			
+				
 				$this->filterSubTable($row);
 			}
 		}
 	}
+	
 }
