@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Renderer.php 3565 2011-01-03 05:49:45Z matt $
+ * @version $Id: Renderer.php 6353 2012-05-28 17:29:23Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -28,20 +28,64 @@ abstract class Piwik_DataTable_Renderer
 	protected $renderSubTables = false;
 	protected $hideIdSubDatatable = false;
 	
+	/**
+	 * Whether to translate column names (i.e. metric names) or not
+	 * @var bool
+	 */
+	public $translateColumnNames = false;
+	
+	/**
+	 * Column translations
+	 * @var array
+	 */
+	private $columnTranslations = false;
+	
+	/**
+	 * The API method that has returned the data that should be rendered
+	 * @var string
+	 */
+	public $apiMethod = false;
+	
+	/**
+	 * API metadata for the current report
+	 * @var array
+	 */
+	private $apiMetaData = null;
+	
+	/**
+	 * The current idSite
+	 * @var int
+	 */
+	public $idSite = 'all';
+
+
 	public function __construct()
 	{
 	}
-	
+
+	/**
+	 * Sets whether to render subtables or not
+	 *
+	 * @param bool  $enableRenderSubTable
+	 */
 	public function setRenderSubTables($enableRenderSubTable)
 	{
 		$this->renderSubTables = (bool)$enableRenderSubTable;
 	}
 
+	/**
+	 * @param bool  $bool
+	 */
 	public function setHideIdSubDatableFromResponse($bool)
 	{
 		$this->hideIdSubDatatable = (bool)$bool;
 	}
-	
+
+	/**
+	 * Returns whether to render subtables or not
+	 *
+	 * @return bool
+	 */
 	protected function isRenderSubtables()
 	{
 		return $this->renderSubTables;
@@ -50,9 +94,9 @@ abstract class Piwik_DataTable_Renderer
 	/**
 	 * Output HTTP Content-Type header
 	 */
-	protected static function renderHeader()
+	protected function renderHeader()
 	{
-		@header('Content-Type: text/html; charset=utf-8');
+		@header('Content-Type: text/plain; charset=utf-8');
 	}
 
 	/**
@@ -77,10 +121,12 @@ abstract class Piwik_DataTable_Renderer
 	{
 		return $this->render();
 	}
-	
+
 	/**
 	 * Set the DataTable to be rendered
-	 * @param Piwik_DataTable|Piwik_DataTable_Simple|Piwik_DataTable_Array $table to be rendered
+	 *
+	 * @param Piwik_DataTable|Piwik_DataTable_Simple|Piwik_DataTable_Array  $table  table to be rendered
+	 * @throws Exception
 	 */
 	public function setTable($table)
 	{
@@ -91,10 +137,12 @@ abstract class Piwik_DataTable_Renderer
 		}
 		$this->table = $table;
 	}
-	
+
 	/**
 	 * Set the Exception to be rendered
-	 * @param Exception $exception to be rendered
+	 *
+	 * @param Exception  $exception  to be rendered
+	 * @throws Exception
 	 */
 	public function setException($exception)
 	{
@@ -106,6 +154,9 @@ abstract class Piwik_DataTable_Renderer
 	}
 	
 
+	/**
+	 * @var array
+	 */
 	static protected $availableRenderers = array(   'xml', 
         											'json', 
         											'csv', 
@@ -113,16 +164,22 @@ abstract class Piwik_DataTable_Renderer
         											'html', 
         											'php' 
 	);
-	
+
+	/**
+	 * Returns available renderers
+	 *
+	 * @return array
+	 */
 	static public function getRenderers()
 	{
 		return self::$availableRenderers;
 	}
-	
+
 	/**
 	 * Returns the DataTable associated to the output format $name
-	 * 
-	 * @throws exception If the renderer is unknown
+	 *
+	 * @param string  $name
+	 * @throws Exception If the renderer is unknown
 	 * @return Piwik_DataTable_Renderer
 	 */
 	static public function factory( $name )
@@ -135,7 +192,7 @@ abstract class Piwik_DataTable_Renderer
 			return new $className;			
 		} catch(Exception $e) {
 			$availableRenderers = implode(', ', self::getRenderers());
-			self::renderHeader();
+			@header('Content-Type: text/plain; charset=utf-8');
 			throw new Exception(Piwik_TranslateException('General_ExceptionInvalidRendererFormat', array($name, $availableRenderers)));
 		}		
 	}
@@ -143,7 +200,7 @@ abstract class Piwik_DataTable_Renderer
 	/**
 	 * Returns $rawData after all applicable characters have been converted to HTML entities.
 	 * 
-	 * @param String $rawData to be converted
+	 * @param String  $rawData  data to be converted
 	 * @return String
 	 */
 	static protected function renderHtmlEntities( $rawData )
@@ -151,6 +208,12 @@ abstract class Piwik_DataTable_Renderer
 		return self::formatValueXml($rawData);
 	}
 
+	/**
+	 * Format a value to xml
+	 *
+	 * @param string|number|bool  $value  value to format
+	 * @return int|string
+	 */
 	public static function formatValueXml($value)
 	{
 		if(is_string($value)
@@ -168,4 +231,123 @@ abstract class Piwik_DataTable_Renderer
 		}
 		return $value;
 	}
+
+	/**
+	 * Translate column names to the current language.
+	 * Used in subclasses.
+	 *
+	 * @param array  $names
+	 * @return array
+	 */
+	protected function translateColumnNames($names)
+	{
+		if (!$this->apiMethod)
+		{
+			return $names;
+		}
+		
+		// load the translations only once
+		// when multiple dates are requested (date=...,...&period=day), the meta data would
+		// be loaded lots of times otherwise
+		if ($this->columnTranslations === false)
+		{
+			$meta = $this->getApiMetaData();
+			if ($meta === false)
+			{
+				return $names;
+			}
+		
+			$t = Piwik_API_API::getDefaultMetricTranslations();
+			foreach (array('metrics', 'processedMetrics', 'metricsGoal', 'processedMetricsGoal') as $index)
+			{
+				if (isset($meta[$index]) && is_array($meta[$index]))
+				{
+					$t = array_merge($t, $meta[$index]);
+				}
+			}
+			
+			$this->columnTranslations = &$t;
+		}
+		
+		foreach ($names as &$name)
+		{
+			if (isset($this->columnTranslations[$name]))
+			{
+				$name = $this->columnTranslations[$name];
+			}
+		}
+		
+		return $names;
+	}
+
+	/**
+	 * @return array|null
+	 */
+	protected function getApiMetaData()
+	{
+		if ($this->apiMetaData === null)
+		{
+			list($apiModule, $apiAction) = explode('.', $this->apiMethod);
+			
+			if(!$apiModule || !$apiAction)
+			{
+				$this->apiMetaData = false;
+			}
+			
+			$api = Piwik_API_API::getInstance();
+			$meta = $api->getMetadata($this->idSite, $apiModule, $apiAction);
+			if (is_array($meta[0]))
+			{
+				$meta = $meta[0];
+			}
+			
+			$this->apiMetaData = &$meta;
+		}
+		
+		return $this->apiMetaData;
+	}
+
+	/**
+	 * Translates the given column name
+	 *
+	 * @param string  $column
+	 * @return mixed
+	 */
+	protected function translateColumnName($column)
+	{
+		$columns = array($column);
+		$columns = $this->translateColumnNames($columns);
+		return $columns[0];
+	}
+
+	/**
+	 * Enables column translating
+	 *
+	 * @param bool  $bool
+	 */
+	public function setTranslateColumnNames($bool)
+	{
+		$this->translateColumnNames = $bool;
+	}
+
+	/**
+	 * Sets the api method
+	 *
+	 * @param $method
+	 */
+	public function setApiMethod($method)
+	{
+		$this->apiMethod = $method;
+	}
+
+	/**
+	 * Sets the site id
+	 *
+	 * @param int  $idSite
+	 */
+	public function setIdSite($idSite)
+	{
+		$this->idSite = $idSite;
+	}
+	
 }
