@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Row.php 4311 2011-04-04 18:49:55Z vipsoft $
+ * @version $Id: Row.php 6400 2012-05-30 09:50:00Z matt $
  * 
  * @category Piwik
  * @package Piwik
@@ -51,19 +51,20 @@ class Piwik_DataTable_Row
 	/**
 	 * Efficient load of the Row structure from a well structured php array
 	 * 
-	 * @param array The row array has the structure
-	 * 					array( 
-	 * 						Piwik_DataTable_Row::COLUMNS => array( 
-	 * 										'label' => 'Piwik',
-	 * 										'column1' => 42,
-	 * 										'visits' => 657,
-	 * 										'time_spent' => 155744,	
-	 * 									),
-	 * 						Piwik_DataTable_Row::METADATA => array(
-	 * 										'logo' => 'test.png'
-	 * 									),
-	 * 						Piwik_DataTable_Row::DATATABLE_ASSOCIATED => #Piwik_DataTable object (but in the row only the ID will be stored)
-	 * 					)
+	 * @param array  $row  The row array has the structure
+	 *                     array(
+	 *                           Piwik_DataTable_Row::COLUMNS => array(
+	 *                                                                 'label' => 'Piwik',
+	 *                                                                 'column1' => 42,
+	 *                                                                 'visits' => 657,
+	 *                                                                 'time_spent' => 155744,
+	 *                                                                 ),
+	 *                            Piwik_DataTable_Row::METADATA => array(
+	 *                                                                  'logo' => 'test.png'
+	 *                                                                  ),
+	 *                            Piwik_DataTable_Row::DATATABLE_ASSOCIATED => #Piwik_DataTable object
+	 *                                                                         (but in the row only the ID will be stored)
+	 *                           )
 	 */
 	public function __construct( $row = array() )
 	{
@@ -100,7 +101,7 @@ class Piwik_DataTable_Row
 	}
 
 	/**
-	 * Applys a basic rendering to the Row and returns the output
+	 * Applies a basic rendering to the Row and returns the output
 	 *
 	 * @return string characterizing the row. Example: - 1 ['label' => 'piwik', 'nb_uniq_visitors' => 1685, 'nb_visits' => 1861, 'nb_actions' => 2271, 'max_actions' => 13, 'sum_visit_length' => 920131, 'bounce_count' => 1599] [] [idsubtable = 1375]
 	 */
@@ -129,8 +130,8 @@ class Piwik_DataTable_Row
 	/**
 	 * Deletes the given column 
 	 *
-	 * @param string Column name
-	 * @return bool True on success, false if the column didn't exist
+	 * @param string  $name  Column name
+	 * @return bool  True on success, false if the column didn't exist
 	 */
 	public function deleteColumn( $name )
 	{
@@ -141,21 +142,28 @@ class Piwik_DataTable_Row
 		unset($this->c[self::COLUMNS][$name]);
 		return true;
 	}
-	
+
+	/**
+	 * Renames the given column
+	 *
+	 * @param string  $oldName
+	 * @param string  $newName
+	 */
 	public function renameColumn($oldName, $newName)
 	{
 		if(isset($this->c[self::COLUMNS][$oldName]))
 		{
 			$this->c[self::COLUMNS][$newName] = $this->c[self::COLUMNS][$oldName];
-			unset($this->c[self::COLUMNS][$oldName]);
 		}
+		// outside the if() since we want to delete nulled columns
+		unset($this->c[self::COLUMNS][$oldName]);
 	}
 	
 	/**
 	 * Returns the given column
 	 * 
-	 * @param string Column name
-	 * @return mixed|false The column value  
+	 * @param string  $name  Column name
+	 * @return mixed|false  The column value
 	 */
 	public function getColumn( $name )
 	{
@@ -170,7 +178,7 @@ class Piwik_DataTable_Row
 	 * Returns the array of all metadata,
 	 * or the specified metadata  
 	 * 
-	 * @param string Metadata name
+	 * @param string  $name  Metadata name
 	 * @return mixed|array|false 
 	 */
 	public function getMetadata( $name = null )
@@ -189,11 +197,11 @@ class Piwik_DataTable_Row
 	/**
 	 * Returns the array containing all the columns
 	 * 
-	 * @return array Example: array( 
-	 * 					'column1' 	=> VALUE,
-	 * 					'label' 	=> 'www.php.net'
-	 * 					'nb_visits' => 15894,
-	 * 			)
+	 * @return array  Example: array(
+	 *                              'column1'   => VALUE,
+	 *                              'label'     => 'www.php.net'
+	 *                              'nb_visits' => 15894,
+	 *                              )
 	 */
 	public function getColumns()
 	{
@@ -216,7 +224,7 @@ class Piwik_DataTable_Row
 	 * If this row doesn't have a SubDataTable yet, we create a new one.
 	 * Then we add the values of the given DataTable to this row's DataTable.
 	 * 	 
-	 * @param Piwik_DataTable Table to sum to this row's subDatatable
+	 * @param Piwik_DataTable  $subTable  Table to sum to this row's subDatatable
 	 * @see Piwik_DataTable::addDataTable() for the algorithm used for the sum 
 	 */
 	public function sumSubtable(Piwik_DataTable $subTable)
@@ -240,7 +248,7 @@ class Piwik_DataTable_Row
 	 * Set a DataTable to be associated to this row.
 	 * If the row already has a DataTable associated to it, throws an Exception.
 	 * 
-	 * @param Piwik_DataTable DataTable to associate to this row
+	 * @param Piwik_DataTable  $subTable  DataTable to associate to this row
 	 * @throws Exception 
 	 * 
 	 */
@@ -257,20 +265,28 @@ class Piwik_DataTable_Row
 	 * Set a DataTable to this row. If there is already 
 	 * a DataTable associated, it is simply overwritten.
 	 * 
-	 * @param Piwik_DataTable DataTable to associate to this row
+	 * @param Piwik_DataTable  $subTable  DataTable to associate to this row
 	 */
 	public function setSubtable(Piwik_DataTable $subTable)
 	{
 		$this->c[self::DATATABLE_ASSOCIATED] = $subTable->getId();
 	}
 	
+	/**
+	 * Remove the sub table reference
+	 */
+	public function removeSubtable()
+	{
+		$this->c[self::DATATABLE_ASSOCIATED] = null;
+	}
+	
 	/**
 	 * Set all the columns at once. Overwrites previously set columns.
 	 * 
-	 * @param array array( 
-	 * 					'label' 	=> 'www.php.net'
-	 * 					'nb_visits' => 15894,
-	 * 			)
+	 * @param array  array(
+	 *                    'label'       => 'www.php.net'
+	 *                    'nb_visits'   => 15894,
+	 *                    )
 	 */
 	public function setColumns( $columns )
 	{
@@ -280,8 +296,8 @@ class Piwik_DataTable_Row
 	/**
 	 * Set the value $value to the column called $name.
 	 * 
-	 * @param string $name of the column to set
-	 * @param mixed $value of the column to set
+	 * @param string  $name   name of the column to set
+	 * @param mixed   $value  value of the column to set
 	 */
 	public function setColumn($name, $value)
 	{
@@ -291,26 +307,47 @@ class Piwik_DataTable_Row
 	/**
 	 * Set the value $value to the metadata called $name.
 	 * 
-	 * @param string $name of the metadata to set
-	 * @param mixed $value of the metadata to set
+	 * @param string  $name   name of the metadata to set
+	 * @param mixed   $value  value of the metadata to set
 	 */
 	public function setMetadata($name, $value)
 	{
 		$this->c[self::METADATA][$name] = $value;
 	}
+
+	/**
+	 * Deletes the given metadata
+	 *
+	 * @param bool|string  $name  Meta column name (omit to delete entire metadata)
+	 * @return bool  True on success, false if the column didn't exist
+	 */
+	public function deleteMetadata($name = false)
+	{
+		if($name === false)
+		{
+			$this->c[self::METADATA] = array();
+			return true;
+		}
+		if(!isset($this->c[self::METADATA][$name]))
+		{
+			return false;
+		}
+		unset($this->c[self::METADATA][$name]);
+		return true;
+	}
 	
 	/**
 	 * Add a new column to the row. If the column already exists, throws an exception
 	 * 
-	 * @param string $name of the column to add
-	 * @param mixed $value of the column to set
+	 * @param string  $name   name of the column to add
+	 * @param mixed   $value  value of the column to set
 	 * @throws Exception
 	 */
 	public function addColumn($name, $value)
 	{
 		if(isset($this->c[self::COLUMNS][$name]))
 		{
-			debug_print_backtrace();
+//			debug_print_backtrace();
 			throw new Exception("Column $name already in the array!");
 		}
 		$this->c[self::COLUMNS][$name] = $value;
@@ -319,22 +356,29 @@ class Piwik_DataTable_Row
 	/**
 	 * Add columns to the row
 	 *
-	 * @param array $columns Name/Value pairs, e.g., array( name => value , ...)
+	 * @param array  $columns  Name/Value pairs, e.g., array( name => value , ...)
 	 * @return void
 	 */
 	public function addColumns($columns)
 	{
 		foreach($columns as $name => $value)
 		{
-			$this->addColumn($name, $value);
+			try {
+				$this->addColumn($name, $value); 
+			} catch(Exception $e) {
+			}
+		}
+		
+		if(!empty($e)) {
+			throw $e;
 		}
 	}
 	
 	/**
 	 * Add a new metadata to the row. If the column already exists, throws an exception.
 	 * 
-	 * @param string $name of the metadata to add
-	 * @param mixed $value of the metadata to set
+	 * @param string  $name   name of the metadata to add
+	 * @param mixed   $value  value of the metadata to set
 	 * @throws Exception
 	 */
 	public function addMetadata($name, $value)
@@ -350,10 +394,12 @@ class Piwik_DataTable_Row
 	 * Sums the given $row columns values to the existing row' columns values.
 	 * It will sum only the int or float values of $row.
 	 * It will not sum the column 'label' even if it has a numeric value.
-	 * 
+	 *
 	 * If a given column doesn't exist in $this then it is added with the value of $row.
 	 * If the column already exists in $this then we have
-	 * 		this.columns[idThisCol] += $row.columns[idThisCol]
+	 *         this.columns[idThisCol] += $row.columns[idThisCol]
+	 *
+	 * @param Piwik_DataTable_Row  $rowToSum
 	 */
 	public function sumRow( Piwik_DataTable_Row $rowToSum )
 	{
@@ -376,7 +422,13 @@ class Piwik_DataTable_Row
 			}
 		}
 	}
-	
+
+	/**
+	 *
+	 * @param number|bool   $thisColumnValue
+	 * @param number|array  $columnToSumValue
+	 * @return array|int
+	 */
 	protected function sumRowArray( $thisColumnValue, $columnToSumValue )
 	{
 		if(is_numeric($columnToSumValue))
@@ -407,7 +459,32 @@ class Piwik_DataTable_Row
 		}
 		return 0;
 	}
-	
+
+	/**
+	 * Helper function to compare array elements
+	 *
+	 * @param mixed  $elem1
+	 * @param mixed  $elem2
+	 * @return bool
+	 */
+	static public function compareElements($elem1, $elem2)
+	{
+		if (is_array($elem1)) {
+			if (is_array($elem2))
+			{
+				return strcmp(serialize($elem1), serialize($elem2));
+			}
+			return 1;
+		}
+		if (is_array($elem2))
+			return -1;
+
+		if ((string)$elem1 === (string)$elem2)
+			return 0;
+
+		return ((string)$elem1 > (string)$elem2) ? 1 : -1;
+	}
+
 	/**
 	 * Helper function to test if two rows are equal.
 	 * 
@@ -415,9 +492,8 @@ class Piwik_DataTable_Row
 	 * - if they have exactly the same columns / metadata
 	 * - if they have a subDataTable associated, then we check that both of them are the same.
 	 * 
-	 * @param Piwik_DataTable_Row row1 to compare
-	 * @param Piwik_DataTable_Row row2 to compare
-	 * 
+	 * @param Piwik_DataTable_Row  $row1  first to compare
+	 * @param Piwik_DataTable_Row  $row2  second to compare
 	 * @return bool
 	 */
 	static public function isEqual( Piwik_DataTable_Row $row1, Piwik_DataTable_Row $row2 )
@@ -425,7 +501,11 @@ class Piwik_DataTable_Row
 		//same columns
 		$cols1 = $row1->getColumns();
 		$cols2 = $row2->getColumns();
-		if(array_diff($cols1, $cols2) !== array_diff($cols2, $cols1))
+
+		$diff1 = array_udiff($cols1, $cols2, array(__CLASS__, 'compareElements'));
+		$diff2 = array_udiff($cols2, $cols1, array(__CLASS__, 'compareElements'));
+
+		if($diff1 != $diff2)
 		{
 			return false;
 		}
