@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Myisam.php 5176 2011-09-18 07:25:19Z matt $
+ * @version $Id: Myisam.php 6448 2012-06-02 23:52:13Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -21,8 +21,8 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Is this MySQL storage engine available?
 	 *
-	 * @param string $engineName
-	 * @return bool True if available and enabled; false otherwise
+	 * @param string  $engineName
+	 * @return bool  True if available and enabled; false otherwise
 	 */
 	static private function hasStorageEngine($engineName)
 	{
@@ -39,7 +39,7 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Is this schema available?
 	 *
-	 * @return bool True if schema is available; false otherwise
+	 * @return bool  True if schema is available; false otherwise
 	 */
 	static public function isAvailable()
 	{
@@ -49,12 +49,12 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Get the SQL to create Piwik tables
 	 *
-	 * @return array of strings containing SQL
+	 * @return array  array of strings containing SQL
 	 */
 	public function getTablesCreateSql()
 	{
-		$config = Zend_Registry::get('config');
-		$prefixTables = $config->database->tables_prefix;
+		$config = Piwik_Config::getInstance();
+		$prefixTables = $config->database['tables_prefix'];
 		$tables = array(
 			'user' => "CREATE TABLE {$prefixTables}user (
 						  login VARCHAR(100) NOT NULL,
@@ -358,7 +358,7 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 								  	  date2 DATE NULL,
 									  period TINYINT UNSIGNED NULL,
 								  	  ts_archived DATETIME NULL,
-								  	  value FLOAT NULL,
+								  	  value DOUBLE NULL,
 									  PRIMARY KEY(idarchive, name),
 									  INDEX index_idsite_dates_period(idsite, date1, date2, period, ts_archived),
 									  INDEX index_period_archived(period, ts_archived)
@@ -385,8 +385,9 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Get the SQL to create a specific Piwik table
 	 *
-	 * @param string $tableName
-	 * @return string SQL
+	 * @param string  $tableName
+	 * @throws Exception
+	 * @return string  SQL
 	 */
 	public function getTableCreateSql( $tableName )
 	{
@@ -404,13 +405,13 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	 * Names of all the prefixed tables in piwik
 	 * Doesn't use the DB
 	 *
-	 * @return array Table names
+	 * @return array  Table names
 	 */
 	public function getTablesNames()
 	{
 		$aTables = array_keys($this->getTablesCreateSql());
-		$config = Zend_Registry::get('config');
-		$prefixTables = $config->database->tables_prefix;
+		$config = Piwik_Config::getInstance();
+		$prefixTables = $config->database['tables_prefix'];
 		$return = array();
 		foreach($aTables as $table)
 		{
@@ -424,9 +425,8 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Get list of tables installed
 	 *
-	 * @param bool $forceReload Invalidate cache
-	 * @param string $idSite
-	 * @return array Tables installed
+	 * @param bool  $forceReload  Invalidate cache
+	 * @return array  installed Tables
 	 */
 	public function getTablesInstalled($forceReload = true)
 	{
@@ -434,8 +434,8 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 			|| $forceReload === true)
 		{
 			$db = Zend_Registry::get('db');
-			$config = Zend_Registry::get('config');
-			$prefixTables = $config->database->tables_prefix;
+			$config = Piwik_Config::getInstance();
+			$prefixTables = $config->database['tables_prefix'];
 
 			// '_' matches any character; force it to be literal
 			$prefixTables = str_replace('_', '\_', $prefixTables);
@@ -461,9 +461,9 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	}
 
 	/**
-	 * Do tables exist?
+	 * Checks whether any table exists
 	 *
-	 * @return bool True if tables exist; false otherwise
+	 * @return bool  True if tables exist; false otherwise
 	 */
 	public function hasTables()
 	{
@@ -473,13 +473,13 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Create database
 	 *
-	 * @param string $dbName
+	 * @param string  $dbName  Name of the database to create
 	 */
 	public function createDatabase( $dbName = null )
 	{
 		if(is_null($dbName))
 		{
-			$dbName = Zend_Registry::get('config')->database->dbname;
+			$dbName = Piwik_Config::getInstance()->database['dbname'];
 		}
 		Piwik_Exec("CREATE DATABASE IF NOT EXISTS ".$dbName." DEFAULT CHARACTER SET utf8");
 	}
@@ -489,9 +489,8 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	 */
 	public function dropDatabase()
 	{
-		$dbName = Zend_Registry::get('config')->database->dbname;
+		$dbName = Piwik_Config::getInstance()->database['dbname'];
 		Piwik_Exec("DROP DATABASE IF EXISTS " . $dbName);
-
 	}
 
 	/**
@@ -500,8 +499,8 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	public function createTables()
 	{
 		$db = Zend_Registry::get('db');
-		$config = Zend_Registry::get('config');
-		$prefixTables = $config->database->tables_prefix;
+		$config = Piwik_Config::getInstance();
+		$prefixTables = $config->database['tables_prefix'];
 
 		$tablesAlreadyInstalled = $this->getTablesInstalled();
 		$tablesToCreate = $this->getTablesCreateSql();
@@ -545,7 +544,7 @@ class Piwik_Db_Schema_Myisam implements Piwik_Db_Schema_Interface
 	/**
 	 * Drop specific tables
 	 *
-	 * @param array $doNotDelete Names of tables to not delete
+	 * @param array  $doNotDelete  Names of tables to not delete
 	 */
 	public function dropTables( $doNotDelete = array() )
 	{
