@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: FrontController.php 5202 2011-09-21 23:00:44Z matt $
+ * @version $Id: FrontController.php 6417 2012-05-31 05:34:08Z matt $
  * 
  * @category Piwik
  * @package Piwik
@@ -53,17 +53,17 @@ class Piwik_FrontController
 		}
 		return self::$instance;
 	}
-	
+
 	/**
 	 * Dispatches the request to the right plugin and executes the requested action on the plugin controller.
-	 * 
-	 * @throws Exception in case the plugin doesn't exist, the action doesn't exist, there is not enough permission, etc.
+	 *
+	 * @throws Exception|Piwik_FrontController_PluginDeactivatedException in case the plugin doesn't exist, the action doesn't exist, there is not enough permission, etc.
 	 *
 	 * @param string $module
 	 * @param string $action
 	 * @param array $parameters
 	 * @return mixed The returned value of the calls, often nothing as the module print but don't return data
-	 * @see fetchDispatch() 
+	 * @see fetchDispatch()
 	 */
 	function dispatch( $module = null, $action = null, $parameters = null)
 	{
@@ -128,8 +128,14 @@ class Piwik_FrontController
 		{
 			throw new Exception("Action $action not found in the controller $controllerClassName.");				
 		}
+		
+		// Generic hook that plugins can use to modify any input to the function, 
+		// or even change the plugin being called
+		$params = array($controller, $action, $parameters);
+		Piwik_PostEvent('FrontController.dispatch', $params);
+		
 		try {
-			return call_user_func_array( array($controller, $action ), $parameters);
+			return call_user_func_array( array($params[0], $params[1] ), $params[2]);
 		} catch(Piwik_Access_NoAccessException $e) {
 			Piwik_PostEvent('FrontController.NoAccessException', $e);					
 		} catch(Exception $e) {
@@ -185,14 +191,18 @@ class Piwik_FrontController
 				|| Piwik_Common::isArchivePhpTriggered()
 				;
 	}
-	
+
 	/**
 	 * Must be called before dispatch()
 	 * - checks that directories are writable,
 	 * - loads the configuration file,
-	 * - loads the plugin, 
+	 * - loads the plugin,
 	 * - inits the DB connection,
 	 * - etc.
+	 * @throws Exception
+	 * @throws Exception
+	 * @throws bool|Exception
+	 * @return
 	 */
 	function init()
 	{
@@ -211,7 +221,8 @@ class Piwik_FrontController
 					'/tmp/',
 					'/tmp/templates_c/',
 					'/tmp/cache/',
-					'/tmp/assets/'
+					'/tmp/assets/',
+					'/tmp/tcpdf/'
 			);
 			
 			Piwik::checkDirectoriesWritableOrDie($directoriesToCheck);
@@ -233,7 +244,7 @@ class Piwik_FrontController
 				Piwik_Session::start();
 			}
 
-			if(Zend_Registry::get('config')->General->maintenance_mode == 1
+			if(Piwik_Config::getInstance()->General['maintenance_mode'] == 1
 				&& !Piwik_Common::isPhpCliMode())
 			{
 				$format = Piwik_Common::getRequestVar('format', '');
@@ -247,8 +258,24 @@ class Piwik_FrontController
 				exit;
 			}
 
+			
+			if(!Piwik_Common::isPhpCliMode()
+				&& Piwik_Config::getInstance()->General['force_ssl'] == 1
+				&& !Piwik::isHttps()
+				// Specifically disable for the opt out iframe 
+				&& !(Piwik_Common::getRequestVar('module', '') == 'CoreAdminHome'
+					&& Piwik_Common::getRequestVar('action', '') == 'optOut')
+			)
+			{
+				$url = Piwik_Url::getCurrentUrl();
+				$url = str_replace("http://", "https://", $url);
+				Piwik_Url::redirectToUrl($url);
+			}
+				
+				
 			$pluginsManager = Piwik_PluginsManager::getInstance();
-			$pluginsManager->loadPlugins( Zend_Registry::get('config')->Plugins->Plugins->toArray() );
+			$pluginsToLoad = Piwik_Config::getInstance()->Plugins['Plugins'];
+			$pluginsManager->loadPlugins( $pluginsToLoad );
 
 			if($exceptionToThrow)
 			{
@@ -288,15 +315,19 @@ class Piwik_FrontController
 				throw new Exception("Authentication object cannot be found in the Registry. Maybe the Login plugin is not activated?
 									<br />You can activate the plugin by adding:<br />
 									<code>Plugins[] = Login</code><br />
-									under the <code>[Plugins]</code> section in your config/config.inc.php");
+									under the <code>[Plugins]</code> section in your config/config.ini.php");
 			}
-			
 			Zend_Registry::get('access')->reloadAccess($authAdapter);
 			
-			Piwik_Translate::getInstance()->reloadLanguage();
-
+			// Force the auth to use the token_auth if specified, so that embed dashboard 
+			// and all other non widgetized controller methods works fine
+			if(($token_auth = Piwik_Common::getRequestVar('token_auth', false, 'string')) !== false)
+			{
+				Piwik_API_Request::reloadAuthUsingTokenAuth();
+			}
 			Piwik::raiseMemoryLimitIfNecessary();
 
+			Piwik_Translate::getInstance()->reloadLanguage();
 			$pluginsManager->postLoadPlugins();
 			
 			Piwik_PostEvent('FrontController.checkForUpdates');
