@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Admin.php 3270 2010-10-28 18:21:55Z vipsoft $
+ * @version $Id: Admin.php 6385 2012-05-29 21:36:24Z SteveG $
  * 
  * @category Piwik
  * @package Piwik_Menu
@@ -16,6 +16,7 @@
 class Piwik_Menu_Admin extends Piwik_Menu_Abstract
 {
 	static private $instance = null;
+
 	/**
 	 * @return Piwik_Menu_Admin
 	 */
@@ -35,7 +36,8 @@ class Piwik_Menu_Admin extends Piwik_Menu_Abstract
 	 */
 	public function get()
 	{
-		if(!$this->menu) {
+		if(!$this->menu)
+		{
 			Piwik_PostEvent('AdminMenu.add');
 		}
 		return parent::get();
@@ -44,6 +46,7 @@ class Piwik_Menu_Admin extends Piwik_Menu_Abstract
 
 /**
  * Returns the current AdminMenu name
+ *
  * @return boolean
  */
 function Piwik_GetCurrentAdminMenuName()
@@ -62,7 +65,11 @@ function Piwik_GetCurrentAdminMenuName()
 	return false;
 }
 
-
+/**
+ * Returns the AdminMenu
+ *
+ * @return Array
+ */
 function Piwik_GetAdminMenu()
 {
 	return Piwik_Menu_Admin::getInstance()->get();
@@ -71,10 +78,10 @@ function Piwik_GetAdminMenu()
 /**
  * Adds a new AdminMenu entry.
  *
- * @param string $adminMenuName
- * @param string $url
- * @param boolean $displayedForCurrentUser
- * @param int $order
+ * @param string   $adminMenuName
+ * @param string   $url
+ * @param boolean  $displayedForCurrentUser
+ * @param int      $order
  */
 function Piwik_AddAdminMenu( $adminMenuName, $url, $displayedForCurrentUser = true, $order = 10 )
 {
@@ -84,8 +91,8 @@ function Piwik_AddAdminMenu( $adminMenuName, $url, $displayedForCurrentUser = tr
 /**
  * Renames an AdminMenu entry.
  *
- * @param string $adminMenuOriginal
- * @param string $adminMenuRenamed
+ * @param string  $adminMenuOriginal
+ * @param string  $adminMenuRenamed
  */
 function Piwik_RenameAdminMenuEntry($adminMenuOriginal, $adminMenuRenamed)
 {
