@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Period.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: Period.php 6385 2012-05-29 21:36:24Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -29,18 +29,23 @@ abstract class Piwik_Period
 	protected $subperiods = array();
 	protected $subperiodsProcessed = false;
 	protected $label = null;
+
+	/**
+	 * @var Piwik_Date
+	 */
 	protected $date = null;
-	static protected $errorAvailablePeriods = 'day, week, month, year';
+	static protected $errorAvailablePeriods = 'day, week, month, year, range';
 	
 	public function __construct( $date )
 	{	
 		$this->checkInputDate( $date );
 		$this->date = clone $date;
 	}
-	
+
 	/**
-	 * @param $strPeriod "day", "week", "month", "year"
-	 * @param $date Piwik_Date object
+	 * @param string $strPeriod "day", "week", "month", "year"
+	 * @param Piwik_Date $date Piwik_Date object
+	 * @throws Exception
 	 * @return Piwik_Period
 	 */
 	static public function factory($strPeriod, Piwik_Date $date)
@@ -186,7 +191,7 @@ abstract class Piwik_Period
 		$this->subperiods[] = $date;
 	}
 	
-	public function toString()
+	public function toString($format = "Y-m-d")
 	{
 		if(!$this->subperiodsProcessed)
 		{
@@ -195,7 +200,7 @@ abstract class Piwik_Period
 		$dateString = array();
 		foreach($this->subperiods as $period)
 		{
-			$dateString[] = $period->toString();
+			$dateString[] = $period->toString($format);
 		}
 		return $dateString;
 	}
