@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Week.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: Week.php 6385 2012-05-29 21:36:24Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -18,6 +18,11 @@ class Piwik_Period_Week extends Piwik_Period
 {
 	protected $label = 'week';
 
+	/**
+	 * Returns the current period as a localized short string
+	 *
+	 * @return string
+	 */
 	public function getLocalizedShortString()
 	{
 		//"30 Dec - 6 Jan 09"
@@ -29,19 +34,35 @@ class Piwik_Period_Week extends Piwik_Period
 		return $out;
 	}
 
+	/**
+	 * Returns the current period as a localized long string
+	 *
+	 * @return string
+	 */
 	public function getLocalizedLongString()
 	{
 		$shortDateStart = $this->getDateStart()->getLocalized("%day% %longMonth%");
 		$shortDateEnd =  $this->getDateEnd()->getLocalized("%day% %longMonth% %longYear%");
 		return Piwik_Translate('CoreHome_PeriodWeek') . " $shortDateStart - $shortDateEnd";
 	}
-	
+
+	/**
+	 * Returns the current period as a string
+	 *
+	 * @return string
+	 */
 	public function getPrettyString()
 	{
-		$out = $this->getDateStart()->toString() . " to " . $this->getDateEnd()->toString();
+		$out = Piwik_Translate('General_DateRangeFromTo', 
+		            array($this->getDateStart()->toString(),
+		                $this->getDateEnd()->toString())
+        );
 		return $out;
 	}
-	
+
+	/**
+	 * Generates the subperiods - one for each day in the week
+	 */
 	protected function generate()
 	{
 		if($this->subperiodsProcessed)
