@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Html.php 4879 2011-06-05 22:59:00Z JulienM $
+ * @version $Id: Html.php 5909 2012-02-25 06:45:24Z matt $
  *
  * @category Piwik
  * @package Piwik_ReportRenderer
@@ -17,6 +17,9 @@
  */
 class Piwik_ReportRenderer_Html extends Piwik_ReportRenderer
 {
+	const IMAGE_GRAPH_WIDTH = 700;
+	const IMAGE_GRAPH_HEIGHT = 200;
+
 	const REPORT_TITLE_TEXT_SIZE = 11;
 	const REPORT_TABLE_HEADER_TEXT_SIZE = 11;
 	const REPORT_TABLE_ROW_TEXT_SIZE = 11;
@@ -57,7 +60,7 @@ class Piwik_ReportRenderer_Html extends Piwik_ReportRenderer
 		Piwik::overrideCacheControlHeaders();
 		header('Content-Description: File Transfer');
 		header('Content-Type: text/html');
-		header('Content-Disposition: attachment; filename="'.basename($filename).'";');
+		header('Content-Disposition: attachment; filename="'.str_replace('"', '\'', basename($filename)).'";');
 		header('Content-Length: '.strlen($this->rendering));
 		echo $this->rendering;
 	}
@@ -103,16 +106,34 @@ class Piwik_ReportRenderer_Html extends Piwik_ReportRenderer
 		$this->assignCommonParameters($smarty);
 
 		$reportMetadata = $processedReport['metadata'];
-		$smarty->assign("reportName", $reportMetadata['name']);
-		$smarty->assign("reportId", $reportMetadata['uniqueId']);
-
 		$reportData = $processedReport['reportData'];
 		$columns = $processedReport['columns'];
 		list($reportData, $columns) = self::processTableFormat($reportMetadata, $reportData, $columns);
 
+		$smarty->assign("reportName", $reportMetadata['name']);
+		$smarty->assign("reportId", $reportMetadata['uniqueId']);
 		$smarty->assign("reportColumns", $columns);
 		$smarty->assign("reportRows", $reportData->getRows());
 		$smarty->assign("reportRowsMetadata", $processedReport['reportMetadata']->getRows());
+		$smarty->assign("displayTable", $processedReport['displayTable']);
+
+		$displayGraph = $processedReport['displayGraph'];
+		$smarty->assign("displayGraph", $displayGraph);
+
+		if($displayGraph)
+		{
+			$smarty->assign("graphWidth", self::IMAGE_GRAPH_WIDTH);
+			$smarty->assign("graphHeight", self::IMAGE_GRAPH_HEIGHT);
+			$smarty->assign("renderImageInline", $this->renderImageInline);
+
+			if($this->renderImageInline)
+			{
+				$imageGraphUrl = $reportMetadata['imageGraphUrl'];
+				$staticGraph = parent::getStaticGraph($imageGraphUrl, self::IMAGE_GRAPH_WIDTH, self::IMAGE_GRAPH_HEIGHT);
+				$smarty->assign("generatedImageGraph", base64_encode($staticGraph));
+				unset($generatedImageGraph);
+			}
+		}
 
 		$this->rendering .= $smarty->fetch(self::prefixTemplatePath("html_report_body.tpl"));
 	}
@@ -121,4 +142,4 @@ class Piwik_ReportRenderer_Html extends Piwik_ReportRenderer
 	{
 		return PIWIK_USER_PATH . "/plugins/CoreHome/templates/" . $templateFile;
 	}
-}
+}
\ No newline at end of file
