@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: ScheduledTask.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: ScheduledTask.php 6221 2012-04-22 00:39:12Z capedfuzz $
  * 
  * @category Piwik
  * @package Piwik
@@ -18,6 +18,12 @@
  */
 class Piwik_ScheduledTask
 {
+	const LOWEST_PRIORITY 	= 12;
+	const LOW_PRIORITY 		= 9;
+	const NORMAL_PRIORITY 	= 6;
+	const HIGH_PRIORITY 	= 3;
+	const HIGHEST_PRIORITY 	= 0;
+	
 	/**
 	 * Class name where the specified method is located
 	 * @var string 
@@ -35,12 +41,24 @@ class Piwik_ScheduledTask
 	 * @var Piwik_ScheduledTime
 	 */
 	var $scheduledTime;
+	
+	/**
+	 * The priority of a task. Affects the order in which this task will be run.
+	 * @var int
+	 */
+	var $priority;
 
-	function __construct( $_className, $_methodName, $_scheduledTime)
+	function __construct( $_className, $_methodName, $_scheduledTime, $_priority = self::NORMAL_PRIORITY )
 	{
+		if ($_priority < self::HIGHEST_PRIORITY || $_priority > self::LOWEST_PRIORITY)
+		{
+			throw new Exception("Invalid priority for ScheduledTask '$_className.$_methodName': $_priority");
+		}
+		
 		$this->className = $_className;
 		$this->methodName = $_methodName;
 		$this->scheduledTime = $_scheduledTime;
+		$this->priority = $_priority;
 	}
 	
 	/*
@@ -69,4 +87,15 @@ class Piwik_ScheduledTask
 	{
 		return $this->scheduledTime;
 	}
+	
+	/**
+	 * Returns the task priority. The priority will be an integer whose value is
+	 * between Piwik_ScheduledTask::HIGH_PRIORITY and Piwik_ScheduledTask::LOW_PRIORITY.
+	 * 
+	 * @return int
+	 */
+	public function getPriority()
+	{
+		return $this->priority;
+	}
 }
