@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Session.php 5070 2011-08-02 04:50:26Z vipsoft $
+ * @version $Id: Session.php 6325 2012-05-26 21:08:06Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -23,19 +23,20 @@ class Piwik_Session extends Zend_Session
 	/**
 	 * Are we using file-based session store?
 	 *
-	 * @return bool True if file-based; false otherwise
+	 * @return bool  True if file-based; false otherwise
 	 */
 	public static function isFileBasedSessions()
 	{
-		$config = Zend_Registry::get('config');
-		return !isset($config->General->session_save_handler)
-			|| $config->General->session_save_handler === 'files';
+		$config = Piwik_Config::getInstance();
+		return !isset($config->General['session_save_handler'])
+			|| $config->General['session_save_handler'] === 'files';
 	}
 
 	/**
 	 * Start the session
 	 *
-	 * @param array $options An array of configuration options; the auto-start (bool) setting is ignored
+	 * @param array|bool  $options  An array of configuration options; the auto-start (bool) setting is ignored
+	 * @return void
 	 */
 	public static function start($options = false)
 	{
@@ -71,23 +72,21 @@ class Piwik_Session extends Zend_Session
 		@ini_set('session.referer_check', '');
 
 		$currentSaveHandler = ini_get('session.save_handler');
-		$config = Zend_Registry::get('config');
+		$config = Piwik_Config::getInstance();
 
 		if (self::isFileBasedSessions())
 		{
 			// Note: this handler doesn't work well in load-balanced environments and may have a concurrency issue with locked session files
 
 			// for "files", use our own folder to prevent local session file hijacking 
-			$sessionPath = PIWIK_USER_PATH . '/tmp/sessions'; 
-			if(!is_dir($sessionPath)) 
-			{ 
-				Piwik_Common::mkdir($sessionPath); 
-			} 
+			$sessionPath = PIWIK_USER_PATH . '/tmp/sessions';
+			// We always call mkdir since it also chmods the directory which might help when permissions were reverted for some reasons 
+			Piwik_Common::mkdir($sessionPath); 
 
 			@ini_set('session.save_handler', 'files');
 			@ini_set('session.save_path', $sessionPath); 
 		}
-		else if ($config->General->session_save_handler === 'dbtable'
+		else if ($config->General['session_save_handler'] === 'dbtable'
 			|| in_array($currentSaveHandler, array('user', 'mm')))
 		{
 			// We consider these to be misconfigurations, in that:
@@ -123,7 +122,19 @@ class Piwik_Session extends Zend_Session
 			register_shutdown_function(array('Zend_Session', 'writeClose'), true);
 		} catch(Exception $e) {
 			Piwik::log('Unable to start session: ' . $e->getMessage());
-			Piwik_ExitWithMessage(Piwik_Translate('General_ExceptionUnableToStartSession'));
+			
+			$enableDbSessions = '';
+			if(Piwik::isInstalled()) 
+			{
+				$enableDbSessions = "<br/>If you still experience issues after trying these changes, 
+			            			we recommend that you <a href='http://piwik.org/faq/how-to-install/#faq_133' target='_blank'>enable database session storage</a>.";
+			}
+
+			$message = 'Error: ' . Piwik_Translate('General_ExceptionUnableToStartSession')
+			            . ' ' .Piwik::getErrorMessageMissingPermissions(Piwik_Common::getPathToPiwikRoot() . '/tmp/sessions/')
+			            . $enableDbSessions
+			            . "\n<pre>Debug: the original error was \n". $e->getMessage()."</pre>";
+			Piwik_ExitWithMessage($message);
 		}
 	}
 }
