@@ -3,8 +3,8 @@
  * Piwik - Open source web analytics
  * 
  * @link http://piwik.org
- * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: modifier.urlRewriteBasicView.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ * @version $Id: modifier.urlRewriteBasicView.php 6300 2012-05-23 21:19:25Z SteveG $
  * 
  * @category Piwik
  * @package SmartyPlugins
@@ -13,7 +13,8 @@
 /**
  * Rewrites the given URL so that it looks like a URL that can be loaded directly.
  * Useful for users who don't handle javascript / ajax, they can still use piwik with these rewritten URLs.
- * 
+ *
+ * @param array $parameters
  * @return string
  */
 function smarty_modifier_urlRewriteBasicView($parameters)
@@ -36,5 +37,5 @@ function smarty_modifier_urlRewriteBasicView($parameters)
 
 	// add module=CoreHome&action=showInContext
 	$url = $url . '&amp;module=CoreHome&amp;action=showInContext';
-	return htmlspecialchars($url);
+	return Piwik_Common::sanitizeInputValue($url);
 }
