@@ -3,8 +3,8 @@
  * Piwik - Open source web analytics
  * 
  * @link http://piwik.org
- * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: modifier.urlRewriteWithParameters.php 2069 2010-04-09 13:10:37Z matt $
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ * @version $Id: modifier.urlRewriteWithParameters.php 6300 2012-05-23 21:19:25Z SteveG $
  * 
  * @category Piwik
  * @package SmartyPlugins
@@ -13,12 +13,13 @@
 /**
  * Rewrites the given URL and modify the given parameters.
  * @see Piwik_Url::getCurrentQueryStringWithParametersModified()
- * 
+ *
+ * @param $parameters
  * @return string
  */
 function smarty_modifier_urlRewriteWithParameters($parameters)
 {
 	$parameters['updated'] = null;
 	$url = Piwik_Url::getCurrentQueryStringWithParametersModified($parameters);
-	return htmlspecialchars($url);
+	return Piwik_Common::sanitizeInputValue($url);
 }
