@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Action.php 5259 2011-09-29 05:19:59Z matt $
+ * @version $Id: Action.php 6300 2012-05-23 21:19:25Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -58,7 +58,7 @@ class Piwik_Tracker_Action implements Piwik_Tracker_Action_Interface
 	private $actionType;
 	private $actionUrl;
 	
-	static private $queryParametersToExclude = array('phpsessid', 'jsessionid', 'sessionid', 'aspsessionid');
+	static private $queryParametersToExclude = array('phpsessid', 'jsessionid', 'sessionid', 'aspsessionid', 'fb_xd_fragment', 'fb_comment_id');
 	
 	public function setRequest($requestArray)
 	{
@@ -363,15 +363,17 @@ class Piwik_Tracker_Action implements Piwik_Tracker_Action_Interface
 	{
 		$this->timestamp = $timestamp;
 	}
-	
-	
+
+
 	/**
 	 * Records in the DB the association between the visit and this action.
-	 * 
-	 * @param int idVisit is the ID of the current visit in the DB table log_visit
-	 * @param int idRefererActionUrl is the ID of the last action done by the current visit. 
-	 * @param int timeSpentRefererAction is the number of seconds since the last action was done. 
-	 * 				It is directly related to idRefererActionUrl.
+	 *
+	 * @param int $idVisit is the ID of the current visit in the DB table log_visit
+	 * @param $visitorIdCookie
+	 * @param int $idRefererActionUrl is the ID of the last action done by the current visit.
+	 * @param $idRefererActionName
+	 * @param int $timeSpentRefererAction is the number of seconds since the last action was done.
+	 *                 It is directly related to idRefererActionUrl.
 	 */
 	 public function record( $idVisit, $visitorIdCookie, $idRefererActionUrl, $idRefererActionName, $timeSpentRefererAction)
 	 {
@@ -478,9 +480,9 @@ class Piwik_Tracker_Action implements Piwik_Tracker_Action_Interface
 			$url = Piwik_Common::getRequestVar( 'url', '', 'string', $this->request);
 
 			// get the delimiter, by default '/'; BC, we read the old action_category_delimiter first (see #1067) 
-			$actionCategoryDelimiter = isset(Piwik_Tracker_Config::getInstance()->General['action_category_delimiter'])
-										? Piwik_Tracker_Config::getInstance()->General['action_category_delimiter']
-										: Piwik_Tracker_Config::getInstance()->General['action_url_category_delimiter'];
+			$actionCategoryDelimiter = isset(Piwik_Config::getInstance()->General['action_category_delimiter'])
+										? Piwik_Config::getInstance()->General['action_category_delimiter']
+										: Piwik_Config::getInstance()->General['action_url_category_delimiter'];
 			
 			// create an array of the categories delimited by the delimiter
 			$split = explode($actionCategoryDelimiter, $actionName);
@@ -520,7 +522,7 @@ class Piwik_Tracker_Action implements Piwik_Tracker_Action_Interface
 		$string = trim($string);
 		$string = str_replace(array("\n", "\r", "\0"), '', $string);
 		
-		$limit = Piwik_Tracker_Config::getInstance()->Tracker['page_maximum_length'];
+		$limit = Piwik_Config::getInstance()->Tracker['page_maximum_length'];
 		return substr($string, 0, $limit);
 	}
 }
