@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Visit.php 4784 2011-05-23 03:15:34Z vipsoft $
+ * @version $Id: Visit.php 6403 2012-05-30 10:49:44Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -48,22 +48,21 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	// can be overwritten in constructor
 	protected $timestamp;
 	protected $ip;
-	// via setForcedVisitorId()
-	protected $forcedVisitorId;
+	
+	// Set to true when we set some custom variables from the cookie
+	protected $customVariablesSetFromRequest = false;
 	
 	/**
 	 * @var Piwik_Tracker_GoalManager
 	 */
 	protected $goalManager;
 
-	const TIME_IN_PAST_TO_SEARCH_FOR_VISITOR = 86400;
-
 	public function __construct($forcedIpString = null, $forcedDateTime = null)
 	{
 		$this->timestamp = time();
 		if(!empty($forcedDateTime))
 		{
-			if(!is_int($forcedDateTime))
+			if(!is_numeric($forcedDateTime))
 			{
 				$forcedDateTime = strtotime($forcedDateTime);
 			}
@@ -76,7 +75,6 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		}
 
 		$ip = Piwik_IP::P2N($ipString);
-		Piwik_PostEvent('Tracker.Visit.setVisitorIp', $ip);
 		$this->ip = $ip;
 	}
 
@@ -136,18 +134,29 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		{
 			return;
 		}
+		
+		// Anonymize IP (after testing for IP exclusion)
+		$ip = $this->ip;
+		Piwik_PostEvent('Tracker.Visit.setVisitorIp', $ip);
+		$this->visitorInfo['location_ip'] = $ip;
+		
 		$this->visitorCustomVariables = self::getCustomVariables($scope = 'visit', $this->request);
+		if(!empty($this->visitorCustomVariables))
+		{
+			$this->customVariablesSetFromRequest = true;
+		}
+	
 		$this->goalManager = new Piwik_Tracker_GoalManager();
 		
 		$someGoalsConverted = $visitIsConverted = false;
-		$idActionUrl = $idActionName = false;
+		$idActionUrl = $idActionName = $actionType = false;
 		$action = null;
 
 		$this->goalManager->init($this->request);
 		
 		$requestIsManualGoalConversion = ($this->goalManager->idGoal > 0);
-		
-		if($this->goalManager->requestIsEcommerce)
+		$requestIsEcommerce = $this->goalManager->requestIsEcommerce;
+		if($requestIsEcommerce)
 		{
 			$someGoalsConverted = true;
 			
@@ -181,6 +190,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$action->loadIdActionNameAndUrl();
 			$idActionUrl = (int)$action->getIdActionUrl();
 			$idActionName = (int)$action->getIdActionName();
+			$actionType = $action->getActionType();
 		}
 
 		// the visitor and session
@@ -188,6 +198,10 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		$isLastActionInTheSameVisit = $this->isLastActionInTheSameVisit();
 
+		if(!$isLastActionInTheSameVisit)
+		{
+			printDebug("Visitor detected, but last action was more than 30 minutes ago...");
+		}
 		// Known visit when:
 		// ( - the visitor has the Piwik cookie with the idcookie ID used by Piwik to match the visitor
 		//   OR
@@ -201,7 +215,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$idRefererActionUrl = $this->visitorInfo['visit_exit_idaction_url'];
 			$idRefererActionName = $this->visitorInfo['visit_exit_idaction_name'];
 			try {
-				$this->handleKnownVisit($idActionUrl, $idActionName, $visitIsConverted);
+				$this->handleKnownVisit($idActionUrl, $idActionName, $actionType, $visitIsConverted);
 				if(!is_null($action))
 				{
 					$action->record( 	$this->visitorInfo['idvisit'],
@@ -219,7 +233,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 				//   because the UPDATE didn't affect any rows (one row was found, but not updated since no field changed)
 				// - the exception is caught here and will result in a new visit incorrectly
 				// In this case, we cancel the current conversion to be recorded:
-				if($requestIsManualGoalConversion)
+				if($requestIsManualGoalConversion
+					|| $requestIsEcommerce)
 				{
 					$someGoalsConverted = $visitIsConverted = false;
 				}
@@ -239,7 +254,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		if(!$this->isVisitorKnown()
 			|| !$isLastActionInTheSameVisit)
 		{
-			$this->handleNewVisit($idActionUrl, $idActionName, $visitIsConverted);
+			$this->handleNewVisit($idActionUrl, $idActionName, $actionType, $visitIsConverted);
 			if(!is_null($action))
 			{
 				$action->record( $this->visitorInfo['idvisit'], $this->visitorInfo['idvisitor'], 0, 0, 0 );
@@ -254,8 +269,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		{
 			$refererTimestamp = Piwik_Common::getRequestVar('_refts', 0, 'int', $this->request);
 			$refererUrl = Piwik_Common::getRequestVar('_ref', '', 'string', $this->request);
-			$refererCampaignName = Piwik_Common::getRequestVar('_rcn', '', 'string', $this->request);
-			$refererCampaignKeyword = Piwik_Common::getRequestVar('_rck', '', 'string', $this->request);
+			$refererCampaignName = trim(urldecode(Piwik_Common::getRequestVar('_rcn', '', 'string', $this->request)));
+			$refererCampaignKeyword = trim(urldecode(Piwik_Common::getRequestVar('_rck', '', 'string', $this->request)));
 
 			$this->goalManager->recordGoals( 
 										$this->idsite,
@@ -311,15 +326,16 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 *
 	 * Tracker.knownVisitorInformation is triggered after saving the new visit data
 	 * Even data is an array with updated information about the visit
+	 * @param $idActionUrl
+	 * @param $idActionName
+	 * @param $actionType
+	 * @param $visitIsConverted
+	 * @throws Piwik_Tracker_Visit_VisitorNotFoundInDatabase
 	 */
-	protected function handleKnownVisit($idActionUrl, $idActionName, $visitIsConverted)
+	protected function handleKnownVisit($idActionUrl, $idActionName, $actionType, $visitIsConverted)
 	{
 		// gather information that needs to be updated
 		$valuesToUpdate = array();
-		if($visitIsConverted)
-		{
-			$valuesToUpdate['visit_goal_converted'] = 1;
-		}
 
 		$sqlActionUpdate = '';
 		if($idActionUrl !== false)
@@ -330,25 +346,28 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		}
 
 		$datetimeServer = Piwik_Tracker::getDatetimeFromTimestamp($this->getCurrentTimestamp());
-		printDebug("Visit is known. ");
+		printDebug("Visit is known (IP = ".Piwik_IP::N2P($this->getVisitorIp()).")");
 
 		$visitTotalTime = $this->getCurrentTimestamp() - $this->visitorInfo['visit_first_action_time'];
 		$valuesToUpdate['visit_last_action_time'] = $datetimeServer;
-		$valuesToUpdate['visit_total_time'] = $visitTotalTime;
-
-		// Update the idvisitor to the latest known value, in case the cookie value changed for some reasons,
-		// safer to always rely on the most recent values
-		if($this->shouldUseThirdPartyCookie())
+		$valuesToUpdate['visit_total_time'] = $visitTotalTime + 1;
+	
+		// Goal conversion
+		if($visitIsConverted)
 		{
-			$idVisitor = $this->cookie->get(0);
+			$valuesToUpdate['visit_goal_converted'] = 1;
+			// If a pageview and goal conversion in the same second, with previously a goal conversion recorded
+			// the request would not "update" the row since all values are the same as previous
+			// therefore the request below throws exception, instead we make sure the UPDATE will affect the row
+			$valuesToUpdate['visit_total_time'] += (int)$this->goalManager->idGoal
+														// +2 to offset idgoal=-1 and idgoal=0 
+														+ 2 ;
 		}
-		else
+		
+		// Might update the idvisitor when it was forced or overwritten for this visit
+		if(strlen($this->visitorInfo['idvisitor']) == Piwik_Tracker::LENGTH_BINARY_ID)
 		{
-			$idVisitor = Piwik_Common::getRequestVar('_id', '', 'string', $this->request);
-		}
-		if(strlen($idVisitor) == Piwik_Tracker::LENGTH_HEX_ID_STRING)
-		{
-			$valuesToUpdate['idvisitor'] = Piwik_Common::hex2bin($idVisitor);
+			$valuesToUpdate['idvisitor'] = $this->visitorInfo['idvisitor']; 
 		}
 
 		// Ecommerce buyer status
@@ -362,7 +381,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		// Will be updated in cookie
 		$timeSpentRefererAction = $this->getCurrentTimestamp() - $this->visitorInfo['visit_last_action_time'];
-		if($timeSpentRefererAction > Piwik_Tracker_Config::getInstance()->Tracker['visit_standard_length'])
+		if($timeSpentRefererAction > Piwik_Config::getInstance()->Tracker['visit_standard_length'])
 		{
 			$timeSpentRefererAction = 0;
 		}
@@ -382,12 +401,12 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$updateParts[] = $name." = ?";
 			$sqlBind[] = $value;
 		}
-//var_dump($valuesToUpdate);exit;
 		$sqlQuery = "UPDATE ". Piwik_Common::prefixTable('log_visit')."
 						SET $sqlActionUpdate ".implode($updateParts, ', ')."
 						WHERE idsite = ?
 							AND idvisit = ?";
-		array_push($sqlBind, $this->idsite, $this->visitorInfo['idvisit']  );
+		array_push($sqlBind, $this->idsite, (int)$this->visitorInfo['idvisit']  );
+
 		$result = Piwik_Tracker::getDatabase()->query($sqlQuery, $sqlBind);
 
 		$this->visitorInfo['visit_last_action_time'] = $this->getCurrentTimestamp();
@@ -423,8 +442,12 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 * 1) Insert the new action
 	 *
 	 * 2) Insert the visit information
+	 * @param $idActionUrl
+	 * @param $idActionName
+	 * @param $actionType
+	 * @param $visitIsConverted
 	 */
-	protected function handleNewVisit($idActionUrl, $idActionName, $visitIsConverted)
+	protected function handleNewVisit($idActionUrl, $idActionName, $actionType, $visitIsConverted)
 	{
 		printDebug("New Visit (IP = ".Piwik_IP::N2P($this->getVisitorIp()).")");
 
@@ -444,7 +467,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 		$idcookie = $this->getVisitorIdcookie();
 
-		$defaultTimeOnePageVisit = Piwik_Tracker_Config::getInstance()->Tracker['default_time_one_page_visit'];
+		$defaultTimeOnePageVisit = Piwik_Config::getInstance()->Tracker['default_time_one_page_visit'];
 
 		// Days since first visit
 		$cookieFirstVisitTimestamp = Piwik_Common::getRequestVar('_idts', 0, 'int', $this->request);
@@ -484,7 +507,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		// User settings
 		$userInfo = $this->getUserSettingsInformation();
 		$country = Piwik_Common::getCountry($userInfo['location_browser_lang'],
-											$enableLanguageToCountryGuess = Piwik_Tracker_Config::getInstance()->Tracker['enable_language_to_country_guess'],
+											$enableLanguageToCountryGuess = Piwik_Config::getInstance()->Tracker['enable_language_to_country_guess'],
 											$this->getVisitorIp());
 
 		// Referrer data
@@ -492,7 +515,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		$refererUrl	= Piwik_Common::getRequestVar( 'urlref', '', 'string', $this->request);
 		$currentUrl	= Piwik_Common::getRequestVar( 'url', '', 'string', $this->request);
 		$refererInfo = $referrer->getRefererInformation($refererUrl, $currentUrl, $this->idsite);
-
+		
 		/**
 		 * Save the visitor
 		 */
@@ -511,13 +534,17 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			'visit_entry_idaction_name' => (int)$idActionName,
 			'visit_exit_idaction_url' 	=> (int)$idActionUrl,
 			'visit_exit_idaction_name' 	=> (int)$idActionName,
-			'visit_total_actions' 		=> 1,
+			'visit_total_actions' 		=> in_array($actionType,
+												array(Piwik_Tracker_Action::TYPE_ACTION_URL,
+													 Piwik_Tracker_Action::TYPE_DOWNLOAD,
+													 Piwik_Tracker_Action::TYPE_OUTLINK))
+											? 1 : 0, // if visit starts with something else (e.g. ecommerce order), don't record as an action
 			'visit_total_time' 			=> $defaultTimeOnePageVisit,
 			'visit_goal_converted'  	=> $visitIsConverted ? 1: 0,
 			'visit_goal_buyer'			=> $this->goalManager->getBuyerType(),
 			'referer_type' 				=> $refererInfo['referer_type'],
 			'referer_name' 				=> $refererInfo['referer_name'],
-			'referer_url' 				=> Piwik_Common::unsanitizeInputValue($refererInfo['referer_url']),
+			'referer_url' 				=> $refererInfo['referer_url'],
 			'referer_keyword' 			=> $refererInfo['referer_keyword'],
 			'config_id' 				=> $userInfo['config_id'],
 			'config_os' 				=> $userInfo['config_os'],
@@ -632,6 +659,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	/**
 	 * Returns the current date in the "Y-m-d" PHP format
 	 *
+	 * @param string $format
 	 * @return string
 	 */
 	protected function getCurrentDate( $format = "Y-m-d")
@@ -670,12 +698,15 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		 * As a result, these sophisticated bots exhibit characteristics of
 		 * browsers (cookies enabled, executing JavaScript, etc).
 		 */
-		if ( strpos($ua, 'Googlebot') !== false					// Googlebot
+		$allowBots = Piwik_Common::getRequestVar('bots', false) != false;
+		if ( !$allowBots
+			&& (strpos($ua, 'Googlebot') !== false					// Googlebot
 				|| strpos($ua, 'Google Web Preview') !== false	// Google Instant
 				|| strpos($ua, 'bingbot') !== false				// Bingbot
 				|| strpos($ua, 'YottaaMonitor') !== false		// Yottaa
 				|| Piwik_IP::isIpInRange($ip,
 					array(
+						// Live/Bing/MSN
 						'64.4.0.0/18',
 						'65.52.0.0/14',
 						'157.54.0.0/15',
@@ -684,7 +715,9 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 						'207.46.0.0/16',
 						'207.68.128.0/18',
 						'207.68.192.0/20',
-					))) // Live/Bing/MSN
+						// Chinese bot hammering websites
+						'1.202.218.8' 
+					)))) 
 		{
 			printDebug('Search bot detected, visit excluded');
 			$excluded = true;
@@ -703,6 +736,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			{
 				printDebug($_SERVER['REQUEST_METHOD'].' parameter '.$parameterForceRecord.' not found in URL, request excluded');
 				$excluded = true;
+				printDebug("'$parameterForceRecord' parameter not found.");
 			}
 		}
 
@@ -718,12 +752,20 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		if(!$excluded)
 		{
 			$excluded = $this->isIgnoreCookieFound();
+			if($excluded)
+			{
+				printDebug("Ignore cookie found.");
+			}
 		}
 
 		// Checking for excluded IPs
 		if(!$excluded)
 		{
 			$excluded = $this->isVisitorIpExcluded($ip);
+			if($excluded)
+			{
+				printDebug("IP excluded.");
+			}
 		}
 
 		if($excluded)
@@ -776,7 +818,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 */
 	protected function getCookieName()
 	{
-		return Piwik_Tracker_Config::getInstance()->Tracker['cookie_name'];
+		return Piwik_Config::getInstance()->Tracker['cookie_name'];
 	}
 
 	/**
@@ -786,7 +828,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 */
 	protected function getCookieExpire()
 	{
-		return $this->getCurrentTimestamp() + Piwik_Tracker_Config::getInstance()->Tracker['cookie_expire'];
+		return $this->getCurrentTimestamp() + Piwik_Config::getInstance()->Tracker['cookie_expire'];
 	}
 
 	/**
@@ -796,54 +838,21 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 */
 	protected function getCookiePath()
 	{
-		return Piwik_Tracker_Config::getInstance()->Tracker['cookie_path'];
+		return Piwik_Config::getInstance()->Tracker['cookie_path'];
 	}
 
 	protected function shouldUseThirdPartyCookie()
 	{
-		return (bool)Piwik_Tracker_Config::getInstance()->Tracker['use_third_party_id_cookie'];
+		return (bool)Piwik_Config::getInstance()->Tracker['use_third_party_id_cookie'];
 	}
 
 	/**
-	 * This methods tries to see if the visitor has visited the website before.
-	 *
-	 * We have to split the visitor into one of the category
-	 * - Known visitor
-	 * - New visitor
-	 *
-	 * A known visitor is a visitor that has already visited the website in the current month.
-	 * We define a known visitor using the algorithm:
-	 *
-	 * 1) Checking if a cookie contains
-	 * 		// a unique id for the visitor
-	 * 		- id_visitor
-	 *
-	 * 		// the timestamp of the last action in the most recent visit
-	 * 		- timestamp_last_action
-	 *
- 	 *  	// the timestamp of the first action in the most recent visit
-	 * 		- timestamp_first_action
-	 *
-	 * 		// the ID of the most recent visit (which could be in the past or the current visit)
-	 * 		- id_visit
-	 *
-	 * 		// the ID of the most recent action
-	 * 		- id_last_action
-	 *
-	 * 2) If the visitor doesn't have a cookie, we try to look for a similar visitor configuration.
-	 * 	  We search for a visitor with the same plugins/OS/Browser/Resolution for today for this website.
+	 * Is the request for a known VisitorId, based on 1st party, 3rd party (optional) cookies or Tracking API forced Visitor ID
+	 * @throws Exception
 	 */
-	protected function recognizeTheVisitor()
+	protected function assignVisitorIdFromRequest()
 	{
-		$this->visitorKnown = false;
-		$this->setCookie( new Piwik_Cookie(
-								$this->getCookieName(),
-								$this->getCookieExpire(),
-								$this->getCookiePath()) );
-
-		$this->printCookie();
-
-		$found = $forcedVisitorId = false;
+		$found = false;
 
 		// Was a Visitor ID "forced" (@see Tracking API setVisitorId()) for this request?
 		$idVisitor = $this->forcedVisitorId;
@@ -853,14 +862,13 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			{
 				throw new Exception("Visitor ID (cid) must be ".Piwik_Tracker::LENGTH_HEX_ID_STRING." characters long");
 			}
-			printDebug("Request will be forced to record for this idvisitor = ".$idVisitor);
-			$forcedVisitorId = true;
+			printDebug("Request will be recorded for this idvisitor = ".$idVisitor);
 			$found = true;
 		}
 
+		// - If set to use 3rd party cookies for Visit ID, read the cookie 
 		if(!$found)
 		{
-			// - If set to use 3rd party cookies for Visit ID, read the cookies
 			// - By default, reads the first party cookie ID
 			$useThirdPartyCookie = $this->shouldUseThirdPartyCookie();
 			if($useThirdPartyCookie)
@@ -880,50 +888,62 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$found = strlen($idVisitor) >= Piwik_Tracker::LENGTH_HEX_ID_STRING;
 		}
 
-		// Does the cookie contain a Visitor ID?
 		if( $found )
 		{
-			$this->visitorInfo['idvisitor'] = Piwik_Common::hex2bin($idVisitor);
-			printDebug("The visitor has the piwik cookie (idvisitor = ".$idVisitor.") ");
-		}
-		else
-		{
-			printDebug("Visitor doesn't have the piwik cookie.");
+			$truncated = substr($idVisitor, 0, Piwik_Tracker::LENGTH_HEX_ID_STRING);
+			$binVisitorId = @Piwik_Common::hex2bin($truncated);
+			if(!empty($binVisitorId))
+			{
+				$this->visitorInfo['idvisitor'] = $binVisitorId;
+			}
+					
 		}
+	}
+
+	/**
+	 * This methods tries to see if the visitor has visited the website before.
+	 *
+	 * We have to split the visitor into one of the category
+	 * - Known visitor
+	 * - New visitor
+	 */
+	protected function recognizeTheVisitor()
+	{
+		$this->visitorKnown = false;
+		$this->setCookie( new Piwik_Cookie(
+								$this->getCookieName(),
+								$this->getCookieExpire(),
+								$this->getCookiePath()) );
+		$this->printCookie();
 
 		$userInfo = $this->getUserSettingsInformation();
 		$configId = $userInfo['config_id'];
-		$timeLookBack = date('Y-m-d H:i:s', $this->getCurrentTimestamp() - self::TIME_IN_PAST_TO_SEARCH_FOR_VISITOR);
-
-		$where = "visit_last_action_time >= ?
-					AND idsite = ?";
-		$bindSql = array( $timeLookBack, $this->idsite);
-
-		$forcedVisitorId = $forcedVisitorId || Piwik_Tracker_Config::getInstance()->Tracker['trust_visitors_cookies'];
 		
-		// we always match on the config_id, except if the current request forces the visitor id
-		if(!$forcedVisitorId)
+		$this->assignVisitorIdFromRequest();
+		$matchVisitorId = !empty($this->visitorInfo['idvisitor']);
+		
+		if($matchVisitorId)
 		{
-			$where .= ' AND config_id = ? ';
-			$bindSql[] = $configId;
-		}
-		// We force to match a visitor ID
-		// 1) If the visitor cookies should be trusted (ie. intranet) - config file setting
-		// 2) or if the Visitor ID was forced via the Tracking API setVisitorId()
-		else if(!empty($this->visitorInfo['idvisitor']))
-		{
-			printDebug("Matching the visitor based on his idcookie: ".bin2hex($this->visitorInfo['idvisitor']) ."...");
-
-			$where .= ' AND idvisitor = ?';
-			$bindSql[] = $this->visitorInfo['idvisitor'];
+			printDebug("Matching visitors with: visitorId=".bin2hex($this->visitorInfo['idvisitor'])." OR configId=".bin2hex($configId));
 		}
 		else
 		{
-			// Forced idvisitor, but empty idvisitor  
-			return;
+			printDebug("Visitor doesn't have the piwik cookie...");
 		}
-
-		$sql = " SELECT  	idvisitor,
+		
+		$selectCustomVariables = '';
+		// No custom var were found in the request, so let's copy the previous one in a potential conversion later
+		if(!$this->customVariablesSetFromRequest)
+		{
+			$selectCustomVariables = ', 
+				custom_var_k1, custom_var_v1,
+				custom_var_k2, custom_var_v2,
+				custom_var_k3, custom_var_v3,
+				custom_var_k4, custom_var_v4,
+				custom_var_k5, custom_var_v5';
+		}
+		
+		$select = "SELECT  	idvisitor,
 							visit_last_action_time,
 							visit_first_action_time,
 							idvisit,
@@ -932,24 +952,114 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 							visitor_returning,
 							visitor_days_since_first,
 							visitor_days_since_order,
+							location_country,
+							location_continent,
 							referer_name,
 							referer_keyword,
 							referer_type,
 							visitor_count_visits,
 							visit_goal_buyer
-				FROM ".Piwik_Common::prefixTable('log_visit').
-				" WHERE ".$where."
+							$selectCustomVariables 
+		";
+		$from = "FROM ".Piwik_Common::prefixTable('log_visit');
+
+		
+		$bindSql = array();
+		
+		$timeLookBack = date('Y-m-d H:i:s', $this->getCurrentTimestamp() - Piwik_Config::getInstance()->Tracker['visit_standard_length']);
+
+		// This setting would be enabled for Intranet websites, to ensure that visitors using all the same computer config, same IP
+		// are not counted as 1 visitor. In this case, we want to enforce and trust the visitor ID from the cookie.
+		$trustCookiesOnly = Piwik_Config::getInstance()->Tracker['trust_visitors_cookies'];
+		
+		$shouldMatchOneFieldOnly = ($matchVisitorId && $trustCookiesOnly) || !$matchVisitorId;
+		
+		// Two use cases:
+		// 1) there is no visitor ID so we try to match only on config_id (heuristics)
+		// 		Possible causes of no visitor ID: no browser cookie support, direct Tracking API request without visitor ID passed, etc.
+		// 		We can use config_id heuristics to try find the visitor in the past, there is a risk to assign 
+		// 		this page view to the wrong visitor, but this is better than creating artificial visits.
+		// 2) there is a visitor ID and we trust it (config setting trust_visitors_cookies), so we force to look up this visitor id
+		if($shouldMatchOneFieldOnly)
+		{
+			$where = "visit_last_action_time >= ? AND idsite = ?";
+			$bindSql[] = $timeLookBack;
+			$bindSql[] = $this->idsite;
+			if(!$matchVisitorId)
+			{
+				$where .= ' AND config_id = ?';
+				$bindSql[] = $configId;
+			}
+			else
+			{
+				$where .= ' AND idvisitor = ?';
+				$bindSql[] = $this->visitorInfo['idvisitor'];
+			}
+			
+			$sql = "$select
+				$from
+				WHERE ".$where."
 				ORDER BY visit_last_action_time DESC
 				LIMIT 1";
+		}
+		// We have a config_id AND a visitor_id. We match on either of these.
+		// 		Why do we also match on config_id?
+		//		we do not trust the visitor ID only. Indeed, some browsers, or browser addons, 
+		// 		cause the visitor id from the 1st party cookie to be different on each page view! 
+		// 		It is not acceptable to create a new visit every time such browser does a page view, 
+		// 		so we also backup by searching for matching config_id. 
+		// We use a UNION here so that each sql query uses its own INDEX
+		else
+		{
+			$whereSameBothQueries = "visit_last_action_time >= ? AND idsite = ?";
+			
+			
+			// will use INDEX index_idsite_config_datetime (idsite, config_id, visit_last_action_time)
+			$bindSql[] = $timeLookBack;
+			$bindSql[] = $this->idsite;
+			$where = ' AND config_id = ?';
+			$bindSql[] = $configId;
+			$sqlConfigId = "$select ,
+					0 as priority
+					$from
+					WHERE $whereSameBothQueries $where
+					ORDER BY visit_last_action_time DESC
+					LIMIT 1
+			";
+		
+			// will use INDEX index_idsite_idvisitor (idsite, idvisitor)
+			$bindSql[] = $timeLookBack;
+			$bindSql[] = $this->idsite;
+			$where = ' AND idvisitor = ?';
+			$bindSql[] = $this->visitorInfo['idvisitor'];
+			$sqlVisitorId = "$select ,
+					1 as priority
+					$from
+					WHERE $whereSameBothQueries $where
+					LIMIT 1
+			";
+			
+			// We join both queries and favor the one matching the visitor_id if it did match
+			$sql = " ( $sqlConfigId ) 
+					UNION 
+					( $sqlVisitorId ) 
+					ORDER BY priority DESC 
+					LIMIT 1";
+		}
+		
+		
 		$visitRow = Piwik_Tracker::getDatabase()->fetch($sql, $bindSql);
-
-		if( !Piwik_Tracker_Config::getInstance()->Debug['tracker_always_new_visitor']
+//		var_dump($sql);var_dump($bindSql);var_dump($visitRow);
+		
+		if( !Piwik_Config::getInstance()->Debug['tracker_always_new_visitor']
 			&& $visitRow
 			&& count($visitRow) > 0)
 		{
 			// These values will be used throughout the request
 			$this->visitorInfo['visit_last_action_time'] = strtotime($visitRow['visit_last_action_time']);
 			$this->visitorInfo['visit_first_action_time'] = strtotime($visitRow['visit_first_action_time']);
+			
+			// We always keep the first idvisitor seen for this visit (so that all page views for this visit have the same idvisitor)
 			$this->visitorInfo['idvisitor'] = $visitRow['idvisitor'];
 			$this->visitorInfo['idvisit'] = $visitRow['idvisit'];
 			$this->visitorInfo['visit_exit_idaction_url'] = $visitRow['visit_exit_idaction_url'];
@@ -959,13 +1069,33 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$this->visitorInfo['visitor_days_since_order'] = $visitRow['visitor_days_since_order'];
 			$this->visitorInfo['visitor_count_visits'] = $visitRow['visitor_count_visits'];
 			$this->visitorInfo['visit_goal_buyer'] = $visitRow['visit_goal_buyer'];
+			$this->visitorInfo['location_country'] = $visitRow['location_country'];
+			$this->visitorInfo['location_continent'] = $visitRow['location_continent'];
 			
 			// Referer information will be potentially used for Goal Conversion attribution
 			$this->visitorInfo['referer_name'] = $visitRow['referer_name'];
 			$this->visitorInfo['referer_keyword'] = $visitRow['referer_keyword'];
 			$this->visitorInfo['referer_type'] = $visitRow['referer_type'];
-			$this->visitorKnown = true;
 
+			// Custom Variables copied from Visit in potential later conversion
+			if(!empty($selectCustomVariables))
+			{
+				for($i=1; $i<=Piwik_Tracker::MAX_CUSTOM_VARIABLES; $i++) 
+				{
+					if(isset($visitRow['custom_var_k'.$i])
+					    && strlen($visitRow['custom_var_k'.$i]))
+					{
+						$this->visitorInfo['custom_var_k'.$i] = $visitRow['custom_var_k'.$i];
+					}
+					if(isset($visitRow['custom_var_v'.$i])
+					    && strlen($visitRow['custom_var_v'.$i]))
+					{
+						$this->visitorInfo['custom_var_v'.$i] = $visitRow['custom_var_v'.$i];
+					}
+				}
+			}
+			
+			$this->visitorKnown = true;
 			printDebug("The visitor is known (idvisitor = ".bin2hex($this->visitorInfo['idvisitor']).",
 						config_id = ".bin2hex($configId).",
 						idvisit = {$this->visitorInfo['idvisit']},
@@ -991,9 +1121,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			$parameter = 'cvar';
 			$debug = 'Page level';
 		}
-		$customVar = Piwik_Common::unsanitizeInputValue(Piwik_Common::getRequestVar( $parameter, '', 'string', $request));
-		$customVar = @json_decode($customVar, $assoc = true);
-
+		
+		$customVar = Piwik_Common::unsanitizeInputValues(Piwik_Common::getRequestVar($parameter, '', 'json', $request));
 		if(!is_array($customVar))
 		{
 			return array();
@@ -1005,14 +1134,16 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 			if($id < 1
 				|| $id > Piwik_Tracker::MAX_CUSTOM_VARIABLES
 				|| count($keyValue) != 2
-				|| !is_string($keyValue[0])
-				|| !is_string($keyValue[1])
+				|| (!is_string($keyValue[0]) && !is_numeric($keyValue[0]))
 			)
 			{
 				printDebug("Invalid custom variables detected (id=$id)");
 				continue;
 			}
-
+			if(strlen($keyValue[1]) == 0)
+			{
+				$keyValue[1] = "";
+			}
 			// We keep in the URL when Custom Variable have empty names
 			// and values, as it means they can be deleted server side
 
@@ -1120,11 +1251,12 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	{
 		return isset($this->visitorInfo['visit_last_action_time'])
 					&& ($this->visitorInfo['visit_last_action_time']
-						> ($this->getCurrentTimestamp() - Piwik_Tracker_Config::getInstance()->Tracker['visit_standard_length']));
+						> ($this->getCurrentTimestamp() - Piwik_Config::getInstance()->Tracker['visit_standard_length']));
 	}
 
 	/**
 	 * Returns true if the recognizeTheVisitor() method did recognize the visitor
+	 * @return bool
 	 */
 	protected function isVisitorKnown()
 	{
@@ -1151,6 +1283,7 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 	 * Returns an object able to handle the current action
 	 * Plugins can return an override Action that for example, does not record the action in the DB
 	 *
+	 * @throws Exception
 	 * @return Piwik_Tracker_Action child or fake but with same public interface
 	 */
 	protected function newAction()
@@ -1181,8 +1314,8 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 		{
 			return false;
 		}
-		$actionUrl = $action->getActionUrl();
-		$actionUrlParsed = @parse_url(Piwik_Common::unsanitizeInputValue($actionUrl));
+		$decodedActionUrl = $action->getActionUrl();
+		$actionUrlParsed = @parse_url($decodedActionUrl);
 		if(!isset($actionUrlParsed['host']))
 		{
 			return false;
@@ -1192,18 +1325,35 @@ class Piwik_Tracker_Visit implements Piwik_Tracker_Visit_Interface
 
 	/**
 	 * Returns a 64-bit hash of all the configuration settings
+	 * @param $os
+	 * @param $browserName
+	 * @param $browserVersion
+	 * @param $resolution
+	 * @param $plugin_Flash
+	 * @param $plugin_Java
+	 * @param $plugin_Director
+	 * @param $plugin_Quicktime
+	 * @param $plugin_RealPlayer
+	 * @param $plugin_PDF
+	 * @param $plugin_WindowsMedia
+	 * @param $plugin_Gears
+	 * @param $plugin_Silverlight
+	 * @param $plugin_Cookie
+	 * @param $ip
+	 * @param $browserLang
 	 * @return string
 	 */
 	protected function getConfigHash( $os, $browserName, $browserVersion, $resolution, $plugin_Flash, $plugin_Java, $plugin_Director, $plugin_Quicktime, $plugin_RealPlayer, $plugin_PDF, $plugin_WindowsMedia, $plugin_Gears, $plugin_Silverlight, $plugin_Cookie, $ip, $browserLang)
 	{
 		$hash = md5( $os . $browserName . $browserVersion . $plugin_Flash . $plugin_Java . $plugin_Director . $plugin_Quicktime . $plugin_RealPlayer . $plugin_PDF . $plugin_WindowsMedia . $plugin_Gears . $plugin_Silverlight . $plugin_Cookie . $ip . $browserLang, $raw_output = true );
-		return substr( $hash, 0, Piwik_Tracker::LENGTH_BINARY_ID);
+		return Piwik_Common::substr( $hash, 0, Piwik_Tracker::LENGTH_BINARY_ID );
 	}
 
 	/**
 	 * Returns either
 	 * - "-1" for a known visitor
 	 * - at least 16 char identifier in hex @see Piwik_Common::generateUniqId()
+	 * @return int|string
 	 */
 	protected function getVisitorUniqueId()
 	{
@@ -1258,35 +1408,45 @@ class Piwik_Tracker_Visit_Referer
 	/**
 	 * Returns an array containing the following information:
 	 * - referer_type
-	 *		- direct			-- absence of referer URL OR referer URL has the same host
-	 *		- site				-- based on the referer URL
-	 *		- search_engine		-- based on the referer URL
-	 *		- campaign			-- based on campaign URL parameter
+	 *        - direct            -- absence of referer URL OR referer URL has the same host
+	 *        - site                -- based on the referer URL
+	 *        - search_engine        -- based on the referer URL
+	 *        - campaign            -- based on campaign URL parameter
 	 *
 	 * - referer_name
-	 * 		- ()
-	 * 		- piwik.net			-- site host name
-	 * 		- google.fr			-- search engine host name
-	 * 		- adwords-search	-- campaign name
+	 *         - ()
+	 *         - piwik.net            -- site host name
+	 *         - google.fr            -- search engine host name
+	 *         - adwords-search    -- campaign name
 	 *
 	 * - referer_keyword
-	 * 		- ()
-	 * 		- ()
-	 * 		- my keyword
-	 * 		- my paid keyword
-	 * 		- ()
-	 * 		- ()
+	 *         - ()
+	 *         - ()
+	 *         - my keyword
+	 *         - my paid keyword
+	 *         - ()
+	 *         - ()
 	 *
 	 * - referer_url : the same for all the referer types
 	 *
-	 * @param URLs must be URL Encoded
+	 * @param $refererUrl must be URL Encoded
+	 * @param $currentUrl
+	 * @param $idSite
+	 * @return array
 	 */
 	public function getRefererInformation($refererUrl, $currentUrl, $idSite)
 	{
 		$this->idsite = $idSite;
 
 		// default values for the referer_* fields
-		$this->refererUrl = Piwik_Common::unsanitizeInputValue($refererUrl);
+		$refererUrl = Piwik_Common::unsanitizeInputValue($refererUrl);
+		if(!empty($refererUrl)
+			&& !Piwik_Common::isLookLikeUrl($refererUrl))
+		{
+			$refererUrl = '';
+		}
+		
+		$this->refererUrl = $refererUrl;
 		$this->refererUrlParse = @parse_url($this->refererUrl);
 		$this->currentUrlParse = @parse_url(Piwik_Common::unsanitizeInputValue($currentUrl));
 		$this->typeRefererAnalyzed = Piwik_Common::REFERER_TYPE_DIRECT_ENTRY;
@@ -1327,7 +1487,7 @@ class Piwik_Tracker_Visit_Referer
 			'referer_type' 		=> $this->typeRefererAnalyzed,
 			'referer_name' 		=> $this->nameRefererAnalyzed,
 			'referer_keyword' 	=> $this->keywordRefererAnalyzed,
-			'referer_url' 		=> $refererUrl,
+			'referer_url' 		=> $this->refererUrl,
 		);
 
 		return $refererInformation;
@@ -1350,44 +1510,65 @@ class Piwik_Tracker_Visit_Referer
 		return true;
 	}
 
+	protected function detectCampaignFromString($string)
+	{
+		foreach($this->campaignNames as $campaignNameParameter)
+		{
+			$campaignName = trim(urldecode(Piwik_Common::getParameterFromQueryString($string, $campaignNameParameter)));
+			if( !empty($campaignName))
+			{
+				break;
+			}
+		}
+
+		if(!empty($campaignName))
+		{
+			$this->typeRefererAnalyzed = Piwik_Common::REFERER_TYPE_CAMPAIGN;
+			$this->nameRefererAnalyzed = $campaignName;
+
+			foreach($this->campaignKeywords as $campaignKeywordParameter)
+			{
+				$campaignKeyword = Piwik_Common::getParameterFromQueryString($string, $campaignKeywordParameter);
+				if( !empty($campaignKeyword))
+				{
+					$this->keywordRefererAnalyzed = trim(urldecode($campaignKeyword));
+					break;
+				}
+			}
+			return true;
+		}
+		return false;
+	}
+	
 	/*
 	 * Campaign analysis
 	 */
 	protected function detectRefererCampaign()
 	{
+		if(!isset($this->currentUrlParse['query'])
+			&& !isset($this->currentUrlParse['fragment']))
+		{
+			return false;
+		}
+		$campaignParameters = Piwik_Common::getCampaignParameters();
+		$this->campaignNames = $campaignParameters[0];
+		$this->campaignKeywords = $campaignParameters[1];
+		
+		$found = false;
+		
+		// 1) Detect campaign from query string
 		if(isset($this->currentUrlParse['query']))
 		{
-			$campaignParameters = Piwik_Common::getCampaignParameters();
-
-			$campaignNames = $campaignParameters[0];
-			foreach($campaignNames as $campaignNameParameter)
-			{
-				$campaignName = Piwik_Common::getParameterFromQueryString($this->currentUrlParse['query'], $campaignNameParameter);
-				if( !empty($campaignName))
-				{
-					break;
-				}
-			}
-
-			if(!empty($campaignName))
-			{
-				$this->typeRefererAnalyzed = Piwik_Common::REFERER_TYPE_CAMPAIGN;
-				$this->nameRefererAnalyzed = $campaignName;
-
-				$campaignKeywords = $campaignParameters[1];
-				foreach($campaignKeywords as $campaignKeywordParameter)
-				{
-					$campaignKeyword = Piwik_Common::getParameterFromQueryString($this->currentUrlParse['query'], $campaignKeywordParameter);
-					if( !empty($campaignKeyword))
-					{
-						$this->keywordRefererAnalyzed = $campaignKeyword;
-						break;
-					}
-				}
-				return true;
-			}
+			$found = $this->detectCampaignFromString($this->currentUrlParse['query']);
 		}
-		return false;
+
+		// 2) Detect from fragment #hash
+		if(!$found
+			&& isset($this->currentUrlParse['fragment']))
+		{
+			$found = $this->detectCampaignFromString($this->currentUrlParse['fragment']);
+		}
+		return $found;
 	}
 
 	/*
