@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Translate.php 3481 2010-12-21 05:05:03Z vipsoft $
+ * @version $Id: Translate.php 6300 2012-05-23 21:19:25Z SteveG $
  * 
  * @category Piwik
  * @package Piwik
@@ -16,6 +16,7 @@
 class Piwik_Translate
 {
 	static private $instance = null;
+	static private $languageToLoad = null;
 	private $loadedLanguage = false;
 	
 	/**
@@ -51,11 +52,11 @@ class Piwik_Translate
 		$this->loadCoreTranslation($language);
 		Piwik_PluginsManager::getInstance()->loadPluginTranslations($language);
 	}
-	
+
 	/**
 	 * Reads the specified code translation file in memory.
-	 * 
-	 * @param $language 2 letter language code. If not specified, will detect current user translation, or load default translation.
+	 *
+	 * @param bool|string $language 2 letter language code. If not specified, will detect current user translation, or load default translation.
 	 * @return void
 	 */
 	public function loadCoreTranslation($language = false)
@@ -100,36 +101,38 @@ class Piwik_Translate
 	 */
 	public function getLanguageToLoad()
 	{
-		static $language = null;
-		if(!is_null($language))
+		if(is_null(self::$languageToLoad))
 		{
-			return $language;
+			$lang = Piwik_Common::getRequestVar('language', '', 'string');
+
+			Piwik_PostEvent('Translate.getLanguageToLoad', $lang);
+
+			self::$languageToLoad = $lang;
 		}
 
-		Piwik_PostEvent('Translate.getLanguageToLoad', $language);
-		
-		$language = Piwik_Common::getRequestVar('language', is_null($language) ? '' : $language, 'string');
-		if(empty($language))
-		{
-			$language = $this->getLanguageDefault();
-		}
-		if( Piwik_Common::isValidFilename($language))
-		{
-			return $language;
-		}
-		else
-		{
-			throw new Exception("The language selected ('$language') is not a valid language file ");
-		}
+		return self::$languageToLoad;
+	}
+	
+	/** Reset the cached language to load. Used in tests. */
+	static public function reset()
+	{
+		self::$languageToLoad = null;
+	}
+	
+	public function getLanguageLoaded()
+	{
+		return $this->loadedLanguage;
 	}
 	
 	public function getLanguageDefault()
 	{
-		return Zend_Registry::get('config')->General->default_language;
+		return Piwik_Config::getInstance()->General['default_language'];
 	}
+
 	/**
 	 * Generate javascript translations array
-	 * 
+	 *
+	 * @param array $moduleList
 	 * @return string containing javascript code with translations array (including <script> tag)
 	 */
 	public function getJavascriptTranslations(array $moduleList)
@@ -148,8 +151,15 @@ class Piwik_Translate
 		}
 		$moduleRegex = substr($moduleRegex, 0, -1);
 		$moduleRegex .= ')_.*_js$#i';
-		
-		foreach($GLOBALS['Piwik_translations'] as $key => $value)
+
+		// Hack: common translations used in JS but not only, force as them to be defined in JS
+		$translations = $GLOBALS['Piwik_translations'];
+		$toSetInJs = array('General_Save', 'General_OrCancel');
+		foreach($toSetInJs as $toSetId) 
+		{
+    		$translations[$toSetId.'_js'] = $translations[$toSetId];
+		}
+		foreach($translations as $key => $value)
 		{
 			if( preg_match($moduleRegex,$key) ) {
 				$js .= '"'.$key.'": "'.str_replace('"','\"',$value).'",';
@@ -183,7 +193,7 @@ class Piwik_Translate
 /**
  * Returns translated string or given message if translation is not found.
  *
- * @param string Translation string index
+ * @param string $string Translation string index
  * @param array $args sprintf arguments
  * @return string
  */
