@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: UpdateCheck.php 3296 2010-11-06 19:24:43Z vipsoft $
+ * @version $Id: UpdateCheck.php 6404 2012-05-30 11:46:29Z matt $
  * 
  * @category Piwik
  * @package Piwik
@@ -25,12 +25,13 @@ class Piwik_UpdateCheck
 	/**
 	 * Check for a newer version
 	 *
-	 * @param bool $force Force check
+	 * @param bool  $force  Force check
 	 */
 	public static function check($force = false)
 	{
 		$lastTimeChecked = Piwik_GetOption(self::LAST_TIME_CHECKED);
-		if($force || $lastTimeChecked === false
+		if($force
+			|| $lastTimeChecked === false
 			|| time() - self::CHECK_INTERVAL > $lastTimeChecked )
 		{
 			// set the time checked first, so that parallel Piwik requests don't all trigger the http requests
@@ -43,25 +44,35 @@ class Piwik_UpdateCheck
 				'timezone' => Piwik_SitesManager_API::getInstance()->getDefaultTimezone(),
 			);
 
-			$url = Zend_Registry::get('config')->General->api_service_url;
-			$url .= '/1.0/getLatestVersion/';
-			$url .= '?' . http_build_query($parameters, '', '&');
+			$url = Piwik_Config::getInstance()->General['api_service_url']
+				. '/1.0/getLatestVersion/'
+				. '?' . http_build_query($parameters, '', '&');
 			$timeout = self::SOCKET_TIMEOUT;
+			
+			if(@Piwik_Config::getInstance()->Debug['allow_upgrades_to_beta'])
+			{
+				$url = 'http://builds.piwik.org/LATEST_BETA';
+			}
+			
 			try {
 				$latestVersion = Piwik_Http::sendHttpRequest($url, $timeout);
-				Piwik_SetOption(self::LATEST_VERSION, $latestVersion);
+				if (!preg_match('~^[0-9][0-9a-zA-Z_.-]*$~D', $latestVersion))
+				{
+					$latestVersion = '';
+				}
 			} catch(Exception $e) {
 				// e.g., disable_functions = fsockopen; allow_url_open = Off
-				Piwik_SetOption(self::LATEST_VERSION, '');
+				$latestVersion = '';
 			}
+			Piwik_SetOption(self::LATEST_VERSION, $latestVersion);
 		}
 	}
 	
 	/**
 	 * Returns version number of a newer Piwik release.
 	 *
-	 * @return string|false false if current version is the latest available, 
-	 * 	 or the latest version number if a newest release is available
+	 * @return string|false  false if current version is the latest available,
+	 *                       or the latest version number if a newest release is available
 	 */
 	public static function isNewestVersionAvailable()
 	{
