@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Url.php 5281 2011-10-10 19:22:30Z vipsoft $
+ * @version $Id: Url.php 6208 2012-04-14 21:01:43Z vipsoft $
  *
  * @category Piwik
  * @package Piwik
@@ -88,28 +88,27 @@ class Piwik_Url
 	static public function getCurrentScriptName()
 	{
 		$url = '';
-		if( !empty($_SERVER['PATH_INFO']) ) 
-		{ 
-			$url = $_SERVER['PATH_INFO'];
-		} 
-		else if( !empty($_SERVER['REQUEST_URI']) ) 
+
+		if( !empty($_SERVER['REQUEST_URI']) ) 
 		{
-			$requestUri = $_SERVER['REQUEST_URI'];
+			$url = $_SERVER['REQUEST_URI'];
 
 			// strip http://host (Apache+Rails anomaly)
-			if(preg_match('~^https?://[^/]+($|/.*)~D', $requestUri, $matches))
+			if(preg_match('~^https?://[^/]+($|/.*)~D', $url, $matches))
 			{
-				$requestUri = $matches[1];
+				$url = $matches[1];
 			}
 
 			// strip parameters
-			if( ($pos = strpos($requestUri, "?")) !== false ) 
+			if(($pos = strpos($url, "?")) !== false) 
 			{
-				$url = substr($requestUri, 0, $pos);
+				$url = substr($url, 0, $pos);
 			} 
-			else 
+
+			// strip path_info
+			if(isset($_SERVER['PATH_INFO']))
 			{
-				$url = $requestUri;
+				$url = substr($url, 0, -strlen($_SERVER['PATH_INFO']));
 			}
 		} 
 
@@ -149,9 +148,7 @@ class Piwik_Url
 	 */
 	static public function getCurrentScheme()
 	{
-		$config = Zend_Registry::get('config');
-		$assume_secure_protocol = $config !== false && $config->General->assume_secure_protocol;
-
+		$assume_secure_protocol = @Piwik_Config::getInstance()->General['assume_secure_protocol'];
 		if($assume_secure_protocol
 			|| (isset($_SERVER['HTTPS'])
 				&& ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] === true))
@@ -162,38 +159,71 @@ class Piwik_Url
 		return 'http';
 	}
 
+	/*
+	 * Validate "Host" (untrusted user input)
+	 *
+	 * @param string $host         Contents of Host: header from Request
+	 * @param array  $trustedHosts An array of trusted hosts
+	 *
+	 * @return boolean True if valid; false otherwise
+	 */
+	public function isValidHost($host, $trustedHosts)
+	{
+		// Only punctuation we allow is '[', ']', ':', '.' and '-'
+		$hostLength = Piwik_Common::strlen($host);
+		if ($hostLength !== strcspn($host, '`~!@#$%^&*()_+={}\\|;"\'<>,?/ '))
+		{
+			return false;
+		}
+
+		$untrustedHost = Piwik_Common::mb_strtolower($host);
+		$hostRegex     = Piwik_Common::mb_strtolower(str_replace('.', '\.', '/(^|.)' . implode('|', $trustedHosts) . '(:[0-9]+)?$/'));
+
+		return 0 !== preg_match($hostRegex, rtrim($untrustedHost, '.'));
+	}
+
+	/**
+	 * Get host
+	 *
+	 * @return string|false
+	 */
+	static public function getHost()
+	{
+		// HTTP/1.1 request
+		if (isset($_SERVER['HTTP_HOST'])
+			&& strlen($host = $_SERVER['HTTP_HOST'])
+			&& (!($trustedHosts = @Piwik_Config::getInstance()->General['trusted_hosts'])
+			|| self::isValidHost($host, $trustedHosts)))
+		{
+			return $host;
+		}
+		
+		// HTTP/1.0 request doesn't include Host: header
+		if (isset($_SERVER['SERVER_ADDR']))
+		{
+			return $_SERVER['SERVER_ADDR'];
+		}
+
+		return false;
+	}
+
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "example.org"
-	 *
+	 *	
 	 * @param string $default Default value to return if host unknown
 	 * @return string
 	 */
 	static public function getCurrentHost($default = 'unknown')
 	{
-		$hostHeaders = null;
-		$config = Zend_Registry::get('config');
-		if($config !== false && $config->General->proxy_host_headers)
-		{
-			$hostHeaders = $config->General->proxy_host_headers->toArray();
-		}
+		$hostHeaders = @Piwik_Config::getInstance()->General['proxy_host_headers'];
 		if(!is_array($hostHeaders))
 		{
 			$hostHeaders = array();
 		}
 
-		$default = Piwik_Common::sanitizeInputValue($default);
-		if(isset($_SERVER['HTTP_HOST'])
-			&& !empty($_SERVER['HTTP_HOST']))
-		{
-			$default = Piwik_Common::sanitizeInputValue($_SERVER['HTTP_HOST']);
-		}
-
-		// temporary workaround for #1331
-		if(!method_exists('Piwik_IP', 'getNonProxyIpFromHeader'))
-		{
-			return $default;
-		}
+		$host = self::getHost();
+		$default = Piwik_Common::sanitizeInputValue($host ? $host : $default);
 
 		return Piwik_IP::getNonProxyIpFromHeader($default, $hostHeaders);
 	}
@@ -275,12 +305,12 @@ class Piwik_Url
 			{
 				foreach($value as $theValue)
 				{
-					$query .= $name . "[]=" . $theValue . "&";
+					$query .= $name . "[]=" . urlencode($theValue) . "&";
 				}
 			}
 			else
 			{
-				$query .= $name . "=" . $value . "&";
+				$query .= $name . "=" . urlencode($value) . "&";
 			}
 		}
 		$query = substr($query, 0, -1);
@@ -308,7 +338,15 @@ class Piwik_Url
 	 */
 	static public function redirectToUrl( $url )
 	{
-		@header("Location: $url");
+		if(Piwik_Common::isLookLikeUrl($url)
+			|| strpos($url, 'index.php') === 0)
+		{
+			@header("Location: $url");
+		}
+		else
+		{
+			echo "Invalid URL to redirect to.";
+		}
 		exit;
 	}
 
@@ -342,7 +380,7 @@ class Piwik_Url
 		// handle host name mangling
 		$requestUri = isset($_SERVER['SCRIPT_URI']) ? $_SERVER['SCRIPT_URI'] : '';
 		$parseRequest = @parse_url($requestUri);
-		$hosts = array(	$_SERVER['HTTP_HOST'], self::getCurrentHost() );
+		$hosts = array(	self::getHost(), self::getCurrentHost() );
 		if(isset($parseRequest['host']))
 		{
 			$hosts[] = $parseRequest['host'];
