@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Sparkline.php 2968 2010-08-20 15:26:33Z vipsoft $
+ * @version $Id: Sparkline.php 5999 2012-03-08 02:56:21Z matt $
  *
  * @category Piwik
  * @package Piwik
@@ -23,7 +23,7 @@ require_once PIWIK_INCLUDE_PATH . '/libs/sparkline/lib/Sparkline_Line.php';
  * @package Piwik
  * @subpackage Piwik_Visualization
  */
-class Piwik_Visualization_Sparkline implements Piwik_iView
+class Piwik_Visualization_Sparkline implements Piwik_View_Interface
 {
 	/**
 	 * Array with format: array( x, y, z, ... )
@@ -57,15 +57,20 @@ class Piwik_Visualization_Sparkline implements Piwik_iView
 		
 		$min = $max = $last = null;
 		$i = 0;
+		$toRemove = array('%', str_replace('%s', '', Piwik_Translate('General_Seconds')));
 		foreach($this->values as $value)
 		{
-			// 50% should be plotted as 50
-			$toRemove = '%';
-			if(strpos($value, $toRemove) !== false)
+			// 50% and 50s should be plotted as 50
+			$value = str_replace($toRemove, '', $value);
+			// replace localized decimal separator
+			$value = str_replace(',', '.', $value);
+			if ($value == '')
 			{
-				$value = str_replace($toRemove, '', $value);
+				$value = 0;
 			}
+			
 			$sparkline->SetData($i, $value);
+			
 			if(	null == $min || $value <= $min[1])
 			{
 				$min = array($i, $value);
