@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: index.php 4765 2011-05-22 18:52:37Z vipsoft $
+ * @version $Id: index.php 6068 2012-03-20 06:23:29Z matt $
  *
  * @package Piwik
  */
@@ -16,7 +16,7 @@ if(file_exists(PIWIK_DOCUMENT_ROOT . '/bootstrap.php'))
 }
 
 error_reporting(E_ALL|E_NOTICE);
-@ini_set('display_errors', (!defined('PIWIK_DISPLAY_ERRORS') || PIWIK_DISPLAY_ERRORS) ? 1 : 0);
+@ini_set('display_errors', defined('PIWIK_DISPLAY_ERRORS') ? PIWIK_DISPLAY_ERRORS : @ini_get('display_errors')); 
 @ini_set('xdebug.show_exception_trace', 0);
 @ini_set('magic_quotes_runtime', 0);
 
