@@ -16,7 +16,7 @@
  *
  * Incompatible with these (and earlier) versions of:
  * - IE4 - try..catch and for..in introduced in IE5
- * - IE5 - named anonymous functions, array.push, encodeURIComponent, and decodeURIComponent introduced in IE5.5
+ * - IE5 - named anonymous functions, array.push, encodeURIComponent, decodeURIComponent, and getElementsByTagName introduced in IE5.5
  * - Firefox 1.0 and Netscape 8.x - FF1.5 adds array.indexOf, among other things
  * - Mozilla 1.7 and Netscape 6.x-7.x
  * - Netscape 4.8
@@ -28,7 +28,7 @@
  * JSON - public domain reference implementation by Douglas Crockford
  * @link http://www.JSON.org/json2.js
  ************************************************************/
-/*jslint evil: true, strict: true, regexp: false, type: true, bitwise: true */
+/*jslint evil: true, regexp: false, bitwise: true */
 /*global JSON2 */
 /*members "", "\b", "\t", "\n", "\f", "\r", "\"", JSON2, "\\", apply,
     call, charCodeAt, getUTCDate, getUTCFullYear, getUTCHours,
@@ -367,23 +367,23 @@ if (!this.JSON2) {
  * end JSON
  ************************************************************/
 
-/*jslint browser:true, plusplus:true, vars:true, dangling:true, nomen:true, strict:true, evil:true */
+/*jslint browser:true, plusplus:true, vars:true, nomen:true, evil:true */
 /*global window */
 /*global unescape */
 /*global ActiveXObject */
 /*global _paq:true */
-/*members encodeURIComponent, decodeURIComponent,
+/*members encodeURIComponent, decodeURIComponent, getElementsByTagName,
 	shift, unshift,
-	addEventListener, attachEvent, removeEventListener, detachEvent,
-	cookie, domain, readyState, documentElement, doScroll, title,
+	addEventListener, attachEvent, removeEventListener, detachEvent, disableCookies,
+	cookie, domain, readyState, documentElement, doScroll, title, text,
 	location, top, document, referrer, parent, links, href, protocol, GearsFactory,
 	event, which, button, srcElement, type, target,
 	parentNode, tagName, hostname, className,
 	userAgent, cookieEnabled, platform, mimeTypes, enabledPlugin, javaEnabled,
-	XDomainRequest, XMLHttpRequest, ActiveXObject, open, setRequestHeader, onreadystatechange, setRequestHeader, send, readyState, status,
-	getTime, setTime, toGMTString, getHours, getMinutes, getSeconds,
-	toLowerCase, charAt, indexOf, lastIndexOf, split, slice,
-	onLoad, src,
+	XMLHttpRequest, ActiveXObject, open, setRequestHeader, onreadystatechange, send, readyState, status,
+	getTime, getTimeAlias, setTime, toGMTString, getHours, getMinutes, getSeconds,
+	toLowerCase, charAt, indexOf, lastIndexOf, split, slice, toUpperCase,
+	onload, src,
 	round, random,
 	exec,
 	res, width, height,
@@ -402,9 +402,9 @@ if (!this.JSON2) {
 	setCookieNamePrefix, setCookieDomain, setCookiePath, setVisitorIdCookie,
 	setVisitorCookieTimeout, setSessionCookieTimeout, setReferralCookieTimeout,
 	setConversionAttributionFirstReferrer,
-	doNotTrack, setDoNotTrack,
+	doNotTrack, setDoNotTrack, msDoNotTrack,
 	addListener, enableLinkTracking, setLinkTrackingTimer,
-	setHeartBeatTimer, killFrame, redirectFile,
+	setHeartBeatTimer, killFrame, redirectFile, setCountPreRendered,
 	trackGoal, trackLink, trackPageView, setEcommerceView, addEcommerceItem, trackEcommerceOrder, trackEcommerceCartUpdate,
 	addPlugin, getTracker, getAsyncTracker
 */
@@ -562,7 +562,7 @@ var
 				//     while (Date.now() < expireDateTime) { }
 				do {
 					now = new Date();
-				} while (now.getTime() < expireDateTime);
+				} while (now.getTimeAlias() < expireDateTime);
 			}
 		}
 
@@ -688,36 +688,6 @@ var
 			return result ? decodeWrapper(result[1]) : '';
 		}
 
-		/*
-		 * Set cookie value
-		 */
-		function setCookie(cookieName, value, msToExpire, path, domain, secure) {
-			var expiryDate;
-
-			// relative time to expire in milliseconds
-			if (msToExpire) {
-				expiryDate = new Date();
-				expiryDate.setTime(expiryDate.getTime() + msToExpire);
-			}
-
-			documentAlias.cookie = cookieName + '=' + encodeWrapper(value) +
-				(msToExpire ? ';expires=' + expiryDate.toGMTString() : '') +
-				';path=' + (path || '/') +
-				(domain ? ';domain=' + domain : '') +
-				(secure ? ';secure' : '');
-		}
-
-		/*
-		 * Get cookie value
-		 */
-		function getCookie(cookieName) {
-			var cookiePattern = new RegExp('(^|;)[ ]*' + cookieName + '=([^;]*)'),
-
-				cookieMatch = cookiePattern.exec(documentAlias.cookie);
-
-			return cookieMatch ? decodeWrapper(cookieMatch[2]) : 0;
-		}
-
 		/*
 		 * UTF-8 encoding
 		 */
@@ -905,6 +875,21 @@ var
 			return domain;
 		}
 
+		/*
+		 * Title fixup
+		 */
+		function titleFixup(title) {
+			if (!isString(title)) {
+				title = title.text || '';
+
+				var tmp = documentAlias.getElementsByTagName('title');
+				if (tmp && isDefined(tmp[0])) {
+					title = tmp[0].text;
+				}
+			}
+			return title;
+		}
+
 		/*
 		 * Piwik Tracker class
 		 *
@@ -994,9 +979,15 @@ var
 				// Default is user agent defined.
 				configCookiePath,
 
+				// Cookies are disabled
+				configCookiesDisabled = false,
+
 				// Do Not Track
 				configDoNotTrack,
 
+				// Count sites which are pre-rendered
+				configCountPreRendered,
+
 				// Do we attribute the conversion to the first referrer or the most recent referrer?
 				configConversionAttributionFirstReferrer,
 
@@ -1049,6 +1040,42 @@ var
 				// Visitor UUID
 				visitorUUID;
 
+
+			/*
+			 * Set cookie value
+			 */
+			function setCookie(cookieName, value, msToExpire, path, domain, secure) {
+				if (configCookiesDisabled) {
+					return;
+				}
+				var expiryDate;
+
+				// relative time to expire in milliseconds
+				if (msToExpire) {
+					expiryDate = new Date();
+					expiryDate.setTime(expiryDate.getTime() + msToExpire);
+				}
+
+				documentAlias.cookie = cookieName + '=' + encodeWrapper(value) +
+					(msToExpire ? ';expires=' + expiryDate.toGMTString() : '') +
+					';path=' + (path || '/') +
+					(domain ? ';domain=' + domain : '') +
+					(secure ? ';secure' : '');
+			}
+
+			/*
+			 * Get cookie value
+			 */
+			function getCookie(cookieName) {
+				if (configCookiesDisabled) {
+					return 0;
+				}
+				var cookiePattern = new RegExp('(^|;)[ ]*' + cookieName + '=([^;]*)'),
+					cookieMatch = cookiePattern.exec(documentAlias.cookie);
+
+				return cookieMatch ? decodeWrapper(cookieMatch[2]) : 0;
+			}
+
 			/*
 			 * Removes hash tag from the URL
 			 *
@@ -1129,7 +1156,7 @@ var
 			function getImage(request) {
 				var image = new Image(1, 1);
 
-				image.onLoad = function () { };
+				image.onload = function () { };
 				image.src = configTrackerUrl + (configTrackerUrl.indexOf('?') < 0 ? '?' : '&') + request;
 			}
 
@@ -1141,10 +1168,9 @@ var
 					// we use the progid Microsoft.XMLHTTP because
 					// IE5.5 included MSXML 2.5; the progid MSXML2.XMLHTTP
 					// is pinned to MSXML2.XMLHTTP.3.0
-					var xhr = windowAlias.XDomainRequest ? new windowAlias.XDomainRequest() :
-							windowAlias.XMLHttpRequest ? new windowAlias.XMLHttpRequest() :
-									windowAlias.ActiveXObject ? new ActiveXObject('Microsoft.XMLHTTP') :
-											null;
+					var xhr = windowAlias.XMLHttpRequest ? new windowAlias.XMLHttpRequest() :
+							windowAlias.ActiveXObject ? new ActiveXObject('Microsoft.XMLHTTP') :
+									null;
 
 					xhr.open('POST', configTrackerUrl, true);
 
@@ -1155,11 +1181,10 @@ var
 						}
 					};
 
+					// see XMLHttpRequest Level 2 spec, section 4.7.2 for invalid headers
+					// @link http://dvcs.w3.org/hg/xhr/raw-file/tip/Overview.html
 					xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
 
-					// Safari: unsafe headers
-//					xhr.setRequestHeader('Content-Length', request.length);
-//					xhr.setRequestHeader('Connection', 'close');
 					xhr.send(request);
 				} catch (e) {
 					// fallback
@@ -1197,9 +1222,11 @@ var
 			 * Does browser have cookies enabled (for this site)?
 			 */
 			function hasCookies() {
-				var testCookieName = getCookieName('testcookie');
-
+				if (configCookiesDisabled) {
+					return '0';
+				}
 				if (!isDefined(navigatorAlias.cookieEnabled)) {
+					var testCookieName = getCookieName('testcookie');
 					setCookie(testCookieName, '1');
 					return getCookie(testCookieName) === '1' ? '1' : '0';
 				}
@@ -1374,11 +1401,17 @@ var
 					campaignNameDetected,
 					campaignKeywordDetected;
 
+				if (configCookiesDisabled) {
+					// Temporarily allow cookies just to delete the existing ones
+					configCookiesDisabled = false;
+					setCookie(idname, '', -86400, configCookiePath, configCookieDomain);
+					setCookie(sesname, '', -86400, configCookiePath, configCookieDomain);
+					setCookie(cvarname, '', -86400, configCookiePath, configCookieDomain);
+					setCookie(refname, '', -86400, configCookiePath, configCookieDomain);
+					configCookiesDisabled = true;
+				}
+
 				if (configDoNotTrack) {
-					setCookie(idname, '', -1, configCookiePath, configCookieDomain);
-					setCookie(sesname, '', -1, configCookiePath, configCookieDomain);
-					setCookie(cvarname, '', -1, configCookiePath, configCookieDomain);
-					setCookie(refname, '', -1, configCookiePath, configCookieDomain);
 					return '';
 				}
 
@@ -1599,7 +1632,7 @@ var
 			 */
 			function logPageView(customTitle, customData) {
 				var now = new Date(),
-					request = getRequest('action_name=' + encodeWrapper(customTitle || configTitle), customData, 'log');
+					request = getRequest('action_name=' + encodeWrapper(titleFixup(customTitle || configTitle)), customData, 'log');
 
 				sendRequest(request, configTrackerPause);
 
@@ -1665,6 +1698,58 @@ var
 				sendRequest(request, configTrackerPause);
 			}
 
+			/*
+			 * Browser prefix
+			 */
+			function prefixPropertyName(prefix, propertyName) {
+				if (prefix !== '') {
+					return prefix + propertyName.charAt(0).toUpperCase() + propertyName.slice(1);
+				}
+
+				return propertyName;
+			}
+
+			/*
+			 * Check for pre-rendered web pages, and log the page view/link/goal
+			 * according to the configuration and/or visibility
+			 *
+			 * @see http://dvcs.w3.org/hg/webperf/raw-file/tip/specs/PageVisibility/Overview.html
+			 */
+			function trackCallback(callback) {
+				var isPreRendered,
+					i,
+					// Chrome 13, IE10, FF10
+					prefixes = ['', 'webkit', 'ms', 'moz'],
+					prefix;
+
+				if (!configCountPreRendered) {
+					for (i = 0; i < prefixes.length; i++) {
+						prefix = prefixes[i];
+
+						// does this browser support the page visibility API?
+						if (Object.prototype.hasOwnProperty.call(documentAlias, prefixPropertyName(prefix, 'hidden'))) {
+							// if pre-rendered, then defer callback until page visibility changes
+							if (documentAlias[prefixPropertyName(prefix, 'visibilityState')] === 'prerender') {
+								isPreRendered = true;
+							}
+							break;
+						}
+					}
+				}
+
+				if (isPreRendered) {
+					// note: the event name doesn't follow the same naming convention as vendor properties
+					addEventListener(documentAlias, prefix + 'visibilitychange', function ready() {
+						documentAlias.removeEventListener(prefix + 'visibilitychange', ready, false);
+						callback();
+					});
+					return;
+				}
+
+				// configCountPreRendered === true || isPreRendered === false
+				callback();
+			}
+
 			/*
 			 * Construct regular expression of classes
 			 */
@@ -1741,7 +1826,7 @@ var
 					var originalSourceHostName = sourceElement.hostname || getHostName(sourceElement.href),
 						sourceHostName = originalSourceHostName.toLowerCase(),
 						sourceHref = sourceElement.href.replace(originalSourceHostName, sourceHostName),
-						scriptProtocol = new RegExp('^(javascript|vbscript|jscript|mocha|livescript|ecmascript):', 'i');
+						scriptProtocol = new RegExp('^(javascript|vbscript|jscript|mocha|livescript|ecmascript|mailto):', 'i');
 
 					// ignore script pseudo-protocol links
 					if (!scriptProtocol.test(sourceHref)) {
@@ -1848,32 +1933,36 @@ var
 						ag: 'application/x-silverlight'
 					};
 
-				// general plugin detection
-				if (navigatorAlias.mimeTypes && navigatorAlias.mimeTypes.length) {
-					for (i in pluginMap) {
-						if (Object.prototype.hasOwnProperty.call(pluginMap, i)) {
-							mimeType = navigatorAlias.mimeTypes[pluginMap[i]];
-							browserFeatures[i] = (mimeType && mimeType.enabledPlugin) ? '1' : '0';
+				if (!((new RegExp('MSIE')).test(navigatorAlias.userAgent))) {
+					// general plugin detection
+					if (navigatorAlias.mimeTypes && navigatorAlias.mimeTypes.length) {
+						for (i in pluginMap) {
+							if (Object.prototype.hasOwnProperty.call(pluginMap, i)) {
+								mimeType = navigatorAlias.mimeTypes[pluginMap[i]];
+								browserFeatures[i] = (mimeType && mimeType.enabledPlugin) ? '1' : '0';
+							}
 						}
 					}
+
+					// Safari and Opera
+					// IE6/IE7 navigator.javaEnabled can't be aliased, so test directly
+					if (typeof navigator.javaEnabled !== 'unknown' &&
+							isDefined(navigatorAlias.javaEnabled) &&
+							navigatorAlias.javaEnabled()) {
+						browserFeatures.java = '1';
+					}
+
+					// Firefox
+					if (isFunction(windowAlias.GearsFactory)) {
+						browserFeatures.gears = '1';
+					}
+
+					// other browser features
+					browserFeatures.cookie = hasCookies();
 				}
 
-				// Safari and Opera
-				// IE6/IE7 navigator.javaEnabled can't be aliased, so test directly
-				if (typeof navigator.javaEnabled !== 'unknown' &&
-						isDefined(navigatorAlias.javaEnabled) &&
-						navigatorAlias.javaEnabled()) {
-					browserFeatures.java = '1';
-				}
-
-				// Firefox
-				if (isFunction(windowAlias.GearsFactory)) {
-					browserFeatures.gears = '1';
-				}
-
-				// other browser features
+				// screen resolution
 				browserFeatures.res = screenAlias.width + 'x' + screenAlias.height;
-				browserFeatures.cookie = hasCookies();
 			}
 
 /*<DEBUG>*/
@@ -2065,6 +2154,8 @@ var
 						scope = 'visit';
 					}
 					if (index > 0) {
+						name = isDefined(name) && !isString(name) ? String(name) : name;
+						value = isDefined(value) && !isString(value) ? String(value) : value;
 						toRecord = [name.slice(0, customVariableMaximumLength), value.slice(0, customVariableMaximumLength)];
 						if (scope === 'visit' || scope === 2) { /* GA compatibility/misuse */
 							loadCustomVariables();
@@ -2308,13 +2399,29 @@ var
 					configConversionAttributionFirstReferrer = enable;
 				},
 
+				/**
+				 * Disables all cookies from being set
+				 * Existing cookies will be deleted on the next call to track*
+				 * 
+				 */
+				disableCookies: function () {
+					configCookiesDisabled = true;
+					browserFeatures.cookie = '0';
+				},
+
 				/**
 				 * Handle do-not-track requests
 				 *
 				 * @param bool enable If true, don't track if user agent sends 'do-not-track' header
 				 */
 				setDoNotTrack: function (enable) {
-					configDoNotTrack = enable && navigatorAlias.doNotTrack;
+					var dnt = navigatorAlias.doNotTrack || navigatorAlias.msDoNotTrack;
+					configDoNotTrack = enable && (dnt === 'yes' || dnt === '1');
+
+					// do not track also disables cookies and deletes existing cookies
+					if (configDoNotTrack) {
+						this.disableCookies();
+					}
 				},
 
 				/**
@@ -2390,6 +2497,15 @@ var
 					}
 				},
 
+				/**
+				 * Count sites in pre-rendered state
+				 *
+				 * @param bool enable If true, track when in pre-rendered state
+				 */
+				setCountPreRendered: function (enable) {
+					configCountPreRendered = enable;
+				},
+
 				/**
 				 * Trigger a goal
 				 *
@@ -2398,7 +2514,9 @@ var
 				 * @param mixed customData
 				 */
 				trackGoal: function (idGoal, customRevenue, customData) {
-					logGoal(idGoal, customRevenue, customData);
+					trackCallback(function () {
+						logGoal(idGoal, customRevenue, customData);
+					});
 				},
 
 				/**
@@ -2409,7 +2527,9 @@ var
 				 * @param mixed customData
 				 */
 				trackLink: function (sourceUrl, linkType, customData) {
-					logLink(sourceUrl, linkType, customData);
+					trackCallback(function () {
+						logLink(sourceUrl, linkType, customData);
+					});
 				},
 
 				/**
@@ -2419,7 +2539,9 @@ var
 				 * @param mixed customData
 				 */
 				trackPageView: function (customTitle, customData) {
-					logPageView(customTitle, customData);
+					trackCallback(function () {
+						logPageView(customTitle, customData);
+					});
 				},
 
 
@@ -2437,11 +2559,13 @@ var
 				 * @param string sku Item's SKU code being viewed
 				 * @param string name Item's Name being viewed
 				 * @param string category Category page being viewed. On an Item's page, this is the item's category
-				 * @param float price Item's display price, not use in standard Piwik reports, but output in API product reports. 
+				 * @param float price Item's display price, not use in standard Piwik reports, but output in API product reports.
 				 */
 				setEcommerceView: function (sku, name, category, price) {
 					if (!isDefined(category) || !category.length) {
 						category = "";
+					} else if (category instanceof Array) {
+						category = JSON2.stringify(category);
 					}
 					customVariablesPage[5] = ['_pkc', category];
 					if (isDefined(price) && String(price).length) {
@@ -2532,6 +2656,8 @@ var
 		addEventListener(windowAlias, 'beforeunload', beforeUnloadHandler, false);
 		addReadyListener();
 
+		Date.prototype.getTimeAlias = Date.prototype.getTime;
+
 		asyncTracker = new Tracker();
 
 		for (i = 0; i < _paq.length; i++) {
