@@ -110,10 +110,7 @@ $translations = array(
 	'API_LoadedAPIs' => 'ማስጋባት ተሳክቷል %s ኤፒአይዎች',
 	'CoreHome_CategoryNoData' => 'በዚህ ፈርጅ ምንም ውሂብ የለም. "ሁሉንም ምድብ" ለማጠቃለል ይሞክሩ።',
 	'CoreHome_ShowJSCode' => 'ለማስገባት የጃቫ ስክሪፕትን ኮድ አሳይ',
-	'CoreHome_IncludeAllPopulation_js' => 'ሁሉንም ምድብ ያጠቃሉ',
-	'CoreHome_ExcludeLowPopulation_js' => 'አነስተኛ ምድቦችን ይቀንሱ',
 	'CoreHome_PageOf_js' => '%1$s የ %2$s',
-	'CoreHome_DayFormat' => '%ረዥም ቀን% %ቀን% %lረዥም ወር% %ረዥም ዓመት%',
 	'CoreHome_PeriodDay' => 'ቀን',
 	'CoreHome_PeriodWeek' => 'ሳምንት',
 	'CoreHome_PeriodMonth' => 'ወር',
@@ -182,7 +179,6 @@ $translations = array(
 	'CoreUpdater_InstallingTheLatestVersion' => 'አዲሱን ስሪት በመጫን ላይ',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'የፒዊክ ማላቅ ተሳክቷል!',
 	'Dashboard_Dashboard' => 'ዳሽቦርድ',
-	'Dashboard_AddWidget' => 'widget ጨምር...',
 	'Dashboard_DeleteWidgetConfirm' => 'እርግጠኛ ነህ ይህ widget ከዳሽቦርድ ይሰረዝ?',
 	'Dashboard_SelectWidget' => 'ወደ ዳሽቦርድ የሚጨመረውን widget ምረጥ',
 	'Dashboard_AddPreviewedWidget_js' => 'ቅድመ እይታ የተሰጠውን widget ወደ ዳሽቦርዱ ጨምር',
@@ -519,8 +515,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Reunion Island',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Russia',
 	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_ru' => 'Russia',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudi Arabia',
 	'UserCountry_country_sb' => 'Solomon Islands',
@@ -660,7 +656,6 @@ $translations = array(
 	'VisitorInterest_NPages' => '%s ገፆች',
 	'VisitsSummary_NbVisits' => '%s ጉበኝቶች',
 	'VisitsSummary_NbUniqueVisitors' => '%s የተለዩ ጎብኚዎች',
-	'VisitsSummary_NbActions' => '%s ርምጃዎች (የገፅ ትይታዎች)',
 	'VisitsSummary_MaxNbActions' => '%s በአንድ ጉብኝት የተወሰዱ ከፍተኛ ርምጃዎች',
 	'VisitsSummary_NbVisitsBounced' => '%s የተመለሱ ጉብኝቶች (ከአንድ ገፅ በኋላ ገፁን የተዉ)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolution በመጨረሻው ላይ %s',
