@@ -1,63 +1,201 @@
 <?php
 $translations = array(
 	'General_Locale' => 'ca_ES.UTF-8',
-	'General_TranslatorName' => 'Isaac Sánchez Barrera',
-	'General_TranslatorEmail' => 'isb1009 [at] [don\'t write this] astronomipedia [dot] es',
+	'General_TranslatorName' => 'Isaac Sánchez Barrera, Joan Juvanteny',
+	'General_TranslatorEmail' => 'isb1009 [at] [don\'t write this] astronomipedia [dot] es,jjuvan@grn.cat',
 	'General_EnglishLanguageName' => 'Catalan',
 	'General_OriginalLanguageName' => 'Català',
+	'General_LayoutDirection' => 'ltr',
 	'General_HelloUser' => 'Hola, %s!',
 	'General_OpenSourceWebAnalytics' => 'Anàlisi web de codi obert',
+	'General_Dashboard' => 'Tauler',
+	'General_DashboardForASpecificWebsite' => 'Tauler per un lloc web concret',
+	'General_MultiSitesSummary' => 'Tots els llocs web',
+	'General_AllWebsitesDashboard' => 'Tauler de tots els llocs web',
 	'General_API' => 'API',
 	'General_Widgets' => 'Ginys',
 	'General_Settings' => 'Tauler de control',
 	'General_GiveUsYourFeedback' => 'Què penseu del Piwik?',
 	'General_Unknown' => 'Desconegut',
+	'General_Never' => 'Mai',
 	'General_Required' => '%s requerit',
+	'General_NotValid' => '%s no és vàlid',
+	'General_NotDefined' => '%s no definit',
+	'General_Id' => 'Id',
 	'General_Error' => 'Error',
 	'General_Warning' => 'Avís',
 	'General_BackToHomepage' => 'Torna a la pàgina principal de Piwik',
 	'General_Yes' => 'Sí',
 	'General_No' => 'No',
 	'General_Delete' => 'Esborra',
+	'General_Report' => 'Informe',
+	'General_Reports' => 'Informes',
 	'General_Edit' => 'Edita',
+	'General_Download' => 'Descàrrega',
+	'General_Upload' => 'Càrrega',
 	'General_Ok' => 'D\'acord',
 	'General_Close' => 'Tanca',
+	'General_OrCancel' => 'o %s cancel·la %s',
 	'General_Logout' => 'Surt',
+	'General_Username' => 'Usuari',
+	'General_Description' => 'Descripció',
 	'General_Done' => 'Fet',
+	'General_PoweredBy' => 'Funcionant amb',
+	'General_MetricsToPlot' => 'Valors per graficar',
+	'General_RowsToDisplay' => 'Files a mostrar',
+	'General_MetricToPlot' => 'Mètrica a mostrar',
+	'General_RecordsToPlot' => 'Entrades a mostrar',
+	'General_Name' => 'Nom',
+	'General_Value' => 'Valor',
+	'General_Total' => 'Total',
+	'General_TotalVisitsActionsRevenue' => '(Total: %s visite, %s accions, %s ingressos)',
+	'General_AverageOrderValue' => 'Valor mig de les comandes',
+	'General_PurchasedProducts' => 'Productes comprats',
+	'General_EcommerceOrders' => 'Comandes d\'e-commerce',
+	'General_AbandonedCarts' => 'Cistelles abandonades',
+	'General_TotalRevenue' => 'Total Ingressos',
+	'General_ProductRevenue' => 'Ingressos de productes',
+	'General_AveragePrice' => 'Preu mig',
+	'General_AverageQuantity' => 'Qualitat mitja',
+	'General_UniquePurchases' => 'Compres úniques',
+	'General_ProductConversionRate' => 'Taxa de conversió del producte',
+	'General_Quantity' => 'Quantitat',
+	'General_Price' => 'Preu',
+	'General_Subtotal' => 'Subtotal',
+	'General_Tax' => 'Impostos',
+	'General_Shipping' => 'Enviament',
+	'General_Discount' => 'Descompte',
+	'General_Details' => 'Detalls',
+	'General_Default' => 'Per defecte',
+	'General_Visit' => 'Visita',
+	'General_FromReferrer' => 'de',
+	'General_VisitorIP' => 'Ip del visitant',
+	'General_VisitorID' => 'ID del visitant',
+	'General_VisitType' => 'Tipus de visitant',
+	'General_VisitTypeExample' => 'Per exemple, per seleccionar tots els visitants que han retornat al lloc web, incloent els que han comprat alguna cosa en anteriors visites, la petició de l\'API tindria %s',
+	'General_DaysSinceLastVisit' => 'Dies des de l\'última visita',
+	'General_DaysSinceFirstVisit' => 'Dies des de la primera visita',
+	'General_DaysSinceLastEcommerceOrder' => 'Dies des de la última comanda d\'e-commerce',
+	'General_NumberOfVisits' => 'Número de visites',
+	'General_VisitConvertedGoal' => 'La visita ha convertit al menys un objectiu',
+	'General_VisitConvertedGoalId' => 'La visita ha convertit un id d\'objectiu especific',
+	'General_EcommerceVisitStatus' => 'Visita l\'estat de l\'e-commerce al final de la visita. Per exempel, seleccionar totes les visites que han fet una comanda d\'e-commerce, la petició de l\'API tindrà %s',
+	'General_VisitConvertedNGoals' => 'La visita ha convertit %s objectius',
+	'General_NewVisitor' => 'Nova visita',
+	'General_NewVisits' => 'Noves visites',
+	'General_ReturningVisitor' => 'Visita que retorna',
+	'General_Visitor' => 'Visita',
+	'General_Date' => 'Data',
+	'General_Period' => 'Període',
+	'General_ChooseDate' => 'Triar data',
+	'General_Today' => 'Avui',
+	'General_Yesterday' => 'Ahir',
+	'General_CurrentWeek' => 'Setmana actual',
+	'General_CurrentMonth' => 'Mes actual',
+	'General_CurrentYear' => 'Any actual',
+	'General_DateRange' => 'Rang de dates:',
+	'General_DateRangeInPeriodList' => 'Rang de dates',
+	'General_DateRangeFromTo' => 'De %s fins a %s',
+	'General_ApplyDateRange' => 'Aplicar un rang de dates',
+	'General_InvalidDateRange_js' => 'Rang de dates no vàlid, si us plau proveu-ho de nou',
+	'General_DateRangeFrom_js' => 'De',
+	'General_DateRangeTo_js' => 'Fins',
+	'General_PreviousDays' => '%s dies anteriors (sense incloure avui)',
+	'General_LastDays' => 'Últims %s dies (incloent avui)',
 	'General_LoadingData' => 'Les dades s\'estan carregant…',
 	'General_Loading_js' => 'Carregant…',
+	'General_GoTo' => 'Anar a %s',
 	'General_Next' => 'Següent',
 	'General_Previous' => 'Anterior',
+	'General_First' => 'Primer',
 	'General_Search' => 'Cerca',
 	'General_Others' => 'Altres',
 	'General_Table' => 'Taula',
 	'General_Piechart' => 'Gràfic de sectors',
 	'General_TagCloud' => 'Núvol d\'etiquetes',
 	'General_VBarGraph' => 'Gràfic de barres',
+	'General_View' => 'Vista',
+	'General_OpenInNewWindow_js' => 'Obrir en una nova finestra',
+	'General_SaveImageOnYourComputer_js' => 'Per guardar la imatge al vostre ordinador, feu click amb el botó dret sobre la imatge i trieu "Guardar la imatge com.."',
 	'General_Refresh' => 'Actualitza la pàgina',
 	'General_Visitors' => 'Visitants',
+	'General_ExportThisReport' => 'Guardar aquestes dades en altres formats',
+	'General_ExportAsImage_js' => 'Exportar com a imatge',
 	'General_Export' => 'Exporta',
+	'General_ParameterMustIntegerBetween' => 'El paràmetre %s ha de ser un enter entre %s i %s',
+	'General_YourChangesHaveBeenSaved' => 'Els vostres canvis s\'han guardat',
 	'General_ErrorRequest' => 'Ups! Hi ha hagut un problema amb la sol·licitud, torneu-ho a intentar.',
 	'General_ColumnNbUniqVisitors' => 'Visitants únics',
+	'General_ColumnNbUniqVisitorsDocumentation' => 'El número de visitant únics que han vingut al vostre lloc web. Cada usuari es compta només una vegada, encara que visiti el lloc web més d\'un cop al dia.',
 	'General_ColumnNbVisits' => 'Visites',
+	'General_ColumnNbVisitsDocumentation' => 'Si la visita arriba al vostre lloc web per primera vegada o si obre una pàgina després de més de 30 minuts sense activitat, es comptarà com una nova visita.',
+	'General_ColumnPercentageVisits' => '% Visites',
 	'General_ColumnNbActions' => 'Accions',
+	'General_ColumnNbActionsDocumentation' => 'El número d\'accions que han realitzat els vostres visitant. Les accions poden ser pàgines vistes, descarregues o enllaços externs.',
+	'General_NbActions' => 'Número d\'accions',
 	'General_ColumnMaxActions' => 'Accions màximes en una visita',
 	'General_ColumnSumVisitLength' => 'Temps total acumulat pels visitants (en segons)',
 	'General_ColumnLabel' => 'Etiqueta',
+	'General_ColumnConversionRate' => 'Tarifa de conversió',
+	'General_ColumnConversionRateDocumentation' => 'El percentatge de visites que han disparat una conversió d\'objectiu.',
 	'General_ColumnActionsPerVisit' => 'Accions per visita',
+	'General_ColumnActionsPerVisitDocumentation' => 'El número mig d\'accions (pàgines vistes, descarregues o enllaços de sortida) que s\'han fet durant les visites.',
+	'General_VisitDuration' => 'Temps mig de visita (en segons)',
 	'General_ColumnAvgTimeOnSite' => 'Temps mitjà per visita',
+	'General_ColumnAvgTimeOnSiteDocumentation' => 'La durada mitja de una visita.',
+	'General_ColumnVisitDuration' => 'Durada de la visita (en segons)',
 	'General_ColumnBounceRate' => 'Raó de rebots',
+	'General_ColumnBounceRateDocumentation' => 'El percentatge de visites que només han vist una pàgina. Això significa, que el visitant ha marxat del lloc web directament per la pàgina d\'entrada.',
+	'General_ColumnBounceRateForPageDocumentation' => 'El percentatge de visites que han acabat en aquesta pàgina.',
+	'General_ColumnPageBounceRateDocumentation' => 'El percentatge de visites que han començat en aquesta pàgina i han deixat el lloc web directament.',
+	'General_ColumnExitRate' => 'Taxa de sortida',
+	'General_ColumnExitRateDocumentation' => 'El percentatge de visites que han deixat el lloc web després de veure aquesta pàgina.',
 	'General_ColumnPageviews' => 'Visualitzacions de pàgina',
+	'General_ColumnPageviewsDocumentation' => 'El número de vegades que s\'ha visitat aquesta pàgina.',
 	'General_ColumnUniquePageviews' => 'Visualitzacions de pàgina úniques',
+	'General_ColumnUniquePageviewsDocumentation' => 'El número de visites que incloïen aquesta pàgina. Si una pàgina s\'ha vist múltiples vegades durant una visita, només es compta un cop.',
+	'General_ColumnBounces' => 'Rebots',
+	'General_ColumnBouncesDocumentation' => 'El número de visites que han començat i acabat en aquesta pàgina. Això significa que la visita ha deixat el lloc web després de veure només aquesta pàgina.',
+	'General_ColumnUniqueEntrances' => 'Entrades úniques',
+	'General_ColumnEntrances' => 'Entrades',
+	'General_ColumnEntrancesDocumentation' => 'Número de visites que han començat en aquesta pàgina.',
+	'General_ColumnExits' => 'Sortides',
+	'General_ColumnUniqueExits' => 'Sortides úniques',
+	'General_ColumnExitsDocumentation' => 'Número de visites que acaben en aquesta pàgina.',
+	'General_ColumnAverageTimeOnPage' => 'Temps mig a la pàgina',
+	'General_ColumnAverageTimeOnPageDocumentation' => 'La mitjana de temps que els visitants s\'han passat en aquesta pàgina (només la pàgina no el lloc enter).',
 	'General_ColumnValuePerVisit' => 'Valor per visita',
 	'General_ColumnVisitsWithConversions' => 'Visites amb conversions',
+	'General_VisitsWith' => 'Visites amb %s',
+	'General_HoursMinutes' => '%1$s hores %2$s min',
+	'General_MinutesSeconds' => '%1$s min %2$ss',
+	'General_Seconds' => '%ss',
 	'General_Save' => 'Desa',
+	'General_Faq' => 'PMF',
+	'General_ForExampleShort' => 'p.ex.',
+	'General_YouMustBeLoggedIn' => 'Has d\'entrar per accedir a aquesta funcionalitat.',
 	'General_Website' => 'Lloc web',
+	'General_GeneralSettings' => 'Paràmetres generals',
+	'General_AllowPiwikArchivingToTriggerBrowser' => 'Permetre que l\'arxivat del Piwik es dispari quan els informes es veuen des del navegador',
+	'General_ArchivingInlineHelp' => 'Per llocs amb transit entre mig i alt, es recomana desactivar l\'arxivat del Piwik des del navegador. En canvi, recomanem que configureu una tasca de cron per processar els informes de Piwik cada hora.',
+	'General_ArchivingTriggerDescription' => 'Recomanat per instal·lacions grans de Piwik, es pot %sconfigurar una %stasca programada per processar les entrades automàticament.',
+	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Vegeu la %sinformació oficial%s per més informació.',
+	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Informes per avui (o un altre rang de dates incloent avui) es processaran com a molt cada',
+	'General_NSeconds' => '%s segons',
+	'General_SmallTrafficYouCanLeaveDefault' => 'Per llocs amb poc transit, pots deixar el valor per defecte de %s segons i accedir als informes en temps real.',
+	'General_RequiresFlash' => 'Mostrar gràfics en el Piwik requereix Flash',
 	'General_NoDataForGraph' => 'No hi ha dades...',
 	'General_NoDataForTagCloud' => 'No hi ha dades...',
+	'General_DisplaySimpleTable' => 'Mostrar una taula simple',
+	'General_DisplayTableWithMoreMetrics' => 'Mostrar una taula amb més paràmetres',
+	'General_DisplayTableWithGoalMetrics' => 'Mostrar una taula amb paràmetres globals',
 	'General_PiwikIsACollaborativeProjectYouCanContribute' => 'El %1$s Piwik %2$s és un projecte col·laboratiu. %3$s Si us agrada, podeu ajudar-nos! Mireu-vos %4$s Com col·laborar amb el Piwik (en anglès)%5$s',
+	'General_YouAreViewingDemoShortMessage' => 'Ara mateix estàs veient la demo del Piwik',
+	'General_YouAreCurrentlyUsing' => 'Ara mateix estàs fent servir el Piwik %s.',
+	'General_NewUpdatePiwikX' => 'Nova actualització: Piwik %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Hi ha una nova versió del Piwik, %1$s, disponible! %2$s Si us plau, actualitzeu ara!%3$s (%4$s Mostra els canvis%5$s)',
 	'General_BackToPiwik' => 'Torna al Piwik',
+	'General_ClickHere' => 'Fes clic aquí per més informació.',
 	'General_ShortMonth_1' => 'Gen',
 	'General_ShortMonth_2' => 'Feb',
 	'General_ShortMonth_3' => 'Mar',
@@ -96,6 +234,37 @@ $translations = array(
 	'General_LongDay_5' => 'divendres',
 	'General_LongDay_6' => 'dissabte',
 	'General_LongDay_7' => 'diumenge',
+	'General_Daily' => 'Diariament',
+	'General_Weekly' => 'Setmanalment',
+	'General_Monthly' => 'Mensualment',
+	'General_ConfigFileIsNotWritable' => 'El fitxer de configuració del Piwiki %s no es pot modificar, alguns dels canvis que has fet no es guardaran. Si us plau %s canvia els permisos del fitxer de configuració per tal que es pugui modificar.',
+	'General_ExceptionDatabaseVersion' => 'La teva %1$s versió és %s2$s però el Piwik necessita com a mínim %3$s',
+	'General_ExceptionMissingFile' => 'Falta fitxer: %s',
+	'General_ExceptionFileIntegrity' => 'Ha fallat la verificació de integritat: %s',
+	'General_ExceptionNonceMismatch' => 'No s\'ha pogut verificar el token del formulari.',
+	'General_ExceptionGoalNotFound' => 'L\'objectiu amb id = %s no s\'ha trobat.',
+	'General_ExceptionUndeletableFile' => 'No s\'ha pogut esborrar %s',
+	'General_ExceptionPrivilege' => 'No podeu accedir a aquest recurs perquè requereix un accés de %s',
+	'General_ExceptionLanguageFileNotFound' => 'El fitxer d\'idioma \'%s\' no s\'ha trobat.',
+	'General_ExceptionUnableToStartSession' => 'No s\'ha pogut començar la sessió.',
+	'General_UseSMTPServerForEmail' => 'Fer servir un servidor SMTP per el correu',
+	'General_SmtpServerAddress' => 'adreça del servidor SMTP',
+	'General_SmtpPort' => 'Port SMTP',
+	'General_AuthenticationMethodSmtp' => 'Mètode d\'autenticació SMTP',
+	'General_SmtpUsername' => 'usuari SMTP',
+	'General_SmtpPassword' => 'contrasenya SMTP',
+	'General_SmtpEncryption' => 'encriptació SMTP',
+	'General_InvalidResponse' => 'Les dades rebudes són invàlides.',
+	'General_ChooseLanguage' => 'Tria idioma',
+	'General_ChoosePeriod' => 'Triar període',
+	'General_ChooseWebsite' => 'Triar lloc web',
+	'General_Language' => 'Idioma',
+	'General_PleaseUpdatePiwik' => 'Si us plau actualitzeu el Piwik',
+	'General_UsePlusMinusIconsDocumentation' => 'Fes servir les icones de més i menys a l\'esquerra per navegar.',
+	'General_Recommended' => '(recomanat)',
+	'General_Goal' => 'Objectiu',
+	'General_Outlink' => 'Enllaç extern',
+	'General_Help' => 'Ajuda',
 	'Actions_Actions' => 'Accions',
 	'Actions_SubmenuPages' => 'Pàgines',
 	'Actions_SubmenuOutlinks' => 'Enllaços externs',
@@ -110,10 +279,7 @@ $translations = array(
 	'API_LoadedAPIs' => 'S\'ha carregat correctament un total de %s API',
 	'CoreHome_CategoryNoData' => 'No hi ha dades en aquesta categoria. Proveu d\'<em>incloure tota la població</em>.',
 	'CoreHome_ShowJSCode' => 'Mostra el codi JavaScript necessari',
-	'CoreHome_IncludeAllPopulation_js' => 'Inclou tota la població',
-	'CoreHome_ExcludeLowPopulation_js' => 'Exclou la població baixa',
 	'CoreHome_PageOf_js' => '%1$s de %2$s',
-	'CoreHome_DayFormat' => '%longDay%, %day% de %longMonth% de %longYear%',
 	'CoreHome_PeriodDay' => 'Dia',
 	'CoreHome_PeriodWeek' => 'Setmana',
 	'CoreHome_PeriodMonth' => 'Mes',
@@ -195,7 +361,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveEmpty' => 'Arxiu buit',
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'L\'arxiu és incomplet: manquen alguns fitxers (per exemple, %s).',
 	'Dashboard_Dashboard' => 'Tauler',
-	'Dashboard_AddWidget' => 'Afegeix un giny…',
 	'Dashboard_DeleteWidgetConfirm' => 'Realment voleu esborrar aquest giny?',
 	'Dashboard_SelectWidget' => 'Escolliu el giny que voleu afegir a la consola',
 	'Dashboard_AddPreviewedWidget_js' => 'Afegeix el giny al tauler',
@@ -560,8 +725,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Illa de la Reunió',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Rússia',
 	'UserCountry_country_rs' => 'Sèrbia',
+	'UserCountry_country_ru' => 'Rússia',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Aràbia Saudita',
 	'UserCountry_country_sb' => 'Illes Salomó',
@@ -705,7 +870,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'Resum de les visites',
 	'VisitsSummary_NbVisits' => '%s visites',
 	'VisitsSummary_NbUniqueVisitors' => '%s visitants únics',
-	'VisitsSummary_NbActions' => '%s accions (pàgines vistes)',
 	'VisitsSummary_MaxNbActions' => 'Hi ha %s accions màximes en una visita',
 	'VisitsSummary_NbVisitsBounced' => '%s visites han rebotat (abandonat el lloc després de veure una pàgina)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolució dels darrers %s',
