@@ -8,16 +8,18 @@ $translations = array(
 	'General_HelloUser' => 'Ahoj, %s!',
 	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
 	'General_Dashboard' => 'Nástěnka',
-	'General_DashboardForASpecificWebsite' => 'Nástěnka pro určitou stránku',
+	'General_DashboardForASpecificWebsite' => 'Nástěnka pro vybrané sídlo',
 	'General_MultiSitesSummary' => 'Všechna sídla',
 	'General_AllWebsitesDashboard' => 'Nástěnka pro všechna sídla',
 	'General_API' => 'API',
 	'General_Widgets' => 'Widgety',
 	'General_Settings' => 'Nastavení',
-	'General_GiveUsYourFeedback' => 'Zanechejte nám odezvu!',
+	'General_GiveUsYourFeedback' => 'Zanechejte nám zpětnou vazbu!',
 	'General_Unknown' => 'Neznámý',
+	'General_Never' => 'Nikdy',
 	'General_Required' => '%s požadováno',
 	'General_NotValid' => '%s není platné',
+	'General_NotDefined' => '%s není definováno',
 	'General_Id' => 'ID',
 	'General_Error' => 'Chyba',
 	'General_Warning' => 'Varování',
@@ -26,56 +28,88 @@ $translations = array(
 	'General_No' => 'Ne',
 	'General_Delete' => 'Vymazat',
 	'General_Report' => 'Hlášení',
+	'General_Reports' => 'Hlášení',
 	'General_Edit' => 'Upravit',
 	'General_Download' => 'Stáhnout',
-	'General_Ok' => 'Ok',
+	'General_Upload' => 'Nahrát',
+	'General_Ok' => 'OK',
 	'General_Close' => 'Zavřít',
-	'General_OrCancel' => 'nebo %s Storno %s',
+	'General_OrCancel' => 'nebo %s Zrušit %s',
 	'General_Logout' => 'Odhlásit se',
 	'General_Username' => 'Uživatelské jméno',
 	'General_Description' => 'Popis',
 	'General_Done' => 'Hotovo',
 	'General_Name' => 'Jméno',
 	'General_Value' => 'Hodnota',
+	'General_Total' => 'Celkem',
+	'General_PurchasedProducts' => 'Zakoupené produkty',
+	'General_EcommerceOrders' => 'Elektronické objednávky',
+	'General_AveragePrice' => 'Průměrná cena',
+	'General_AverageQuantity' => 'Průměrné množství',
+	'General_UniquePurchases' => 'Jedineční nakupující',
+	'General_Quantity' => 'Množství',
+	'General_Price' => 'Cena',
+	'General_Subtotal' => 'Mezisoučet',
+	'General_Tax' => 'Daň',
+	'General_Discount' => 'Sleva',
 	'General_Details' => 'Detaily',
 	'General_Default' => 'Výchozí',
+	'General_Visit' => 'Návštěva',
+	'General_FromReferrer' => 'z',
+	'General_VisitorIP' => 'IP návštěvníka',
+	'General_VisitType' => 'Typ návštěvníka',
+	'General_DaysSinceLastVisit' => 'Dnů od poslední návštěvy',
+	'General_DaysSinceFirstVisit' => 'Dnů od první návštěvy',
+	'General_DaysSinceLastEcommerceOrder' => 'Dnů od poslední elektronické objednávky',
+	'General_NumberOfVisits' => 'Počet návštěv',
+	'General_NewVisitor' => 'Nový návštěvník',
+	'General_NewVisits' => 'Nové návštěvy',
+	'General_Visitor' => 'Návštěvník',
 	'General_Date' => 'Datum',
-	'General_Period' => 'Perioda',
+	'General_Period' => 'Období',
+	'General_ChooseDate' => 'Vyber datum',
 	'General_Today' => 'Dnes',
 	'General_Yesterday' => 'Včera',
 	'General_CurrentWeek' => 'Tento týden',
 	'General_CurrentMonth' => 'Tento měsíc',
 	'General_CurrentYear' => 'Tento rok',
-	'General_DateRange' => 'Data',
+	'General_DateRangeFromTo' => 'Od %s do %s',
+	'General_DateRangeFrom_js' => 'Od',
+	'General_DateRangeTo_js' => 'Do',
+	'General_LastDays' => 'Posledních %s dní (včetně dnes)',
 	'General_LoadingData' => 'Načítám data...',
 	'General_Loading_js' => 'Načítám...',
 	'General_GoTo' => 'Jdi na %s',
 	'General_Next' => 'Další',
 	'General_Previous' => 'Předchozí',
+	'General_First' => 'První',
 	'General_Search' => 'Hledat',
 	'General_Others' => 'Ostatní',
 	'General_Table' => 'Tabulka',
 	'General_Piechart' => 'Koláčový graf',
 	'General_TagCloud' => 'Oblak tagů',
-	'General_VBarGraph' => 'Svislý graf',
+	'General_VBarGraph' => 'Svislý sloupcový graf',
+	'General_OpenInNewWindow_js' => 'Otevřít nové okno',
 	'General_SaveImageOnYourComputer_js' => 'K uložení obrázku na váš počítač klikněte na obrázek pravým tlačítkem myši a zvolte "Uložit obrázek jako..."',
 	'General_Refresh' => 'Obnovit stránku',
 	'General_Visitors' => 'Návštěvníci',
 	'General_ExportThisReport' => 'Exportovat data v ostatních formátech',
 	'General_ExportAsImage_js' => 'Exportovat obrázek',
 	'General_Export' => 'Exportovat',
+	'General_ParameterMustIntegerBetween' => 'Proměnná %s musí být číselná hodnota mezi %s a %s.',
 	'General_YourChangesHaveBeenSaved' => 'Vaše změny byly uloženy',
-	'General_ErrorRequest' => 'Oops… behěm požadavku se vyskytla chyba, prosím vyzkoušejte jej znovu',
+	'General_ErrorRequest' => 'Jej... během požadavku se vyskytla chyba, prosím zkuste to znovu.',
 	'General_ColumnNbUniqVisitors' => 'Jedineční návštěvníci',
 	'General_ColumnNbVisits' => 'Návštěv',
 	'General_ColumnPercentageVisits' => '% návštěv',
 	'General_ColumnNbActions' => 'Akce',
+	'General_NbActions' => 'Počet akcí',
 	'General_ColumnMaxActions' => 'Maximální počet akcí při jedné návštěvě',
-	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštěvníky ( v sekundách )',
+	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštěvníky (v sekundách)',
 	'General_ColumnLabel' => 'Popisek',
 	'General_ColumnConversionRate' => 'Frekvence konverzí',
 	'General_ColumnActionsPerVisit' => 'Akcí za návštěvu',
-	'General_VisitDuration' => 'Průměrna doba trvání návštěv (v sekundách)',
+	'General_VisitDuration' => 'Průměrná doba trvání návštěv (v sekundách)',
 	'General_ColumnAvgTimeOnSite' => 'Průměrně času na stránkách',
 	'General_ColumnBounceRate' => 'Odchozí frekvence',
 	'General_ColumnExitRate' => 'Frekvence odchodů',
@@ -154,30 +188,30 @@ $translations = array(
 	'General_LongDay_7' => 'Neděle',
 	'General_Daily' => 'Denně',
 	'General_Weekly' => 'Týdně',
-	'General_Monthly' => 'Měsíčne',
+	'General_Monthly' => 'Měsíčně',
 	'General_ConfigFileIsNotWritable' => 'Konfigurační soubor Piwiku %s není zapisovatelný, některé změny nebudou uloženy. %s Prosím upravte oprávnění ke konfiguračnímu souboru',
 	'General_ExceptionDatabaseVersion' => 'Vaše %1$s verze je %2$s ale Piwik vyžaduje minimálně %3$s.',
 	'General_ExceptionIncompatibleClientServerVersions' => 'Vaše %1$s verze klienta je %2$s tato je ale nekompatibilní se serverem %3$s.',
 	'General_ExceptionMissingFile' => 'Chybějící soubor: %s',
-	'General_ExceptionFilesizeMismatch' => 'Nesouhlasí velikost souboru: %1$s (očekávaná dělka: %2$s, nalezeno: %3$s)',
+	'General_ExceptionFilesizeMismatch' => 'Nesouhlasí velikost souboru: %1$s (očekávaná délka: %2$s, nalezeno: %3$s)',
 	'General_ExceptionFileIntegrity' => 'Test integrity selhal: %s',
 	'General_ExceptionNonceMismatch' => 'Nemůžu ověřit bezpečnostní token tohoto formuláře',
 	'General_PleaseSpecifyValue' => 'Prosím zapiště hodnotu pro \'%s\'.',
 	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' neexistuje nebo není dostupná v modulu \'%s\'.',
 	'General_ExceptionInvalidRendererFormat' => 'Formát rendereru \'%s\' není platný. Vyzkoušejte nějaký jiný místo: %s.',
 	'General_ExceptionInvalidPeriod' => 'Perioda \'%s\' není podporovaná. Vyzkoušejte nějakou z následujících místo: %s.',
-	'General_ExceptionInvalidDateRange' => 'Datum \'%s\' není v platném rozmězí. Může mít následující formát: %s.',
+	'General_ExceptionInvalidDateRange' => 'Datum \'%s\' není v platném rozmezí. Může mít následující formát: %s.',
 	'General_ExceptionGoalNotFound' => 'Cíl id = %s nenalezen',
 	'General_ExceptionUndeletableFile' => 'Nelze vymazat soubor %s',
-	'General_ExceptionPrivilege' => 'Nemůžete přístupovat k tomuto zdroji, protože vyžaduje oprávnění %s.',
+	'General_ExceptionPrivilege' => 'Nemůžete přistupovat k tomuto zdroji, protože vyžaduje oprávnění %s.',
 	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Nemůžete přistupovat k tomuto zdroji, protože vyžaduje oprávnění %s alespoň pro jedno sídlo',
 	'General_ExceptionInvalidArchiveTimeToLive' => 'Dnešní doba života archivu musí být číslo větší než nula',
 	'General_ExceptionConfigurationFileNotFound' => 'Konfigurační soubor {%s} nebyl nalezen',
-	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfigurační soubor {%s} je nečitelny. Host může být zakázán %s.',
+	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfigurační soubor {%s} je nečitelný. Host může být zakázán %s.',
 	'General_ExceptionInvalidToken' => 'Token je neplatný',
 	'General_ExceptionInvalidDateFormat' => 'Formát data musí být: %s nebo klíčové slovo podporované funkcí %s (více informací viz %s)',
 	'General_ExceptionLanguageFileNotFound' => 'Jazykový soubor \'%s\' nenalezen',
-	'General_WarningFileIntegritySkipped' => 'Detekováno vývojařské nastavení. Test integrity souboru vynechán',
+	'General_WarningFileIntegritySkipped' => 'Detekováno vývojářské nastavení. Test integrity souboru vynechán',
 	'General_WarningFileIntegrityNoManifest' => 'Test integrity nemůže být proveden z důvodů chybějícího souboru manifest.inc.php.',
 	'General_WarningFileIntegrityNoMd5file' => 'Test integrity nemůže být dokončen z důvodů chybějící funkce md5_file().',
 	'General_FileIntegrityWarningExplanation' => 'Test integrity selhal a nahlásil nějaké chyby. To je díky částečně nebo špatně nahraným souborům Piwiku. Měli byste znova nahrát všechny soubory Piwiku v módu BINARY.',
@@ -187,14 +221,15 @@ $translations = array(
 	'General_AuthenticationMethodSmtp' => 'Autentizační metoda SMTP',
 	'General_SmtpUsername' => 'Uživatelské jméno SMTP',
 	'General_SmtpPassword' => 'Heslo SMTP',
+	'General_SmtpEncryption' => 'SMTP šifrování',
 	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Zvolte "Ano" pokud chcete e-mail posílat pomocí uvedeného serveru místo lokální funkce PHP mail',
 	'General_OnlyUsedIfUserPwdIsSet' => 'Použito pouze v případě, že je nastaveno uživatelské jméno/heslo. V případě že si nejste jisti jakou metodu použít, zeptejte se vašeho poskytovatele',
 	'General_OnlyEnterIfRequired' => 'Uživatelské jméno zadejte pouze v případě, že jej váš SMTP server vyžaduje',
 	'General_OnlyEnterIfRequiredPassword' => 'Heslo zadejte pouze v případě, že jej váš SMTP server vyžaduje',
-	'General_WarningPasswordStored' => '%sUporoznění:%s Toto heslo bude uloženo v konfiguračním souboru viditelné pro všechny s přístupem k němiu',
-	'General_InvalidResponse' => 'Obdržená data jsou neplatná',
+	'General_WarningPasswordStored' => '%sUpozornění:%s Toto heslo bude uloženo v konfiguračním souboru viditelné pro všechny s přístupem k němu.',
+	'General_InvalidResponse' => 'Obdržená data jsou neplatná.',
 	'General_ChooseLanguage' => 'Zvolte jazyk',
-	'General_ChoosePeriod' => 'Zvolte periodu',
+	'General_ChoosePeriod' => 'Zvolte období',
 	'General_ChooseWebsite' => 'Zvolte sídlo',
 	'General_Language' => 'Jazyk',
 	'General_PleaseUpdatePiwik' => 'Prosím aktualizujte Piwik',
@@ -232,10 +267,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Pro toto hlášení nejsou k dispozici žádná data',
 	'CoreHome_CategoryNoData' => 'V této kategorii nejsou k dispozici žádná data. Zkuste "Zobrazit všechny výsledky".',
 	'CoreHome_ShowJSCode' => 'Zobrazit JavaScriptový kód ke vložení',
-	'CoreHome_IncludeAllPopulation_js' => 'Zobrazit všechny výsledky',
-	'CoreHome_ExcludeLowPopulation_js' => 'Vynechat nízké výsledky',
 	'CoreHome_PageOf_js' => '%s z %s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'Den',
 	'CoreHome_PeriodWeek' => 'Týden',
 	'CoreHome_PeriodMonth' => 'Měsíc',
@@ -353,7 +385,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archív je nekompletní: některé soubory chybí (např.: %s).',
 	'Dashboard_PluginDescription' => 'Váše nástěnka analýzy Web stránek. Můžete si jí upravit: přidat nové widgety, změnit jejich pořadí. Každý uživatel přistupuje ke své vlastní nástěncei',
 	'Dashboard_Dashboard' => 'Nástěnka',
-	'Dashboard_AddWidget' => 'Přidat widget...',
 	'Dashboard_DeleteWidgetConfirm' => 'Jste si jistí, že chcete odstranit tento widget z nástěnky?',
 	'Dashboard_SelectWidget' => 'Zvolte widget pro přidání na nástěnku',
 	'Dashboard_AddPreviewedWidget_js' => 'Přidat widget v náhledu na nástěnku',
@@ -592,7 +623,6 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'Mobile_AccessUrlLabel' => 'Přístupová URL Piwiku',
 	'Mobile_EnableGraphsLabel' => 'Zobrazit grafy',
 	'Mobile_MultiChartLabel' => 'Zobrazit multi grafy',
-	'Mobile_MultiChartInfo' => 'dále ke každému sídlu na uvítací obrazovce',
 	'Mobile_NetworkNotReachable' => 'Síť je nedosažitelná',
 	'Mobile_SaveSuccessError' => 'Prosím zkontrolujte si vaše nastavení',
 	'Mobile_YouAreOffline' => 'Omlouváme se, momentálně jste offline',
@@ -609,7 +639,6 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'Referers_DirectEntry' => 'Přímy vstup',
 	'Referers_Websites' => 'Web sídla',
 	'Referers_Campaigns' => 'Kampaně',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (z %2$s)',
 	'Referers_Evolution' => 'Vývoj za periodu',
 	'Referers_Type' => 'Typ refereru',
 	'Referers_ColumnRefererType' => 'Typ refereru',
@@ -642,11 +671,9 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'SecurityInfo_SecurityInformation' => 'Informace o zabezpečení PHP',
 	'SecurityInfo_Test' => 'Test',
 	'SecurityInfo_Result' => 'Výsledek',
-	'SEO_SeoRankings' => 'Hdnocení SEO',
+	'SEO_SeoRankings' => 'Hodnocení SEO',
 	'SEO_AlexaRank' => 'Hodnocení Alexa',
-	'SEO_YahooIndexedPages' => 'Idexované stránky Yahoo',
 	'SEO_DomainAge' => 'Staří domény',
-	'SEO_YahooBacklinks' => 'Zpětné odkazy Yahoo',
 	'SEO_Rank' => 'Hodnocení',
 	'SEO_Backlinks' => 'Zpětné odkazy',
 	'SEO_Pages' => 'Stránky',
@@ -916,8 +943,8 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Reunion Island',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Russia',
 	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_ru' => 'Russia',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudi Arabia',
 	'UserCountry_country_sb' => 'Solomon Islands',
@@ -1106,7 +1133,6 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'VisitsSummary_VisitsSummary' => 'Shrnutí návštěv',
 	'VisitsSummary_NbVisits' => '%s návštěv',
 	'VisitsSummary_NbUniqueVisitors' => '%s unikátních návštěvníků',
-	'VisitsSummary_NbActions' => '%s akcí (zobrazení stránky)',
 	'VisitsSummary_NbActionsDescription' => '%s akcí (zobrazení stránek, stažení a odchodů)',
 	'VisitsSummary_AverageVisitDuration' => '%s průměrná doba návštěvy',
 	'VisitsSummary_MaxNbActions' => '%s maximální počet akcí na návštěvu',
@@ -1129,17 +1155,20 @@ Poznámka: tento klíč expiruje za 24 hodin.',
 	'VisitTime_WidgetServerTime' => 'Návštěvy podle serverového času',
 	'VisitTime_SubmenuTimes' => 'Časy',
 	'VisitTime_NHour' => '%sh',
-	'Widgetize_PluginDescription' => 'Tento plugin zjednodušuje export widgetů Piwiku na váš blog, sídlo nebo Igoogle and Netvibes!',
+	'Widgetize_PluginDescription' => 'Tento plugin zjednodušuje export widgetů Piwiku na váš blog, sídlo nebo Igoogle a Netvibes!',
 	'PDFReports_EmailReports' => 'Poslat reporty na e-mail',
 	'PDFReports_PDF' => 'PDF',
 	'PDFReports_SendReportNow' => 'Odeslat report ihned',
 	'PDFReports_EmailSchedule' => 'Plánování zasílání reportů',
 	'PDFReports_SendReportTo' => 'Odeslat report',
-	'PDFReports_SentToMe' => 'Odeslat report mi',
-	'PDFReports_WeeklyScheduleHelp' => 'Týdenní plán: hlšení bude odesláno každé pondělí',
+	'PDFReports_SentToMe' => 'Odeslat report mně',
+	'PDFReports_WeeklyScheduleHelp' => 'Týdenní plán: hlášení bude odesláno každé pondělí',
 	'PDFReports_MonthlyScheduleHelp' => 'Měsíční plán: hlášení bude odesláno první den měsíce',
 	'PDFReports_AlsoSendReportToTheseEmails' => 'Odesílat hlášení také na tyto e-maily (jeden e-mail na řádek):',
 	'PDFReports_PiwikReports' => 'Hlášení Piwiku',
 	'PDFReports_EmailHello' => 'Ahoj,',
-	'PDFReports_PleaseFindAttachedFile' => 'Prosím najděte si v přiloženém souboru %1$s hlášení pro %2$s',
+	'PDFReports_PleaseFindAttachedFile' => 'Prosím najděte v přiloženém souboru %1$s hlášení pro %2$s',
+	'PDFReports_FrontPage' => 'Hlavní strana',
+	'PDFReports_TopOfReport' => 'Zpět nahoru',
+	'PDFReports_Pagination' => 'Stránka %s z %s',
 );
