@@ -1,14 +1,13 @@
-<?php 
+<?php
 $translations = array(
 	'General_Locale' => 'et_ET.UTF-8',
 	'General_TranslatorName' => 'Kaido Toomingas',
 	'General_TranslatorEmail' => 'toomingas.k@gmail.com',
 	'General_EnglishLanguageName' => 'Estonian',
 	'General_OriginalLanguageName' => 'Eesti keel',
-	'General_Settings' => 'Seaded',
-	'General_YourDashboard' => 'Töölaud',
 	'General_API' => 'API',
 	'General_Widgets' => 'Moodulid',
+	'General_Settings' => 'Seaded',
 	'General_GiveUsYourFeedback' => 'Tagasiside!',
 	'General_Unknown' => 'Tundmatu',
 	'General_Required' => '%s on nõutav',
@@ -24,7 +23,6 @@ $translations = array(
 	'General_Logout' => 'Logi välja',
 	'General_Done' => 'Tehtud',
 	'General_LoadingData' => 'Laen infot...',
-	'General_ErrorRequest' => 'Oops&hellip; nõude esitamisel tekkis viga, palun proovi uuesi.',
 	'General_Next' => 'Järgmine',
 	'General_Previous' => 'Eelmine',
 	'General_Search' => 'Otsi',
@@ -33,9 +31,10 @@ $translations = array(
 	'General_Piechart' => 'Sektordiagramm',
 	'General_TagCloud' => 'sildipilv',
 	'General_VBarGraph' => 'Vertikaaltulbad',
-	'General_Export' => 'Expordi',
 	'General_Refresh' => 'Värskenda lehte',
 	'General_Visitors' => 'Külastajad',
+	'General_Export' => 'Expordi',
+	'General_ErrorRequest' => 'Oops… nõude esitamisel tekkis viga, palun proovi uuesi.',
 	'General_ColumnNbUniqVisitors' => 'Unikaalsed külastajad',
 	'General_ColumnNbVisits' => 'Külastused',
 	'General_ColumnLabel' => 'Tiitel',
@@ -43,34 +42,14 @@ $translations = array(
 	'General_Website' => 'Veebileht',
 	'General_NoDataForGraph' => 'Graafik - infot pole veel',
 	'General_NoDataForTagCloud' => 'Sildipilv - Infot ei ole veel.',
-	'General_PiwikIsACollaborativeProject' => '%s Piwik %s on pidevalt arenev koostööl põhinev projekt. %s Kui sa tahad aidata palun %s võta ühendust!%s.',
-	'CorePluginsAdmin_Plugins' => 'Pluginad',
-	'CorePluginsAdmin_PluginsManagement' => 'Pluginate haldus',
-	'CorePluginsAdmin_MainDescription' => 'Plugins võimendavad ja suurendavad Piwik-i funktsionaalsust. Kui plugin on installeeritud ja aktiveeritud saad seda sisse ja välja lülitada siin.',
-	'CorePluginsAdmin_Plugin' => 'Plugin',
-	'CorePluginsAdmin_Version' => 'Versioon',
-	'CorePluginsAdmin_Description' => 'Kirjeldus',
-	'CorePluginsAdmin_Status' => 'Olek',
-	'CorePluginsAdmin_Action' => 'Tegevus',
-	'CorePluginsAdmin_PluginHomepage' => 'Plugina koduleht',
-	'CorePluginsAdmin_Activated' => 'Aktiveeritud',
-	'CorePluginsAdmin_Active' => 'Aktiivne',
-	'CorePluginsAdmin_Inactive' => 'Mitteaktiivne',
-	'CorePluginsAdmin_ActivatedHelp' => 'Seda pluginat ei saa välja lülitada',
-	'CorePluginsAdmin_Deactivate' => 'Lülita välja',
-	'CorePluginsAdmin_Activate' => 'Aktiveeri',
-	'CorePluginsAdmin_MenuPlugins' => 'Pluginad',
-	'API_QuickDocumentation' => '<h2>API quick documentation</h2><p>If you don\'t have data for today you can first <a href=\'misc/generateVisits.php\' target=_blank>generate some data</a> using the Visits Generator script.</p><p>You can try the different formats available for every method. It is very easy to extract any data you want from piwik!</p><p><b>For more information have a look at the <a href=\'http://dev.piwik.org/trac/wiki/API\'>official API Documentation</a> or the <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>User authentication</h2><p>If you want to <b>request the data in your scripts, in a crontab, etc. </b> you need to add the parameter <code><u>&token_auth=%s</u></code> to the API calls URLs that require authentication.</p><p>This token_auth is as secret as your login and password, <b>do not share it!</p>',
+	'Actions_Actions' => 'Tegevused',
+	'Actions_SubmenuPages' => 'Vaadatud lehed',
+	'Actions_SubmenuOutlinks' => 'Väljuvad lingid',
+	'Actions_SubmenuDownloads' => 'Allalaadimised',
 	'API_LoadedAPIs' => 'Edukalt laetud %s API-id',
-	'CoreHome_NoPrivileges' => 'Sa oled sisse loginud \'%s\', kuid tundub, et sul puuduvad õigused vaatamaks informatsiooni.<br />Palun teata administraatorile, et ta annaks sulle veebianalüütika \'view\' õigused.',
-	'CoreHome_TableNoData' => 'Info puudub.',
 	'CoreHome_CategoryNoData' => 'Informatsioon puudub selles kategoorias. Proovi "Include all population".',
 	'CoreHome_ShowJSCode' => 'Näita sisestatavat javaacript koodi',
-	'CoreHome_IncludeAllPopulation_js' => 'Include all population',
-	'CoreHome_ExcludeLowPopulation_js' => 'Exclude low population',
 	'CoreHome_PageOf_js' => '%1$s - %2$s',
-	'CoreHome_Loading_js' => 'Laen...',
-	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
 	'CoreHome_PeriodDay' => 'Päev',
 	'CoreHome_PeriodWeek' => 'Nädal',
 	'CoreHome_PeriodMonth' => 'Kuu',
@@ -120,10 +99,22 @@ $translations = array(
 	'CoreHome_MonthOctober_js' => 'Oktoober',
 	'CoreHome_MonthNovember_js' => 'November',
 	'CoreHome_MonthDecember_js' => 'Detsember',
-	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Uuendus',
-	'CoreUpdater_UpdateRequired' => 'Uuuendamine nõutav',
+	'CorePluginsAdmin_Plugins' => 'Pluginad',
+	'CorePluginsAdmin_PluginsManagement' => 'Pluginate haldus',
+	'CorePluginsAdmin_MainDescription' => 'Plugins võimendavad ja suurendavad Piwik-i funktsionaalsust. Kui plugin on installeeritud ja aktiveeritud saad seda sisse ja välja lülitada siin.',
+	'CorePluginsAdmin_Plugin' => 'Plugin',
+	'CorePluginsAdmin_Version' => 'Versioon',
+	'CorePluginsAdmin_Status' => 'Olek',
+	'CorePluginsAdmin_Action' => 'Tegevus',
+	'CorePluginsAdmin_PluginHomepage' => 'Plugina koduleht',
+	'CorePluginsAdmin_Activated' => 'Aktiveeritud',
+	'CorePluginsAdmin_Active' => 'Aktiivne',
+	'CorePluginsAdmin_Inactive' => 'Mitteaktiivne',
+	'CorePluginsAdmin_Deactivate' => 'Lülita välja',
+	'CorePluginsAdmin_Activate' => 'Aktiveeri',
+	'CorePluginsAdmin_MenuPlugins' => 'Pluginad',
+	'CoreUpdater_UpdateTitle' => 'Piwik › Uuendus',
 	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Sinu piwik-i andmebaas on vananenud, enne jätkamist pead uuendama.',
-	'CoreUpdater_PiwikWillBeUpgradedToVersionX' => 'Piwik uuendatatakse %s versioonile.',
 	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Käesolevad puginad uuendatakse: %s.',
 	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Uuendamise protsess võtab veidi aega, palun ole kannatlik.',
 	'CoreUpdater_UpgradePiwik' => 'Uuenda Piwik',
@@ -137,70 +128,106 @@ $translations = array(
 	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Lülitame automaatselt välja järgnevalt pluginad: %s',
 	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik edukalt uuendatud!',
 	'CoreUpdater_ContinueToPiwik' => 'Jätka Piwikiga',
-	'Actions_Actions' => 'Tegevused',
-	'Actions_SubmenuPages' => 'Vaadatud lehed',
-	'Actions_SubmenuOutlinks' => 'Väljuvad lingid',
-	'Actions_SubmenuDownloads' => 'Allalaadimised',
 	'Dashboard_Dashboard' => 'Töölaud',
-	'Dashboard_AddWidget' => 'Lisa moodul...',
 	'Dashboard_DeleteWidgetConfirm' => 'Oled sa kindel selle mooduli kustutamises oma töölaualt?',
 	'Dashboard_SelectWidget' => 'Vali töölauale lisatav moodul',
-	'Dashboard_AddPreviewedWidget' => 'Lisa vaadeldud moodul töölauale',
-	'Dashboard_WidgetPreview' => 'Mooduli eelvaade',
 	'Dashboard_TitleWidgetInDashboard_js' => 'Moodul on juba töölaual',
 	'Dashboard_TitleClickToAdd_js' => 'Kliki lisamaks töölauale',
-	'Dashboard_LoadingPreview_js' => 'Laen eelvaadet, palun oota...',
 	'Dashboard_LoadingWidget_js' => 'Laen moodulit, palun oota...',
 	'Dashboard_WidgetNotFound_js' => 'Moodulit ei leitud',
+	'DBStats_DatabaseUsage' => 'Andmebaasi kasutus',
+	'DBStats_MainDescription' => 'Piwik salvestab kõik veebianalüütika andmed Mysql andmebaasi. Hetkel, Piwiki tabelid kasutavad %s.',
+	'DBStats_Table' => 'Tabel',
+	'DBStats_DataSize' => 'Andmemaht',
+	'DBStats_IndexSize' => 'Indeksi maht',
+	'Installation_Installation' => 'Installatsioon',
+	'Installation_InstallationStatus' => 'Installatiooni olek',
+	'Installation_PercentDone' => '%s %% Tehtud',
+	'Installation_NoConfigFound' => 'Piwiki konfguratsioonifaili ei leitud, kuid sa üritasid minna Piwiki lehele.<br /><b>  » Võid <a href=\'index.php\'>installeerida Piwiko</a></b><br /><small>Kui Piwik on varem installeeritud ja sul on andmebaasis tabeleid, siis ei ole põhjust muretsemiseks saad taaskasutada ja säilitada olemasolevad andmed!</small>',
+	'Installation_JsTag' => 'Javascript tag',
+	'Installation_Congratulations' => 'Õnnitleme',
+	'Installation_CongratulationsHelp' => '<p>Õnnitlused! Sinu Piwiki Installatsioon on edukalt lõpuni viidud.</p><p>Sisesta javascript kood oma lehele ja jää külastusi ootama!</p>',
+	'Installation_SetupWebsite' => 'Seadista veebileht',
+	'Installation_SetupWebsiteError' => 'Veebilehe lisamisel tekkis viga',
+	'Installation_SystemCheck' => 'Süsteemi kontroll',
+	'Installation_SystemCheckPhp' => 'PHP versioon',
+	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
+	'Installation_SystemCheckWriteDirsHelp' => 'Parandamaks seda viga linux süsteemis, trüki sisse käsk/käsud.',
+	'Installation_SystemCheckMemoryLimit' => 'Mälu limiit',
+	'Installation_SystemCheckMemoryLimitHelp' => 'Suure liiklusega veebileht võib vajada arhiveerimiseks rohkem mälu, kui hetkel lubatud.<br />Vaata üle oma memory_limit oma php.ini failis, kui see osutub vajalikuks.',
+	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
+	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
+	'Installation_SystemCheckTimeLimitHelp' => 'Suure liiklusega veebilehe puhul, või arhiveerimisprotssess võtta rohkem aega, kui hetkel lubatud.<br />Vaata direktiiv max_execution_time  oma php.ini failis, kui see on vajalik',
+	'Installation_SystemCheckError' => 'Ilmnes viga - Enne jätkamist tuleb see parandada.',
+	'Installation_SystemCheckWarning' => 'Piwik toimib normaalselt, kuid osad võimalused võivad puududa.',
+	'Installation_Tables' => 'Tabelite loomine',
+	'Installation_TablesFound' => 'Andmebaasist leiti järgnevad tabelid',
+	'Installation_TablesWarningHelp' => 'Nüüd saad valida, kas kasutad olemasolevaid tabeleid ja andmeid või lood uued tabelid.',
+	'Installation_TablesReuse' => 'Taaskasuta olemasolevaid tabeleid',
+	'Installation_TablesDelete' => 'Kustuta leitud tabelid',
+	'Installation_TablesDeletedSuccess' => 'Olemasolevad tabelid kustutatud',
+	'Installation_TablesCreatedSuccess' => 'Tabelid loodud!',
+	'Installation_DatabaseCreatedSuccess' => '%s andmebaas loodud!',
+	'Installation_Welcome' => 'Tere tulemast!',
+	'Installation_WelcomeHelp' => '<p>Piwik on vabavaraline veebianalüüika tarkvara, mis teeb lihtsaks oma külastajate kohta andmete kogumise ja nende analüüsimise.</p><p>See protsess sisaldab %s sammu ja võtab aega u. 5 minutit.</p>',
+	'Login_LoginPasswordNotCorrect' => 'Kasutajanimi & salasõna olid valed',
+	'Login_Password' => 'Salasõna',
+	'Login_LoginOrEmail' => 'Kasutajanimi või E-mail',
+	'Login_LogIn' => 'Sisene',
+	'Login_Logout' => 'Välju',
+	'Login_LostYourPassword' => 'Kaotasid oma salasõna?',
+	'Login_RemindPassword' => 'Meenuta salasõna',
+	'Login_PasswordReminder' => 'Palun sisesta kasutaja või e-mail address. Sulle saadetakse salasõna e-mailiga.',
+	'Login_InvalidUsernameEmail' => 'Vale kasutajanimi ja/või e-maili address',
+	'Login_MailTopicPasswordRecovery' => 'Salasõna taastamine',
+	'Login_PasswordSent' => 'Salasõna saadetud. Kontrolli oma e-maili.',
+	'Login_ContactAdmin' => 'Võimalik põhjus: sinu majutusel on mail() funktsioon välja lülitatud. <br />Palun kontakteeru administraatoriga.',
+	'Provider_WidgetProviders' => 'Pakkujad',
+	'Provider_SubmenuLocationsProvider' => 'Asukoht & pakkuja',
 	'Referers_Referers' => 'Viitajad',
 	'Referers_SearchEngines' => 'Otsingumootorid',
 	'Referers_Keywords' => 'Võtmesõnad',
 	'Referers_DirectEntry' => 'Otse sisenetud',
 	'Referers_Websites' => 'Veebilehed',
-	'Referers_Partners' => 'Partnerid',
-	'Referers_Newsletters' => 'Uudiskirjad',
 	'Referers_Campaigns' => 'Kampaaniad',
 	'Referers_Evolution' => 'Perioodi üldareng',
 	'Referers_Type' => 'Viitaja tüüp',
 	'Referers_TypeDirectEntries' => '%s otse sisenemist',
 	'Referers_TypeSearchEngines' => '%s otsomootoritest',
-	'Referers_TypePartners' => '%s partnerite lehtedelt',
 	'Referers_TypeWebsites' => '%s veebilehtedelt',
-	'Referers_TypeNewsletters' => '%s uudiskirjadest',
 	'Referers_TypeCampaigns' => '%s kampaaniatest',
-	'Referers_Other' => 'Other',
-	'Referers_OtherDistinctSearchEngines' => '%s erinevat otsimootorit',
-	'Referers_OtherDistinctKeywords' => '%s erinevat võtmesõna',
-	'Referers_OtherDistinctWebsites' => '%1s erinevat veebilehte (kasutati %2s erinevat url-i)',
-	'Referers_OtherDistinctPartners' => '%1s erinevat partnerit (kasutatud %2s erinevat url-i)',
-	'Referers_OtherDistinctCampaigns' => '%s erinevat kampaaniat',
-	'Referers_TagCloud' => 'sildipilve väljund',
-	'Referers_SubmenuEvolution' => 'Evolutsioon',
 	'Referers_SubmenuSearchEngines' => 'Otsimootorid & võtmesõnad',
 	'Referers_SubmenuWebsites' => 'Veebilehed',
 	'Referers_SubmenuCampaigns' => 'Kampaaniad',
-	'Referers_SubmenuPartners' => 'Partnerid',
 	'Referers_WidgetKeywords' => 'Võtmesõnade nimistu',
-	'Referers_WidgetPartners' => 'Partnerite nimistu',
 	'Referers_WidgetCampaigns' => 'Kampaaniate nimistu',
 	'Referers_WidgetExternalWebsites' => 'Väliste viitajate nimekiri',
 	'Referers_WidgetSearchEngines' => 'Parimad otsimootorid',
 	'Referers_WidgetOverview' => 'Ülevaade',
-	'UserSettings_BrowserFamilies' => 'Sirvijate tüübid',
-	'UserSettings_Browsers' => 'Veebisirvijad',
-	'UserSettings_Plugins' => 'Pluginad',
-	'UserSettings_Configurations' => 'Konfiguratsioonid',
-	'UserSettings_OperatingSystems' => 'Operatsioonisüsteemid',
-	'UserSettings_Resolutions' => 'Resolutsioonid',
-	'UserSettings_WideScreen' => 'Laiekraan',
-	'UserSettings_WidgetResolutions' => 'Ekraani resolutsioonid',
-	'UserSettings_WidgetBrowsers' => 'Külastajate veebisirvijad',
-	'UserSettings_WidgetPlugins' => 'Pluginate nimistu',
-	'UserSettings_WidgetWidescreen' => 'Normaal / Laiekraan',
-	'UserSettings_WidgetBrowserFamilies' => 'Sirvija tüübid',
-	'UserSettings_WidgetOperatingSystems' => 'Operatsioonisüsteemid',
-	'UserSettings_WidgetGlobalVisitors' => 'Kohalike külastajate seaded',
-	'UserSettings_SubmenuSettings' => 'Seaded',
+	'SitesManager_Sites' => 'Sites',
+	'SitesManager_WebsitesManagement' => 'Veebilehe haldamine',
+	'SitesManager_MainDescription' => 'Sinu veebianalüütika vajab veebilehti, mida hallata! Lisa, uuenda, kustuta veebilehti, ja näita Javascript koodi mida lisada veebilehtedele.',
+	'SitesManager_NoWebsites' => 'Sul pole saite mida administreerida.',
+	'SitesManager_AddSite' => 'Lisa uus sait',
+	'SitesManager_Urls' => 'URL-id',
+	'SitesManager_MenuSites' => 'Saidid',
+	'SitesManager_DeleteConfirm_js' => 'Oled sa kindel %s kustutamises?',
+	'SitesManager_ExceptionDeleteSite' => 'Seda veebilehte ei ole võimalik kustutada, sest see on ainuke registreeritud leht selles andmebaasis. Lisa ennem uus leht ja siis kustuta see leht.',
+	'SitesManager_ExceptionNoUrl' => 'Pead määratlema vähemasti ühe saidil oleva URL-i.',
+	'SitesManager_ExceptionEmptyName' => 'Saidi nimi ei saa olla tühi.',
+	'SitesManager_ExceptionInvalidUrl' => 'Aadress \'%s\' ei ole kehtiv veebiaadress.',
+	'TranslationsAdmin_MenuTranslations' => 'Tõlked',
+	'TranslationsAdmin_MenuLanguages' => 'Keeled',
+	'TranslationsAdmin_LanguageCode' => 'Keele kood',
+	'TranslationsAdmin_Plugin' => 'Plugin',
+	'TranslationsAdmin_Definition' => 'Definitsioon',
+	'TranslationsAdmin_DefaultString' => 'Vaikimisi keel (Inglise keel)',
+	'TranslationsAdmin_TranslationString' => 'Tõlke tõmmis (Praegune keel: %s)',
+	'TranslationsAdmin_Translations' => 'Tõlked',
+	'TranslationsAdmin_FixPermissions' => 'Palun korrasta failisüsteemi õigused',
+	'TranslationsAdmin_AddLanguage' => 'Lisa keel',
+	'TranslationsAdmin_Export' => 'Ekspordi keel',
+	'TranslationsAdmin_Import' => 'Impordi keel',
 	'UserCountry_Country' => 'Riik',
 	'UserCountry_Continent' => 'Kontinent',
 	'UserCountry_DistinctCountries' => '%s eri riigist',
@@ -282,6 +309,7 @@ $translations = array(
 	'UserCountry_country_fo' => 'Fääri saared',
 	'UserCountry_country_fr' => 'Prantsusmaa',
 	'UserCountry_country_ga' => 'Gabon',
+	'UserCountry_country_gb' => 'Suurbritannia',
 	'UserCountry_country_gd' => 'Grenada',
 	'UserCountry_country_ge' => 'Gruusia',
 	'UserCountry_country_gf' => 'Prantsuse Guyana',
@@ -392,8 +420,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_re' => 'Reunion Saar',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Vene Föderatsioon',
 	'UserCountry_country_rs' => 'Venemaa',
+	'UserCountry_country_ru' => 'Vene Föderatsioon',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudi-Araabia',
 	'UserCountry_country_sb' => 'Solomoni Saared',
@@ -434,14 +462,13 @@ $translations = array(
 	'UserCountry_country_ua' => 'Ukraina',
 	'UserCountry_country_ug' => 'Uganda',
 	'UserCountry_country_uk' => 'Ühendatud kuningriigid',
-	'UserCountry_country_gb' => 'Suurbritannia',
 	'UserCountry_country_um' => 'United States Minor Outlying Islands',
 	'UserCountry_country_us' => 'Ameerika ühendriigid',
 	'UserCountry_country_uy' => 'Uruguai',
 	'UserCountry_country_uz' => 'Uzbekistan',
 	'UserCountry_country_va' => 'Vatikani linn',
 	'UserCountry_country_vc' => 'Püha Vincent ja Grenadiinid',
-	'UserCountry_country_ve' => 'Venetsueela ',
+	'UserCountry_country_ve' => 'Venetsueela',
 	'UserCountry_country_vg' => 'Virgin saared, Briti',
 	'UserCountry_country_vi' => 'Virgin saared, U.S.',
 	'UserCountry_country_vn' => 'Vietnam',
@@ -458,60 +485,24 @@ $translations = array(
 	'UserCountry_continent_eur' => 'Euroopa',
 	'UserCountry_continent_afr' => 'Aafrika',
 	'UserCountry_continent_asi' => 'Aasia',
-	'UserCountry_continent_ams' => 'Lõuna ja Kesk Ameerika',
 	'UserCountry_continent_amn' => 'Põhja Ameerika',
+	'UserCountry_continent_ams' => 'Lõuna ja Kesk Ameerika',
 	'UserCountry_continent_oce' => 'Okeaania',
-	'VisitsSummary_NbVisits' => '%s külastust',
-	'VisitsSummary_NbUniqueVisitors' => '%s unikaalset külastajat',
-	'VisitsSummary_NbActions' => '%s tegevust (lehe vaatamist)',
-	'VisitsSummary_TotalTime' => '%s Kogu aeg, mille vältel lehte on külastatud',
-	'VisitsSummary_MaxNbActions' => '%s maksmimum tegevuste arv ühel külastusel',
-	'VisitsSummary_NbBounced' => '%s hülgas lehe (lahkus peale ühe lehe vaatamist)',
-	'VisitsSummary_Evolution' => 'Viimase 30 päeva areng',
-	'VisitsSummary_Report' => 'Raport',
-	'VisitsSummary_GenerateTime' => 'Lehe genereerimiseks kulus %s sekundit',
-	'VisitsSummary_GenerateQueries' => '%s katkestatud päringut',
-	'VisitsSummary_WidgetLastVisits' => 'Viimaste külastuste graafik',
-	'VisitsSummary_WidgetVisits' => 'Külastuste ülevaade',
-	'VisitsSummary_WidgetLastVisitors' => 'Viimaste unikaalsete külastajate graafik',
-	'VisitsSummary_WidgetOverviewGraph' => 'Graafikutega ülevaade',
-	'VisitsSummary_SubmenuOverview' => 'Ülevaade',
-	'VisitFrequency_Evolution' => 'Perioodi areng',
-	'VisitFrequency_ReturnVisits' => '%s korduvat külastust',
-	'VisitFrequency_ReturnActions' => '%s tegevust tegi korduv külastaja',
-	'VisitFrequency_ReturnMaxActions' => '%s on maksmimaalne arv tegevusi korduva külastajalt',
-	'VisitFrequency_ReturnTotalTime' => '%s korduva külastaja veedetud aeg',
-	'VisitFrequency_ReturnBounces' => '%s korda, mil taaskülastus on katkestatud (lahkutud peale ühe lehe vaatamist)',
-	'VisitFrequency_WidgetOverview' => 'Sageduse ülevaade',
-	'VisitFrequency_WidgetGraphReturning' => 'Korduvate külastuste graafik',
-	'VisitFrequency_SubmenuFrequency' => 'Sagedus',
-	'VisitTime_LocalTime' => 'Külastused kohaliku kellaaja järgi',
-	'VisitTime_ServerTime' => 'Külastused serveri kellaaja järgi',
-	'VisitTime_WidgetLocalTime' => 'Külastused kohaliku kellaaja järgi',
-	'VisitTime_WidgetServerTime' => 'Külastused serveri kellaaja järgi',
-	'VisitTime_SubmenuTimes' => 'Korda',
-	'VisitTime_NHour' => '%s',
-	'VisitorInterest_VisitsPerDuration' => 'Visits per visit duration',
-	'VisitorInterest_VisitsPerNbOfPages' => 'Visits per number of pages',
-	'VisitorInterest_WidgetLengths' => 'Külastuste kestvus',
-	'VisitorInterest_WidgetPages' => 'Erinevaid lehti külastuse kohta',
-	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Sagedus & Lojaalsus',
-	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_OnePage' => '1 leht',
-	'VisitorInterest_NPages' => '%s lehte',
-	'Login_LoginPasswordNotCorrect' => 'Kasutajanimi & salasõna olid valed',
-	'Login_Login' => 'Kasutajanimi',
-	'Login_Password' => 'Salasõna',
-	'Login_LoginOrEmail' => 'Kasutajanimi või E-mail',
-	'Login_LogIn' => 'Sisene',
-	'Login_Logout' => 'Välju',
-	'Login_LostYourPassword' => 'Kaotasid oma salasõna?',
-	'Login_RemindPassword' => 'Meenuta salasõna',
-	'Login_PasswordReminder' => 'Palun sisesta kasutaja või e-mail address. Sulle saadetakse salasõna e-mailiga.',
-	'Login_InvalidUsernameEmail' => 'Vale kasutajanimi ja/või e-maili address',
-	'Login_MailTopicPasswordRecovery' => 'Salasõna taastamine',
-	'Login_PasswordSent' => 'Salasõna saadetud. Kontrolli oma e-maili.',
-	'Login_ContactAdmin' => 'Võimalik põhjus: sinu majutusel on mail() funktsioon välja lülitatud. <br />Palun kontakteeru administraatoriga.',
+	'UserSettings_BrowserFamilies' => 'Sirvijate tüübid',
+	'UserSettings_Browsers' => 'Veebisirvijad',
+	'UserSettings_Plugins' => 'Pluginad',
+	'UserSettings_Configurations' => 'Konfiguratsioonid',
+	'UserSettings_OperatingSystems' => 'Operatsioonisüsteemid',
+	'UserSettings_Resolutions' => 'Resolutsioonid',
+	'UserSettings_WideScreen' => 'Laiekraan',
+	'UserSettings_WidgetResolutions' => 'Ekraani resolutsioonid',
+	'UserSettings_WidgetBrowsers' => 'Külastajate veebisirvijad',
+	'UserSettings_WidgetPlugins' => 'Pluginate nimistu',
+	'UserSettings_WidgetWidescreen' => 'Normaal / Laiekraan',
+	'UserSettings_WidgetBrowserFamilies' => 'Sirvija tüübid',
+	'UserSettings_WidgetOperatingSystems' => 'Operatsioonisüsteemid',
+	'UserSettings_WidgetGlobalVisitors' => 'Kohalike külastajate seaded',
+	'UserSettings_SubmenuSettings' => 'Seaded',
 	'UsersManager_UsersManagement' => 'Kasutajate haldamine',
 	'UsersManager_UsersManagementMainDescription' => 'Loo uusi kasutajakontosid või uuenda olemasolevaid. Saad seada nende õigused ülalpool.',
 	'UsersManager_ManageAccess' => 'Halda ligipääsu',
@@ -524,105 +515,48 @@ $translations = array(
 	'UsersManager_PrivView' => 'Vaata',
 	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Kas sa oled kindel soovis anda \'%s\' õigused kõigile veebilehtedele?',
-	'UsersManager_Login' => 'Logi sisse',
 	'UsersManager_Password' => 'Salasõna',
 	'UsersManager_Email' => 'Email',
 	'UsersManager_Alias' => 'Alias',
-	'UsersManager_Token' => 'token_auth',
 	'UsersManager_Edit' => 'Muuda',
 	'UsersManager_AddUser' => 'Lisa uus kasutaja',
 	'UsersManager_MenuUsers' => 'Kasutajad',
 	'UsersManager_DeleteConfirm_js' => 'Kas oled kindel, et soovid %s kustutada?',
 	'UsersManager_ExceptionLoginExists' => 'Kasutajanimi \'%s\' on kasutusel.',
 	'UsersManager_ExceptionEmailExists' => 'Sellise e-mailiga \'%s\' kasutaja on olemas.',
-	'UsersManager_ExceptionInvalidLogin' => 'Sisse logimise informatsioon peab sisaldama tähti, numbreid või järgnevaid tähemärke \'_\' ja \'-\' ning \'.\'',
-	'UsersManager_ExceptionInvalidPassword' => 'Salasõna pikkus peab olema 6 kuni 26 tähemärki.',
 	'UsersManager_ExceptionInvalidEmail' => 'Emaili aadress ei ole õiges formaadis.',
 	'UsersManager_ExceptionDeleteDoesNotExist' => 'Kasutajat nimega \'%s\' ei eksisteeri seepärast ei saa teda ka kustutada.',
 	'UsersManager_ExceptionAdminAnonymous' => 'Sa ei saa anda \'admin\' õiguseid \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionEditAnonymous' => 'Anonüümset kasutajat ei saa muuta ega kustutada. Piwik kasutab seda määratlemaks kasutajat, kes ei ole veel sisse loginud. Näiteks, saad teha statistika lubada \'view\' statistikat õigused \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'Kasutaja \'%s\' puudub.',
 	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
-	'SitesManager_Sites' => 'Sites',
-	'SitesManager_WebsitesManagement' => 'Veebilehe haldamine',
-	'SitesManager_MainDescription' => 'Sinu veebianalüütika vajab veebilehti, mida hallata! Lisa, uuenda, kustuta veebilehti, ja näita Javascript koodi mida lisada veebilehtedele.',
-	'SitesManager_JsCode' => 'Javascript kood',
-	'SitesManager_JsCodeHelp' => 'Siin on Javaskript kood mille peab lisama igale lehele',
-	'SitesManager_ShowJsCode' => 'Näita koodi',
-	'SitesManager_NoWebsites' => 'Sul pole saite mida administreerida.',
-	'SitesManager_AddSite' => 'Lisa uus sait',
-	'SitesManager_Id' => 'Id',
-	'SitesManager_Name' => 'Nimi',
-	'SitesManager_Urls' => 'URL-id',
-	'SitesManager_MenuSites' => 'Saidid',
-	'SitesManager_DeleteConfirm_js' => 'Oled sa kindel %s kustutamises?',
-	'SitesManager_ExceptionDeleteSite' => 'Seda veebilehte ei ole võimalik kustutada, sest see on ainuke registreeritud leht selles andmebaasis. Lisa ennem uus leht ja siis kustuta see leht.',
-	'SitesManager_ExceptionNoUrl' => 'Pead määratlema vähemasti ühe saidil oleva URL-i.',
-	'SitesManager_ExceptionEmptyName' => 'Saidi nimi ei saa olla tühi.',
-	'SitesManager_ExceptionInvalidUrl' => 'Aadress \'%s\' ei ole kehtiv veebiaadress.',
-	'Installation_Installation' => 'Installatsioon',
-	'Installation_InstallationStatus' => 'Installatiooni olek',
-	'Installation_PercentDone' => '%s %% Tehtud',
-	'Installation_NoConfigFound' => 'Piwiki konfguratsioonifaili ei leitud, kuid sa üritasid minna Piwiki lehele.<br /><b>&nbsp;&nbsp;&raquo; Võid <a href=\'index.php\'>installeerida Piwiko</a></b><br /><small>Kui Piwik on varem installeeritud ja sul on andmebaasis tabeleid, siis ei ole põhjust muretsemiseks saad taaskasutada ja säilitada olemasolevad andmed!</small>',
-	'Installation_MysqlSetup' => 'Mysql andmebaasi seadistamine',
-	'Installation_MysqlErrorConnect' => 'Mysql andmebaasiga ühendamisel tekkis viga.',
-	'Installation_JsTag' => 'Javascript tag',
-	'Installation_JsTagHelp' => '<p>Lugemaks kõiki külastusi, pead sisestama javascript koodi kõigile oma lehtedele.</p><p>Sinu lehel ei pea olema tehtud kasutades PHP-ed, Piwik töötab kõigil lehtedel (pole vahet on see HTML, ASP, Perl või mõni muu programeerimiskeel).</p><p>Siin on kood, mille pead lisama veebilehtedele: (Kopeeri ja aseta see kõigile lehtedele) </p>',
-	'Installation_Congratulations' => 'Õnnitleme',
-	'Installation_CongratulationsHelp' => '<p>Õnnitlused! Sinu Piwiki Installatsioon on edukalt lõpuni viidud.</p><p>Sisesta javascript kood oma lehele ja jää külastusi ootama!</p>',
-	'Installation_GoToPiwik' => 'Mine Piwikisse',
-	'Installation_SetupWebsite' => 'Seadista veebileht',
-	'Installation_SetupWebsiteError' => 'Veebilehe lisamisel tekkis viga',
-	'Installation_GeneralSetup' => 'Üldine seadistus',
-	'Installation_GeneralSetupSuccess' => 'Üldine seadistus edukalt konfigureeritud.',
-	'Installation_SystemCheck' => 'Süsteemi kontroll',
-	'Installation_SystemCheckPhp' => 'PHP versioon',
-	'Installation_SystemCheckPdo' => 'Pdo laiendus',
-	'Installation_SystemCheckPdoMysql' => 'Pdo_Mysql laiendus',
-	'Installation_SystemCheckPdoError' => 'Pead lubama PDO ja PDO_MYSQL laiendused php.ini failis.',
-	'Installation_SystemCheckPdoHelp' => 'Windows serveri puhul lisa php.ini faili järgnevad read %s <br /><br />Linux serveri puhul saad lisada järgnevad php võimalused %s oma php.ini failis, lisades järgnevad read %s<br /><br />Rohkem infot leiad <a style="color:red" href="http://php.net/pdo">PHP veebilehelt/a>.',
-	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
-	'Installation_SystemCheckWriteDirsHelp' => 'Parandamaks seda viga linux süsteemis, trüki sisse käsk/käsud.',
-	'Installation_SystemCheckMemoryLimit' => 'Mälu limiit',
-	'Installation_SystemCheckMemoryLimitHelp' => 'Suure liiklusega veebileht võib vajada arhiveerimiseks rohkem mälu, kui hetkel lubatud.<br />Vaata üle oma memory_limit oma php.ini failis, kui see osutub vajalikuks.',
-	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphics)',
-	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
-	'Installation_SystemCheckTimeLimit' => 'set_time_limit() lubatud',
-	'Installation_SystemCheckTimeLimitHelp' => 'Suure liiklusega veebilehe puhul, või arhiveerimisprotssess võtta rohkem aega, kui hetkel lubatud.<br />Vaata direktiiv max_execution_time  oma php.ini failis, kui see on vajalik',
-	'Installation_SystemCheckMail' => 'mail() lubatud',
-	'Installation_SystemCheckError' => 'Ilmnes viga - Enne jätkamist tuleb see parandada.',
-	'Installation_SystemCheckWarning' => 'Piwik toimib normaalselt, kuid osad võimalused võivad puududa.',
-	'Installation_Tables' => 'Tabelite loomine',
-	'Installation_TablesWarning' => 'Osad <span id="linkToggle">Piwiki tabelid</span> on juba andmebaasi installeeritud',
-	'Installation_TablesFound' => 'Andmebaasist leiti järgnevad tabelid',
-	'Installation_TablesWarningHelp' => 'Nüüd saad valida, kas kasutad olemasolevaid tabeleid ja andmeid või lood uued tabelid.',
-	'Installation_TablesReuse' => 'Taaskasuta olemasolevaid tabeleid',
-	'Installation_TablesDelete' => 'Kustuta leitud tabelid',
-	'Installation_TablesDeletedSuccess' => 'Olemasolevad tabelid kustutatud',
-	'Installation_TablesCreatedSuccess' => 'Tabelid loodud!',
-	'Installation_DatabaseCreatedSuccess' => '%s andmebaas loodud!',
-	'Installation_TablesDeleteConfirm' => 'Oled sa kindel soovis kustudada käesolevad tabelid Piwiki andmebaasist?',
-	'Installation_Welcome' => 'Tere tulemast!',
-	'Installation_WelcomeHelp' => '<p>Piwik on vabavaraline veebianalüüika tarkvara, mis teeb lihtsaks oma külastajate kohta andmete kogumise ja nende analüüsimise.</p><p>See protsess sisaldab %s sammu ja võtab aega u. 5 minutit.</p>',
-	'Provider_WidgetProviders' => 'Pakkujad',
-	'Provider_SubmenuLocationsProvider' => 'Asukoht & pakkuja',
-	'DBStats_DatabaseUsage' => 'Andmebaasi kasutus',
-	'DBStats_MainDescription' => 'Piwik salvestab kõik veebianalüütika andmed Mysql andmebaasi. Hetkel, Piwiki tabelid kasutavad %s.',
-	'DBStats_Table' => 'Tabel',
-	'DBStats_RowNumber' => 'Rea number',
-	'DBStats_DataSize' => 'Andmemaht',
-	'DBStats_IndexSize' => 'Indeksi maht',
-	'TranslationsAdmin_MenuTranslations' => 'Tõlked',
-	'TranslationsAdmin_MenuLanguages' => 'Keeled',
-	'TranslationsAdmin_Plugin' => 'Plugin',
-	'TranslationsAdmin_Definition' => 'Definitsioon',
-	'TranslationsAdmin_DefaultString' => 'Vaikimisi keel (Inglise keel)',
-	'TranslationsAdmin_TranslationString' => 'Tõlke tõmmis (Praegune keel: %s)',
-	'TranslationsAdmin_Translations' => 'Tõlked',
-	'TranslationsAdmin_FixPermissions' => 'Palun korrasta failisüsteemi õigused',
-	'TranslationsAdmin_AvailableLanguages' => 'Saada olevad keeled',
-	'TranslationsAdmin_AddLanguage' => 'Lisa keel',
-	'TranslationsAdmin_LanguageCode' => 'Keele kood',
-	'TranslationsAdmin_Export' => 'Ekspordi keel',
-	'TranslationsAdmin_Import' => 'Impordi keel',
+	'VisitFrequency_Evolution' => 'Perioodi areng',
+	'VisitFrequency_ReturnVisits' => '%s korduvat külastust',
+	'VisitFrequency_ReturnActions' => '%s tegevust tegi korduv külastaja',
+	'VisitFrequency_WidgetOverview' => 'Sageduse ülevaade',
+	'VisitFrequency_WidgetGraphReturning' => 'Korduvate külastuste graafik',
+	'VisitFrequency_SubmenuFrequency' => 'Sagedus',
+	'VisitorInterest_VisitsPerDuration' => 'Visits per visit duration',
+	'VisitorInterest_VisitsPerNbOfPages' => 'Visits per number of pages',
+	'VisitorInterest_WidgetLengths' => 'Külastuste kestvus',
+	'VisitorInterest_WidgetPages' => 'Erinevaid lehti külastuse kohta',
+	'VisitorInterest_PlusXMin' => '%s min',
+	'VisitorInterest_OnePage' => '1 leht',
+	'VisitorInterest_NPages' => '%s lehte',
+	'VisitsSummary_NbVisits' => '%s külastust',
+	'VisitsSummary_NbUniqueVisitors' => '%s unikaalset külastajat',
+	'VisitsSummary_MaxNbActions' => '%s maksmimum tegevuste arv ühel külastusel',
+	'VisitsSummary_GenerateTime' => 'Lehe genereerimiseks kulus %s sekundit',
+	'VisitsSummary_GenerateQueries' => '%s katkestatud päringut',
+	'VisitsSummary_WidgetLastVisits' => 'Viimaste külastuste graafik',
+	'VisitsSummary_WidgetVisits' => 'Külastuste ülevaade',
+	'VisitsSummary_WidgetLastVisitors' => 'Viimaste unikaalsete külastajate graafik',
+	'VisitsSummary_WidgetOverviewGraph' => 'Graafikutega ülevaade',
+	'VisitsSummary_SubmenuOverview' => 'Ülevaade',
+	'VisitTime_LocalTime' => 'Külastused kohaliku kellaaja järgi',
+	'VisitTime_ServerTime' => 'Külastused serveri kellaaja järgi',
+	'VisitTime_WidgetLocalTime' => 'Külastused kohaliku kellaaja järgi',
+	'VisitTime_WidgetServerTime' => 'Külastused serveri kellaaja järgi',
+	'VisitTime_SubmenuTimes' => 'Korda',
+	'VisitTime_NHour' => '%s',
 );
