@@ -194,10 +194,7 @@ $translations = array(
 	'CoreHome_JavascriptDisabled' => 'JavaScript-ek gaituta egon behar du Piwik ikuspegi estandarrean erabiltzeko.<br />Badirudi ordea JavaScript desgaituta dagoela edo zure nabigatzaileak ez duela onartzen.<br />Ikuspegi estandarra erabiltzeako, gaitu JavaScript zure nabigatzailearen aukeretan eta ondoren %1$ssaiatu berriro%2$s.<br />',
 	'CoreHome_CategoryNoData' => 'Daturik ez kategoria honetan. Saiatu "Sartu populazio guztia" aukerarekin.',
 	'CoreHome_ShowJSCode' => 'Erakutsi txertatu beharreko JavaScript kodea',
-	'CoreHome_IncludeAllPopulation_js' => 'Sartu populazio guztia',
-	'CoreHome_ExcludeLowPopulation_js' => 'Baztertu populazio txikia',
 	'CoreHome_PageOf_js' => '%1$s / %2$s',
-	'CoreHome_DayFormat' => '%longDay%, %longYear%(e)ko %longMonth%ren %day%a',
 	'CoreHome_PeriodDay' => 'Eguna',
 	'CoreHome_PeriodWeek' => 'Astea',
 	'CoreHome_PeriodMonth' => 'Hilabetea',
@@ -306,7 +303,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveEmpty' => 'Artxibo hutsa.',
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Artxiboa osatu gabe dago: fitxategi batzuk falta dira (adib. %s).',
 	'Dashboard_Dashboard' => 'Arbela',
-	'Dashboard_AddWidget' => 'Gehitu widget-a...',
 	'Dashboard_DeleteWidgetConfirm' => 'Ziur zaude widget hau arbeletik ezabatu nahi duzula?',
 	'Dashboard_SelectWidget' => 'Hautatu arbelean gehitzeko widget-a',
 	'Dashboard_AddPreviewedWidget_js' => 'Gehitu arbelean aurrebistako widget-a',
@@ -479,7 +475,6 @@ Oharra: tokena 24 ordutan iraungiko da.',
 	'Referers_DirectEntry' => 'Sarrera zuzena',
 	'Referers_Websites' => 'Webguneak',
 	'Referers_Campaigns' => 'Kanpainak',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (%2$s)',
 	'Referers_Evolution' => 'Bilakaera periodoan zehar',
 	'Referers_Type' => 'Erreferente mota',
 	'Referers_ColumnRefererType' => 'Erreferente mota',
@@ -743,8 +738,8 @@ Oharra: tokena 24 ordutan iraungiko da.',
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Reunion',
 	'UserCountry_country_ro' => 'Errumania',
-	'UserCountry_country_ru' => 'Errusia',
 	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_ru' => 'Errusia',
 	'UserCountry_country_rw' => 'Ruanda',
 	'UserCountry_country_sa' => 'Saudi Arabia',
 	'UserCountry_country_sb' => 'Solomon Uharteak',
@@ -888,7 +883,6 @@ Oharra: tokena 24 ordutan iraungiko da.',
 	'VisitsSummary_VisitsSummary' => 'Bisiten laburpena',
 	'VisitsSummary_NbVisits' => '%s bisita',
 	'VisitsSummary_NbUniqueVisitors' => '%s bisitari desberdin',
-	'VisitsSummary_NbActions' => '%s ekintza (ikusitako orriak)',
 	'VisitsSummary_MaxNbActions' => '%s ekintza gehienez bisita batean',
 	'VisitsSummary_NbVisitsBounced' => '%s bisita errebotatu dira (webgunea utzi dute orri bat ikusi ondoren)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Bilakaera azken %san zehar',
