@@ -1,53 +1,173 @@
-<?php 
+<?php
 $translations = array(
 	'General_Locale' => 'gl_ES.UTF-8',
-	'General_TranslatorName' => 'OUSLI - Ourense Software Libre',
+	'General_TranslatorName' => 'OUSLI - Ourense Software Libre, Antonio Andina',
 	'General_TranslatorEmail' => 'info@ousli.org',
 	'General_EnglishLanguageName' => 'Galician',
 	'General_OriginalLanguageName' => 'Galego',
+	'General_HelloUser' => 'Ola, %s!',
+	'General_OpenSourceWebAnalytics' => 'Analise Web de Open Source',
+	'General_Dashboard' => 'Tableiro',
+	'General_DashboardForASpecificWebsite' => 'Tableiro dunha soa Web',
+	'General_MultiSitesSummary' => 'Todas as Webs',
+	'General_AllWebsitesDashboard' => 'Tableiro de todas as Webs',
+	'General_API' => 'API',
+	'General_Widgets' => 'Engadidos',
+	'General_Settings' => 'Configuración',
+	'General_GiveUsYourFeedback' => 'Contacte con Nos',
 	'General_Unknown' => 'Descoñecido',
+	'General_Never' => 'Nunca',
 	'General_Required' => '%s necesario',
+	'General_NotValid' => '%s non é valido',
+	'General_Id' => 'ID',
 	'General_Error' => 'Erro',
 	'General_Warning' => 'Advertencia',
 	'General_BackToHomepage' => 'Voltar á páxina de inicio',
 	'General_Yes' => 'Si',
 	'General_No' => 'Non',
 	'General_Delete' => 'Borrar',
+	'General_Report' => 'Informe',
 	'General_Edit' => 'Editar',
+	'General_Download' => 'Descarga',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Pechar',
+	'General_OrCancel' => 'ou %s Cancelar %s',
 	'General_Logout' => 'Desconectarse',
+	'General_Username' => 'Usuario',
+	'General_Description' => 'Descripción',
 	'General_Done' => 'Feito',
-	'General_LoadingData' => 'Cargando...',
-	'General_ErrorRequest' => 'Oops&hellip; Problema durante a petición, por favor probe de novo.',
+	'General_Name' => 'Nome',
+	'General_Value' => 'Valor',
+	'General_Details' => 'Detalle',
+	'General_Default' => 'Predeterminado',
+	'General_Visit' => 'Visita',
+	'General_VisitorIP' => 'IP Visita',
+	'General_VisitType' => 'Tipo Visitante',
+	'General_DaysSinceLastVisit' => 'Días desde Última Visita',
+	'General_DaysSinceFirstVisit' => 'Días desde Primeira Visita',
+	'General_NumberOfVisits' => 'Número de Visitas',
+	'General_VisitConvertedGoal' => 'Visita convertida en Obxectivo',
+	'General_NewVisitor' => 'Nova Visita',
+	'General_ReturningVisitor' => 'Re-Visita',
+	'General_Date' => 'Data',
+	'General_Period' => 'Periodo',
+	'General_ChooseDate' => 'Escolla Data',
+	'General_Today' => 'Hoxe',
+	'General_Yesterday' => 'Onte',
+	'General_CurrentWeek' => 'Semana Actual',
+	'General_CurrentMonth' => 'Mes Actual',
+	'General_CurrentYear' => 'Ano Actual',
+	'General_DateRange' => 'Rango de Datas',
+	'General_LoadingData' => 'Cargando Datos...',
+	'General_Loading_js' => 'Cargando',
+	'General_GoTo' => 'Ir a %s',
 	'General_Next' => 'Seguinte',
 	'General_Previous' => 'Anterior',
+	'General_Search' => 'Procurar',
+	'General_Others' => 'Outros',
 	'General_Table' => 'Táboa',
 	'General_Piechart' => 'Gráfico circular',
 	'General_TagCloud' => 'Nube de etiquetas',
 	'General_VBarGraph' => 'Gráfico de barras',
+	'General_OpenInNewWindow_js' => 'Abrir en nova Xanela',
+	'General_SaveImageOnYourComputer_js' => 'Para grabar a imaxe no computador faga click-dereito na imaxe e seleccione "Grabar Imaxe como.."',
 	'General_Refresh' => 'Actualizar páxina',
+	'General_Visitors' => 'Visitantes',
+	'General_ExportThisReport' => 'Exportar datos noutros formatos',
+	'General_ExportAsImage_js' => 'Exportar como Imaxe',
+	'General_YourChangesHaveBeenSaved' => 'Os cambios foron grabados',
+	'General_ErrorRequest' => 'Oops… Problema durante a petición, por favor probe de novo.',
 	'General_ColumnNbUniqVisitors' => 'Visitantes únicos',
 	'General_ColumnNbVisits' => 'Visitas',
+	'General_ColumnPercentageVisits' => '% Visitas',
+	'General_ColumnNbActions' => 'Accións',
+	'General_NbActions' => 'Numero de Accións',
+	'General_ColumnMaxActions' => 'Máximas accións nunha visita',
+	'General_ColumnSumVisitLength' => 'Tempo por visitantes (en segundos)',
 	'General_ColumnLabel' => 'Etiqueta',
+	'General_ColumnConversionRate' => 'Tasa de Conversión',
+	'General_ColumnActionsPerVisit' => 'Accións por Visita',
+	'General_VisitDuration' => 'Duración Media Visita (en segs)',
+	'General_ColumnAvgTimeOnSite' => 'Tempo Medio na Web',
+	'General_ColumnVisitDuration' => 'Duración Visita (en segs)',
+	'General_ColumnBounceRate' => 'Ratio de Rebotes',
+	'General_ColumnExitRate' => 'Tasa de Saídas',
+	'General_ColumnPageviews' => 'Páxinas Vistas',
+	'General_ColumnUniquePageviews' => 'Páxinas Únicas',
+	'General_ColumnBounces' => 'Rebotes',
+	'General_ColumnEntrances' => 'Entradas',
+	'General_ColumnExits' => 'Saídas',
+	'General_ColumnAverageTimeOnPage' => 'Tempo medio na pax.',
+	'General_ColumnValuePerVisit' => 'Valor por Visita',
+	'General_ColumnVisitsWithConversions' => 'Visitas con Conversións',
+	'General_YearsDays' => '%1$s anos %2$s días',
+	'General_DaysHours' => '%1$s días %2$s horas',
+	'General_HoursMinutes' => '%1$s horas %2$s min',
+	'General_MinutesSeconds' => '%1$s min %2$segs',
+	'General_Seconds' => '%segs',
 	'General_Save' => 'Gardar',
-	'CorePluginsAdmin_Plugins' => 'Plugins',
-	'CorePluginsAdmin_Activated' => 'Activado',
-	'CorePluginsAdmin_ActivatedHelp' => 'Este plugin non se pode desactivar',
-	'CorePluginsAdmin_Deactivate' => 'Desactivar',
-	'CorePluginsAdmin_Activate' => 'Activar',
-	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
-	'API_QuickDocumentation' => '<h2>Documentación rápida de API</h2><p>Se non ten datos hoxe, primeiro pode <a href=\'misc/generateVisits.php\' target=_blank>xerar algúns datos</a> usando o script de xeración de visitas.</p><p>Pode probar os distintos formatos dispoñibles para cada método. É realmente sinxelo extraer o dato que desexe desde piwik!</p><p><b>Para máis información bótelle un  ollo á<a href=\'http://dev.piwik.org/trac/wiki/API\'>A documentación oficial de API</a> ou a <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>Referencia API</a>.</b></P><h2>Autentificación de usuario</h2><p>Se desexa <b>obter os datos nos seus scripts, nun crontab, etc. </b> necesitará engadir o parámetro  <code><u>&token_auth=%s</u></code> ás chamadas da API a URLs que requiran a identificación do usuario.</p><p>Esta token_auth é secreta, así como o seu contrasinal de usuario, <b>¡non lla dea a ninguén!</p>',
+	'General_ForExampleShort' => 'ex.',
+	'General_YouMustBeLoggedIn' => 'Debes de rexistrate para acceder a esta función.',
+	'General_Website' => 'Web',
+	'General_GeneralSettings' => 'Configuración Xeral',
+	'General_NSeconds' => '%s segs',
+	'General_NoDataForGraph' => 'Sin datos para este Gráfico',
+	'General_NoDataForTagCloud' => 'Sin datos para esta Nube',
+	'General_DisplaySimpleTable' => 'Amosar táboa sinxela',
+	'General_DisplayTableWithMoreMetrics' => 'Amosar táboa con máis medidas',
+	'General_DisplayTableWithGoalMetrics' => 'Amosar táboa con Obexctivos',
+	'General_YouAreViewingDemoShortMessage' => 'Vostede esta vendo a demo de Piwik',
+	'General_NewUpdatePiwikX' => 'Nova Actualización: Piwik %s',
+	'General_AboutPiwikX' => 'Acerca de Piwik %s',
+	'General_BackToPiwik' => 'Voltar a Piwik',
+	'General_ShortMonth_1' => 'Xan',
+	'General_ShortMonth_2' => 'Feb',
+	'General_ShortMonth_3' => 'Mar',
+	'General_ShortMonth_4' => 'Abr',
+	'General_ShortMonth_5' => 'Mai',
+	'General_ShortMonth_6' => 'Xuñ',
+	'General_ShortMonth_7' => 'Xul',
+	'General_ShortMonth_8' => 'Ago',
+	'General_ShortMonth_9' => 'Set',
+	'General_ShortMonth_10' => 'Out',
+	'General_ShortMonth_11' => 'Nov',
+	'General_ShortMonth_12' => 'Dec',
+	'General_LongMonth_1' => 'Xaneiro',
+	'General_LongMonth_2' => 'Febreiro',
+	'General_LongMonth_3' => 'Marzo',
+	'General_LongMonth_4' => 'Abril',
+	'General_LongMonth_5' => 'Maio',
+	'General_LongMonth_6' => 'Xuño',
+	'General_LongMonth_7' => 'Xullo',
+	'General_LongMonth_8' => 'Agosto',
+	'General_LongMonth_9' => 'Setembro',
+	'General_LongMonth_10' => 'Outubro',
+	'General_LongMonth_11' => 'Novembro',
+	'General_LongMonth_12' => 'Decembro',
+	'General_ShortDay_1' => 'Lun',
+	'General_ShortDay_2' => 'Mar',
+	'General_ShortDay_3' => 'Mer',
+	'General_ShortDay_4' => 'Xov',
+	'General_ShortDay_5' => 'Ven',
+	'General_ShortDay_6' => 'Sab',
+	'General_ShortDay_7' => 'Dom',
+	'General_LongDay_1' => 'Lúns',
+	'General_LongDay_2' => 'Martes',
+	'General_LongDay_3' => 'Mércores',
+	'General_LongDay_4' => 'Xoves',
+	'General_LongDay_5' => 'Venres',
+	'General_LongDay_6' => 'Sábado',
+	'General_LongDay_7' => 'Domingo',
+	'General_Daily' => 'Diariamente',
+	'General_Weekly' => 'Semanalmente',
+	'General_Monthly' => 'Mensualmente',
+	'Actions_SubmenuPages' => 'Páxinas',
+	'Actions_SubmenuOutlinks' => 'Ligazóns externos',
+	'Actions_SubmenuDownloads' => 'Descargas',
 	'API_LoadedAPIs' => '%s APIs foro cargadas con éxito',
-	'CoreHome_NoPrivileges' => 'Está identificado como \'%s\', pero semella que non ten os permisos en Piwik.<br />Contacte co administrador do seu sistema Piwik para que lle dea acceso para entrar á páxina.',
-	'CoreHome_TableNoData' => 'Non hai datos para esta táboa.',
 	'CoreHome_CategoryNoData' => 'Non hai datos nesta categoría. Intente "Incluir todos os datos".',
 	'CoreHome_ShowJSCode' => 'Ver o código javascript para insertar',
-	'CoreHome_IncludeAllPopulation_js' => 'Incluir todos os datos',
-	'CoreHome_ExcludeLowPopulation_js' => 'Excluir os datos menos relevantes',
 	'CoreHome_PageOf_js' => '%1$s de %2$s',
-	'CoreHome_Loading_js' => 'Cargando...',
-	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
 	'CoreHome_PeriodDay' => 'Día',
 	'CoreHome_PeriodWeek' => 'Semana',
 	'CoreHome_PeriodMonth' => 'Mes',
@@ -71,39 +191,71 @@ $translations = array(
 	'CoreHome_MonthOctober_js' => 'Outubro',
 	'CoreHome_MonthNovember_js' => 'Novembro',
 	'CoreHome_MonthDecember_js' => 'Decembro',
-	'Actions_SubmenuPages' => 'Páxinas',
-	'Actions_SubmenuOutlinks' => 'Ligazóns externos',
-	'Actions_SubmenuDownloads' => 'Descargas',
-	'Dashboard_AddWidget' => 'Engadir un widget ...',
+	'CorePluginsAdmin_Plugins' => 'Plugins',
+	'CorePluginsAdmin_Activated' => 'Activado',
+	'CorePluginsAdmin_Deactivate' => 'Desactivar',
+	'CorePluginsAdmin_Activate' => 'Activar',
+	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
 	'Dashboard_DeleteWidgetConfirm' => '¿Está seguro de que desexa borrar este widget desde el tablón?',
 	'Dashboard_SelectWidget' => 'Seleccione un widget para engadilo no tablón',
-	'Dashboard_AddPreviewedWidget' => 'Engadir a previsualización do widget ao taboleiro',
-	'Dashboard_WidgetPreview' => 'Previsualización do widget',
 	'Dashboard_TitleWidgetInDashboard_js' => 'O widget xa se atopa no taboleiro',
 	'Dashboard_TitleClickToAdd_js' => 'Clic para engadir ao taboleiro',
-	'Dashboard_LoadingPreview_js' => 'Cargando vista previa, agarde por favor...',
 	'Dashboard_LoadingWidget_js' => 'Cargando widget, agarde por favor...',
 	'Dashboard_WidgetNotFound_js' => 'Widget non atopado',
+	'Installation_Installation' => 'Instalación',
+	'Installation_InstallationStatus' => 'Estado da instalación',
+	'Installation_PercentDone' => '%s %%Hecho',
+	'Installation_NoConfigFound' => 'O ficheiro de configuración de Piwik non se atopou e vostede está tentando acceder a unha páxina de Piwik.<br><b>  » Pode <a href=\'index.php\'>instalar Piwik agora</a></b><br><small>Se instalou Piwik con anterioridade e ten táboas na súa base de datos, non se preocupe, pode reutilizar ditas táboas e manter os datos que se atopan nelas!</small>',
+	'Installation_JsTag' => 'Etiqueta Javascript',
+	'Installation_Congratulations' => 'Noraboa!',
+	'Installation_CongratulationsHelp' => '<p>Noraboa! A instalación de Piwik foi completada.</p><p>Asegúrese de inserir o código Javascript en todas as páxinas, e agora, agarde aos primeiros visitantes!</p>',
+	'Installation_SetupWebsite' => 'Configurar unha páxina web',
+	'Installation_SetupWebsiteError' => 'Houbo un erro ao engadir o sitio',
+	'Installation_SystemCheck' => 'Comprobación do sitio',
+	'Installation_SystemCheckPhp' => 'Versión PHP',
+	'Installation_SystemCheckWriteDirs' => 'Directorios con permisos de escrita',
+	'Installation_SystemCheckWriteDirsHelp' => 'Para arranxar este erro no seu sistema GNU/Linux, tente inserindo os seguintes comandos',
+	'Installation_SystemCheckMemoryLimit' => 'Límite de memoria',
+	'Installation_SystemCheckMemoryLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire o apartado memory_limit no seu ficheiro php.ini se é necesario.',
+	'Installation_SystemCheckGD' => 'GD > 2.x (gráficos)',
+	'Installation_SystemCheckGDHelp' => 'Os sparklines (gráficos pequenos) non funcionarán.',
+	'Installation_SystemCheckTimeLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire a directiva max_execution_time no seu ficheiro php.ini se fose necesario',
+	'Installation_SystemCheckError' => 'Houbo un erro - Debe arranxarse antes de continuar',
+	'Installation_SystemCheckWarning' => 'Piwik traballará correctamente, pero algunhas características poden faltar',
+	'Installation_Tables' => 'Creando as táboas',
+	'Installation_TablesFound' => 'As seguintes táboas atopáronse na base de datos',
+	'Installation_TablesWarningHelp' => 'Ou ben optar pola reutilización de táboas de bases de datos existentes ou seleccionar unha instalación limpa para eliminar todos os datos existentes na base de datos.',
+	'Installation_TablesReuse' => 'Reutilizar as táboas xa existentes',
+	'Installation_TablesDelete' => 'Eliminar as táboas detectadas',
+	'Installation_TablesDeletedSuccess' => 'Táboas existentes de piwik eliminadas con éxito',
+	'Installation_TablesCreatedSuccess' => 'Táboas creadas con éxito!',
+	'Installation_Welcome' => 'Benvido!',
+	'Installation_WelcomeHelp' => '<p>Piwik é unha aplicación de código aberto de estatísticas que che permitirá recompilar información sobre o teu sitio facilmente.</p><p>Este proceso divídese en %s pasos sinxelos que levarán uns 5 minutos.</p>',
+	'Login_LoginPasswordNotCorrect' => 'Usuario e contrasinal incorrectos',
+	'Login_Password' => 'Contrasinal',
+	'Login_LoginOrEmail' => 'Login ou E-mail',
+	'Login_LogIn' => 'Conectar',
+	'Login_Logout' => 'Desconectar',
+	'Login_LostYourPassword' => 'Esqueceu o contrasinal?',
+	'Login_RemindPassword' => 'Lembrar contrasinal',
+	'Login_PasswordReminder' => 'Por favor, introduzca o seu nome de usuario ou enderezo de correo electrónico. Recibirá un novo contrasinal por correo electrónico',
+	'Login_InvalidUsernameEmail' => 'O nome do usuario ou o enderezo de correo electrónicoo son incorrectos',
+	'Login_MailTopicPasswordRecovery' => 'Recuperar contrasinal',
+	'Login_PasswordSent' => 'O contrasinal acaba de ser enviado. Comprobe o seu correo electrónico.',
+	'Login_ContactAdmin' => 'Posible razón: o seu aloxamento pode ter deshabilitado a función mail().<br>Por favor contacte co seu administrador de piwik.',
+	'Provider_WidgetProviders' => 'Provedores',
+	'Provider_SubmenuLocationsProvider' => 'Localizacións e provedor',
 	'Referers_SearchEngines' => 'Motores de busca',
 	'Referers_Keywords' => 'Palabras clave',
 	'Referers_DirectEntry' => 'Entrada directa',
 	'Referers_Websites' => 'Páxinas web',
-	'Referers_Newsletters' => 'Boletíns',
 	'Referers_Campaigns' => 'Campañas',
 	'Referers_Evolution' => 'Evolución no periodo',
 	'Referers_Type' => 'Tipo de Referer',
 	'Referers_TypeDirectEntries' => '%s entradas directas',
 	'Referers_TypeSearchEngines' => '%s desde motores de busca',
 	'Referers_TypeWebsites' => '%s desde outras webs',
-	'Referers_TypeNewsletters' => '%s desde boletíns',
 	'Referers_TypeCampaigns' => '%s desde campañas',
-	'Referers_Other' => 'Outros',
-	'Referers_OtherDistinctSearchEngines' => '%s motores de busca distintos',
-	'Referers_OtherDistinctKeywords' => '%s palabras clave distintas',
-	'Referers_OtherDistinctWebsites' => '%1s páxinas web distintas (usando %2s URLs diferentes)',
-	'Referers_OtherDistinctCampaigns' => '%s campañas distintas',
-	'Referers_TagCloud' => 'Nube de etiquetas de saída',
-	'Referers_SubmenuEvolution' => 'Evolución',
 	'Referers_SubmenuSearchEngines' => 'Motores de busca e palabras clave',
 	'Referers_SubmenuWebsites' => 'Páxinas web',
 	'Referers_SubmenuCampaigns' => 'Campañas',
@@ -112,21 +264,28 @@ $translations = array(
 	'Referers_WidgetExternalWebsites' => 'Lista de webs externas',
 	'Referers_WidgetSearchEngines' => 'Mellores motores de busca',
 	'Referers_WidgetOverview' => 'Xeral',
-	'UserSettings_BrowserFamilies' => 'Familias de navegadores',
-	'UserSettings_Browsers' => 'Navegadores',
-	'UserSettings_Plugins' => 'Plugins',
-	'UserSettings_Configurations' => 'Configuracións',
-	'UserSettings_OperatingSystems' => 'Sistemas Operativos',
-	'UserSettings_Resolutions' => 'Resolucións',
-	'UserSettings_WideScreen' => 'Pantalla panorámica',
-	'UserSettings_WidgetResolutions' => 'Resolucións de pantalla',
-	'UserSettings_WidgetBrowsers' => 'Navegadores dos visitantes',
-	'UserSettings_WidgetPlugins' => 'Lista de plugins',
-	'UserSettings_WidgetWidescreen' => 'Normal / Panorámica',
-	'UserSettings_WidgetBrowserFamilies' => 'Buscadores por familia',
-	'UserSettings_WidgetOperatingSystems' => 'Sistemas Operativos',
-	'UserSettings_WidgetGlobalVisitors' => 'Configuración global de visitantes',
-	'UserSettings_SubmenuSettings' => 'Axustes',
+	'SitesManager_Sites' => 'Sitios',
+	'SitesManager_NoWebsites' => 'Vostede non ten ningunha web que administrar',
+	'SitesManager_AddSite' => 'Engadir un sitio',
+	'SitesManager_Urls' => 'URLs',
+	'SitesManager_MenuSites' => 'Sitios',
+	'SitesManager_DeleteConfirm_js' => 'Está seguro de querer eliminar o sitio %s?',
+	'SitesManager_ExceptionDeleteSite' => 'Non é posible eliminar este sitio xa que é o único que hai rexistrado. Antes de eliminalo, engada un novo.',
+	'SitesManager_ExceptionNoUrl' => 'Debe especificar polo menos unha URL do seu sitio.',
+	'SitesManager_ExceptionEmptyName' => 'O nome do sitio non pode estar baleiro.',
+	'SitesManager_ExceptionInvalidUrl' => 'A URL \'%s\' non é unha URL válida.',
+	'TranslationsAdmin_MenuTranslations' => 'Traducións',
+	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
+	'TranslationsAdmin_LanguageCode' => 'Código de idioma',
+	'TranslationsAdmin_Plugin' => 'Complemento',
+	'TranslationsAdmin_Definition' => 'Definición',
+	'TranslationsAdmin_DefaultString' => 'Cadea por defecto (Castelán)',
+	'TranslationsAdmin_TranslationString' => 'Cadea traducida (Idioma actual: %s)',
+	'TranslationsAdmin_Translations' => 'Traducións',
+	'TranslationsAdmin_FixPermissions' => 'Por favor arranxe os permisos dos ficheiros',
+	'TranslationsAdmin_AddLanguage' => 'Engadir un idioma',
+	'TranslationsAdmin_Export' => 'Exportar idioma',
+	'TranslationsAdmin_Import' => 'Importar idioma',
 	'UserCountry_Country' => 'País',
 	'UserCountry_Continent' => 'Continente',
 	'UserCountry_DistinctCountries' => '%s continentes distintos',
@@ -208,6 +367,7 @@ $translations = array(
 	'UserCountry_country_fo' => 'Islas Feroe',
 	'UserCountry_country_fr' => 'Francia',
 	'UserCountry_country_ga' => 'Gabón',
+	'UserCountry_country_gb' => 'Gran Bretaña',
 	'UserCountry_country_gd' => 'Granada',
 	'UserCountry_country_ge' => 'Xeorxia',
 	'UserCountry_country_gf' => 'Guayana Francesa',
@@ -358,7 +518,6 @@ $translations = array(
 	'UserCountry_country_ua' => 'Ucrania',
 	'UserCountry_country_ug' => 'Uganda',
 	'UserCountry_country_uk' => 'Reino Unido',
-	'UserCountry_country_gb' => 'Gran Bretaña',
 	'UserCountry_country_um' => 'Illas Menores dos EEUU',
 	'UserCountry_country_us' => 'Estados Unidos',
 	'UserCountry_country_uy' => 'Uruguai',
@@ -367,7 +526,7 @@ $translations = array(
 	'UserCountry_country_vc' => 'San Vicente e as Graadinas',
 	'UserCountry_country_ve' => 'Venezuela',
 	'UserCountry_country_vg' => 'Illas Virxes Británicas',
-	'UserCountry_country_vi' => 'Illas Virxes, EE.UU. ',
+	'UserCountry_country_vi' => 'Illas Virxes, EE.UU.',
 	'UserCountry_country_vn' => 'Vietnam',
 	'UserCountry_country_vu' => 'Vanuatu',
 	'UserCountry_country_wf' => 'Wallis e Futuna',
@@ -382,58 +541,24 @@ $translations = array(
 	'UserCountry_continent_eur' => 'Europa',
 	'UserCountry_continent_afr' => 'África',
 	'UserCountry_continent_asi' => 'Asia',
-	'UserCountry_continent_ams' => 'América do Sur e Central',
 	'UserCountry_continent_amn' => 'América do Norte',
+	'UserCountry_continent_ams' => 'América do Sur e Central',
 	'UserCountry_continent_oce' => 'Oceanía',
-	'VisitsSummary_NbVisits' => '%s visitas',
-	'VisitsSummary_NbUniqueVisitors' => '%s visitas únicas',
-	'VisitsSummary_NbActions' => '%s accións (impresións de páxina)',
-	'VisitsSummary_TotalTime' => '%s tempo total dos usuarios en liña',
-	'VisitsSummary_MaxNbActions' => '%s accións máximas nunha visita',
-	'VisitsSummary_NbBounced' => '%s visitantes sairon (saiu da páxina despois dunha páxina)',
-	'VisitsSummary_Evolution' => 'Evolución nos derradeiros 30 %s',
-	'VisitsSummary_Report' => 'Informe',
-	'VisitsSummary_GenerateTime' => '%s segundos para xerar a páxina',
-	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
-	'VisitsSummary_WidgetLastVisits' => 'Gráfico das últimas visitas ',
-	'VisitsSummary_WidgetVisits' => 'Visión xeral de visitas',
-	'VisitsSummary_WidgetLastVisitors' => 'Gráfico dos últimos visitantes únicos',
-	'VisitsSummary_WidgetOverviewGraph' => 'Visión xeral con gráfico',
-	'VisitsSummary_SubmenuOverview' => 'Visión xeral',
-	'VisitFrequency_Evolution' => 'Evolución no período',
-	'VisitFrequency_ReturnVisits' => '%s visitantes que voltaron',
-	'VisitFrequency_ReturnActions' => '%s accións realizadas polos visitantes que voltaron',
-	'VisitFrequency_ReturnMaxActions' => '%s máximo de accións por visitante que volve',
-	'VisitFrequency_ReturnTotalTime' => '%s tempo total empregado por visitantes que voltaron',
-	'VisitFrequency_ReturnBounces' => '%s veces que abandoou a páxina un visitante que voltou',
-	'VisitFrequency_WidgetOverview' => 'Listado de frecuencias',
-	'VisitFrequency_WidgetGraphReturning' => 'Gráfico de visitantes que volven',
-	'VisitFrequency_SubmenuFrequency' => 'Frecuencia',
-	'VisitTime_LocalTime' => 'Visitas por hora local',
-	'VisitTime_ServerTime' => 'Visitas por hora do servidor',
-	'VisitTime_WidgetLocalTime' => 'Visitas por hora local',
-	'VisitTime_WidgetServerTime' => 'Visitas por hora do servidor',
-	'VisitTime_SubmenuTimes' => 'Tempos',
-	'VisitorInterest_VisitsPerDuration' => 'Visitas por duración',
-	'VisitorInterest_VisitsPerNbOfPages' => 'Visitas por número de páxinas visitadas',
-	'VisitorInterest_WidgetLengths' => 'Duración das visitas',
-	'VisitorInterest_WidgetPages' => 'Páxinas vistas por visita',
-	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frecuencia e Lealdade',
-	'Provider_WidgetProviders' => 'Provedores',
-	'Provider_SubmenuLocationsProvider' => 'Localizacións e provedor',
-	'Login_LoginPasswordNotCorrect' => 'Usuario e contrasinal incorrectos',
-	'Login_Login' => 'Usuario',
-	'Login_Password' => 'Contrasinal',
-	'Login_LoginOrEmail' => 'Login ou E-mail',
-	'Login_LogIn' => 'Conectar',
-	'Login_Logout' => 'Desconectar',
-	'Login_LostYourPassword' => 'Esqueceu o contrasinal?',
-	'Login_RemindPassword' => 'Lembrar contrasinal',
-	'Login_PasswordReminder' => 'Por favor, introduzca o seu nome de usuario ou enderezo de correo electrónico. Recibirá un novo contrasinal por correo electrónico',
-	'Login_InvalidUsernameEmail' => 'O nome do usuario ou o enderezo de correo electrónicoo son incorrectos',
-	'Login_MailTopicPasswordRecovery' => 'Recuperar contrasinal',
-	'Login_PasswordSent' => 'O contrasinal acaba de ser enviado. Comprobe o seu correo electrónico.',
-	'Login_ContactAdmin' => 'Posible razón: o seu aloxamento pode ter deshabilitado a función mail().<br>Por favor contacte co seu administrador de piwik.',
+	'UserSettings_BrowserFamilies' => 'Familias de navegadores',
+	'UserSettings_Browsers' => 'Navegadores',
+	'UserSettings_Plugins' => 'Plugins',
+	'UserSettings_Configurations' => 'Configuracións',
+	'UserSettings_OperatingSystems' => 'Sistemas Operativos',
+	'UserSettings_Resolutions' => 'Resolucións',
+	'UserSettings_WideScreen' => 'Pantalla panorámica',
+	'UserSettings_WidgetResolutions' => 'Resolucións de pantalla',
+	'UserSettings_WidgetBrowsers' => 'Navegadores dos visitantes',
+	'UserSettings_WidgetPlugins' => 'Lista de plugins',
+	'UserSettings_WidgetWidescreen' => 'Normal / Panorámica',
+	'UserSettings_WidgetBrowserFamilies' => 'Buscadores por familia',
+	'UserSettings_WidgetOperatingSystems' => 'Sistemas Operativos',
+	'UserSettings_WidgetGlobalVisitors' => 'Configuración global de visitantes',
+	'UserSettings_SubmenuSettings' => 'Axustes',
 	'UsersManager_ManageAccess' => 'Administrar o acceso',
 	'UsersManager_Sites' => 'Sitios',
 	'UsersManager_AllWebsites' => 'Todas as webs',
@@ -443,93 +568,43 @@ $translations = array(
 	'UsersManager_PrivView' => 'Ver',
 	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Está seguro que quere cambiar \'%s\' permisos en todas as páxinas web?',
-	'UsersManager_Login' => 'Conectar',
 	'UsersManager_Password' => 'Contrasinal',
 	'UsersManager_Email' => 'Enderezo electrónico',
 	'UsersManager_Alias' => 'Alias',
-	'UsersManager_Token' => 'token_auth',
 	'UsersManager_Edit' => 'Modificar',
 	'UsersManager_AddUser' => 'Engadir un novo usuario',
 	'UsersManager_MenuUsers' => 'Usuario',
 	'UsersManager_DeleteConfirm_js' => 'Está seguro de que desexa eliminar ao usuario %s?',
 	'UsersManager_ExceptionLoginExists' => 'O nome de usuario \'%s\' xa existe.',
-	'UsersManager_ExceptionInvalidLogin' => 'O nome de usuario só pode conter letras, números, \'_\' , \'-\' ou \'.\'',
-	'UsersManager_ExceptionInvalidPassword' => 'A lonxitude do contrasinal debe ter entre 6 e 26 caracteres',
 	'UsersManager_ExceptionInvalidEmail' => 'O enderezo electrónico non ten un formato correcto.',
 	'UsersManager_ExceptionDeleteDoesNotExist' => 'O usuario \'%s\' non existe, polo que non pode ser eliminado.',
 	'UsersManager_ExceptionAdminAnonymous' => 'Non pode concederlle o acceso de \'administrador\' a un usuario \'anónimo\'.',
 	'UsersManager_ExceptionEditAnonymous' => 'O usuario anónimo non pode ser eliminado ou modificado, xa que é empregado por Piwik para identificar a usuarios  non conectados. Por exemplo, pode facer as súas estatísticas públicas dando acceso á \'visión\' aos visitantes \'anónimos\'.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'O usuario \'%s\' non existe.',
 	'UsersManager_ExceptionAccessValues' => 'O parámetro debe ter acceso a un dos seguintes valores: [%s]',
-	'SitesManager_Sites' => 'Sitios',
-	'SitesManager_JsCode' => 'Código Javascript',
-	'SitesManager_JsCodeHelp' => 'Aquí está o código Javascript que debe incluír en todas as súas páxinas',
-	'SitesManager_ShowJsCode' => 'Amosar código',
-	'SitesManager_NoWebsites' => 'Vostede non ten ningunha web que administrar',
-	'SitesManager_AddSite' => 'Engadir un sitio',
-	'SitesManager_Id' => 'ID',
-	'SitesManager_Name' => 'Nome',
-	'SitesManager_Urls' => 'URLs',
-	'SitesManager_MenuSites' => 'Sitios',
-	'SitesManager_DeleteConfirm_js' => 'Está seguro de querer eliminar o sitio %s?',
-	'SitesManager_ExceptionDeleteSite' => 'Non é posible eliminar este sitio xa que é o único que hai rexistrado. Antes de eliminalo, engada un novo.',
-	'SitesManager_ExceptionNoUrl' => 'Debe especificar polo menos unha URL do seu sitio.',
-	'SitesManager_ExceptionEmptyName' => 'O nome do sitio non pode estar baleiro.',
-	'SitesManager_ExceptionInvalidUrl' => 'A URL \'%s\' non é unha URL válida.',
-	'Installation_Installation' => 'Instalación',
-	'Installation_InstallationStatus' => 'Estado da instalación',
-	'Installation_PercentDone' => '%s %%Hecho',
-	'Installation_NoConfigFound' => 'O ficheiro de configuración de Piwik non se atopou e vostede está tentando acceder a unha páxina de Piwik.<br><b>&nbsp;&nbsp;&raquo; Pode <a href=\'index.php\'>instalar Piwik agora</a></b><br><small>Se instalou Piwik con anterioridade e ten táboas na súa base de datos, non se preocupe, pode reutilizar ditas táboas e manter os datos que se atopan nelas!</small>',
-	'Installation_MysqlSetup' => 'Instalación da base de datos Mysql',
-	'Installation_MysqlErrorConnect' => 'Erro ao tentar conectar coa base de datos',
-	'Installation_JsTag' => 'Etiqueta Javascript',
-	'Installation_JsTagHelp' => '<p>Para contar todos os visitantes, debe inserir o código Javascript en todas as páxinas.</p><p>As súas páxinas non teñen por que estar feitas en PHP, Piwik funcionará en todas as páxinas (tanto se son HTML, ASP, Perl ou calquera outra linguaxe).</p><p>Aquí está o código a inserir: (cópiao e pégao en todas as túas páxinas) </p>',
-	'Installation_Congratulations' => 'Noraboa!',
-	'Installation_CongratulationsHelp' => '<p>Noraboa! A instalación de Piwik foi completada.</p><p>Asegúrese de inserir o código Javascript en todas as páxinas, e agora, agarde aos primeiros visitantes!</p>',
-	'Installation_GoToPiwik' => 'Ir a Piwik',
-	'Installation_SetupWebsite' => 'Configurar unha páxina web',
-	'Installation_SetupWebsiteError' => 'Houbo un erro ao engadir o sitio',
-	'Installation_xeralSetup' => 'Configuración xeral',
-	'Installation_xeralSetupSuccess' => 'Configuración xeral realizada con éxito',
-	'Installation_SystemCheck' => 'Comprobación do sitio',
-	'Installation_SystemCheckPhp' => 'Versión PHP',
-	'Installation_SystemCheckPdo' => 'Extensión PDO',
-	'Installation_SystemCheckPdoMysql' => 'Extensión PDO_Mysql',
-	'Installation_SystemCheckPdoError' => 'Necesita habilitar as extensións PDO e PDO_MYSQL no seu ficheiro php.ini.',
-	'Installation_SystemCheckPdoHelp' => 'Nun servidor Windows, pode engadir as seguintes liñas no seu php.ini %s<br><br>Nun servidor GNU/Linux pode compilar php coas seguinte opción %s no seu php.ini, engada as seguintes liñas %s<br><br>Máis información <a style="color:red" href="http://php.net/pdo">na web de PHP</a>.',
-	'Installation_SystemCheckWriteDirs' => 'Directorios con permisos de escrita',
-	'Installation_SystemCheckWriteDirsHelp' => 'Para arranxar este erro no seu sistema GNU/Linux, tente inserindo os seguintes comandos',
-	'Installation_SystemCheckMemoryLimit' => 'Límite de memoria',
-	'Installation_SystemCheckMemoryLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire o apartado memory_limit no seu ficheiro php.ini se é necesario.',
-	'Installation_SystemCheckGD' => 'GD &gt; 2.x (gráficos)',
-	'Installation_SystemCheckGDHelp' => 'Os sparklines (gráficos pequenos) non funcionarán.',
-	'Installation_SystemCheckTimeLimit' => 'set_time_limit() permitido',
-	'Installation_SystemCheckTimeLimitHelp' => 'Nun sitio web cun tráfico elevado, o proceso de arquivado pode requirir máis memoria da que está dispoñible.<br>Mire a directiva max_execution_time no seu ficheiro php.ini se fose necesario',
-	'Installation_SystemCheckMail' => 'mail() permitido',
-	'Installation_SystemCheckError' => 'Houbo un erro - Debe arranxarse antes de continuar',
-	'Installation_SystemCheckWarning' => 'Piwik traballará correctamente, pero algunhas características poden faltar',
-	'Installation_Tables' => 'Creando as táboas',
-	'Installation_TablesWarning' => 'Algunhas <span id="linkToggle">táboas de Piwik</span> están xa instaladas na base de datos',
-	'Installation_TablesFound' => 'As seguintes táboas atopáronse na base de datos',
-	'Installation_TablesWarningHelp' => 'Ou ben optar pola reutilización de táboas de bases de datos existentes ou seleccionar unha instalación limpa para eliminar todos os datos existentes na base de datos.',
-	'Installation_TablesReuse' => 'Reutilizar as táboas xa existentes',
-	'Installation_TablesDelete' => 'Eliminar as táboas detectadas',
-	'Installation_TablesDeletedSuccess' => 'Táboas existentes de piwik eliminadas con éxito',
-	'Installation_TablesCreatedSuccess' => 'Táboas creadas con éxito!',
-	'Installation_TablesDeleteConfirm' => 'Está seguro de querer eliminar todas as táboas de Piwik desta base de datos?',
-	'Installation_Welcome' => 'Benvido!',
-	'Installation_WelcomeHelp' => '<p>Piwik é unha aplicación de código aberto de estatísticas que che permitirá recompilar información sobre o teu sitio facilmente.</p><p>Este proceso divídese en %s pasos sinxelos que levarán uns 5 minutos.</p>',
-	'TranslationsAdmin_MenuTranslations' => 'Traducións',
-	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
-	'TranslationsAdmin_Plugin' => 'Complemento',
-	'TranslationsAdmin_Definition' => 'Definición',
-	'TranslationsAdmin_DefaultString' => 'Cadea por defecto (Castelán)',
-	'TranslationsAdmin_TranslationString' => 'Cadea traducida (Idioma actual: %s)',
-	'TranslationsAdmin_Translations' => 'Traducións',
-	'TranslationsAdmin_FixPermissions' => 'Por favor arranxe os permisos dos ficheiros',
-	'TranslationsAdmin_AvailableLanguages' => 'Idiomas dispoñibles',
-	'TranslationsAdmin_AddLanguage' => 'Engadir un idioma',
-	'TranslationsAdmin_LanguageCode' => 'Código de idioma',
-	'TranslationsAdmin_Export' => 'Exportar idioma',
-	'TranslationsAdmin_Import' => 'Importar idioma',
+	'VisitFrequency_Evolution' => 'Evolución no período',
+	'VisitFrequency_ReturnVisits' => '%s visitantes que voltaron',
+	'VisitFrequency_ReturnActions' => '%s accións realizadas polos visitantes que voltaron',
+	'VisitFrequency_WidgetOverview' => 'Listado de frecuencias',
+	'VisitFrequency_WidgetGraphReturning' => 'Gráfico de visitantes que volven',
+	'VisitFrequency_SubmenuFrequency' => 'Frecuencia',
+	'VisitorInterest_VisitsPerDuration' => 'Visitas por duración',
+	'VisitorInterest_VisitsPerNbOfPages' => 'Visitas por número de páxinas visitadas',
+	'VisitorInterest_WidgetLengths' => 'Duración das visitas',
+	'VisitorInterest_WidgetPages' => 'Páxinas vistas por visita',
+	'VisitsSummary_NbVisits' => '%s visitas',
+	'VisitsSummary_NbUniqueVisitors' => '%s visitas únicas',
+	'VisitsSummary_MaxNbActions' => '%s accións máximas nunha visita',
+	'VisitsSummary_GenerateTime' => '%s segundos para xerar a páxina',
+	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
+	'VisitsSummary_WidgetLastVisits' => 'Gráfico das últimas visitas',
+	'VisitsSummary_WidgetVisits' => 'Visión xeral de visitas',
+	'VisitsSummary_WidgetLastVisitors' => 'Gráfico dos últimos visitantes únicos',
+	'VisitsSummary_WidgetOverviewGraph' => 'Visión xeral con gráfico',
+	'VisitsSummary_SubmenuOverview' => 'Visión xeral',
+	'VisitTime_LocalTime' => 'Visitas por hora local',
+	'VisitTime_ServerTime' => 'Visitas por hora do servidor',
+	'VisitTime_WidgetLocalTime' => 'Visitas por hora local',
+	'VisitTime_WidgetServerTime' => 'Visitas por hora do servidor',
+	'VisitTime_SubmenuTimes' => 'Tempos',
 );
