@@ -273,10 +273,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'אין מידע להצגה עבור הדוח',
 	'CoreHome_CategoryNoData' => 'אין מידע בקטגוריה זו. נא לנסות "לכלול את כלל האוכלוסייה"',
 	'CoreHome_ShowJSCode' => 'הצגת הJavaScript להטמעה',
-	'CoreHome_IncludeAllPopulation_js' => 'לכלול את כלל האוכלוסייה',
-	'CoreHome_ExcludeLowPopulation_js' => 'למעט אוכלוסייה נמוכה',
 	'CoreHome_PageOf_js' => '%1$s מתוך %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'יום',
 	'CoreHome_PeriodWeek' => 'שבוע',
 	'CoreHome_PeriodMonth' => 'חודש',
@@ -400,7 +397,6 @@ $translations = array(
 	'CustomVariables_ColumnCustomVariableValue' => 'ערך המשתנה',
 	'Dashboard_PluginDescription' => 'סקירה כללית של ניתוח פעילות אתרך. ניתן להתאים אישית את פאנל הסקירה: הוספת יישומונים, שינוי סדר הופעתם. כל משתמש יכול לגש ללוח סקירה כללית משל עצמו.',
 	'Dashboard_Dashboard' => 'פאנל סקירה',
-	'Dashboard_AddWidget' => 'הוספת יישומון...',
 	'Dashboard_DeleteWidgetConfirm' => 'למחוק את היישומון מפאנל הסקירה? 100%?',
 	'Dashboard_SelectWidget' => 'בחירת היישומון להוספה לפאנל הסקירה',
 	'Dashboard_AddPreviewedWidget_js' => 'הוספת היישומון המוצג לפאנל הסקירה',
@@ -484,7 +480,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'תקציר ביקורים',
 	'VisitsSummary_NbVisits' => '%s ביקורים',
 	'VisitsSummary_NbUniqueVisitors' => '%s מבקרים יחודיים',
-	'VisitsSummary_NbActions' => '%s פעולות',
 	'VisitsSummary_NbActionsDescription' => '%s פעולות (צפייה בעמודים, הורדות וקישורים יוצאים)',
 	'VisitsSummary_AverageVisitDuration' => '%s זמן ביקור ממוצע',
 	'VisitsSummary_MaxNbActions' => '%s מספר פעולות מקסימלי בביקור אחד',
