@@ -325,10 +325,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Nincs adat ehhez a jelentéshez.',
 	'CoreHome_CategoryNoData' => 'Nincs adat ebben a kategóriában. Próbáld meg a "Tartalmazza a teljes populációt" opciót.',
 	'CoreHome_ShowJSCode' => 'Mutasd a JavaScript kódot a beillesztéshez',
-	'CoreHome_IncludeAllPopulation_js' => 'Tartalmazza a teljes populációt',
-	'CoreHome_ExcludeLowPopulation_js' => 'Kivéve alacsony populáció',
 	'CoreHome_PageOf_js' => '%1$s — %2$s',
-	'CoreHome_DayFormat' => '%longYear%. %longMonth% %day%., %longDay%',
 	'CoreHome_PeriodDay' => 'Nap',
 	'CoreHome_PeriodWeek' => 'Hét',
 	'CoreHome_PeriodMonth' => 'Hónap',
@@ -448,7 +445,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Hiányos archívum: néhány fájl hiányzik (pl. %s).',
 	'Dashboard_PluginDescription' => 'Webanalitikai vezérlőpultod. Állítsd be ízlésednek megfelelően a saját vezérlőpultod: adj hozzá újabb modulokat vagy változtasd meg azok sorrendjét. Minden felhasználónak saját egyéni vezérlőpultja van.',
 	'Dashboard_Dashboard' => 'Vezérlőpult',
-	'Dashboard_AddWidget' => 'Kiegészítő hozzáadása…',
 	'Dashboard_DeleteWidgetConfirm' => 'Biztosan törölni akarod ezt a modult a vezérlőpultról?',
 	'Dashboard_SelectWidget' => 'Válaszd ki melyik modult szeretnéd hozzáadni a vezérlőpulthoz!',
 	'Dashboard_AddPreviewedWidget_js' => 'Add hozzá a megtekintett modult a vezérlőpultodhoz',
@@ -708,7 +704,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'Közvetlen látogatás',
 	'Referers_Websites' => 'Weboldalak',
 	'Referers_Campaigns' => 'Kampányok',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (%2$s-ból)',
 	'Referers_Evolution' => 'Tendenciák',
 	'Referers_Type' => 'Forgalmi források típusa',
 	'Referers_ColumnRefererType' => 'Forgalmi források típusa',
@@ -744,9 +739,7 @@ $translations = array(
 	'SecurityInfo_Result' => 'Eredmény',
 	'SEO_SeoRankings' => 'Keresőoptimalizálási adatok',
 	'SEO_AlexaRank' => 'Alexa Rank',
-	'SEO_YahooIndexedPages' => 'Yahoo! indexelt weblapok',
 	'SEO_DomainAge' => 'Domain életkora',
-	'SEO_YahooBacklinks' => 'Yahoo! külső linkek',
 	'SEO_Rank' => 'Lekérdezés',
 	'SEO_Backlinks' => 'külső link',
 	'SEO_Pages' => 'weblap',
@@ -1018,8 +1011,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_re' => 'Réunion',
 	'UserCountry_country_ro' => 'Románia',
-	'UserCountry_country_ru' => 'Oroszország',
 	'UserCountry_country_rs' => 'Szerbia',
+	'UserCountry_country_ru' => 'Oroszország',
 	'UserCountry_country_rw' => 'Ruanda',
 	'UserCountry_country_sa' => 'Szaúd-Arábia',
 	'UserCountry_country_sb' => 'Salamon-szigetek',
@@ -1219,7 +1212,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummaryDocumentation' => 'Ez egy összefoglaló nézet a látogatások folyamatáról.',
 	'VisitsSummary_NbVisits' => '%s látogatás',
 	'VisitsSummary_NbUniqueVisitors' => '%s egyedi látogatás',
-	'VisitsSummary_NbActions' => '%s akció (oldal megtekintések)',
 	'VisitsSummary_NbActionsDescription' => '%s akció (weblap megnyitása, letöltések és kimenő linkek)',
 	'VisitsSummary_AverageVisitDuration' => '%s az átlagos látogatás időtartama',
 	'VisitsSummary_MaxNbActions' => '%s akció egy látogatás során maximum',
