@@ -223,7 +223,6 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Það eru eingin gögn til fyrir þessa skýrslu',
 	'CoreHome_ShowJSCode' => 'Sýna JavaScript kóða til að setja inn',
 	'CoreHome_PageOf_js' => '%1$s of %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'Dagur',
 	'CoreHome_PeriodWeek' => 'Vika',
 	'CoreHome_PeriodMonth' => 'Mánuður',
@@ -296,7 +295,6 @@ $translations = array(
 	'CorePluginsAdmin_MenuPlugins' => 'Íbætur',
 	'Dashboard_PluginDescription' => 'Vefgreiningarskjáborðið þitt. Þú getur sérsniðið skjáborðið þitt: bætt við nýjum aukahlutum, breytt uppröðun aukahluta. Sérhver notandi hefur aðgang að sínu eigin sérsniðna skjáborði.',
 	'Dashboard_Dashboard' => 'Skjáborð',
-	'Dashboard_AddWidget' => 'Bæta við aukahlut...',
 	'Dashboard_DeleteWidgetConfirm' => 'Ertu viss um að þú viljir eyða þessum aukahlut af skjáborðinu.',
 	'Dashboard_SelectWidget' => 'Veldu aukahlutinn til að bæta við skjáborðið',
 	'Dashboard_AddPreviewedWidget_js' => 'Bæta forskoðuðum aukahlut á skjáborðið',
