@@ -257,10 +257,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'このリポートのデータがありません。',
 	'CoreHome_CategoryNoData' => 'このカテゴリにデータはありません。 "すべての母集団（統計の対象とする集団）を含める" を試してみてください。',
 	'CoreHome_ShowJSCode' => '挿入する javascript コードを表示',
-	'CoreHome_IncludeAllPopulation_js' => 'すべての母集団（統計の対象とする集団）を含める',
-	'CoreHome_ExcludeLowPopulation_js' => '低い母集団（統計の対象とする集団）を除外する',
 	'CoreHome_PageOf_js' => '%1$s / %2$s',
-	'CoreHome_DayFormat' => '%longYear% %longMonth% %day% %longDay%',
 	'CoreHome_PeriodDay' => '日',
 	'CoreHome_PeriodWeek' => '週',
 	'CoreHome_PeriodMonth' => '月',
@@ -380,7 +377,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'アーカイブが不完全です：いくつかのファイルが不足しています（%s など）。',
 	'Dashboard_PluginDescription' => 'ウェブ解析のダッシュボードです。 新しいウィジェットを追加したり、ウィジェットの並び順を変更することで、あなたのダッシュボードをカスタマイズすることができます。 各ユーザーは、ユーザー自身のカスタムダッシュボードにアクセスすることができます。',
 	'Dashboard_Dashboard' => 'ダッシュボード',
-	'Dashboard_AddWidget' => 'ウィジェットを追加...',
 	'Dashboard_DeleteWidgetConfirm' => '本当にこのウィジェットをダッシュボードから削除しますか？',
 	'Dashboard_SelectWidget' => 'ダッシュボードに追加するウィジェットの選択',
 	'Dashboard_AddPreviewedWidget_js' => 'プレビューされたウィジェットをダッシュボードに追加します',
@@ -623,7 +619,6 @@ $translations = array(
 	'Mobile_EnableGraphsLabel' => 'グラフの表示',
 	'Mobile_DefaultReportDate' => 'リポートの日付',
 	'Mobile_MultiChartLabel' => 'スパークラインの表示',
-	'Mobile_MultiChartInfo' => 'ウェルカム画面の各ウェブサイトの隣',
 	'Mobile_NetworkNotReachable' => 'ネットワークに到達できませんでした',
 	'Mobile_SaveSuccessError' => '設定を確認してください',
 	'Mobile_YouAreOffline' => '現在はオフラインです',
@@ -640,7 +635,6 @@ $translations = array(
 	'Referers_DirectEntry' => '直接アクセス',
 	'Referers_Websites' => 'ウェブサイト',
 	'Referers_Campaigns' => 'キャンペーン',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s （%2$s経由）',
 	'Referers_Evolution' => '一定期間の推移',
 	'Referers_Type' => '参照元タイプ',
 	'Referers_ColumnRefererType' => '参照元タイプ',
@@ -676,9 +670,7 @@ $translations = array(
 	'SecurityInfo_Result' => '結果',
 	'SEO_SeoRankings' => 'SEO ランキング',
 	'SEO_AlexaRank' => 'Alexa ランク',
-	'SEO_YahooIndexedPages' => 'Yahoo インデックスページ',
 	'SEO_DomainAge' => 'ドメインエイジ',
-	'SEO_YahooBacklinks' => 'Yahoo バックリンク',
 	'SEO_Rank' => 'ランク',
 	'SEO_Backlinks' => 'バックリンク',
 	'SEO_Pages' => 'ページ',
@@ -949,8 +941,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'カタール',
 	'UserCountry_country_re' => 'レユニオン（フランス領）',
 	'UserCountry_country_ro' => 'ルーマニア',
-	'UserCountry_country_ru' => 'ロシア連邦',
 	'UserCountry_country_rs' => 'セルビア',
+	'UserCountry_country_ru' => 'ロシア連邦',
 	'UserCountry_country_rw' => 'ルワンダ',
 	'UserCountry_country_sa' => 'サウジアラビア',
 	'UserCountry_country_sb' => 'ソロモン諸島',
