@@ -1,4 +1,4 @@
-<?php 
+<?php
 $translations = array(
 	'General_Locale' => 'ko_KR.UTF-8',
 	'General_TranslatorName' => 'Jong-In Kim',
@@ -7,7 +7,6 @@ $translations = array(
 	'General_OriginalLanguageName' => '한국어',
 	'General_HelloUser' => '안녕하세요, %s 님!',
 	'General_OpenSourceWebAnalytics' => '오픈 소스 웹 분석기',
-	'General_YourDashboard' => '대시보드',
 	'General_API' => 'API',
 	'General_Widgets' => '위젯',
 	'General_Settings' => '설정',
@@ -27,7 +26,6 @@ $translations = array(
 	'General_Done' => '끝',
 	'General_LoadingData' => '데이터 로딩중...',
 	'General_Loading_js' => '로딩중...',
-	'General_ErrorRequest' => '요청중에 문제가 발생했습니다. 다시 시도해보세요.',
 	'General_Next' => '다음',
 	'General_Previous' => '이전',
 	'General_Search' => '검색',
@@ -36,11 +34,10 @@ $translations = array(
 	'General_Piechart' => '파이차트',
 	'General_TagCloud' => '태그 클라우드',
 	'General_VBarGraph' => '수직 막대 그래프',
-	'General_Export' => '내보내기',
-	'General_ExportAsImage' => '이미지로 내보내기',
-	'General_SaveImageOnYourComputer' => '컴퓨터에 이미지를 저장하기 위해서 마우스 우클릭 후 "이미지로 저장..."을 선택하세요.',
 	'General_Refresh' => '페이지 새로고침',
 	'General_Visitors' => '방문자 수',
+	'General_Export' => '내보내기',
+	'General_ErrorRequest' => '요청중에 문제가 발생했습니다. 다시 시도해보세요.',
 	'General_ColumnNbUniqVisitors' => '고유 방문자 수',
 	'General_ColumnNbVisits' => '방문 수',
 	'General_ColumnNbActions' => '활동 수',
@@ -58,10 +55,7 @@ $translations = array(
 	'General_Website' => '웹사이트',
 	'General_NoDataForGraph' => '이 그래프를 위한 데이터가 없습니다.',
 	'General_NoDataForTagCloud' => '이 태그 클라우드를 위한 데이터가 없습니다.',
-	'General_DisplayNormalTable' => '일반 테이블 표시',
-	'General_DisplayMoreData' => '더 많은 데이터 표시',
-	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s 은 협력 프로젝트입니다. %3$s 만약 Piwik이 마음에 드신다면, 도와주실 수 있습니다! %4$s 어떻게 Piwik에 도움을 줄 수 있는지 보시겠습니까?%5$s ',
-	'General_YouAreCurrentlyViewingDemoOfPiwik' => '현재 %s 의 데모를 보고 있습니다; 풀버전을 %sdownload%s 받으세요! %s 확인하세요',
+	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s 은 협력 프로젝트입니다. %3$s 만약 Piwik이 마음에 드신다면, 도와주실 수 있습니다! %4$s 어떻게 Piwik에 도움을 줄 수 있는지 보시겠습니까?%5$s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s 이 사용 가능합니다. %2$s 지금 업데이트하세요!%3$s (보기: %4$s 변경%5$s).',
 	'General_BackToPiwik' => 'Piwik으로 돌아가기',
 	'General_ShortMonth_1' => '1월',
@@ -102,33 +96,21 @@ $translations = array(
 	'General_LongDay_5' => '금요일',
 	'General_LongDay_6' => '토요일',
 	'General_LongDay_7' => '일요일',
-	'CorePluginsAdmin_Plugins' => '플러그인',
-	'CorePluginsAdmin_PluginsManagement' => '플러그인 관리',
-	'CorePluginsAdmin_MainDescription' => '플러그인 확장과 Piwik의 기능성 확장페이지입니다. 플러그인이 한번 설치되면 이곳에서 활성화하거나 비활성화하실 수 있습니다.',
-	'CorePluginsAdmin_Plugin' => '플러그인',
-	'CorePluginsAdmin_Version' => '버전',
-	'CorePluginsAdmin_Description' => '설명',
-	'CorePluginsAdmin_Status' => '상태',
-	'CorePluginsAdmin_Action' => '동작',
-	'CorePluginsAdmin_PluginHomepage' => '플러그인 홈페이지',
-	'CorePluginsAdmin_Activated' => '활성화됨',
-	'CorePluginsAdmin_Active' => '활성',
-	'CorePluginsAdmin_Inactive' => '비활성',
-	'CorePluginsAdmin_ActivatedHelp' => '이 플러그인은 비활성화될 수 없습니다',
-	'CorePluginsAdmin_Deactivate' => '비활성화',
-	'CorePluginsAdmin_Activate' => '활성화',
-	'CorePluginsAdmin_MenuPlugins' => '플러그인',
-	'API_QuickDocumentation' => '<h2>API 간단 문서</h2><p>만약 오늘의 데이터가 없다면 먼저 방문자 생성 스크립트를 이용해 <a href=\'misc/generateVisits.php\' target=_blank>몇가지 데이터를 생성</a> 할 수 있습니다.</p><p>모든 방식에 다른 형식을 시도할 수 있습니다. Piwik에서 원하는 어느 데이터든지 매우 쉽게 추출할 수 있습니다!</p><p><b>더 많은 정보를 위해서 <a href=\'http://dev.piwik.org/trac/wiki/API\'>공식 API 문서</a> 나 <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API 레퍼런스</a>를 살펴보세요.</b></P><h2>사용자 인증</h2><p>만약 스크립트안의 데이터를 요청하길 원한다면. </b> 코드 <code><u>&token_auth=%s</u></code> 를 API에 넣어 인증 URL을 불러오게 하세요.</p><p>이 token_auth 는 당신의 아이디와 비밀번호와 같이 중요합니다. <b>공유하지 마세요!</p>',
+	'Actions_Actions' => '활동',
+	'Actions_SubmenuPages' => '페이지',
+	'Actions_SubmenuOutlinks' => '아웃링크',
+	'Actions_SubmenuDownloads' => '다운로드',
+	'Actions_ColumnClicks' => '조회수',
+	'Actions_ColumnUniqueClicks' => '고유 조회수',
+	'Actions_ColumnDownloads' => '다운로드 수',
+	'Actions_ColumnUniqueDownloads' => '고유 다운로드 수',
+	'Actions_ColumnPageName' => '페이지명',
+	'Actions_ColumnClickedURL' => '조회한 URL',
+	'Actions_ColumnDownloadURL' => '다운로드 URL',
 	'API_LoadedAPIs' => '성공적으로 %s API를 불러옴',
-	'CoreHome_NoPrivileges' => '\'%s\' 님으로 로그인했으나 Piwik에 어떤 권한도 없는 것 같습니다.<br />Piwik 관리자에게 웹사이트의 \'view\' 접근을 요청해보세요.',
-	'CoreHome_TableNoData' => '이 테이블을 위한 데이터가 없습니다.',
 	'CoreHome_CategoryNoData' => '이 카테고리 안에 데이터가 없습니다. "모든 집단 포함"을 시도해보세요.',
 	'CoreHome_ShowJSCode' => '삽입할 자바스크립트 코드 보기',
-	'CoreHome_IncludeAllPopulation_js' => '모든 집단 포함',
-	'CoreHome_ExcludeLowPopulation_js' => '낮은 집단 제외',
 	'CoreHome_PageOf_js' => '%1$s : %2$s',
-	'CoreHome_Loading_js' => '로딩중...',
-	'CoreHome_DayFormat' => '%longYear%년 %longMonth% %day%일 %longDay%',
 	'CoreHome_PeriodDay' => '일간',
 	'CoreHome_PeriodWeek' => '주간',
 	'CoreHome_PeriodMonth' => '월간',
@@ -182,7 +164,21 @@ $translations = array(
 	'CoreHome_MonthOctober_js' => '10월',
 	'CoreHome_MonthNovember_js' => '11월',
 	'CoreHome_MonthDecember_js' => '12월',
-	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; 업데이트',
+	'CorePluginsAdmin_Plugins' => '플러그인',
+	'CorePluginsAdmin_PluginsManagement' => '플러그인 관리',
+	'CorePluginsAdmin_MainDescription' => '플러그인 확장과 Piwik의 기능성 확장페이지입니다. 플러그인이 한번 설치되면 이곳에서 활성화하거나 비활성화하실 수 있습니다.',
+	'CorePluginsAdmin_Plugin' => '플러그인',
+	'CorePluginsAdmin_Version' => '버전',
+	'CorePluginsAdmin_Status' => '상태',
+	'CorePluginsAdmin_Action' => '동작',
+	'CorePluginsAdmin_PluginHomepage' => '플러그인 홈페이지',
+	'CorePluginsAdmin_Activated' => '활성화됨',
+	'CorePluginsAdmin_Active' => '활성',
+	'CorePluginsAdmin_Inactive' => '비활성',
+	'CorePluginsAdmin_Deactivate' => '비활성화',
+	'CorePluginsAdmin_Activate' => '활성화',
+	'CorePluginsAdmin_MenuPlugins' => '플러그인',
+	'CoreUpdater_UpdateTitle' => 'Piwik › 업데이트',
 	'CoreUpdater_DatabaseUpgradeRequired' => '데이터베이스 업그레이드 필요함',
 	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik 데이터베이스가 오래되었으니 계속하기 이전에 먼저 업그레이드가 되어야 합니다.',
 	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik 데이터베이스가 %1$s 버전에서 %2$s 새 버전으로 업그레이드됩니다.',
@@ -204,26 +200,12 @@ $translations = array(
 	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => '%s 버전으로 자동 업데이트하거나 수동적으로 패키지를 받아서 업데이트 할 수 있습니다:',
 	'CoreUpdater_DownloadX' => '다운로드 %s',
 	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik 원클릭 업데이트가 취소되었습니다. 만약 위의 에러 메세지를 고칠 수 없다면, 수동으로 Piwik을 업데이트하는 것을 권장합니다. %1$s 시작하기 위해 %2$s업데이트 문서%3$s 를 확인하세요!',
-	'CoreUpdate_DownloadingUpdateFromX' => '%s 에서 업데이트 다운로드중',
-	'CoreUpdate_UnpackingTheUpdate' => '업데이트 압축 푸는중',
 	'CoreUpdater_VerifyingUnpackedFiles' => '압축이 풀린 파일 확인중',
 	'CoreUpdater_CreatingBackupOfConfigurationFile' => '%s 안의 설정 파일 백업 생성중',
 	'CoreUpdater_InstallingTheLatestVersion' => '최근 버전 설치중',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik 업데이트가 성공적으로 완료되었습니다!',
 	'CoreUpdater_EmptyDatabaseError' => '데이터베이스 %s 는 비어있습니다. Piwik 설정 파일을 편집하거나 제거해야 합니다.',
-	'Actions_Actions' => '활동',
-	'Actions_SubmenuPages' => '페이지',
-	'Actions_SubmenuOutlinks' => '아웃링크',
-	'Actions_SubmenuDownloads' => '다운로드',
-	'Actions_ColumnClicks' => '조회수',
-	'Actions_ColumnUniqueClicks' => '고유 조회수',
-	'Actions_ColumnDownloads' => '다운로드 수',
-	'Actions_ColumnUniqueDownloads' => '고유 다운로드 수',
-	'Actions_ColumnPageName' => '페이지명',
-	'Actions_ColumnClickedURL' => '조회한 URL',
-	'Actions_ColumnDownloadURL' => '다운로드 URL',
 	'Dashboard_Dashboard' => '대시보드',
-	'Dashboard_AddWidget' => '위젯 추가...',
 	'Dashboard_DeleteWidgetConfirm' => '대시보드에서 이 위젯을 삭제하시겠습니까?',
 	'Dashboard_SelectWidget' => '대시보드에 추가할 위젯 선택',
 	'Dashboard_AddPreviewedWidget_js' => '대시보드에 미리보기된 위젯 추가',
@@ -233,6 +215,79 @@ $translations = array(
 	'Dashboard_TitleClickToAdd_js' => '클릭해서 대시보드에 추가',
 	'Dashboard_LoadingWidget_js' => '위젯 로딩중, 잠시만 기다리세요...',
 	'Dashboard_WidgetNotFound_js' => '위젯을 찾지 못함',
+	'DBStats_DatabaseUsage' => '데이터베이스 사용량',
+	'DBStats_MainDescription' => 'Piwik은 모든 웹 분석 데이터를 MySQL 데이터베이스에 저장하고 있습니다. 현재, Piwik 테이블은 %s 를 사용하고 있습니다.',
+	'DBStats_Table' => '테이블',
+	'DBStats_DataSize' => '데이터 용량',
+	'DBStats_IndexSize' => '인덱스 용량',
+	'DBStats_TotalSize' => '전체 용량',
+	'Goals_ColumnConversions' => '전환수',
+	'Goals_ColumnRevenue' => '수익',
+	'Installation_Installation' => '설치',
+	'Installation_InstallationStatus' => '설치 상태',
+	'Installation_PercentDone' => '%s %% 완료',
+	'Installation_NoConfigFound' => 'Piwik 설정 파일을 찾을 수 없으며 당신은 Piwik 페이지로 접근을 계속 시도하고 있습니다.<br /><b>  » <a href=\'index.php\'>지금 Piwik을 설치하세요.</a></b><br /><small>만약 Piwik을 이전에 설치한 적이 있고 DB에 테이블이 좀 있다면 걱정하지마세요, 같은 테이블을 재사용할 수 있고 현재 데이터를 보존할 수 있습니다!</small>',
+	'Installation_JsTag' => '자바스크립트 태그',
+	'Installation_Congratulations' => '축하합니다',
+	'Installation_CongratulationsHelp' => '<p>축하합니다! Piwik 설치가 완료되었습니다.</p><p>페이지에 자바스크립트 코드가 입력되있는지 확인하시고 첫 방문객을 기다리세요!</p>',
+	'Installation_ContinueToPiwik' => 'Piwik 계속 하기',
+	'Installation_SetupWebsite' => '웹사이트 설정',
+	'Installation_SetupWebsiteError' => '웹사이트 추가중에 에러가 있었습니다',
+	'Installation_SuperUserLogin' => '슈퍼 사용자 로그인',
+	'Installation_Password' => '비밀번호',
+	'Installation_PasswordRepeat' => '비밀번호 (반복)',
+	'Installation_Email' => '이메일',
+	'Installation_SecurityNewsletter' => 'Piwik의 주요 업그레이드 그리고 보안 경고를 이메일로 받기',
+	'Installation_CommunityNewsletter' => '커뮤니티 업데이트를 이메일로 받기 (새로운 플러그인,새로운 기능 등등)',
+	'Installation_PasswordDoNotMatch' => '비밀번호가 맞지 않습니다',
+	'Installation_Requirements' => 'Piwik 요구 사항',
+	'Installation_Optional' => '옵션',
+	'Installation_Legend' => '범례',
+	'Installation_SystemCheck' => '시스템 체크',
+	'Installation_SystemCheckPhp' => 'PHP 버전',
+	'Installation_SystemCheckExtensions' => '필수 확장',
+	'Installation_SystemCheckSplHelp' => '스탠다드 PHP 라이브러리가 활성화된 상태로 PHP를 설정하고 리빌딩해야 합니다. (기본).',
+	'Installation_SystemCheckZlibHelp' => 'zlib 지원 활성화가 된 상태로 PHP를 설정하고 리빌빙해야 합니다.',
+	'Installation_SystemCheckWriteDirs' => '쓰기 접근 가능 디렉토리',
+	'Installation_SystemCheckWriteDirsHelp' => '리눅스 시스템에서 이 에러를 고치기 위해서, 다음 명령어를 입력해보세요.',
+	'Installation_SystemCheckMemoryLimit' => '메모리 제한',
+	'Installation_SystemCheckMemoryLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 높은 메모리를 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 memory_limit을 변경하세요.',
+	'Installation_SystemCheckGD' => 'GD > 2.x (그래픽)',
+	'Installation_SystemCheckGDHelp' => '스파크라인(소규모 그래프)은 작동하지 않습니다.',
+	'Installation_SystemCheckFunctions' => '필수 기능',
+	'Installation_SystemCheckTimeLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 많은 시간을 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 max_execution_time을 변경하세요..',
+	'Installation_SystemCheckMailHelp' => 'mail() 없이 피드백과 잊어버린 비밀번호 메세지는 보내지지 않습니다.',
+	'Installation_SystemCheckError' => '에러 발생 - 진행 전에 수정이 필요함',
+	'Installation_SystemCheckWarning' => 'Piwik 은 정상적으로 작동하지만 몇몇의 기능이 작동하지 않을 수 있습니다.',
+	'Installation_Tables' => '테이블 생성',
+	'Installation_TablesWithSameNamesFound' => '몇몇의 테이블: %1$s / 데이터베이스: %2$s 가 Piwik이 생성하려고 하는 테이블 이름과 같습니다.',
+	'Installation_TablesFound' => '데이터베이스에서 다음의 테이블을 찾았습니다',
+	'Installation_TablesWarningHelp' => '존재하는 데이터베이스 테이블을 재사용하거나 모든 존재하는 데이터를 삭제하고 클린 설치를 할 지 선택하세요.',
+	'Installation_TablesReuse' => '존재하는 테이블을 재사용',
+	'Installation_TablesDelete' => '감지된 테이블 삭제',
+	'Installation_TablesDeletedSuccess' => '존재하는 Piwik 테이블을 성공적으로 삭제했습니다',
+	'Installation_TablesCreatedSuccess' => '테이블 생성을 성공적으로 마쳤습니다!',
+	'Installation_DatabaseCreatedSuccess' => '데이터베이스 %s 를 성공적으로 생성했습니다!',
+	'Installation_GoBackAndDefinePrefix' => '돌아가서 Piwik 테이블을 위해 Prefix를 정의합니다',
+	'Installation_ConfirmDeleteExistingTables' => '테이블 %s 을(를) 데이터베이스로부터 삭제하기를 원합니까? 경고: 이 테이블의 데이터는 복구되지 않습니다!',
+	'Installation_Welcome' => '환영합니다!',
+	'Installation_WelcomeHelp' => '<p>Piwik 은 오픈 소스 웹 분석 소프트웨어로써 쉽고 원하는 정보를 당신의 방문자들로부터 얻을 수 있게 해줍니다.</p><p>이 과정은 %s 의 쉬운 단계로 나뉘어 있고 5분 정도만 소요됩니다.</p>',
+	'Installation_ErrorInvalidState' => '에러: 설치 과정의 단계를 뛰어넘으려고 하는 것 같습니다, 또는 쿠키가 비활성화거나, 또는 Piwik 설정 파일이 이미 생성되었습니다. %1$s쿠키가 활성화되어 있는지 확인하시고%2$s 설치 첫페이지로 %3$s 돌아가세요 %4$s.',
+	'Login_LoginPasswordNotCorrect' => '사용자명 & 비밀번호가 맞지 않습니다',
+	'Login_Password' => '비밀번호',
+	'Login_LoginOrEmail' => '아이디 또는 이메일',
+	'Login_LogIn' => '로그인',
+	'Login_Logout' => '로그아웃',
+	'Login_LostYourPassword' => '비밀번호를 잊으셨습니까?',
+	'Login_RemindPassword' => '비밀번호 떠올리기',
+	'Login_PasswordReminder' => '사용자명 또는 이메일 주소를 입력하세요. 새 비밀번호를 이메일을 통해 받게될 것입니다.',
+	'Login_InvalidUsernameEmail' => '잘못된 사용자명 그리고/또는 이메일 주소',
+	'Login_MailTopicPasswordRecovery' => '비밀번호 복구',
+	'Login_PasswordSent' => '비밀번호는 방금 전송되었습니다. 이메일을 확인하세요.',
+	'Login_ContactAdmin' => '가능한 이유: 호스트가 메일 기능을 비활성화했을 수 있습니다. <br />당신의 Piwik 관리자에게 연락해보세요.',
+	'Provider_WidgetProviders' => '공급자',
+	'Provider_ColumnProvider' => '공급자',
+	'Provider_SubmenuLocationsProvider' => '위치&공급자',
 	'Referers_Referers' => '리퍼러',
 	'Referers_SearchEngines' => '검색엔진',
 	'Referers_Keywords' => '키워드',
@@ -257,7 +312,6 @@ $translations = array(
 	'Referers_DistinctKeywords' => '고유 키워드',
 	'Referers_DistinctCampaigns' => '고유 캠페인',
 	'Referers_DistinctWebsites' => '고유 웹사이트',
-	'Referers_SubmenuEvolution' => '진행 과정',
 	'Referers_SubmenuSearchEngines' => '검색엔진&키워드',
 	'Referers_SubmenuWebsites' => '웹사이트',
 	'Referers_SubmenuCampaigns' => '캠페인',
@@ -266,29 +320,33 @@ $translations = array(
 	'Referers_WidgetExternalWebsites' => '외부 웹사이트 목록',
 	'Referers_WidgetSearchEngines' => '인기 검색엔진',
 	'Referers_WidgetOverview' => '개요',
-	'UserSettings_VisitorSettings' => '방문자 설정',
-	'UserSettings_BrowserFamilies' => '브라우저 타입',
-	'UserSettings_Browsers' => '브라우저',
-	'UserSettings_Plugins' => '플러그인',
-	'UserSettings_Configurations' => '구성',
-	'UserSettings_OperatingSystems' => '운영체제',
-	'UserSettings_Resolutions' => '해상도',
-	'UserSettings_WideScreen' => '와이드 스크린',
-	'UserSettings_ColumnBrowserFamily' => '브라우저 타입',
-	'UserSettings_ColumnBrowser' => '브라우저',
-	'UserSettings_ColumnPlugin' => '플러그인',
-	'UserSettings_ColumnConfiguration' => '구성',
-	'UserSettings_ColumnOperatingSystem' => '운영체제',
-	'UserSettings_ColumnResolution' => '해상도',
-	'UserSettings_ColumnTypeOfScreen' => '스크린 타입',
-	'UserSettings_WidgetResolutions' => '스크린 해상도',
-	'UserSettings_WidgetBrowsers' => '방문자 브라우저',
-	'UserSettings_WidgetPlugins' => '플러그인 목록',
-	'UserSettings_WidgetWidescreen' => '보통 / 와이드 스크린',
-	'UserSettings_WidgetBrowserFamilies' => '브라우저 타입',
-	'UserSettings_WidgetOperatingSystems' => '운영체제',
-	'UserSettings_WidgetGlobalVisitors' => '글로벌 방문자 구성',
-	'UserSettings_SubmenuSettings' => '설정',
+	'SitesManager_Sites' => '웹사이트',
+	'SitesManager_WebsitesManagement' => '웹사이트 관리',
+	'SitesManager_MainDescription' => '웹 분석 리포트는 웹사이트가 필요합니다! 추가,업데이트,웹사이트 삭제, 그리고 페이지에 삽입한 자바스크립트를 봅니다.',
+	'SitesManager_JsTrackingTag' => '자바스크립트 트래킹 태그',
+	'SitesManager_JsTrackingTagHelp' => '모든 페이지를 포함한 자바스크립트 트래킹 태그입니다.',
+	'SitesManager_ShowTrackingTag' => '트래킹 태그 보기',
+	'SitesManager_NoWebsites' => '관리할 웹사이트를 가지고 있지 않습니다.',
+	'SitesManager_AddSite' => '새 사이트 추가',
+	'SitesManager_Urls' => 'URL',
+	'SitesManager_MenuSites' => '웹사이트',
+	'SitesManager_DeleteConfirm_js' => '%s 웹사이트를 삭제하시겠습니까?',
+	'SitesManager_ExceptionDeleteSite' => '이 웹사이트만 등록되있기에 이 웹사이트를 삭제할 수 없습니다. 새 웹사이트를 먼저 추가하시고 이 웹사이트를 삭제하세요.',
+	'SitesManager_ExceptionNoUrl' => '최소한 하나의 웹사이트 URL을 넣어주셔야 합니다.',
+	'SitesManager_ExceptionEmptyName' => '웹사이트명은 빈칸으로 둘 수 없습니다.',
+	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' 은(는) 유효한 URL이 아닙니다.',
+	'TranslationsAdmin_MenuTranslations' => '번역',
+	'TranslationsAdmin_MenuLanguages' => '언어',
+	'TranslationsAdmin_LanguageCode' => '언어 코드',
+	'TranslationsAdmin_Plugin' => '플러그인',
+	'TranslationsAdmin_Definition' => '정의',
+	'TranslationsAdmin_DefaultString' => '기본 문자 (영어)',
+	'TranslationsAdmin_TranslationString' => '번역 문자 (현재 언어: %s)',
+	'TranslationsAdmin_Translations' => '번역',
+	'TranslationsAdmin_FixPermissions' => '파일시스템 권한을 수정하세요',
+	'TranslationsAdmin_AddLanguage' => '언어 추가',
+	'TranslationsAdmin_Export' => '언어 내보내기',
+	'TranslationsAdmin_Import' => '언어 가져오기',
 	'UserCountry_Country' => '나라',
 	'UserCountry_Continent' => '대륙',
 	'UserCountry_DistinctCountries' => '%s 개의 나라',
@@ -493,8 +551,8 @@ $translations = array(
 	'UserCountry_country_qa' => '카타르',
 	'UserCountry_country_re' => '레위니옹 섬',
 	'UserCountry_country_ro' => '루마니아',
-	'UserCountry_country_ru' => '러시아',
 	'UserCountry_country_rs' => '세르비아',
+	'UserCountry_country_ru' => '러시아',
 	'UserCountry_country_rw' => '르완다',
 	'UserCountry_country_sa' => '사우디 아라비아',
 	'UserCountry_country_sb' => '솔로몬 아일랜드',
@@ -561,69 +619,32 @@ $translations = array(
 	'UserCountry_continent_eur' => '유럽',
 	'UserCountry_continent_afr' => '아프리카',
 	'UserCountry_continent_asi' => '아시아',
-	'UserCountry_continent_ams' => '중남미',
 	'UserCountry_continent_amn' => '북미',
+	'UserCountry_continent_ams' => '중남미',
 	'UserCountry_continent_oce' => '오세아니아',
-	'VisitsSummary_NbVisits' => '%s 방문 수',
-	'VisitsSummary_NbUniqueVisitors' => '%s 고유 방문자 수',
-	'VisitsSummary_NbActions' => '%s 활동 수 (페이지뷰)',
-	'VisitsSummary_TotalTime' => '%s 방문자의 총 방문 시간',
-	'VisitsSummary_MaxNbActions' => '%s 한번 방문의 최대 활동 수',
-	'VisitsSummary_NbVisitsBounced' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
-	'VisitsSummary_EvolutionOverLastPeriods' => '지난 %s 진행 과정',
-	'VisitsSummary_Report' => '리포트',
-	'VisitsSummary_GenerateTime' => '페이지 생성에 %s 초 걸림',
-	'VisitsSummary_GenerateQueries' => '%s 쿼리 실행됨',
-	'VisitsSummary_WidgetLastVisits' => '최근 방문 그래프',
-	'VisitsSummary_WidgetVisits' => '방문자 개요',
-	'VisitsSummary_WidgetLastVisitors' => '최근 고유 방문자 그래프',
-	'VisitsSummary_WidgetOverviewGraph' => '개요 그래프',
-	'VisitsSummary_SubmenuOverview' => '개요',
-	'VisitFrequency_Evolution' => '기간동안 진행 과정',
-	'VisitFrequency_ColumnReturningVisits' => '돌아온 방문 수',
-	'VisitFrequency_ColumnActionsByReturningVisits' => '돌아온 방문의 활동 수',
-	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => '돌아온 방문의 최대 활동 수',
-	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => '돌아온 방문의 총 소요시간 (초당)',
-	'VisitFrequency_ColumnBounceRateForReturningVisits' => '돌아온 방문의 반송률',
-	'VisitFrequency_ReturnVisits' => '%s 돌아온 방문 수',
-	'VisitFrequency_ReturnActions' => '%s 돌아온 방문의 활동 수',
-	'VisitFrequency_ReturnMaxActions' => '%s 돌아온 방문의 최대 활동 수',
-	'VisitFrequency_ReturnTotalTime' => '%s 돌아온 방문의 총 소요시간',
-	'VisitFrequency_ReturnBounceRate' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
-	'VisitFrequency_WidgetOverview' => '프리퀸시 개요',
-	'VisitFrequency_WidgetGraphReturning' => '돌아온 방문 수 그래프',
-	'VisitFrequency_SubmenuFrequency' => '프리퀸시',
-	'VisitTime_LocalTime' => '현지 시간 기준 방문 수',
-	'VisitTime_ServerTime' => '서버 시간 기준 방문 수',
-	'VisitTime_ColumnServerTime' => '서버 시간',
-	'VisitTime_ColumnLocalTime' => '현지 시간',
-	'VisitTime_WidgetLocalTime' => '현지 시간 기준 방문 수',
-	'VisitTime_WidgetServerTime' => '서버 시간 기준 방문 수',
-	'VisitTime_SubmenuTimes' => '시간',
-	'VisitTime_NHour' => '%s시',
-	'VisitorInterest_VisitsPerDuration' => '방문시 소요 시간',
-	'VisitorInterest_VisitsPerNbOfPages' => '방문시 읽은 페이지 수',
-	'VisitorInterest_ColumnVisitDuration' => '방문 시간',
-	'VisitorInterest_ColumnPagesPerVisit' => '방문시 읽은 페이지 수',
-	'VisitorInterest_WidgetLengths' => '방문의 길이',
-	'VisitorInterest_WidgetPages' => '방문시 읽은 페이지 수',
-	'VisitorInterest_SubmenuFrequencyLoyalty' => '방문빈도&충성도',
-	'VisitorInterest_PlusXMin' => '%s분',
-	'VisitorInterest_OnePage' => '1 개의 페이지',
-	'VisitorInterest_NPages' => '%s 개의 페이지',
-	'Login_LoginPasswordNotCorrect' => '사용자명 & 비밀번호가 맞지 않습니다',
-	'Login_Login' => '사용자명',
-	'Login_Password' => '비밀번호',
-	'Login_LoginOrEmail' => '아이디 또는 이메일',
-	'Login_LogIn' => '로그인',
-	'Login_Logout' => '로그아웃',
-	'Login_LostYourPassword' => '비밀번호를 잊으셨습니까?',
-	'Login_RemindPassword' => '비밀번호 떠올리기',
-	'Login_PasswordReminder' => '사용자명 또는 이메일 주소를 입력하세요. 새 비밀번호를 이메일을 통해 받게될 것입니다.',
-	'Login_InvalidUsernameEmail' => '잘못된 사용자명 그리고/또는 이메일 주소',
-	'Login_MailTopicPasswordRecovery' => '비밀번호 복구',
-	'Login_PasswordSent' => '비밀번호는 방금 전송되었습니다. 이메일을 확인하세요.',
-	'Login_ContactAdmin' => '가능한 이유: 호스트가 메일 기능을 비활성화했을 수 있습니다. <br />당신의 Piwik 관리자에게 연락해보세요.',
+	'UserSettings_VisitorSettings' => '방문자 설정',
+	'UserSettings_BrowserFamilies' => '브라우저 타입',
+	'UserSettings_Browsers' => '브라우저',
+	'UserSettings_Plugins' => '플러그인',
+	'UserSettings_Configurations' => '구성',
+	'UserSettings_OperatingSystems' => '운영체제',
+	'UserSettings_Resolutions' => '해상도',
+	'UserSettings_WideScreen' => '와이드 스크린',
+	'UserSettings_ColumnBrowserFamily' => '브라우저 타입',
+	'UserSettings_ColumnBrowser' => '브라우저',
+	'UserSettings_ColumnPlugin' => '플러그인',
+	'UserSettings_ColumnConfiguration' => '구성',
+	'UserSettings_ColumnOperatingSystem' => '운영체제',
+	'UserSettings_ColumnResolution' => '해상도',
+	'UserSettings_ColumnTypeOfScreen' => '스크린 타입',
+	'UserSettings_WidgetResolutions' => '스크린 해상도',
+	'UserSettings_WidgetBrowsers' => '방문자 브라우저',
+	'UserSettings_WidgetPlugins' => '플러그인 목록',
+	'UserSettings_WidgetWidescreen' => '보통 / 와이드 스크린',
+	'UserSettings_WidgetBrowserFamilies' => '브라우저 타입',
+	'UserSettings_WidgetOperatingSystems' => '운영체제',
+	'UserSettings_WidgetGlobalVisitors' => '글로벌 방문자 구성',
+	'UserSettings_SubmenuSettings' => '설정',
 	'UsersManager_UsersManagement' => '사용자 관리',
 	'UsersManager_UsersManagementMainDescription' => '새로운 사용자를 생성하거나 또는 존재하는 사용자를 업데이트할 수 있습니다. 그리고 위에서 그들의 권한을 설정할 수 있습니다.',
 	'UsersManager_ManageAccess' => '관리 접근',
@@ -636,7 +657,6 @@ $translations = array(
 	'UsersManager_PrivView' => '보기',
 	'UsersManager_PrivAdmin' => '관리자',
 	'UsersManager_ChangeAllConfirm' => '모든 웹사이트에 대한 \'%s\' 권한을 변경하시겠습니까?',
-	'UsersManager_Login' => '로그인',
 	'UsersManager_Password' => '비밀번호',
 	'UsersManager_Email' => '이메일',
 	'UsersManager_Alias' => '별명',
@@ -647,113 +667,50 @@ $translations = array(
 	'UsersManager_ExceptionLoginExists' => '\'%s\' 님은 이미 존재합니다.',
 	'UsersManager_ExceptionEmailExists' => '\'%s\' 의 이메일을 가진 사용자는 이미 존재합니다.',
 	'UsersManager_ExceptionInvalidLoginFormat' => '아이디는 %1$s 에서 %2$s 사이의 글자 수여야 하고 오직 문자,숫자, 또는 \'_\' 나 \'-\' 또는 \'.\'만 포함해야 합니다.',
-	'UsersManager_ExceptionInvalidPassword' => '비밀번호는 6 에서 26 글자 수 사이여야만 합니다.',
 	'UsersManager_ExceptionInvalidEmail' => '이메일이 유효한 형식이 아닙니다.',
 	'UsersManager_ExceptionDeleteDoesNotExist' => '사용자 \'%s\' 님은 존재하지 않아서 삭제가 불가능합니다.',
-	'UsersManager_ExceptionAdminAnonymous' => ' \'관리자\' 권한을 \'익명\' 사용자에게 줄 수 없습니다.',
+	'UsersManager_ExceptionAdminAnonymous' => '\'관리자\' 권한을 \'익명\' 사용자에게 줄 수 없습니다.',
 	'UsersManager_ExceptionEditAnonymous' => '익명 사용자는 편집이나 삭제를 할 수 없습니다. Piwik에서 아직 로그인하지 않은 사용자를 골라낼 때 사용하기 때문입니다. 예를 들어, \'보기\' 접근을 \'익명\' 사용자에게 주어서 당신의 상태를 공개할 수 있습니다.',
 	'UsersManager_ExceptionSuperUser' => '요청한 사용자는 슈퍼 사용자이며 API를 통해 쿼리,편집,삭제할 수 없습니다. Piwik 설정 파일에서 슈퍼 사용자를 수동으로 편집할 수 있습니다.',
 	'UsersManager_ExceptionUserDoesNotExist' => '사용자 \'%s\' 님은 존재하지 않습니다.',
 	'UsersManager_ExceptionAccessValues' => '파라미터 접근은 다음과 같은 값중에 하나여야 합니다 : [ %s ]',
-	'SitesManager_Sites' => '웹사이트',
-	'SitesManager_WebsitesManagement' => '웹사이트 관리',
-	'SitesManager_MainDescription' => '웹 분석 리포트는 웹사이트가 필요합니다! 추가,업데이트,웹사이트 삭제, 그리고 페이지에 삽입한 자바스크립트를 봅니다.',
-	'SitesManager_JsTrackingTag' => '자바스크립트 트래킹 태그',
-	'SitesManager_JsTrackingTagHelp' => '모든 페이지를 포함한 자바스크립트 트래킹 태그입니다.',
-	'SitesManager_ShowTrackingTag' => '트래킹 태그 보기',
-	'SitesManager_NoWebsites' => '관리할 웹사이트를 가지고 있지 않습니다.',
-	'SitesManager_AddSite' => '새 사이트 추가',
-	'SitesManager_Id' => '아이디',
-	'SitesManager_Name' => '이름',
-	'SitesManager_Urls' => 'URL',
-	'SitesManager_MenuSites' => '웹사이트',
-	'SitesManager_DeleteConfirm_js' => '%s 웹사이트를 삭제하시겠습니까?',
-	'SitesManager_ExceptionDeleteSite' => '이 웹사이트만 등록되있기에 이 웹사이트를 삭제할 수 없습니다. 새 웹사이트를 먼저 추가하시고 이 웹사이트를 삭제하세요.',
-	'SitesManager_ExceptionNoUrl' => '최소한 하나의 웹사이트 URL을 넣어주셔야 합니다.',
-	'SitesManager_ExceptionEmptyName' => '웹사이트명은 빈칸으로 둘 수 없습니다.',
-	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' 은(는) 유효한 URL이 아닙니다.',
-	'Installation_Installation' => '설치',
-	'Installation_InstallationStatus' => '설치 상태',
-	'Installation_PercentDone' => '%s %% 완료',
-	'Installation_NoConfigFound' => 'Piwik 설정 파일을 찾을 수 없으며 당신은 Piwik 페이지로 접근을 계속 시도하고 있습니다.<br /><b>&nbsp;&nbsp;&raquo; <a href=\'index.php\'>지금 Piwik을 설치하세요.</a></b><br /><small>만약 Piwik을 이전에 설치한 적이 있고 DB에 테이블이 좀 있다면 걱정하지마세요, 같은 테이블을 재사용할 수 있고 현재 데이터를 보존할 수 있습니다!</small>',
-	'Installation_MysqlSetup' => 'MySQL 데이터베이스 설정',
-	'Installation_MysqlErrorConnect' => 'MySQL 데이터베이스에 연결을 시도하는 도중에 에러 발생',
-	'Installation_JsTag' => '자바스크립트 태그',
-	'Installation_JsTagHelp' => '<p>모든 방문자를 세려면, 자바스크립트 코드를 모든 페이지에 삽입해야 합니다.</p><p>Y페이지는 PHP로 만들어질 필요는 없으며, Piwik은 모든 종류의 페이지에서 작동합니다(HTML, ASP, Perl 또는 다른 언어 상관없이).</p><p>삽입해야 될 코드입니다: (복사하고 모든 페이지에 붙여넣기하세요.) </p>',
-	'Installation_Congratulations' => '축하합니다',
-	'Installation_CongratulationsHelp' => '<p>축하합니다! Piwik 설치가 완료되었습니다.</p><p>페이지에 자바스크립트 코드가 입력되있는지 확인하시고 첫 방문객을 기다리세요!</p>',
-	'Installation_ContinueToPiwik' => 'Piwik 계속 하기',
-	'Installation_SetupWebsite' => '웹사이트 설정',
-	'Installation_SetupWebsiteError' => '웹사이트 추가중에 에러가 있었습니다',
-	'Installation_GeneralSetup' => '일반 설정',
-	'Installation_GeneralSetupSuccess' => '일반 설정을 성공적으로 구성하였습니다',
-	'Installation_SuperUserLogin' => '슈퍼 사용자 로그인',
-	'Installation_Password' => '비밀번호',
-	'Installation_PasswordRepeat' => '비밀번호 (반복)',
-	'Installation_Email' => '이메일',
-	'Installation_SecurityNewsletter' => 'Piwik의 주요 업그레이드 그리고 보안 경고를 이메일로 받기',
-	'Installation_CommunityNewsletter' => '커뮤니티 업데이트를 이메일로 받기 (새로운 플러그인,새로운 기능 등등)',
-	'Installation_PasswordDoNotMatch' => '비밀번호가 맞지 않습니다',
-	'Installation_SubmitGo' => '실행!',
-	'Installation_Requirements' => 'Piwik 요구 사항',
-	'Installation_Optional' => '옵션',
-	'Installation_Legend' => '범례',
-	'Installation_SystemCheck' => '시스템 체크',
-	'Installation_SystemCheckPhp' => 'PHP 버전',
-	'Installation_SystemCheckExtensions' => '필수 확장',
-	'Installation_SystemCheckPdoHelp' => 'php.ini 파일 안의 PDO 확장을 활성화해야 합니다.',
-	'Installation_SystemCheckPdoMysqlHelp' => 'php.ini 파일 안의 PDO_MYSQL 확장을 활성화해야 합니다.',
-	'Installation_SystemCheckSplHelp' => '스탠다드 PHP 라이브러리가 활성화된 상태로 PHP를 설정하고 리빌딩해야 합니다. (기본).',
-	'Installation_SystemCheckZlibHelp' => 'zlib 지원 활성화가 된 상태로 PHP를 설정하고 리빌빙해야 합니다.',
-	'Installation_SystemCheckWriteDirs' => '쓰기 접근 가능 디렉토리',
-	'Installation_SystemCheckWriteDirsHelp' => '리눅스 시스템에서 이 에러를 고치기 위해서, 다음 명령어를 입력해보세요.',
-	'Installation_SystemCheckMemoryLimit' => '메모리 제한',
-	'Installation_SystemCheckMemoryLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 높은 메모리를 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 memory_limit을 변경하세요.',
-	'Installation_SystemCheckGD' => 'GD &gt; 2.x (그래픽)',
-	'Installation_SystemCheckGDHelp' => '스파크라인(소규모 그래프)은 작동하지 않습니다.',
-	'Installation_SystemCheckFunctions' => '필수 기능',
-	'Installation_SystemCheckTimeLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 많은 시간을 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 max_execution_time을 변경하세요..',
-	'Installation_SystemCheckMailHelp' => 'mail() 없이 피드백과 잊어버린 비밀번호 메세지는 보내지지 않습니다.',
-	'Installation_SystemCheckError' => '에러 발생 - 진행 전에 수정이 필요함',
-	'Installation_SystemCheckWarning' => 'Piwik 은 정상적으로 작동하지만 몇몇의 기능이 작동하지 않을 수 있습니다.',
-	'Installation_Tables' => '테이블 생성',
-	'Installation_TablesWithSameNamesFound' => '몇몇의 테이블: %1$s / 데이터베이스: %2$s 가 Piwik이 생성하려고 하는 테이블 이름과 같습니다.',
-	'Installation_TablesFound' => '데이터베이스에서 다음의 테이블을 찾았습니다',
-	'Installation_TablesWarningHelp' => '존재하는 데이터베이스 테이블을 재사용하거나 모든 존재하는 데이터를 삭제하고 클린 설치를 할 지 선택하세요.',
-	'Installation_TablesReuse' => '존재하는 테이블을 재사용',
-	'Installation_TablesDelete' => '감지된 테이블 삭제',
-	'Installation_TablesDeletedSuccess' => '존재하는 Piwik 테이블을 성공적으로 삭제했습니다',
-	'Installation_TablesCreatedSuccess' => '테이블 생성을 성공적으로 마쳤습니다!',
-	'Installation_DatabaseCreatedSuccess' => '데이터베이스 %s 를 성공적으로 생성했습니다!',
-	'Installation_GoBackAndDefinePrefix' => '돌아가서 Piwik 테이블을 위해 Prefix를 정의합니다',
-	'Installation_ConfirmDeleteExistingTables' => '테이블 %s 을(를) 데이터베이스로부터 삭제하기를 원합니까? 경고: 이 테이블의 데이터는 복구되지 않습니다!',
-	'Installation_Welcome' => '환영합니다!',
-	'Installation_WelcomeHelp' => '<p>Piwik 은 오픈 소스 웹 분석 소프트웨어로써 쉽고 원하는 정보를 당신의 방문자들로부터 얻을 수 있게 해줍니다.</p><p>이 과정은 %s 의 쉬운 단계로 나뉘어 있고 5분 정도만 소요됩니다.</p>',
-	'Installation_ErrorInvalidState' => '에러: 설치 과정의 단계를 뛰어넘으려고 하는 것 같습니다, 또는 쿠키가 비활성화거나, 또는 Piwik 설정 파일이 이미 생성되었습니다. %1$s쿠키가 활성화되어 있는지 확인하시고%2$s 설치 첫페이지로 %3$s 돌아가세요 %4$s.',
-	'Provider_WidgetProviders' => '공급자',
-	'Provider_ColumnProvider' => '공급자',
-	'Provider_SubmenuLocationsProvider' => '위치&공급자',
-	'Goals_ColumnConversions' => '전환수',
-	'Goals_ColumnConversionRate' => '전환율',
-	'Goals_ColumnRevenue' => '수익',
-	'DBStats_DatabaseUsage' => '데이터베이스 사용량',
-	'DBStats_MainDescription' => 'Piwik은 모든 웹 분석 데이터를 MySQL 데이터베이스에 저장하고 있습니다. 현재, Piwik 테이블은 %s 를 사용하고 있습니다.',
-	'DBStats_Table' => '테이블',
-	'DBStats_RowNumber' => '행의 수',
-	'DBStats_DataSize' => '데이터 용량',
-	'DBStats_IndexSize' => '인덱스 용량',
-	'DBStats_TotalSize' => '전체 용량',
-	'TranslationsAdmin_MenuTranslations' => '번역',
-	'TranslationsAdmin_MenuLanguages' => '언어',
-	'TranslationsAdmin_Plugin' => '플러그인',
-	'TranslationsAdmin_Definition' => '정의',
-	'TranslationsAdmin_DefaultString' => '기본 문자 (영어)',
-	'TranslationsAdmin_TranslationString' => '번역 문자 (현재 언어: %s)',
-	'TranslationsAdmin_Translations' => '번역',
-	'TranslationsAdmin_FixPermissions' => '파일시스템 권한을 수정하세요',
-	'TranslationsAdmin_AvailableLanguages' => '사용 가능한 언어',
-	'TranslationsAdmin_AddLanguage' => '언어 추가',
-	'TranslationsAdmin_LanguageCode' => '언어 코드',
-	'TranslationsAdmin_Export' => '언어 내보내기',
-	'TranslationsAdmin_Import' => '언어 가져오기',
+	'VisitFrequency_Evolution' => '기간동안 진행 과정',
+	'VisitFrequency_ColumnReturningVisits' => '돌아온 방문 수',
+	'VisitFrequency_ColumnActionsByReturningVisits' => '돌아온 방문의 활동 수',
+	'VisitFrequency_ColumnBounceRateForReturningVisits' => '돌아온 방문의 반송률',
+	'VisitFrequency_ReturnVisits' => '%s 돌아온 방문 수',
+	'VisitFrequency_ReturnActions' => '%s 돌아온 방문의 활동 수',
+	'VisitFrequency_ReturnBounceRate' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
+	'VisitFrequency_WidgetOverview' => '프리퀸시 개요',
+	'VisitFrequency_WidgetGraphReturning' => '돌아온 방문 수 그래프',
+	'VisitFrequency_SubmenuFrequency' => '프리퀸시',
+	'VisitorInterest_VisitsPerDuration' => '방문시 소요 시간',
+	'VisitorInterest_VisitsPerNbOfPages' => '방문시 읽은 페이지 수',
+	'VisitorInterest_ColumnVisitDuration' => '방문 시간',
+	'VisitorInterest_ColumnPagesPerVisit' => '방문시 읽은 페이지 수',
+	'VisitorInterest_WidgetLengths' => '방문의 길이',
+	'VisitorInterest_WidgetPages' => '방문시 읽은 페이지 수',
+	'VisitorInterest_PlusXMin' => '%s분',
+	'VisitorInterest_OnePage' => '1 개의 페이지',
+	'VisitorInterest_NPages' => '%s 개의 페이지',
+	'VisitsSummary_NbVisits' => '%s 방문 수',
+	'VisitsSummary_NbUniqueVisitors' => '%s 고유 방문자 수',
+	'VisitsSummary_MaxNbActions' => '%s 한번 방문의 최대 활동 수',
+	'VisitsSummary_NbVisitsBounced' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
+	'VisitsSummary_EvolutionOverLastPeriods' => '지난 %s 진행 과정',
+	'VisitsSummary_GenerateTime' => '페이지 생성에 %s 초 걸림',
+	'VisitsSummary_GenerateQueries' => '%s 쿼리 실행됨',
+	'VisitsSummary_WidgetLastVisits' => '최근 방문 그래프',
+	'VisitsSummary_WidgetVisits' => '방문자 개요',
+	'VisitsSummary_WidgetLastVisitors' => '최근 고유 방문자 그래프',
+	'VisitsSummary_WidgetOverviewGraph' => '개요 그래프',
+	'VisitsSummary_SubmenuOverview' => '개요',
+	'VisitTime_LocalTime' => '현지 시간 기준 방문 수',
+	'VisitTime_ServerTime' => '서버 시간 기준 방문 수',
+	'VisitTime_ColumnServerTime' => '서버 시간',
+	'VisitTime_ColumnLocalTime' => '현지 시간',
+	'VisitTime_WidgetLocalTime' => '현지 시간 기준 방문 수',
+	'VisitTime_WidgetServerTime' => '서버 시간 기준 방문 수',
+	'VisitTime_SubmenuTimes' => '시간',
+	'VisitTime_NHour' => '%s시',
 );
