@@ -292,9 +292,7 @@ $translations = array(
 	'PrivacyManager_TeaserHeadline' => 'Privatumo nustatymai',
 	'PrivacyManager_MenuPrivacySettings' => 'Privatumas',
 	'PrivacyManager_UseAnonymizeIp' => 'Paslėpti lankytojų IP adresus',
-	'PrivacyManager_DeleteLogSettings' => 'Ištrinti senus apsilankymų įrašus duombazėje',
 	'PrivacyManager_DeleteLogsOlderThan' => 'Ištrinti įrašus senesnius nei',
-	'PrivacyManager_DeleteLogInterval' => 'Ištrinti senus įrašus kas',
 	'PrivacyManager_DeleteMaxRows' => 'Maksimalus vienu metu trinamų eilučių kiekis:',
 	'PrivacyManager_LastDelete' => 'Paskutinis išvalymas atliktas',
 	'PrivacyManager_NextDelete' => 'Kitas suplanuotas išvalymas',
@@ -304,10 +302,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Nėra duomenų šiai ataskaitai.',
 	'CoreHome_CategoryNoData' => 'Šioje kategorijoje duomenų nėra. Pabandykite "Įtraukti visą populiaciją"',
 	'CoreHome_ShowJSCode' => 'Parodyti JavaScript kodą įvedimui',
-	'CoreHome_IncludeAllPopulation_js' => 'Įtraukti visą populiaciją',
-	'CoreHome_ExcludeLowPopulation_js' => 'Neįtraukti menkos populiacijos',
 	'CoreHome_PageOf_js' => '%1$s iš %2$s',
-	'CoreHome_DayFormat' => '%longDay% %longYear% %longMonth% %day%',
 	'CoreHome_PeriodDay' => 'Diena',
 	'CoreHome_PeriodWeek' => 'Savaitė',
 	'CoreHome_PeriodMonth' => 'Mėnuo',
@@ -425,7 +420,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archyvas nepilnas: trūksta kai kurių failų (pvz. %s).',
 	'Dashboard_PluginDescription' => 'Jūsų žiniatinklio analizės sprendimo skydelis. Galite pritaikyti skydelį savo poreikiams: pridėti naujų valdiklių, pakeisti jų išdėstymo tvarką. Kiekvienas naudotojas gali susikurti savo asmeninį skydelį.',
 	'Dashboard_Dashboard' => 'Skydelis',
-	'Dashboard_AddWidget' => 'Pridėti valdiklį...',
 	'Dashboard_DeleteWidgetConfirm' => 'Ar tikrai norite pašalinti šį valdiklį iš skydelio?',
 	'Dashboard_SelectWidget' => 'Pasirinkite valdiklį, kurį norite įdėti į skydelį',
 	'Dashboard_AddPreviewedWidget_js' => 'Įdėti peržiūrėtą valdiklį į skydelį',
@@ -664,7 +658,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'Tiesioginis apsilankymas',
 	'Referers_Websites' => 'Svetainės',
 	'Referers_Campaigns' => 'Kampanijos',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (iš %2$s)',
 	'Referers_Evolution' => 'Raida periodu',
 	'Referers_Type' => 'Šaltinio tipas',
 	'Referers_ColumnRefererType' => 'Šaltinio tipas',
@@ -701,9 +694,7 @@ $translations = array(
 	'SecurityInfo_Result' => 'Rezultatas',
 	'SEO_SeoRankings' => 'SEO reitingai',
 	'SEO_AlexaRank' => 'Alexa reitingas',
-	'SEO_YahooIndexedPages' => 'Yahoo indeksuoti puslapiai',
 	'SEO_DomainAge' => 'Adresų srities amžius',
-	'SEO_YahooBacklinks' => 'Yahoo nuorodos į svetainę',
 	'SEO_Rank' => 'Reitingas',
 	'SEO_Backlinks' => 'Nuorodos į svetainę',
 	'SEO_Pages' => 'Puslapiai',
@@ -976,8 +967,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Reunion Island',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Rusija',
 	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_ru' => 'Rusija',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudi Arabia',
 	'UserCountry_country_sb' => 'Solomon Islands',
@@ -1160,7 +1151,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'Apsilankymų suvestinė',
 	'VisitsSummary_NbVisits' => '%s apsilankymai',
 	'VisitsSummary_NbUniqueVisitors' => '%s unikalūs lankytojai',
-	'VisitsSummary_NbActions' => '%s veiksmai (puslapių peržiūros)',
 	'VisitsSummary_NbActionsDescription' => '%s veiksmai (puslapio peržiūros, atsisiuntimai ir išorinės nuorodos)',
 	'VisitsSummary_AverageVisitDuration' => '%s vidutinio apsilankymo trukmė',
 	'VisitsSummary_MaxNbActions' => '%s daugiausia veiksmų per apsilankymą',
