@@ -182,10 +182,7 @@ $translations = array(
 	'CoreAdminHome_Administration' => 'Administrasjon',
 	'CoreHome_CategoryNoData' => 'Inga data i denne kategorien. Prøv \'Inkluder heile datasettet\'',
 	'CoreHome_ShowJSCode' => 'Vis JavaScriptkoden for å setja inn.',
-	'CoreHome_IncludeAllPopulation_js' => 'Inkluder heile populasjonen',
-	'CoreHome_ExcludeLowPopulation_js' => 'Ekskluder låg populasjon',
 	'CoreHome_PageOf_js' => '%1$s av %2$s',
-	'CoreHome_DayFormat' => '%langDag% %dag% %langMånad% %langtÅr%',
 	'CoreHome_PeriodDay' => 'Dag',
 	'CoreHome_PeriodWeek' => 'Veke',
 	'CoreHome_PeriodMonth' => 'Månad',
@@ -296,7 +293,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveEmpty' => 'Tomt arkiv.',
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arkivet er mangelfullt: nokon filar manglar (td %s).',
 	'Dashboard_Dashboard' => 'Dashbord',
-	'Dashboard_AddWidget' => 'Legg til ein dings...',
 	'Dashboard_DeleteWidgetConfirm' => 'Er du sikker på at du vil fjerna denne dingsen frå ditt dashbord?',
 	'Dashboard_SelectWidget' => 'Vel den dingsen du vil legga til dashbordet',
 	'Dashboard_AddPreviewedWidget_js' => 'Legg framvist dings til dashbordet',
@@ -708,8 +704,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Reunion Island',
 	'UserCountry_country_ro' => 'Romania',
-	'UserCountry_country_ru' => 'Russland',
 	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_ru' => 'Russland',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudi Arabia',
 	'UserCountry_country_sb' => 'Salomonøyane',
@@ -875,7 +871,6 @@ $translations = array(
 	'VisitorInterest_NPages' => '%s sider',
 	'VisitsSummary_NbVisits' => '%s vitjingar',
 	'VisitsSummary_NbUniqueVisitors' => '%s unike vitjarar',
-	'VisitsSummary_NbActions' => '%s handlingar (sidevisingar)',
 	'VisitsSummary_MaxNbActions' => '%s maks mengd handlingar på ein vitjing',
 	'VisitsSummary_NbVisitsBounced' => '%s vitjarar hev hoppa (forsvunne etter ein sidevising)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Utvikling over den siste %s',
