@@ -1,8 +1,8 @@
 <?php
 $translations = array(
 	'General_Locale' => 'pt_BR.UTF-8',
-	'General_TranslatorName' => 'Marcos Napier, Marcela Ferraro, Zob',
-	'General_TranslatorEmail' => 'marcusbacus@gmail.com, mah_ferraro@yahoo.com.br',
+	'General_TranslatorName' => 'Marcos Napier, Marcela Ferraro, Zob,Raphael Milani',
+	'General_TranslatorEmail' => 'marcusbacus@gmail.com, mah_ferraro@yahoo.com.br , ramilani@gmail.com',
 	'General_EnglishLanguageName' => 'Brazilian Portuguese',
 	'General_OriginalLanguageName' => 'Português brasileiro',
 	'General_HelloUser' => 'Olá, %s!',
@@ -18,6 +18,8 @@ $translations = array(
 	'General_Unknown' => 'Desconhecido',
 	'General_Required' => '%s necessário',
 	'General_NotValid' => '%s não é válido',
+	'General_NotDefined' => '%s não definido',
+	'General_Id' => 'Id',
 	'General_Error' => 'Erro',
 	'General_Warning' => 'Aviso',
 	'General_BackToHomepage' => 'Voltar a página do Piwik',
@@ -25,14 +27,18 @@ $translations = array(
 	'General_No' => 'Não',
 	'General_Delete' => 'Apagar',
 	'General_Report' => 'Relatório',
+	'General_Reports' => 'Relatórios',
 	'General_Edit' => 'Editar',
 	'General_Download' => 'Baixar',
+	'General_Upload' => 'Upload',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Fechar',
+	'General_OrCancel' => 'ou %s Cancele %s',
 	'General_Logout' => 'Sair',
 	'General_Username' => 'Nome de Usuário',
 	'General_Description' => 'Descrição',
 	'General_Done' => 'Pronto',
+	'General_PoweredBy' => 'Powered by',
 	'General_Name' => 'Nome',
 	'General_Value' => 'Valor',
 	'General_Details' => 'Detalhes',
@@ -238,10 +244,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Não existem dados para esse relatório.',
 	'CoreHome_CategoryNoData' => 'Sem dados nesta categoria. Tente o "Incluir toda a população".',
 	'CoreHome_ShowJSCode' => 'Mostra o código JavaScript a inserir',
-	'CoreHome_IncludeAllPopulation_js' => 'Incluir toda a população',
-	'CoreHome_ExcludeLowPopulation_js' => 'Excluir a baixa população',
 	'CoreHome_PageOf_js' => '%1$s de %2$s',
-	'CoreHome_DayFormat' => '%longDia% %dia% %longMes% %longAno%',
 	'CoreHome_PeriodDay' => 'Dia',
 	'CoreHome_PeriodWeek' => 'Semana',
 	'CoreHome_PeriodMonth' => 'Mês',
@@ -359,7 +362,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arquivo está incompleto: alguns arquivos estão faltando (ex. %s).',
 	'Dashboard_PluginDescription' => 'Seu painel de ferramentas',
 	'Dashboard_Dashboard' => 'Painel de Ferramentas',
-	'Dashboard_AddWidget' => 'Adicionar um widget...',
 	'Dashboard_DeleteWidgetConfirm' => 'Tem certeza que deseja excluir este widget do seu Painel?',
 	'Dashboard_SelectWidget' => 'Selecione o widget a adicionar ao painel',
 	'Dashboard_AddPreviewedWidget_js' => 'Adicionar o widget visualizado no preview ao painel',
@@ -585,7 +587,6 @@ $translations = array(
 	'Mobile_AccessUrlLabel' => 'Url de Acesso Piwik',
 	'Mobile_EnableGraphsLabel' => 'Mostrar gráficos',
 	'Mobile_MultiChartLabel' => 'Mostrar sparklines',
-	'Mobile_MultiChartInfo' => 'ao lado de cada website na tela de boas vindas',
 	'Mobile_NetworkNotReachable' => 'Rede não encontrada',
 	'Mobile_SaveSuccessError' => 'Por favor verifique configurações',
 	'Mobile_YouAreOffline' => 'Desculpe, no momento você está offline.',
@@ -602,7 +603,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'Entrada Direta',
 	'Referers_Websites' => 'Websites',
 	'Referers_Campaigns' => 'Campanhas',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (de %2$s)',
 	'Referers_Evolution' => 'Evolução no período',
 	'Referers_Type' => 'Tipo de Referer',
 	'Referers_ColumnRefererType' => 'Tipo de Referer',
@@ -637,9 +637,7 @@ $translations = array(
 	'SecurityInfo_Result' => 'Resultado',
 	'SEO_SeoRankings' => 'Ranking SEO',
 	'SEO_AlexaRank' => 'Rank Alexa',
-	'SEO_YahooIndexedPages' => 'Páginas Yahoo indexadas',
 	'SEO_DomainAge' => 'Idade de Domínio',
-	'SEO_YahooBacklinks' => 'Yahoo Backlinks',
 	'SEO_Rank' => 'Rank',
 	'SEO_Backlinks' => 'Backlinks',
 	'SEO_Pages' => 'Páginas',
@@ -649,6 +647,8 @@ $translations = array(
 	'SitesManager_TrackingTags' => 'Rastreando tags para %s',
 	'SitesManager_WebsitesManagement' => 'Gerenciamento de Sites',
 	'SitesManager_MainDescription' => 'Seus relatórios de Web Analytics precisam de websites! Adiciona, atualiza, elimina websites, e mostra o JavaScript necessário para inserir em suas páginas.',
+	'SitesManager_YouCurrentlyHaveAccessToNWebsites' => 'Você possui atualmente acessos a Websites %s',
+	'SitesManager_OnlyOneSiteAtTime_js' => 'Você pode editar um website por vez. Por favor salve ou cancele as modificações do website atual %s.',
 	'SitesManager_JsTrackingTag' => 'Tag de rastreamento JavaScript',
 	'SitesManager_JsTrackingTagHelp' => 'Aqui está a tag de rastreamento JavaScript a ser incluída em todas as suas páginas',
 	'SitesManager_ShowTrackingTag' => 'mostra tag de rastreamento',
@@ -909,8 +909,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Qatar',
 	'UserCountry_country_re' => 'Ilhas Reunião',
 	'UserCountry_country_ro' => 'Romênia',
-	'UserCountry_country_ru' => 'Rússia',
 	'UserCountry_country_rs' => 'Sérvia',
+	'UserCountry_country_ru' => 'Rússia',
 	'UserCountry_country_rw' => 'Ruanda',
 	'UserCountry_country_sa' => 'Arábia Saudita',
 	'UserCountry_country_sb' => 'Ilhas Salomão',
@@ -1086,7 +1086,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'Resumo dos Visitantes',
 	'VisitsSummary_NbVisits' => '%s visitas',
 	'VisitsSummary_NbUniqueVisitors' => '%s visitantes únicos',
-	'VisitsSummary_NbActions' => '%s ações (page views)',
 	'VisitsSummary_NbActionsDescription' => '%s ações (visualizações de páginas, downloads e links externos)',
 	'VisitsSummary_MaxNbActions' => '%s ações máximas em uma visita',
 	'VisitsSummary_NbVisitsBounced' => '%s visitantes saíram (deixaram o website após uma página)',
