@@ -1,12 +1,13 @@
 <?php
 $translations = array(
 	'General_Locale' => 'sk_SK.UTF-8',
-	'General_TranslatorName' => 'Miroslav Habara, Zdenko Podobný',
-	'General_TranslatorEmail' => 'miroslav.habara@gmail.com, zdenop@gmail.com',
+	'General_TranslatorName' => 'Miroslav Habara, Zdenko Podobný, Juraj "Lup0" Viktorín',
+	'General_TranslatorEmail' => 'miroslav.habara@gmail.com, zdenop@gmail.com, viktorin@automotopneu.sk',
 	'General_EnglishLanguageName' => 'Slovak',
 	'General_OriginalLanguageName' => 'Slovensky',
+	'General_LayoutDirection' => 'ltr',
 	'General_HelloUser' => 'Vitaj %s!',
-	'General_OpenSourceWebAnalytics' => 'Open Source Analýza Webu',
+	'General_OpenSourceWebAnalytics' => 'Analýza Webu na báze Open Source',
 	'General_Dashboard' => 'Nástenka',
 	'General_DashboardForASpecificWebsite' => 'Nástenka pre konkrétnu web stránku',
 	'General_MultiSitesSummary' => 'Všetky webstránky',
@@ -16,8 +17,10 @@ $translations = array(
 	'General_Settings' => 'Nastavenia',
 	'General_GiveUsYourFeedback' => 'Spätná reakcia!',
 	'General_Unknown' => 'Neznáme',
+	'General_Never' => 'Nikdy',
 	'General_Required' => '%s požadované',
 	'General_NotValid' => '%s nie je platné',
+	'General_NotDefined' => '%s nie je definované',
 	'General_Id' => 'Id',
 	'General_Error' => 'Chyba',
 	'General_Warning' => 'Varovanie',
@@ -26,8 +29,10 @@ $translations = array(
 	'General_No' => 'Nie',
 	'General_Delete' => 'Odstrániť',
 	'General_Report' => 'Správa',
+	'General_Reports' => 'Správy',
 	'General_Edit' => 'Upraviť',
 	'General_Download' => 'Stiahnuť',
+	'General_Upload' => 'Nahrať',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Zatvoriť',
 	'General_OrCancel' => 'alebo %s Zatvoriť %s',
@@ -35,88 +40,169 @@ $translations = array(
 	'General_Username' => 'Používateľské meno',
 	'General_Description' => 'Popis',
 	'General_Done' => 'Hotovo',
+	'General_PoweredBy' => 'Beží na',
+	'General_MetricsToPlot' => 'Metriky na zobrazenie',
+	'General_MetricToPlot' => 'Metrika na zobrazenie',
+	'General_RecordsToPlot' => 'Záznamy na zobrazenie',
 	'General_Name' => 'Meno',
 	'General_Value' => 'Hodnota',
+	'General_Total' => 'Spolu',
+	'General_TotalVisitsActionsRevenue' => '(Spolu: %s návštev, %s akcií, %s príjmov)',
+	'General_AverageOrderValue' => 'Prierná hodnota nákupu',
+	'General_PurchasedProducts' => 'Nakúpené produkty',
+	'General_EcommerceOrders' => 'Ecommerce objednávky',
+	'General_AbandonedCarts' => 'Opustené košíky',
+	'General_TotalRevenue' => 'Celkový príjem',
+	'General_ProductRevenue' => 'Príjem z produktu',
+	'General_AveragePrice' => 'Priemerná cena',
+	'General_AverageQuantity' => 'Priemerné množstvo',
+	'General_UniquePurchases' => 'Unikátne nákupy',
+	'General_ProductConversionRate' => 'Konverzná miera produktu',
+	'General_Quantity' => 'Množstvo',
+	'General_Price' => 'Cena',
+	'General_Subtotal' => 'Medzisúčet',
+	'General_Tax' => 'Daň',
+	'General_Shipping' => 'Doprava',
+	'General_Discount' => 'Zľava',
 	'General_Details' => 'Detail',
 	'General_Default' => 'Základné nastavenie',
+	'General_Visit' => 'Návšteva',
+	'General_FromReferrer' => 'z',
+	'General_VisitorIP' => 'IP návštevníka',
+	'General_VisitorID' => 'ID návštevníka',
+	'General_VisitType' => 'Typ návštevníka',
+	'General_VisitTypeExample' => 'Napríklad: Pre výber všetkých návštevníkov, ktorí sa vrátili na webovú stránku, vrátane tých, ktorí niečo nakúpili počas prechádzajúcej návštevy by API požiadavka obsahovala %s',
+	'General_DaysSinceLastVisit' => 'Dní od poslednej návštevy',
+	'General_DaysSinceFirstVisit' => 'Dní od prvej návštevy',
+	'General_DaysSinceLastEcommerceOrder' => 'Dní od poslednej ecommerce objednávky',
+	'General_NumberOfVisits' => 'Počet návštev',
+	'General_VisitConvertedGoal' => 'Návšteva dokončila aspoň jeden cieľ',
+	'General_VisitConvertedGoalId' => 'Návšteva dokončila špecifické ID cieľu',
+	'General_EcommerceVisitStatus' => 'Navštívte stav Ecommerce návštevy na konci trvania návštevy. Napríklad: Pre výber všetkých návštev, ktoré vykonali online objednávku by API požiadavka obsahovala %s',
+	'General_VisitConvertedNGoals' => 'Návšteva dokončila %s cieľov',
+	'General_NewVisitor' => 'Nový návštevník',
+	'General_NewVisits' => 'Nové návštevy',
+	'General_ReturningVisitor' => 'Vracajúci sa návštevník',
+	'General_Visitor' => 'Návštevník',
 	'General_Date' => 'Dátum',
 	'General_Period' => 'Obdobie',
+	'General_ChooseDate' => 'Vybrať dátum',
 	'General_Today' => 'Dnes',
 	'General_Yesterday' => 'Včera',
 	'General_CurrentWeek' => 'Aktuálny týždeň',
 	'General_CurrentMonth' => 'Aktuálny mesiac',
 	'General_CurrentYear' => 'Aktuálny rok',
 	'General_DateRange' => 'Časové obdobie:',
+	'General_DateRangeInPeriodList' => 'Časové obdobie',
+	'General_DateRangeFromTo' => 'Od %s do %s',
+	'General_ApplyDateRange' => 'Použiť časový rozsah',
+	'General_InvalidDateRange_js' => 'Neplatný cašový rozsah, skúste prosím ešte raz',
+	'General_DateRangeFrom_js' => 'Od',
+	'General_DateRangeTo_js' => 'Do',
+	'General_PreviousDays' => 'Predchádzajúcich %s dní (neobsahuje dnešný deň)',
+	'General_LastDays' => 'Posledných %s dní (vrátane dnešného dňa)',
 	'General_LoadingData' => 'Načítavanie dát…',
 	'General_Loading_js' => 'Načítavanie…',
 	'General_GoTo' => 'Prejsť na %s',
 	'General_Next' => 'Ďalej',
 	'General_Previous' => 'Späť',
+	'General_First' => 'Začiatok',
 	'General_Search' => 'Hľadanie',
 	'General_Others' => 'Ostatné',
 	'General_Table' => 'Tabuľka',
 	'General_Piechart' => 'Koláčový graf',
 	'General_TagCloud' => 'Oblak značiek',
 	'General_VBarGraph' => 'Vertikálny stĺpcový graf',
+	'General_View' => 'Zobrazenie',
+	'General_OpenInNewWindow_js' => 'Otvoriť v novom okne',
 	'General_SaveImageOnYourComputer_js' => 'Ak chcete uložiť obrázok na vašom počítači, kliknite pravým tlačidlom na obrázok a vyberte "Uložiť obrázok ako ..."',
 	'General_Refresh' => 'Aktualizovať stránku',
 	'General_Visitors' => 'Návštevníci',
 	'General_ExportThisReport' => 'Exportovať tento dátový súbor v iných formátoch',
 	'General_ExportAsImage_js' => 'Exportovať ako obrázok',
 	'General_Export' => 'Export',
+	'General_ParameterMustIntegerBetween' => 'Parameter %s musí byť číselná hodnota medzi %s a %s.',
 	'General_YourChangesHaveBeenSaved' => 'Vaše zmeny boli uložené.',
 	'General_ErrorRequest' => 'Oops… problém počas požiadavky, prosím skúste znova.',
 	'General_ColumnNbUniqVisitors' => 'Unikátny návštevníci',
+	'General_ColumnNbUniqVisitorsDocumentation' => 'Počet neduplikovaných návštevníkov na vašu webovú stránku. Každý návštevník sa počíta len raz, aj keď stránku navštívi niekoľko ráz za deň.',
 	'General_ColumnNbVisits' => 'Návštevy',
+	'General_ColumnNbVisitsDocumentation' => 'Ak návšteník príde na vašu webovú stránku prvý krát alebo ak navštívi stránku viac ako 30 minút po poslednej impresii, tak sa to bude počítať ako nová návšteva.',
 	'General_ColumnPercentageVisits' => '% Návštevy',
 	'General_ColumnNbActions' => 'Akcie',
+	'General_ColumnNbActionsDocumentation' => 'Počet akcií vykonaných návštevníkmi. Akcie môžu byť zhliadnuté stránky, stiahnutia alebo odchádzajúce prekliky.',
+	'General_NbActions' => 'Počet akcií',
 	'General_ColumnMaxActions' => 'Maximum akcií počas jednej návštevy',
 	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštevníkmi (v sekundách)',
 	'General_ColumnLabel' => 'Popis',
 	'General_ColumnConversionRate' => 'Miera konverzie',
-	'General_ColumnActionsPerVisit' => 'Akcie počas návštevy',
+	'General_ColumnConversionRateDocumentation' => 'Percento náštev spúšťajúcich konverziu cieľa',
+	'General_ColumnActionsPerVisit' => 'Akcií na návštevu',
+	'General_ColumnActionsPerVisitDocumentation' => 'Priemerná hodnota akcií (zhliadnuté stránky, stiahnutia alebo ochádzajúce prekliky) uskutočnených počas návštev.',
 	'General_VisitDuration' => 'Priem. dĺžka návštevy (v sekundách)',
-	'General_ColumnAvgTimeOnSite' => 'Priem. doba na stránke',
-	'General_ColumnBounceRate' => 'Miera návratov',
-	'General_ColumnExitRate' => 'Miera odchodov',
+	'General_ColumnAvgTimeOnSite' => 'Priem. čas na webovom sídle',
+	'General_ColumnAvgTimeOnSiteDocumentation' => 'Priemerná dĺžka návštevy',
+	'General_ColumnVisitDuration' => 'Dĺžka návštevy (v sekundách)',
+	'General_ColumnBounceRate' => 'Miera odchodov',
+	'General_ColumnBounceRateDocumentation' => 'Percento návštev len s jednou zobrazenou stránkou. To znamená, že návštevník opustil webové sídlo hneď zo vstupnej stránky.',
+	'General_ColumnBounceRateForPageDocumentation' => 'Percento návštev so začiatkom aj koncom na tejto stránke.',
+	'General_ColumnPageBounceRateDocumentation' => 'Percento návštev, ktoré začali na tejto stránke a potom priamo z webového sídla odišli.',
+	'General_ColumnExitRate' => 'Miera opustení',
+	'General_ColumnExitRateDocumentation' => 'Percento návštev, ktoré opustili webové sídlo po zhliadnutí tejto stránky.',
 	'General_ColumnPageviews' => 'Zobrazené stránky',
+	'General_ColumnPageviewsDocumentation' => 'Počet návštev stránky',
 	'General_ColumnUniquePageviews' => 'Unikátne zobrazenia stránok',
+	'General_ColumnUniquePageviewsDocumentation' => 'Počet návštev zarhnutých do stránky. Viacnásobné zobrazenie stránky počas jednej návštevy sa počíta len raz.',
 	'General_ColumnBounces' => 'Odchody',
-	'General_ColumnEntrances' => 'Vstupná stránka',
+	'General_ColumnBouncesDocumentation' => 'Počet návštev so začiatkom aj koncom na tejto stránke. To znamená, že návštevník opustil webové sídlo hneď po zhliadnutí tejto jednej stránky.',
+	'General_ColumnUniqueEntrances' => 'Unikátnych vstupov',
+	'General_ColumnEntrances' => 'Vstupy',
+	'General_ColumnEntrancesDocumentation' => 'Počet návštev so začiatkom na tejto stránke.',
 	'General_ColumnExits' => 'Odchody',
+	'General_ColumnUniqueExits' => 'Unikátne odchody',
+	'General_ColumnExitsDocumentation' => 'Počet návštev s koncom na tejto stránke.',
 	'General_ColumnAverageTimeOnPage' => 'Priem. doba na stránke',
+	'General_ColumnAverageTimeOnPageDocumentation' => 'Priemerný čas, ktorý návštevník strávil na tejto stránke (len na nej, nie na celom webovom sídle).',
 	'General_ColumnValuePerVisit' => 'Hodnota na návštevu',
 	'General_ColumnVisitsWithConversions' => 'Návštevy s konverziou',
+	'General_VisitsWith' => 'Návštevy s %s',
 	'General_YearsDays' => '%1$s rokov %2$s dní',
 	'General_DaysHours' => '%1$s dní %2$s hodín',
 	'General_HoursMinutes' => '%1$s hodín %2$s minút',
 	'General_MinutesSeconds' => '%1$s minút %2$s sekúnd',
 	'General_Seconds' => '%s sekúnd',
 	'General_Save' => 'Uložiť',
-	'General_ForExampleShort' => 'eg.',
+	'General_ForExampleShort' => 'napr.',
 	'General_YouMustBeLoggedIn' => 'Musíte byť prihlásený pre prístup k tejto functionnality.',
-	'General_Website' => 'Webstránka',
+	'General_Website' => 'Webové sídlo',
 	'General_GeneralSettings' => 'Všeobecné nastavenia',
-	'General_AllowPiwikArchivingToTriggerBrowser' => 'Povoliť archivácie pre spustenie, keď je možné vidieť reporty z prehliadača',
-	'General_ArchivingInlineHelp' => 'Pre stredné až vysoké návštevnosti webových stránok, sa odporúča vypnúť Piwik archiváciu z prehliadača. Namiesto toho odporúčame nastaviť cron práce na spracovanie Piwik správy každú hodinu.',
-	'General_ArchivingTriggerDescription' => 'Doporučené pre väčšie inštalácie Piwik, musíte %s nastavit cron %s aby spracovával správy automaticky.',
+	'General_AllowPiwikArchivingToTriggerBrowser' => 'Povoliť Piwiku spustenie archivácií, keď sa reporty zobrazujú z prehliadača',
+	'General_ArchivingInlineHelp' => 'Pre stredné až vysoké návštevnosti webových stránok, sa odporúča vypnúť v Piwiku archiváciu spúštanú prezeraním z  prehliadača. Namiesto toho odporúčame nastaviť cron práce na spracovanie Piwik správy každú hodinu.',
+	'General_ArchivingTriggerDescription' => 'Odporúča sa pre väčšie inštalácie Piwiku, musíte %s nastavit cron %s aby spracovával správy automaticky.',
 	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Pre viac informácií pozri %sofficiálne dokumentácie%s.',
+	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Správy na dnes (alebo iný časový rozsah vrátane dnešného dňa) budú spracované najviac v intervale',
 	'General_NSeconds' => '%s sekúnd',
-	'General_SmallTrafficYouCanLeaveDefault' => 'Pri malej návštevnosti web stránky, môžete ponechať predvolený počet sekúnd %s, a prístup do všetkých správ v reálnom čase.',
-	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pre web stránky, ktoré majú stredne veľkú až veľkú návštevnosť, odporúčame pre spracovanie štatistík nastavenie v daný deň maximálne na každú každú pol hodinu (%s sekúnd), alebo každú hodinu (%s sekúnd).',
+	'General_SmallTrafficYouCanLeaveDefault' => 'Pri malej návštevnosti webového sídla, môžete ponechať predvolený počet sekúnd %s, a prístup do všetkých správ v reálnom čase.',
+	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pre webové sídla, ktoré majú stredne veľkú až veľkú návštevnosť, odporúčame pre spracovanie štatistík nastavenie v daný deň maximálne na každú každú pol hodinu (%s sekúnd), alebo každú hodinu (%s sekúnd).',
 	'General_RequiresFlash' => 'Zobrazenie grafu vyžaduje Flash',
 	'General_GraphHelp' => 'Ďalšie informácie o zobrazení grafov.',
-	'General_NoDataForGraph' => 'Pre tento graf nie sú dáta',
-	'General_NoDataForTagCloud' => 'Pre tento oblak nie sú dáta',
-	'General_DisplaySimpleTable' => 'Zobrazenie jednoduché tabuľky',
+	'General_NoDataForGraph' => 'Pre tento graf nie sú dáta.',
+	'General_NoDataForTagCloud' => 'Pre tento oblak nie sú dáta.',
+	'General_DisplaySimpleTable' => 'Zobrazenie jednoduchej tabuľky',
 	'General_DisplayTableWithMoreMetrics' => 'Zobraziť tabuľku s viacerými metrikami',
 	'General_DisplayTableWithGoalMetrics' => 'Zobraziť tabuľku s cieľmi metrík',
 	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s je kolaboratívny projekt. %3$s Ak sa Vám Piwik páči, tak môžete pomôcť! Pozrite sa na %4$sAko prispieť do projektu Piwik?%5$s',
-	'General_YouAreViewingDemoShortMessage' => 'Momentálne prehliadate demo Piwik',
-	'General_NewUpdatePiwikX' => 'Nové aktualizácie: Piwik %s',
-	'General_AboutPiwikX' => 'O Piwik %s',
-	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je k dispozícií. %2$s Prosím vykonajte aktualizáciu!%3$s (pozrite %4$s zmeny%5$s).',
+	'General_YouAreViewingDemoShortMessage' => 'Momentálne vidíte demo Piwiku',
+	'General_DownloadFullVersion' => '%1$sStiahnuť%2$s plnú verziu! Pozri %3$s',
+	'General_NewUpdatePiwikX' => 'Nová aktualizácia: Piwik %s',
+	'General_AboutPiwikX' => 'O Piwiku %s',
+	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je k dispozícií. %2$s Prosím vykonajte aktualizáciu!%3$s (pozrieť %4$s zmeny%5$s).',
+	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je k dispozícii. Notifikujte, prosím, administrátora webu.',
+	'General_NewReportsWillBeProcessedByCron' => 'Ak nie je archivovanie Piwiku spúštané prehliadačom, nové správy budú spracované crontabom.',
+	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Správy budú budú preto spracované nanajvýš každú hodinu.',
+	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Za predpokladu, že archivovanie je vo vašom prostredí rýchle, môžete crontab nastaviť na vyššie frekvencie.',
 	'General_BackToPiwik' => 'Späť na Piwik',
+	'General_ClickHere' => 'Klinite pre viac informácií.',
 	'General_ShortMonth_1' => 'Jan',
 	'General_ShortMonth_2' => 'Feb',
 	'General_ShortMonth_3' => 'Mar',
@@ -158,12 +244,32 @@ $translations = array(
 	'General_Daily' => 'Denne',
 	'General_Weekly' => 'Týždenne',
 	'General_Monthly' => 'Mesačne',
+	'General_ConfigFileIsNotWritable' => 'Konfiguračný súbor %s Piwiku , some of your changes might not be saved. %s Please change permissions of the config file to make it writable.',
+	'General_ExceptionDatabaseVersion' => 'Vaša verzia %1$s je %2$s,ale Piwik potrebuje aspoň verziu %3$s.',
+	'General_ExceptionIncompatibleClientServerVersions' => 'Vaša verzia klienta %1$s je %2$s je nekompatibilná s verziou servera %3$s.',
+	'General_ExceptionMissingFile' => 'Chýba súbor: %s',
+	'General_ExceptionFilesizeMismatch' => 'Nesedí veľkosť súboru: %1$s (očakávaná veľkosť: %2$s, nájdená veľkosť: %3$s)',
+	'General_ExceptionFileIntegrity' => 'Kontrola integrity sa nepodarila: %s',
+	'General_ExceptionNonceMismatch' => 'Nepodarilo sa overiť bezpečnostný reťazec formulára.',
+	'General_PleaseSpecifyValue' => 'Špecifikujte, prosím, hodnotu pre %s.',
+	'General_ExceptionMethodNotFound' => 'Metóda \'%s\' neexistuje alebo nie je dostupná v module \'%s\'.',
+	'General_ExceptionInvalidRendererFormat' => 'Formát vykresľovania \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
+	'General_ExceptionInvalidReportRendererFormat' => 'Formát správ \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
+	'General_ExceptionInvalidAggregateReportsFormat' => 'Formát agregorvaných správ \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
+	'General_ExceptionInvalidPeriod' => 'Rozsah \'%s\' nie je podporovaný. Skúste namiesto toho použiť jeden z týchto: %s.',
+	'General_ExceptionInvalidDateRange' => 'Dátum \'%s\' nie je platný časový rozsah. Použite nasledovný formát: %s.',
+	'General_ExceptionGoalNotFound' => 'ID cieľa = %s  sa nepodarilo nájsť.',
 	'General_ExceptionUndeletableFile' => 'Nemožno zmazať %s',
+	'General_ExceptionPrivilege' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s".',
+	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s" aspoň pre jedno webové sídlo.',
+	'General_ExceptionPrivilegeAccessWebsite' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s" pre webové sídlo id = %d.',
+	'General_ExceptionInvalidArchiveTimeToLive' => 'Dnešný čas archivovania',
 	'General_ExceptionConfigurationFileNotFound' => 'Konfiguračný súbor{%s} nebol nájdený.',
 	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfiguračný súbor {%s} sa nedá čítať. Váš hostiteľ môže byť poskodený %s.',
-	'General_ExceptionInvalidToken' => 'Token nie je platný.',
+	'General_ExceptionInvalidToken' => 'Bezpečnostný reťazec (token) nie je platný.',
 	'General_ExceptionInvalidDateFormat' => 'Formát dátumu musí byť: %s alebo kľúčového slova ktoré podporuje funkciu %s (pozri %s pre viac informácií)',
 	'General_ExceptionLanguageFileNotFound' => 'Jazykový súbor \'%s\' nebol nájdený.',
+	'General_ExceptionUnableToStartSession' => 'Nepodarilo sa začať session.',
 	'General_WarningFileIntegritySkipped' => 'Vývojové prostredie detekované. Súbor kontrola integrity preskočený.',
 	'General_WarningFileIntegrityNoManifest' => 'Súbor kontrola integrity nemohla byť vykonaná z dôvodu chýbajúcich manifest.inc.php.',
 	'General_WarningFileIntegrityNoMd5file' => 'Súbor kontrola integrity nemožno dokončiť z dôvodu chýbajúcich md5_file () funkcie.',
@@ -172,14 +278,16 @@ $translations = array(
 	'General_SmtpServerAddress' => 'Adresa SMTP servera',
 	'General_SmtpPort' => 'Metóda overovania pre SMTP',
 	'General_AuthenticationMethodSmtp' => 'Metóda overovania pre SMTP',
-	'General_SmtpUsername' => 'SSMTP používateľské meno',
+	'General_SmtpUsername' => 'SMTP používateľské meno',
 	'General_SmtpPassword' => 'SMTP heslo',
 	'General_SmtpEncryption' => 'SMTP šifrovanie',
 	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Vyberte "Áno", ak chcete alebo musíte odoslať e-mail cez názov servera namiesto lokálnej mail funkcie',
+	'General_OptionalSmtpPort' => 'Nepovinné. Východiskové nastavenie je port 25 pre nešifrované spojenie a TLS STMP, či port 465 pre SSL STMP.',
 	'General_OnlyUsedIfUserPwdIsSet' => 'Používa sa používateľské meno/heslo ak je nastavené, opýtajte sa svojho poskytovateľa, ak si nie ste istí, ktorú metódu použiť.',
 	'General_OnlyEnterIfRequired' => 'Ak to Váš SMTP server vyžaduje zadajte meno',
 	'General_OnlyEnterIfRequiredPassword' => 'Ak to Váš SMTP server vyžaduje zadajte heslo',
 	'General_WarningPasswordStored' => '%sVarovanie:%s Toto heslo bude uložené v konfiguračnom súbore viditeľné pre všetkých, ako prístup.',
+	'General_EncryptedSmtpTransport' => 'Zadajte šifrovanie prenosnej vrstvy požadovanej vašim SMTP serverom.',
 	'General_InvalidResponse' => 'Prijaté dáta sú neplatné.',
 	'General_ChooseLanguage' => 'Vyberte jazyk',
 	'General_ChoosePeriod' => 'Vyberte si obdobie',
@@ -187,6 +295,21 @@ $translations = array(
 	'General_Language' => 'Jazyk',
 	'General_PleaseUpdatePiwik' => 'Prosím aktualizujte svoj Piwik',
 	'General_RequestTimedOut' => 'Čas %sS vypršal. Prosím skúste to znova.',
+	'General_UsePlusMinusIconsDocumentation' => 'Pre navigáciu použite symboly plus a mínus vľavo.',
+	'General_BrokenDownReportDocumentation' => 'Je to rozložené do viacerých správ zobrazených ako čiarové grafy na konci stránky. Grafy môžete zväčšiť kliknutím na správu, ktorú chcete vidieť.',
+	'General_ChangeTagCloudView' => 'Všimnite si, že správy môžete vidieť aj iným spôsobom ako  oblak značiek. Použite ovládanie na spodku grafu pre prepínanie zobrazenia.',
+	'General_Recommended' => '(doporučené)',
+	'General_Goal' => 'Cieľ',
+	'General_Outlink' => 'Odchádzajúci preklik',
+	'General_Help' => 'Pomoc',
+	'General_DailySum' => 'Denný súčet',
+	'General_AfterEntry' => 'po zadaní sem',
+	'General_Metadata' => 'Meta údaje',
+	'General_OneVisit' => '1 návšteva',
+	'General_NVisits' => '%s návštev',
+	'General_OneDay' => '1 deň',
+	'General_NDays' => '%s dní',
+	'General_MainMetrics' => 'Hlavné metriky',
 	'Actions_PluginDescription' => 'Správy o zobrazenie stránky, odkazy a súbory na prevzatie.    Odkazy a súbory na prevzatie sa sledujú automaticky!',
 	'Actions_Actions' => 'Akcie',
 	'Actions_SubmenuPages' => 'Stránky',
@@ -214,10 +337,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Neexistujú žiadne dáta pre túto správu.',
 	'CoreHome_CategoryNoData' => 'Pre túto kategóriu nie sú dáta. Skúste použiť „Vrátane celej populácie“.',
 	'CoreHome_ShowJSCode' => 'Zobraziť javascript kód pre vloženie',
-	'CoreHome_IncludeAllPopulation_js' => 'Vrátane celej populácie',
-	'CoreHome_ExcludeLowPopulation_js' => 'Bez nízkej populácie',
 	'CoreHome_PageOf_js' => '%1$s z %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'Deň',
 	'CoreHome_PeriodWeek' => 'Týždeň',
 	'CoreHome_PeriodMonth' => 'Mesiac',
@@ -315,7 +435,6 @@ $translations = array(
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik bol úspešne zaktualizovaný!',
 	'Dashboard_PluginDescription' => 'Váš Web Analytická Nástenka. Môžete si prisp§sobiť Vašu nástenku: Pridať nový nástroj, zmeniť poradie vašich nástrojov. Každý používateľ môže mať prístup k jeho vlastnej nástenke.',
 	'Dashboard_Dashboard' => 'Nástenka',
-	'Dashboard_AddWidget' => 'Pridať miniaplikáciu…',
 	'Dashboard_DeleteWidgetConfirm' => 'Ste si istý, že chcete odstrániť miniaplikáciu z panela?',
 	'Dashboard_SelectWidget' => 'Vyberte miniaplikáciu, ktorá sa pridá na panel',
 	'Dashboard_AddPreviewedWidget_js' => 'Pridať prezeranú miniaplikáciu do panelu',
@@ -449,7 +568,6 @@ $translations = array(
 	'Mobile_AnonymousAccess' => 'Anonymný prístup',
 	'Mobile_AccessUrlLabel' => 'Prístup Url',
 	'Mobile_EnableGraphsLabel' => 'Zobraziť grafy',
-	'Mobile_MultiChartInfo' => 'na každej webovej stránke na uvítacej obrazovke',
 	'MultiSites_PluginDescription' => 'Zobrazuje Multi-Site zhrnutie / štatistiky. V súčasnej dobe je ako hlavný plugin.',
 	'MultiSites_Evolution' => 'Vývoj',
 	'Provider_PluginDescription' => 'Report cez ktorého poskytovateľa pripojenia prišli návštevníci na web stránku.',
@@ -463,7 +581,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'Priamy vstup',
 	'Referers_Websites' => 'Webstránky',
 	'Referers_Campaigns' => 'Kampane',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (od %2$s)',
 	'Referers_Evolution' => 'Vývoj za obdobie',
 	'Referers_Type' => 'Typ odkazu',
 	'Referers_ColumnRefererType' => 'Typ odkazu',
@@ -493,9 +610,7 @@ $translations = array(
 	'Referers_WidgetOverview' => 'Prehľad',
 	'SEO_SeoRankings' => 'SEO hodnotenie',
 	'SEO_AlexaRank' => 'Alexa hodnotenie',
-	'SEO_YahooIndexedPages' => 'Yahoo zaindexované stránky',
 	'SEO_DomainAge' => 'Vek domény',
-	'SEO_YahooBacklinks' => 'Yahoo spätné odkazy',
 	'SEO_Rank' => 'Hodnotenie',
 	'SEO_Backlinks' => 'Spätné linky',
 	'SEO_Pages' => 'Stránky',
@@ -733,8 +848,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_re' => 'Réunion',
 	'UserCountry_country_ro' => 'Rumunsko',
-	'UserCountry_country_ru' => 'Rusko',
 	'UserCountry_country_rs' => 'Srbsko',
+	'UserCountry_country_ru' => 'Rusko',
 	'UserCountry_country_rw' => 'Rwanda',
 	'UserCountry_country_sa' => 'Saudská Arábia',
 	'UserCountry_country_sb' => 'Šalamúnove ostrovy',
@@ -908,7 +1023,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'Všetky návštevy',
 	'VisitsSummary_NbVisits' => 'Počet návštev: %s',
 	'VisitsSummary_NbUniqueVisitors' => 'Počet unikátnych návštevníkov: %s',
-	'VisitsSummary_NbActions' => 'Počet akcií (zobrazení stránok): %s',
 	'VisitsSummary_NbActionsDescription' => '%s akcie (zobrazenie stránok, sťahovanie a odkazujúce odkazy)',
 	'VisitsSummary_AverageVisitDuration' => '%s priemerná dĺžka návštevy',
 	'VisitsSummary_MaxNbActions' => 'Max. akcií na jednu návštevu: %s',
@@ -931,7 +1045,7 @@ $translations = array(
 	'VisitTime_WidgetServerTime' => 'Návštevníci podľa serverového času',
 	'VisitTime_SubmenuTimes' => 'Časy',
 	'VisitTime_NHour' => '%sh',
-	'Widgetize_PluginDescription' => 'Je veľmi jednoduché vypublikovať plugin na svoj blog, web alebo na stránke iGoogle a Netvibes!',
+	'Widgetize_PluginDescription' => 'Je veľmi jednoduché vložiť widget na svoj blog, web alebo na stránku iGoogle a Netvibes!',
 	'PDFReports_EmailReports' => 'Reporty e-mailom',
 	'PDFReports_PDF' => 'PDF',
 	'PDFReports_SendReportNow' => 'Teraz poslať report',
