@@ -2,21 +2,24 @@
 $translations = array(
 	'General_Locale' => 'sl_SI.UTF-8',
 	'General_TranslatorName' => 'Aleksej Lazanski',
-	'General_TranslatorEmail' => 'support@tuts23.com',
+	'General_TranslatorEmail' => 'alazanski@tuts23.com',
 	'General_EnglishLanguageName' => 'Slovenian',
 	'General_OriginalLanguageName' => 'Slovenščina',
 	'General_HelloUser' => 'Pozdravljen, %s!',
+	'General_OpenSourceWebAnalytics' => 'Odprtokodna Spletna Analitika',
 	'General_Dashboard' => 'Nadzorna Plošča',
 	'General_DashboardForASpecificWebsite' => 'Nazdporna plošča za določeno spletno stran',
 	'General_MultiSitesSummary' => 'Vse Spletne Strani',
 	'General_AllWebsitesDashboard' => 'Vse nadzorne plošče spletnih strani',
 	'General_API' => 'API',
+	'General_Widgets' => 'Gradniki',
 	'General_Settings' => 'Nastavitve',
 	'General_GiveUsYourFeedback' => 'Podajte nam Povratno Informacijo!',
 	'General_Unknown' => 'Neznano',
 	'General_Never' => 'Nikoli',
 	'General_Required' => '%s potrebno',
 	'General_NotValid' => '%s ni veljaven',
+	'General_NotDefined' => '%s ni definiran',
 	'General_Id' => 'Id',
 	'General_Error' => 'Napaka',
 	'General_Warning' => 'Opozorilo',
@@ -25,6 +28,7 @@ $translations = array(
 	'General_No' => 'Ne',
 	'General_Delete' => 'Izbriši',
 	'General_Report' => 'Poročilo',
+	'General_Reports' => 'Poročila',
 	'General_Edit' => 'Uredi',
 	'General_Download' => 'Prenesi',
 	'General_Upload' => 'Naloži',
@@ -35,18 +39,48 @@ $translations = array(
 	'General_Username' => 'Uporaniško Ime',
 	'General_Description' => 'Opis',
 	'General_Done' => 'Narejeno',
+	'General_PoweredBy' => 'Poganja',
+	'General_MetricsToPlot' => 'Metrično v spletko',
+	'General_RowsToDisplay' => 'Vrst za prikaz',
+	'General_MetricToPlot' => 'Metrično v spletko',
 	'General_Name' => 'Ime',
 	'General_Value' => 'Vrednost',
+	'General_Total' => 'Skupaj',
+	'General_TotalVisitsActionsRevenue' => '(Skupaj: %s obiskov, %s dejanj, %s izkupiček)',
+	'General_AverageOrderValue' => 'Povprečna vrednost naročila',
+	'General_PurchasedProducts' => 'Kupljeni Izdelki',
+	'General_EcommerceOrders' => 'Ecommerce Naročila',
+	'General_AbandonedCarts' => 'Opuščeni Vozički',
+	'General_TotalRevenue' => 'Skupni izkupiček',
+	'General_ProductRevenue' => 'Izkupiček izdelka',
+	'General_AveragePrice' => 'Povprečna Cena',
+	'General_AverageQuantity' => 'Povprečna Količina',
+	'General_UniquePurchases' => 'Edinstveni Nakupi',
+	'General_Quantity' => 'Količina',
+	'General_Price' => 'Cena',
+	'General_Subtotal' => 'Vmesni seštevek',
+	'General_Tax' => 'Davek',
+	'General_Shipping' => 'Poštnina',
+	'General_Discount' => 'Popust',
 	'General_Details' => 'Podrobnosti',
 	'General_Default' => 'Privzeto',
 	'General_Visit' => 'Obisk',
+	'General_FromReferrer' => 'od',
 	'General_VisitorIP' => 'Obiskovalčev IP',
+	'General_VisitorID' => 'ID Obiskovalca',
 	'General_VisitType' => 'Vrsta obiskovalca',
+	'General_VisitTypeExample' => 'Na primer, če želite zbrati vse obiskovalce, ki so se vrnili na spletno stran, vključno s tistimi, ki so v prejšnjih obiskih kaj kupili, bi API zahteva vsebovala %s',
 	'General_DaysSinceLastVisit' => 'Dni od zadnjega obiska',
 	'General_DaysSinceFirstVisit' => 'Dni od prvega obiska',
+	'General_DaysSinceLastEcommerceOrder' => 'Dni od zadnjega Ecommerce naročila',
 	'General_NumberOfVisits' => 'Število obiskov',
+	'General_VisitConvertedGoal' => 'Obisk je spreobrnil vsaj en Cilj',
+	'General_VisitConvertedGoalId' => 'Obisk je spreobrnil specifičen Id Cilja',
+	'General_VisitConvertedNGoals' => 'Obisk spreobrnil %s Ciljev',
 	'General_NewVisitor' => 'Nov Obiskovalec',
+	'General_NewVisits' => 'Novi obiski',
 	'General_ReturningVisitor' => 'Ponoven Obiskovalec',
+	'General_Visitor' => 'Obiskovalec',
 	'General_Date' => 'Datum',
 	'General_Period' => 'Obdobje',
 	'General_ChooseDate' => 'Izberite datum',
@@ -56,30 +90,40 @@ $translations = array(
 	'General_CurrentMonth' => 'Trenutni Mesec',
 	'General_CurrentYear' => 'Trenutno Leto',
 	'General_DateRange' => 'Datumski razpon:',
+	'General_DateRangeInPeriodList' => 'Datumski razpon',
+	'General_DateRangeFromTo' => 'Od %s do %s',
 	'General_ApplyDateRange' => 'Uveljavi Datumski Razpon',
 	'General_InvalidDateRange_js' => 'Neveljaven Datumski Razpon. Prosimo, Poskusite Znova',
 	'General_DateRangeFrom_js' => 'Od',
+	'General_DateRangeTo_js' => 'Za',
+	'General_PreviousDays' => 'Prejšnjih %s dni (brez današnjega dne)',
+	'General_LastDays' => 'Zadnjih %s dni (vklj. z današ. dnem)',
 	'General_LoadingData' => 'Nalagam podatke...',
 	'General_Loading_js' => 'Nalagam...',
 	'General_GoTo' => 'Pojdi na %s',
 	'General_Next' => 'Naslednji',
 	'General_Previous' => 'Prejšnji',
+	'General_First' => 'Prvi',
 	'General_Search' => 'Išči',
 	'General_Others' => 'Ostali',
 	'General_Table' => 'Tabela',
 	'General_Piechart' => 'Kolačni diagram',
 	'General_TagCloud' => 'Oblak z etiketami',
 	'General_VBarGraph' => 'Stolpični Diagram',
+	'General_View' => 'Ogled',
 	'General_OpenInNewWindow_js' => 'Odpri v novem oknu',
 	'General_SaveImageOnYourComputer_js' => 'Za shranitev te slike na vaš računalnik, kliknite z desno tipko miške na sliko ter izberite "Shrani sliko kot"',
 	'General_Refresh' => 'Osveži stran',
 	'General_Visitors' => 'Obiskovalci',
 	'General_ExportThisReport' => 'Izvoti to razpredelnico v drugih formatih',
 	'General_ExportAsImage_js' => 'Izvozi kot Sliko',
+	'General_Export' => 'Izvozi',
 	'General_YourChangesHaveBeenSaved' => 'Vaše spremembe so bile shranjene.',
 	'General_ErrorRequest' => 'Opa... Med zahtevo je prišlo do napake. Prosimo, poskusite znova.',
 	'General_ColumnNbUniqVisitors' => 'Edinstveni Obiskovalci',
+	'General_ColumnNbUniqVisitorsDocumentation' => 'Število nepodvojenih obiskovalcev, prihajujočih na vašo spletno stran. V primeru, da obiskovalec spletno stran obišče večkrat v enem dnevu, se to šteje le enkrat.',
 	'General_ColumnNbVisits' => 'Obiskov',
+	'General_ColumnNbVisitsDocumentation' => 'V primeru da pride obiskovalec na vašo spletno stran prvič, ali pa je njegov obisk daljši od 30 minut, se bo to štelo kot novi obisk.',
 	'General_ColumnPercentageVisits' => '% Obiskov',
 	'General_ColumnNbActions' => 'Dejanj',
 	'General_NbActions' => 'Šttevilo Dejanj',
@@ -87,21 +131,42 @@ $translations = array(
 	'General_ColumnSumVisitLength' => 'Skupni čas, ki so ga porabili obiskovalci (v sekundah)',
 	'General_ColumnLabel' => 'Oznaka',
 	'General_ColumnConversionRate' => 'Pretvorbeno Razmerje',
+	'General_ColumnConversionRateDocumentation' => 'Procent obiskov, ki so sprožili spreobrnitev cilja.',
 	'General_ColumnActionsPerVisit' => 'Dejanj na Obisk',
+	'General_ColumnActionsPerVisitDocumentation' => 'Povprečno število dejanj (ogledov strani, prenosov ali izhodnih povezav), ki so bila izvedena med obiskom.',
 	'General_VisitDuration' => 'Povpr. Trajanje Obiska (v sekundah)',
 	'General_ColumnAvgTimeOnSite' => 'Povpr. Čas na Spletni Strani',
+	'General_ColumnAvgTimeOnSiteDocumentation' => 'Povprečno trajanje obiska.',
 	'General_ColumnVisitDuration' => 'Trajanje Obiska (v sekundah)',
 	'General_ColumnBounceRate' => 'Odbojno Razmerje',
+	'General_ColumnBounceRateDocumentation' => 'Delež obiskov, ki je vseboval zgolj en sam ogled strani. To pomeni, da je obiskovalec zapustil spletno stran direktno z vhodne strani.',
+	'General_ColumnBounceRateForPageDocumentation' => 'Delež obiskov, ki se tako začeli, kot tudi končali na tej strani.',
+	'General_ColumnPageBounceRateDocumentation' => 'Delež obiskov, ki so se začeli na tej strani, a so nemudoma zapustili spletno stran.',
 	'General_ColumnExitRate' => 'Izhodno Razmerje',
+	'General_ColumnExitRateDocumentation' => 'Delež obiskov, ki so zapustili spletno stran po ogledu te strani.',
 	'General_ColumnPageviews' => 'Ogledov strani',
+	'General_ColumnPageviewsDocumentation' => 'Število, kolikokrat je bila ta stran obiskana.',
 	'General_ColumnUniquePageviews' => 'Edinstvenih Ogledov Strani',
+	'General_ColumnUniquePageviewsDocumentation' => 'Število obiskov, ki so vključevali to stran. V primeru, da je bila stran ogledana večkrat, se to šteje kot le-en ogled.',
 	'General_ColumnBounces' => 'Odbojev',
+	'General_ColumnUniqueEntrances' => 'Edinstveni vhodi',
 	'General_ColumnEntrances' => 'Vhodov',
+	'General_ColumnEntrancesDocumentation' => 'Število obiskov, ki so se začeli na tej strani.',
 	'General_ColumnExits' => 'Izhodov',
+	'General_ColumnUniqueExits' => 'Edinstveni izhodi',
+	'General_ColumnExitsDocumentation' => 'Število obiskov, ki so se zaključili na tej strani.',
 	'General_ColumnAverageTimeOnPage' => 'Povpr. čas na strani',
+	'General_ColumnAverageTimeOnPageDocumentation' => 'Povprečen čas, ki so ga obiskovalci porabili na tej strani (samo na strani, ne na celotni spletni strani).',
 	'General_ColumnValuePerVisit' => 'Vrednost na Obisk',
+	'General_ColumnVisitsWithConversions' => 'Obiski s Spreobrnitvami',
+	'General_VisitsWith' => 'Obiski z/s %s',
+	'General_YearsDays' => '%1$s let %2$s dni',
+	'General_DaysHours' => '%1$s dni %2$s ur',
+	'General_HoursMinutes' => '%1$s ur %2$s min',
+	'General_MinutesSeconds' => '%1$s min %2$ss',
 	'General_Seconds' => '%ss',
 	'General_Save' => 'Shrani',
+	'General_Faq' => 'FAQ',
 	'General_ForExampleShort' => 'npr.',
 	'General_YouMustBeLoggedIn' => 'Za uporabo te funkcije morate biti vpisani.',
 	'General_Website' => 'Spletna stran',
@@ -115,12 +180,15 @@ $translations = array(
 	'General_NoDataForTagCloud' => 'Ni podatkov za oblaček z etiketami',
 	'General_DisplaySimpleTable' => 'Prikaži preprosto tabelo',
 	'General_DisplayTableWithMoreMetrics' => 'Prikaži podrobnejšo tabelo',
+	'General_DisplayTableWithGoalMetrics' => 'Prikaži tabelo z metričnimi cilji',
 	'General_YouAreViewingDemoShortMessage' => 'Trenutno si ogledujete Piwik v demo načinu',
+	'General_DownloadFullVersion' => '%1$sPrenesite%2$s celotno verzijo! Oglejte si %3$s',
 	'General_NewUpdatePiwikX' => 'Nova Posodobitev: Piwik %s',
 	'General_AboutPiwikX' => 'O Piwik %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je na voljo. %2$sProsimo posodobite ga zdaj!ow!%3$s (oglejte si %4$sspremembe%5$s).',
 	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je na voljo. Prosimo, da o tem obvestite skrbnika strani.',
 	'General_BackToPiwik' => 'Nazaj na Piwik',
+	'General_ClickHere' => 'Za več informacij, kliknite tu.',
 	'General_ShortMonth_1' => 'Jan',
 	'General_ShortMonth_2' => 'Feb',
 	'General_ShortMonth_3' => 'Mar',
@@ -171,6 +239,7 @@ $translations = array(
 	'General_ExceptionPrivilege' => 'Ne morete dostopati do tega vira, saj je za to potreben %s dostop.',
 	'General_ExceptionConfigurationFileNotFound' => 'Konfiguracijska datoteka {%s} ni bila najdena.',
 	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfiguracijske datoteke {%s} ni bilo mogoče prebrati. Možno je, da je vaš gostitelj onemogočil %s.',
+	'General_ExceptionInvalidToken' => 'Žeton ni veljaven.',
 	'General_ExceptionLanguageFileNotFound' => 'Jezikovne datoteke "%s" ni bilo mogoče najti.',
 	'General_WarningFileIntegritySkipped' => 'Zaznano je bilo razvojno okolje. Pregled integritete datotek je bil preskočen.',
 	'General_WarningFileIntegrityNoManifest' => 'Pregleda integritete datotek ni bilo mogoče izvesti, saj manjka manifest.inc.php.',
@@ -191,16 +260,32 @@ $translations = array(
 	'General_ChooseWebsite' => 'Izberite spletno stran',
 	'General_Language' => 'Jezik',
 	'General_PleaseUpdatePiwik' => 'Prosimo, da posodobite Piwik',
+	'General_UsePlusMinusIconsDocumentation' => 'Uporabite plus in minus ikoni na levi za navigacijo.',
+	'General_Recommended' => '(priporočano)',
+	'General_Goal' => 'Cilj',
+	'General_Outlink' => 'Izhodna povezaba',
+	'General_Help' => 'Pomoč',
+	'General_AfterEntry' => 'po tukajšnjem vstopu',
+	'General_Metadata' => 'Metadata',
+	'General_OneVisit' => '1 obisk',
+	'General_NVisits' => '%s obiskov',
+	'General_OneDay' => '1 dan',
+	'General_NDays' => '%s dni',
 	'Actions_Actions' => 'Dejanja',
 	'Actions_SubmenuPages' => 'Strani',
 	'Actions_SubmenuPagesEntry' => 'Vstopne strani',
 	'Actions_SubmenuPagesExit' => 'Izhodne strani',
 	'Actions_SubmenuPageTitles' => 'Naslovi strani',
+	'Actions_PageUrls' => 'URL-ji strani',
+	'Actions_SubmenuOutlinks' => 'Izhodne povezave',
 	'Actions_SubmenuDownloads' => 'Prenosi',
 	'Actions_ColumnClicks' => 'Kliki',
+	'Actions_ColumnClicksDocumentation' => 'Število klikov na to povezavo.',
 	'Actions_ColumnUniqueClicks' => 'Edinstveni Kliki',
 	'Actions_ColumnDownloads' => 'Prenosi',
 	'Actions_ColumnUniqueDownloads' => 'Edinstveni Prenosi',
+	'Actions_ColumnOutlinks' => 'Izhodne povezave',
+	'Actions_ColumnUniqueOutlinks' => 'Edinstvene izhodne povezave',
 	'Actions_ColumnPageName' => 'Ime Spletne Strani',
 	'Actions_ColumnPageURL' => 'URL Spletne Strani',
 	'Actions_ColumnClickedURL' => 'Kliknjeni URL-ju',
@@ -209,12 +294,35 @@ $translations = array(
 	'Actions_ColumnEntryPageTitle' => 'Naslov vstopne strani',
 	'Actions_ColumnExitPageURL' => 'URL izhodne strani',
 	'Actions_ColumnExitPageTitle' => 'Naslov izhodne strani',
+	'API_QuickDocumentationTitle' => 'API hitra dokumentacija',
+	'API_UserAuthentication' => 'Overitev uporabnika',
+	'API_LoadedAPIs' => 'Uspešno naloženih %s API-jev',
 	'CoreAdminHome_PluginDescription' => 'Piwik-ovo administrativno okolje.',
 	'CoreAdminHome_MenuGeneralSettings' => 'Splošne nastavitve',
 	'CoreAdminHome_Administration' => 'Administracija',
 	'CoreAdminHome_EmailServerSettings' => 'Nastavitev strežnika za email',
+	'CoreAdminHome_YouAreOptedIn' => 'Trenutno ste pridruženi.',
+	'CoreAdminHome_YouAreOptedOut' => 'Trenutno niste pridruženi.',
+	'CoreAdminHome_ClickHereToOptOut' => 'Kliknite tu, če želite odstopiti.',
+	'CoreAdminHome_ClickHereToOptIn' => 'Kliknite tu za pristop',
+	'CoreAdminHome_BrandingSettings' => 'Nastavitve znamke',
+	'CoreAdminHome_CustomLogoHelpText' => 'Piwik-ov logo lahko prilagodite po vaših željah. Spremembe bodo vidne tako v uporabniškem vmesniku, kot v email poročilih.',
+	'CoreAdminHome_UseCustomLogo' => 'Uporabi poseben logo',
+	'CoreAdminHome_LogoUpload' => 'Izberite Logo za nalaganje',
+	'PrivacyManager_TeaserHeadline' => 'Nastavitve zasebnosti',
+	'PrivacyManager_DeleteLogInfo' => 'Dnevniki iz sledečih tabel bodo izbrizani: %s',
+	'PrivacyManager_UseDeleteLog' => 'Redno izbriši stare dnevnike obiskov iz podatkovne baze',
+	'PrivacyManager_DeleteLogsOlderThan' => 'Izbriši dnevnike, starejše od',
+	'PrivacyManager_DeleteMaxRowsNoLimit' => 'brez omejitve',
+	'PrivacyManager_LastDelete' => 'Zadnji izbris je bil',
+	'PrivacyManager_NextDelete' => 'Naslednji izbris je predviden',
+	'PrivacyManager_ClickHereSettings' => 'Kliknite tu za dostop do %s nastavitev.',
+	'PrivacyManager_LeastDaysInput' => 'Prosimo, navedite število dni, večje od %s.',
+	'CoreHome_NoPrivilegesAskPiwikAdmin' => 'Vpisani ste kot \'%s\', vendar v Piwik-u nimate nastavljenih nobenih pooblastil. %s Poprosite vašega Piwik administratorja (klik za email)%s naj vam da pooblastila za ogled določene(ih) strani.',
+	'CoreHome_ThereIsNoDataForThisReport' => 'Za to poročilo ni podatkov.',
+	'CoreHome_CategoryNoData' => 'V tej kategoriji ni podatkov. Poizkusite "Vključiti celotno populacijo".',
 	'CoreHome_ShowJSCode' => 'Prikaži JavaScript kodo za vstavljanje',
-	'CoreHome_IncludeAllPopulation_js' => 'Vključi vso populacijo',
+	'CoreHome_PageOf_js' => '%1$s od %2$s',
 	'CoreHome_PeriodDay' => 'Dan',
 	'CoreHome_PeriodWeek' => 'Teden',
 	'CoreHome_PeriodMonth' => 'Mesec',
@@ -270,6 +378,7 @@ $translations = array(
 	'CoreHome_MonthDecember_js' => 'December',
 	'CorePluginsAdmin_Plugins' => 'Vtičniki',
 	'CorePluginsAdmin_PluginsManagement' => 'Urejanje Vtičnikov',
+	'CorePluginsAdmin_MainDescription' => 'Vtičniki razširjajo Piwik-ovo funkcionalnost. Ko je vtičnik enkrat nameščen, ga lahko tukaj aktivirate oziroma deaktivirate.',
 	'CorePluginsAdmin_Plugin' => 'Vtičnik',
 	'CorePluginsAdmin_Version' => 'Verzija',
 	'CorePluginsAdmin_Status' => 'Status',
@@ -302,6 +411,9 @@ $translations = array(
 	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik je bil uspešno posodobljen!',
 	'CoreUpdater_ContinueToPiwik' => 'Nadaljuj na Piwik',
 	'CoreUpdater_UpdateAutomatically' => 'Samodejno posodpobi',
+	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Za posodobitev je na voljo nova različica Piwik-a',
+	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Sistem lahko na različico %s posodobite samodejno, ali pa prenesete paket, ter ga namestite ročno:',
+	'CoreUpdater_DownloadX' => 'Prenos %s',
 	'CoreUpdater_DownloadingUpdateFromX' => 'Prenašam posodobitev iz %s',
 	'CoreUpdater_UnpackingTheUpdate' => 'Razpakiram posodobitev',
 	'CoreUpdater_VerifyingUnpackedFiles' => 'Preverjam razpakirane datoteke',
@@ -313,22 +425,51 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nezdružljiv arhic: %s',
 	'CoreUpdater_ExceptionArchiveEmpty' => 'Prazen arhiv.',
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arhiv je nepopoln: manjkajo nekatere datoteke (npr. %s).',
+	'Dashboard_PluginDescription' => 'Nadzorna plošča vaše spletne analitike. Nadzorno ploščo lahko prilagajate: dodajate nove gradnike, spreminjate njihov vrstni red. Vsak uporabnik lahko dostopa do svoje lastne kontrolne plošče.',
 	'Dashboard_Dashboard' => 'Nadzorna Plošča',
+	'Dashboard_AddAWidget' => 'Dodaj gradnik',
+	'Dashboard_DeleteWidgetConfirm' => 'Ste prepričani da želite izbrisati ta gradnik s kontrolne plošče?',
+	'Dashboard_SelectWidget' => 'Izberite gradnik, ki ga želite dodati na kontrolno ploščo.',
+	'Dashboard_AddPreviewedWidget_js' => 'Kliknite, če želite dodati gradnik na kontrolno ploščo',
+	'Dashboard_WidgetPreview_js' => 'Predogled gradnika',
 	'Dashboard_Close_js' => 'Zapri',
 	'Dashboard_Maximise_js' => 'Povečaj',
+	'Dashboard_Minimise_js' => 'Pomanjšaj',
+	'Dashboard_TitleWidgetInDashboard_js' => 'Gradnik je že na v kontrolni plošči',
 	'Dashboard_TitleClickToAdd_js' => 'Kliknite, če želite dodati na nadzorno ploščo',
+	'Dashboard_LoadingWidget_js' => 'Nalagam gradnik...',
+	'Dashboard_WidgetNotFound_js' => 'Gradnik ni bil najden',
+	'Dashboard_ResetDashboard' => 'Ponastavi kontrolno ploščo',
+	'Dashboard_ResetDashboardConfirm' => 'Ste prepričani da želite ponastaviti postavitev kontrolne plošče na privzeti izbor gradnikov?',
+	'Dashboard_WidgetsAndDashboard' => 'Gradniki & Kontrolna Plošča',
+	'Dashboard_ChangeDashboardLayout' => 'Spremeni postavitev nadzorne plošče',
+	'Dashboard_SelectDashboardLayout' => 'Prosimo, izberite vašo novo postavitev nadzorne plošče',
 	'DBStats_PluginDescription' => 'Ta vtičnik poroča o Piwik-ovi uporabi MySQL podatkovne baze.',
 	'DBStats_DatabaseUsage' => 'Uporaba podatkovne baze',
 	'DBStats_MainDescription' => 'Piwik shranjuje vse vaše podatke v MySQL bazo podatkov. Trenutna poraba podatkovne baze je %s.',
 	'DBStats_Table' => 'Tabela',
+	'DBStats_RowCount' => 'Število vrst',
+	'DBStats_DataSize' => 'Velikost podatkov',
+	'DBStats_IndexSize' => 'Velikost indeksa',
+	'DBStats_TotalSize' => 'Skupna velikost',
+	'ExampleAPI_PluginDescription' => 'Primer Vtičnika: Kako ustvariti API za vaš vtičnik za izvažanje vaših podatkov v večih formatih, brez posebnega programiranja.',
 	'Feedback_PluginDescription' => 'Podajte vašo povratno informacijo ekipi Piwik. Zaupajte nam vaše ideje in predloge!',
+	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Imate napako ali pa željo, ki nam jo želite sporočiti?',
+	'Feedback_ViewAnswersToFAQ' => 'Oglejte si odgovore na %sPogosto Zastavljena Vprašanja (FAQ)%s',
 	'Feedback_WhyAreMyVisitsNoTracked' => 'Zakaj niso obiskovalci moje spletne strani sledeni?',
+	'Feedback_HowToExclude' => 'Kako izključim sledenje mojih obiskov?',
+	'Feedback_WhyWrongCountry' => 'Zakaj Piwik prikazuje moje obiske iz napačne države?',
+	'Feedback_VisitTheForums' => 'Obiščite %sForume%s',
+	'Feedback_LearnWaysToParticipate' => 'Oglejte si vse načine kako lahko %ssodelujete%s',
 	'Feedback_ContactThePiwikTeam' => 'Kontaktiraje Piwik-ovo ekipo!',
+	'Feedback_IWantTo' => 'Želim:',
+	'Feedback_CategoryShareStory' => 'Delite Piwik zgodbo o uspehu',
 	'Feedback_CategorySponsor' => 'Sponzorirajte Piwik',
 	'Feedback_CategoryHire' => 'Najemite Piwiki-svetovalca',
 	'Feedback_CategorySecurity' => 'Prijavi varnostno napako',
 	'Feedback_MyEmailAddress' => 'Moj email:',
 	'Feedback_MyMessage' => 'Moje sporočilo:',
+	'Feedback_DetailsPlease' => '(prosimu vključite podrobnosti)',
 	'Feedback_SendFeedback' => 'Pošlji povratno informacijo',
 	'Feedback_ManuallySendEmailTo' => 'Prosimo, da sporočilo ročno pošljete',
 	'Feedback_MessageSent' => 'Vaše sporočilo je bilo poslano Piwik-ovi ekipi.',
@@ -337,9 +478,15 @@ $translations = array(
 	'Feedback_ExceptionBodyLength' => 'Sporočilo mora biti dolgo vsaj %s znakov.',
 	'Feedback_ExceptionNoUrls' => 'Sporočilo ne sme vsebovati URL-ja, da ne bo padlo pod vsiljeno pošto.',
 	'Goals_Goals' => 'Cilji',
+	'Goals_Ecommerce' => 'Ecommerce',
+	'Goals_EcommerceOverview' => 'Ecommerce pregled',
+	'Goals_EcommerceLog' => 'Ecommerce zgodovina',
+	'Goals_AbandonedCart' => 'Opuščen voziček',
 	'Goals_GoalsOverview' => 'Pregled ciljev',
 	'Goals_GoalsManagement' => 'Upravljanje ciljev',
 	'Goals_GoalX' => 'Cilj %s',
+	'Goals_GoalConversion' => 'Spreobrnitev cilja',
+	'Goals_GoalConversions' => 'Spreobrnitve ciljev',
 	'Goals_AddGoal_js' => 'Dodaj Cilj',
 	'Goals_UpdateGoal_js' => 'Posodobi Cilj',
 	'Goals_DeleteGoalConfirm_js' => 'Ste prepričani de želite izbrisati Cilj%s?',
@@ -354,7 +501,14 @@ $translations = array(
 	'Goals_ConversionsOverview' => 'Pregled sprememb',
 	'Goals_Contains' => 'vsebuje %s',
 	'Goals_IsExactly' => 'je točno %s',
+	'Goals_MatchesExpression' => 'se ujema z nizom %s',
 	'Goals_Pattern' => 'Vzorec',
+	'Goals_ProductSKU' => 'SKU izdelka',
+	'Goals_ProductName' => 'Ime izdelka',
+	'Goals_ProductCategory' => 'Kategorija izdelkov',
+	'Goals_Products' => 'Izdelki',
+	'Goals_VisitsUntilConv' => 'Obiskov za spreobrnitev',
+	'Goals_DaysToConv' => 'Dni za spreobrnitev',
 	'Installation_Installation' => 'Namestitev',
 	'Installation_InstallationStatus' => 'Status namestitve',
 	'Installation_PercentDone' => '%s %% Končano',
@@ -390,12 +544,19 @@ $translations = array(
 	'Installation_SystemCheckExtensions' => 'Ostale potrebne razširitve',
 	'Installation_TablesCreatedSuccess' => 'Tabele so bile uspešno ustvarjene!',
 	'Installation_Welcome' => 'Dobrodošli!',
+	'LanguagesManager_PluginDescription' => 'Ta vtičnik bo prikazoval seznam vseh jezikov, ki so na voljo za Piwik-ov vmesnik. Izbrani jezik bo shranjen v nastavitvah vsakega uporabnika.',
 	'LanguagesManager_AboutPiwikTranslations' => 'O prevodih Piwik-a',
+	'Live_PluginDescription' => 'Vohunite za vašimi obiskovalci, v živo!',
+	'Live_LinkVisitorLog' => 'Ogled podrobnega dnevnika obiskovalcev',
 	'Live_Actions' => 'Dejanja',
 	'Live_Action' => 'Dejanje',
+	'Live_VisitorLog' => 'Dnevnik obiskovalcev',
 	'Live_Time' => 'Čas',
+	'Live_LastMinutes' => 'Zadnjih %s minutah',
+	'Live_LastHours' => 'Zadnjih %s urah',
 	'Live_GoalType' => 'Tip',
 	'Live_GoalDetails' => 'Podrobnosti',
+	'Live_VisitorsLastVisit' => 'Zadnji obisk tega obiskovalce je bil pred %s dnevi.',
 	'Login_Password' => 'Geslo',
 	'Login_PasswordRepeat' => 'Geslo (ponovno)',
 	'Login_ChangePassword' => 'Spremeni geslo',
@@ -407,23 +568,68 @@ $translations = array(
 	'Login_RemindPassword' => 'Ponovno pošlji geslo',
 	'Login_PasswordsDoNotMatch' => 'Gesli se ne ujemata.',
 	'Login_PasswordSuccessfullyChanged' => 'Geslo je bilo uspešno spremenjeno!',
+	'Login_MailTopicPasswordRecovery' => 'Povrnitev gesla',
+	'Mobile_LastUpdated' => 'Zadnje posodobljeno: %s',
+	'Mobile_PullDownToRefresh' => 'Potegnite navzdol za osvežitev...',
+	'Mobile_Refresh' => 'Osveži',
+	'Mobile_Reloading' => 'Nalagam...',
+	'Mobile_ReleaseToRefresh' => 'Izpustite za osvežitev...',
+	'Mobile_ShowAll' => 'Prikaži vse',
+	'Mobile_ShowLess' => 'Prikaži manj',
 	'Mobile_AnonymousAccess' => 'Anonimni dostop',
+	'Mobile_AccessUrlLabel' => 'Piwik dostopni URL',
 	'Mobile_EnableGraphsLabel' => 'Prikaži grafe',
+	'Mobile_DefaultReportDate' => 'Datum poročila',
+	'Mobile_NavigationBack' => 'Nazaj',
+	'Mobile_SaveSuccessError' => 'Prosimo, zagotovite nastavitve',
+	'Mobile_YouAreOffline' => 'Oprostite, trenutno ste offline',
+	'MultiSites_Evolution' => 'Evolucija',
 	'Provider_WidgetProviders' => 'Ponudniki',
 	'Provider_ColumnProvider' => 'Ponudnik',
+	'Provider_SubmenuLocationsProvider' => 'Lokacije & Ponudnik',
 	'Referers_SearchEngines' => 'Spletni Iskalniki',
 	'Referers_Keywords' => 'Ključne Besede',
 	'Referers_Websites' => 'Spletne Strani',
+	'Referers_Campaigns' => 'Kampanje',
 	'Referers_ColumnSearchEngine' => 'Spletni Iskalnik',
 	'Referers_ColumnWebsite' => 'Spletna Stran',
+	'Referers_ColumnWebsitePage' => 'Spletna stran',
 	'Referers_ColumnKeyword' => 'Ključna Beseda',
+	'Referers_ColumnCampaign' => 'Kampanja',
+	'Referers_DistinctSearchEngines' => 'različni brskalniki',
+	'Referers_DistinctKeywords' => 'različne ključne besede',
+	'Referers_DistinctCampaigns' => 'različne kampanje',
+	'Referers_DistinctWebsites' => 'različne spletne strani',
 	'Referers_SubmenuOverview' => 'Pregled',
+	'Referers_SubmenuSearchEngines' => 'Brskalniki & ključne besede',
+	'Referers_SubmenuWebsites' => 'Spletne strani',
+	'Referers_SubmenuCampaigns' => 'Kampanje',
 	'Referers_WidgetKeywords' => 'Seznam ključnih besed',
+	'Referers_WidgetCampaigns' => 'Seznam kampanij',
+	'Referers_WidgetExternalWebsites' => 'Seznam zunanjih spletnih strani',
 	'Referers_WidgetSearchEngines' => 'Najboljši spletni iskalniki',
 	'Referers_WidgetOverview' => 'Pregled',
+	'SecurityInfo_Security' => 'Varnost',
+	'SecurityInfo_SecurityInformation' => 'PHP varnostni podatki',
+	'SecurityInfo_Test' => 'Test',
+	'SecurityInfo_Result' => 'Rezultat',
+	'SEO_SeoRankings' => 'SEO položaji',
+	'SEO_AlexaRank' => 'Alexa položaj',
+	'SEO_DomainAge' => 'Starost domene',
+	'SEO_Rank' => 'Položaj',
+	'SEO_Backlinks' => 'Povratne povezave',
+	'SEO_Pages' => 'Strani',
+	'SitesManager_Sites' => 'Spletne strani',
+	'SitesManager_TrackingTags' => 'Sledilna koda za %s',
 	'SitesManager_WebsitesManagement' => 'Upravljanje spletnih strani',
+	'SitesManager_OnlyOneSiteAtTime_js' => 'Sočasno lahko urejate zgolj eno spletno stran. Prosimo, shranite ali pa prekličite vaše trenutne spremembe za spletno stran %s.',
+	'SitesManager_JsTrackingTag' => 'JavaScript sledilna koda',
+	'SitesManager_JsTrackingTagHelp' => 'Tu je JavaScript sledilna koda, ki jo vključite v vse vaše strani',
+	'SitesManager_ShowTrackingTag' => 'Oglej si sledilno kodo',
+	'SitesManager_NoWebsites' => 'Nimate spletnih strani za urejanje',
 	'SitesManager_AddSite' => 'Dodaj novo spletno stran',
 	'SitesManager_NotFound' => 'Ni bilo najdenih spletnih strani za',
+	'SitesManager_Urls' => 'Povezave',
 	'SitesManager_MenuSites' => 'Spletne strani',
 	'SitesManager_DeleteConfirm_js' => 'Ste prepričani da želite izbrisati spletno stran %s?',
 	'SitesManager_ExceptionDeleteSite' => 'Te spletne strani ni mogoče izbrisati, saj je trenutno edina registrirana spletna stran. Šele ko boste dodali novo spletno stran, boste lahko izbrisali to spletno stran.',
@@ -432,27 +638,41 @@ $translations = array(
 	'SitesManager_ExceptionInvalidUrl' => 'Vnešeni URL "%s" ni veljaven.',
 	'SitesManager_ExceptionInvalidTimezone' => 'Časovno območje "%s" ni veljavno. Prosimo, vnesite veljavno časovno območje.',
 	'SitesManager_ExcludedIps' => 'Izključeni IP naslovi',
+	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Spodnji IP-ji bodo izključeni iz sledenja na vseh spletnih straneh.',
 	'SitesManager_ExcludedParameters' => 'Izključeni Parametri',
+	'SitesManager_YourCurrentIpAddressIs' => 'Vaš trenuten IP je %s',
 	'SitesManager_SelectACity' => 'Izberite mesto',
+	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Izberite mesto, ki je v istem časovnem pasu kot vi.',
+	'SitesManager_UTCTimeIs' => 'UTC čas je %s.',
 	'SitesManager_Timezone' => 'Časovno območje',
+	'SitesManager_DefaultTimezoneForNewWebsites' => 'Privzet časovni pas za nove spletne strani',
 	'SitesManager_Currency' => 'Valuta',
 	'SitesManager_DefaultCurrencyForNewWebsites' => 'Privzeta Valuta za nove spletne strani',
 	'SitesManager_SelectDefaultCurrency' => 'Izberete lahko privzeto valuto. Ta bo uporabljena na vseh novo-dodanih spletnih straneh.',
+	'SitesManager_EnableEcommerce' => 'Ecommerce omogočen',
 	'TranslationsAdmin_PluginDescription' => 'Pomagajte nam prevesti Piwik v vaš jezik.',
 	'TranslationsAdmin_MenuTranslations' => 'Prevodi',
 	'TranslationsAdmin_MenuLanguages' => 'Jeziki',
 	'TranslationsAdmin_LanguageCode' => 'Šifra jezika',
+	'TranslationsAdmin_Plugin' => 'Vtičnik',
 	'TranslationsAdmin_Definition' => 'Definicija',
 	'TranslationsAdmin_Translations' => 'Prevodi',
 	'TranslationsAdmin_AddLanguage' => 'Dodaj jezik',
 	'TranslationsAdmin_Export' => 'Izvozi jezik',
 	'TranslationsAdmin_Import' => 'Uvozi jezik',
 	'TranslationsAdmin_ShowOnlyEmpty' => 'Prikaži samo manjkajoče prevode',
+	'TranslationsAdmin_TranslationAlreadyExists' => 'Prevod že obstaja',
+	'TranslationsAdmin_CannotOpenForWriting' => 'Ne morem odpreti %s za zapisovanje',
+	'TranslationsAdmin_InvalidCountry' => 'Napačna država',
+	'TranslationsAdmin_InvalidLanguage' => 'Napačen jezik',
 	'UserCountry_PluginDescription' => 'Sporoči državo, iz katere so obiskovalci.',
 	'UserCountry_Country' => 'Država',
 	'UserCountry_Continent' => 'Kontitent',
 	'UserCountry_Location' => 'Lokacija',
 	'UserCountry_SubmenuLocations' => 'Lokacije',
+	'UserCountry_WidgetContinents' => 'Kontinenti obiskovalcev',
+	'UserCountry_WidgetCountries' => 'Države obiskovalcev',
+	'UserCountry_country_ad' => 'Andora',
 	'UserCountry_country_al' => 'Albanija',
 	'UserCountry_country_ar' => 'Argentina',
 	'UserCountry_country_at' => 'Avstrija',
@@ -461,6 +681,7 @@ $translations = array(
 	'UserCountry_country_be' => 'Belgija',
 	'UserCountry_country_bf' => 'Burkina Faso',
 	'UserCountry_country_br' => 'Brazilija',
+	'UserCountry_country_by' => 'Belorusija',
 	'UserCountry_country_ca' => 'Kanada',
 	'UserCountry_country_cg' => 'Kongo',
 	'UserCountry_country_ch' => 'Švica',
@@ -479,6 +700,7 @@ $translations = array(
 	'UserCountry_country_gr' => 'Grčija',
 	'UserCountry_country_hk' => 'Hong Kong',
 	'UserCountry_country_hr' => 'Hrvaška',
+	'UserCountry_country_ht' => 'Haiti',
 	'UserCountry_country_hu' => 'Madžarska',
 	'UserCountry_country_id' => 'Indonezija',
 	'UserCountry_country_ie' => 'Irska',
@@ -486,25 +708,66 @@ $translations = array(
 	'UserCountry_country_in' => 'Indija',
 	'UserCountry_country_iq' => 'Irak',
 	'UserCountry_country_ir' => 'Iran',
+	'UserCountry_country_is' => 'Islandija',
 	'UserCountry_country_it' => 'Italija',
+	'UserCountry_country_jm' => 'Jamajka',
 	'UserCountry_country_jp' => 'Japonska',
+	'UserCountry_country_lt' => 'Litva',
+	'UserCountry_country_lu' => 'Luksemburg',
+	'UserCountry_country_lv' => 'Matvija',
+	'UserCountry_country_mc' => 'Monako',
+	'UserCountry_country_me' => 'Montenegro',
+	'UserCountry_country_mg' => 'Madagaskar',
 	'UserCountry_country_mk' => 'Makedonija',
+	'UserCountry_country_ml' => 'Mali',
+	'UserCountry_country_mn' => 'Mongolija',
+	'UserCountry_country_mt' => 'Malta',
+	'UserCountry_country_mv' => 'Maldivi',
+	'UserCountry_country_mx' => 'Mehika',
+	'UserCountry_country_nc' => 'Nova Kaledonija',
+	'UserCountry_country_ne' => 'Niger',
+	'UserCountry_country_ng' => 'Nigerija',
+	'UserCountry_country_nl' => 'Nizozemska',
+	'UserCountry_country_no' => 'Norveška',
+	'UserCountry_country_np' => 'Nepal',
+	'UserCountry_country_nz' => 'Nova Zelandija',
+	'UserCountry_country_pe' => 'Peru',
+	'UserCountry_country_pt' => 'Portugalska',
 	'UserCountry_country_rs' => 'Srbija',
 	'UserCountry_country_se' => 'Švedska',
 	'UserCountry_country_sf' => 'Finska',
 	'UserCountry_country_si' => 'Slovenija',
 	'UserCountry_country_sk' => 'Slovaška',
 	'UserCountry_country_th' => 'Tajska',
+	'UserCountry_country_tr' => 'Turčija',
+	'UserCountry_country_tw' => 'Tajvan',
+	'UserCountry_country_ua' => 'Ukrajina',
+	'UserCountry_country_uk' => 'Združeno kraljestvo',
+	'UserCountry_country_us' => 'Združene države',
+	'UserCountry_country_uy' => 'Urugvaj',
+	'UserCountry_country_uz' => 'Uzbekistan',
+	'UserCountry_country_vn' => 'Vietnam',
+	'UserCountry_country_ws' => 'Samoa',
+	'UserCountry_country_yt' => 'Mayotte',
+	'UserCountry_country_yu' => 'Jugoslavija',
+	'UserCountry_country_za' => 'Južna Afrika',
+	'UserCountry_country_zw' => 'Zimbabve',
+	'UserCountry_country_a1' => 'Anonimen Proxy',
+	'UserCountry_country_ap' => 'Azija/Pacifiška regija',
+	'UserCountry_country_o1' => 'Druge države',
+	'UserCountry_continent_eur' => 'Evropa',
 	'UserCountry_continent_afr' => 'Afrika',
 	'UserCountry_continent_ant' => 'Antartika',
 	'UserCountry_continent_asi' => 'Azija',
 	'UserCountry_continent_amn' => 'Severna Amerika',
 	'UserCountry_continent_amc' => 'Sredjna Amerika',
 	'UserCountry_continent_ams' => 'Južna Amerika',
+	'UserCountry_continent_oce' => 'Oceanija',
 	'UserCountryMap_map' => 'zemljevid',
 	'UserCountryMap_worldMap' => 'svetovni zemljevid',
 	'UserCountryMap_toggleFullscreen' => 'Celozaslonski Način',
 	'UserSettings_VisitorSettings' => 'Nastavitve Obiskovalcev',
+	'UserSettings_BrowserFamilies' => 'Družine brskalnikov',
 	'UserSettings_Browsers' => 'Brskalniki',
 	'UserSettings_Plugins' => 'Vtičniki',
 	'UserSettings_Configurations' => 'Nastavitve',
@@ -520,14 +783,18 @@ $translations = array(
 	'UserSettings_ColumnTypeOfScreen' => 'Tip zaslona',
 	'UserSettings_WidgetResolutions' => 'Resolucija zaslona',
 	'UserSettings_WidgetPlugins' => 'Seznam Vtičnikov',
+	'UserSettings_WidgetBrowserFamilies' => 'Brskalniki po družini',
 	'UserSettings_WidgetOperatingSystems' => 'Operacijski sistemi',
 	'UserSettings_SubmenuSettings' => 'Nastavitve',
 	'UsersManager_UsersManagement' => 'Upravljanje Uporabnikov',
 	'UsersManager_ThereAreCurrentlyNRegisteredUsers' => 'Trenutno je %s registriranih uporabnikov.',
 	'UsersManager_ManageAccess' => 'Upravljaj dostop',
+	'UsersManager_Sites' => 'Spletne strani',
 	'UsersManager_AllWebsites' => 'Vse spletne strani',
 	'UsersManager_ApplyToAllWebsites' => 'Uveljavi za vse spletne strani',
 	'UsersManager_User' => 'Uporabnik',
+	'UsersManager_PrivNone' => 'Ni dostopa',
+	'UsersManager_PrivView' => 'Pogled',
 	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_Password' => 'Geslo',
 	'UsersManager_Email' => 'Email',
@@ -540,10 +807,14 @@ $translations = array(
 	'UsersManager_ChangePassword' => 'Spremeni geslo',
 	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Če bi radi spremenili geslo, vpišite novega. Če ne, to pustite prazno.',
 	'UsersManager_TypeYourPasswordAgain' => 'Ponovno vpišite vaše novo geslo.',
+	'UsersManager_TheLoginScreen' => 'Obrazec za vpis',
 	'UsersManager_DeleteConfirm_js' => 'Ste prepričani, da želite izbrisati uporabnika %s?',
 	'UsersManager_YourUsernameCannotBeChanged' => 'Vaše uporabniško ime ne more biti spremenjeno.',
+	'UsersManager_ExceptionLoginExists' => 'Vpis \'%s\' že obstaja.',
 	'UsersManager_ExceptionEmailExists' => 'Uporabnik z emailom "%s" že obstaja.',
+	'UsersManager_ExceptionInvalidPassword' => 'Dolžina gesla mora biti med %1$s in %2$s znaki.',
 	'UsersManager_ExceptionInvalidEmail' => 'Email ni veljavnega formata.',
+	'UsersManager_ExceptionDeleteDoesNotExist' => 'Uporabnik \'%s\' ne obstaja, ter ga tako ni moč izbrisati.',
 	'UsersManager_ExceptionAdminAnonymous' => '"Anonimnemu" uporabniku ne morate dodeliti administrativnih dovoljenj.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'Uporabnik "%s" ne obstaja.',
 	'VisitFrequency_WidgetOverview' => 'Frekvenčni pregled',
@@ -556,19 +827,51 @@ $translations = array(
 	'VisitorGenerator_Submit' => 'Uveljavi',
 	'VisitorGenerator_SelectWebsite' => 'Izberi spletno stran',
 	'VisitorGenerator_NbRequestsPerSec' => 'Zahtev na sekundo',
+	'VisitorInterest_VisitsPerNbOfPages' => 'Obiskov na število strani',
+	'VisitorInterest_ColumnVisitDuration' => 'Trajanje obiska',
+	'VisitorInterest_ColumnPagesPerVisit' => 'Strani na obisk',
+	'VisitorInterest_VisitNum' => 'Številka obiska',
+	'VisitorInterest_WidgetLengths' => 'Dolžina obiskov',
+	'VisitorInterest_WidgetPages' => 'Strani na obisk',
+	'VisitorInterest_OneMinute' => '1 min',
+	'VisitorInterest_PlusXMin' => '%s min',
+	'VisitorInterest_OnePage' => '1 stran',
+	'VisitorInterest_NPages' => '%s strani',
+	'VisitsSummary_NbDownloadsDescription' => '%s prenosov',
+	'VisitsSummary_NbUniqueDownloadsDescription' => '%s edinstvenih prenosov',
+	'VisitsSummary_AverageVisitDuration' => '%s povprečno trajanje obiska',
+	'VisitsSummary_WidgetOverviewGraph' => 'Pregled z grafom',
 	'VisitsSummary_SubmenuOverview' => 'Pregled',
+	'VisitTime_LocalTime' => 'Obiski na lokalni čas',
+	'VisitTime_ServerTime' => 'Obiski na čas strežnika',
 	'VisitTime_ColumnServerTime' => 'Čas na strežniku',
 	'VisitTime_ColumnLocalTime' => 'Lokalni čas',
+	'VisitTime_WidgetLocalTime' => 'Obiski glede na lokalni čas',
+	'VisitTime_WidgetServerTime' => 'Obiski glede na čas na strežniku',
+	'VisitTime_SubmenuTimes' => 'Časi',
+	'VisitTime_NHour' => '%sh',
 	'PDFReports_ManageEmailReports' => 'Urejaj Email Poročila',
 	'PDFReports_EmailReports' => 'Email Poročila',
 	'PDFReports_PDF' => 'PDF',
 	'PDFReports_SendReportNow' => 'Pošlji Poročilo zdaj',
 	'PDFReports_EmailSchedule' => 'Urnik Emailov',
 	'PDFReports_SendReportTo' => 'Pošlji poročilo k',
+	'PDFReports_ReportFormat' => 'Format poročila',
+	'PDFReports_AggregateReportsFormat' => '(opcijsko) Opcije prikaza',
 	'PDFReports_SentToMe' => 'Pošlji meni',
 	'PDFReports_WeeklyScheduleHelp' => 'Mesečno poročilo: poročilo bo poslano vsak ponedeljek.',
 	'PDFReports_MonthlyScheduleHelp' => 'Mesečno poročilo: poročilo bo poslano vsak prvi dan v mesecu.',
 	'PDFReports_AlsoSendReportToTheseEmails' => 'Poročila pošlji tudi na sledeče emaile (en email v vsako vrstico):',
+	'PDFReports_ReportsIncluded' => 'Statistika vključena',
+	'PDFReports_CreateReport' => 'Ustvari poročilo',
+	'PDFReports_UpdateReport' => 'Posodobi poročilo',
 	'PDFReports_PiwikReports' => 'Piwik Poročila',
 	'PDFReports_EmailHello' => 'Zdravo,',
+	'PDFReports_AreYouSureDeleteReport' => 'Ste prepričani, da želite izbrisati to poročilo in urnik?',
+	'PDFReports_FrontPage' => 'Prva Stran',
+	'PDFReports_TableOfContent' => 'Seznam poročil',
+	'PDFReports_TopOfReport' => 'Nazaj na vrh',
+	'PDFReports_Pagination' => 'Stran %s od %s',
+	'ImageGraph_PluginDescription' => 'Ustvarite prelepe, statične, PNG grafe za vsa Piwik poročila.',
+	'ImageGraph_ColumnOrdinateMissing' => 'Vrstice \'%s\' ni bilo moč najti v tem poročilu.',
 );
