@@ -329,10 +329,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Nema podataka za ovaj izveštaj.',
 	'CoreHome_CategoryNoData' => 'Nema podataka u ovoj kategoriji. Probajte sa "Uključi celu populaciju".',
 	'CoreHome_ShowJSCode' => 'Prikaži JavaScript kod',
-	'CoreHome_IncludeAllPopulation_js' => 'Uključi celu populaciju',
-	'CoreHome_ExcludeLowPopulation_js' => 'Isključi celu populaciju',
 	'CoreHome_PageOf_js' => '%1$s od %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'Dan',
 	'CoreHome_PeriodWeek' => 'Nedelja',
 	'CoreHome_PeriodMonth' => 'Mesec',
@@ -456,7 +453,6 @@ $translations = array(
 	'CustomVariables_ColumnCustomVariableValue' => 'Vrednost dodatnog parametra',
 	'Dashboard_PluginDescription' => 'Vaša Konzola za web analitiku. Ovde možete personalizovati vašu Konzolu: dodajte vidžete ili im izmenite redosled. Svaki korisnik ima sopstvenu Konzolu.',
 	'Dashboard_Dashboard' => 'Konzola',
-	'Dashboard_AddWidget' => 'Dodaj vidžet...',
 	'Dashboard_DeleteWidgetConfirm' => 'Da li ste sigurni da želite da uklonite ovaj vidžet sa Konzole?',
 	'Dashboard_SelectWidget' => 'Izaberite vidžet koji želite da dodate na Konzolu',
 	'Dashboard_AddPreviewedWidget_js' => 'Dodaj pregledani vidžet na Konzolu',
@@ -714,7 +710,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'Direktni ulasci',
 	'Referers_Websites' => 'Sajtovi',
 	'Referers_Campaigns' => 'Kampanje',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (sa %2$s)',
 	'Referers_Evolution' => 'Trend kroz period',
 	'Referers_Type' => 'Tip dolaznog linka',
 	'Referers_ColumnRefererType' => 'Tip dolaznog linka',
@@ -751,9 +746,7 @@ $translations = array(
 	'SecurityInfo_Result' => 'Rezultat',
 	'SEO_SeoRankings' => 'SEO rangiranje',
 	'SEO_AlexaRank' => 'Alexa rangiranje',
-	'SEO_YahooIndexedPages' => 'Yahoo indeksirane stranice',
 	'SEO_DomainAge' => 'Starost domena',
-	'SEO_YahooBacklinks' => 'Yahoo povratni linkovi',
 	'SEO_Rank' => 'Rang',
 	'SEO_Backlinks' => 'Povratni linkovi',
 	'SEO_Pages' => 'Stranice',
@@ -1026,8 +1019,8 @@ $translations = array(
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_re' => 'Reunion Ostrva',
 	'UserCountry_country_ro' => 'Rumunija',
-	'UserCountry_country_ru' => 'Rusija',
 	'UserCountry_country_rs' => 'Srbija',
+	'UserCountry_country_ru' => 'Rusija',
 	'UserCountry_country_rw' => 'Ruanda',
 	'UserCountry_country_sa' => 'Saudijska Arabija',
 	'UserCountry_country_sb' => 'Solomonova Ostrva',
@@ -1224,7 +1217,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => 'Sumarno',
 	'VisitsSummary_NbVisits' => 'Broj poseta: %s',
 	'VisitsSummary_NbUniqueVisitors' => 'Broj jedinstvenih posetilaca: %s',
-	'VisitsSummary_NbActions' => 'Broj akcija (prikaza stranica): %s',
 	'VisitsSummary_NbActionsDescription' => 'Broj akcija (prikaza stranica, preuzimanja i odlazaka): %s',
 	'VisitsSummary_AverageVisitDuration' => 'Prosečno trajanje posete: %s',
 	'VisitsSummary_MaxNbActions' => 'Maksimum akcija u jednoj poseti: %s',
