@@ -136,7 +136,6 @@ $translations = array(
 	'CoreAdminHome_PluginDescription' => 'పివిక్ యొక్క నిర్వహణా కేంద్రం.',
 	'CoreAdminHome_MenuGeneralSettings' => 'సాధారణ అమరికలు',
 	'CoreAdminHome_Administration' => 'నిర్వహణ',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'రోజు',
 	'CoreHome_PeriodWeek' => 'వారం',
 	'CoreHome_PeriodMonth' => 'నెల',
@@ -208,7 +207,6 @@ $translations = array(
 	'CoreUpdater_UpgradeComplete' => 'నవీకరణ పూర్తయ్యింది!',
 	'CoreUpdater_WarningMessages' => 'హెచ్చరిక సందేశాలు:',
 	'Dashboard_Dashboard' => 'డాష్‌బోర్డు',
-	'Dashboard_AddWidget' => 'ఒక విడ్జెటుని చేర్చండి...',
 	'Dashboard_WidgetPreview_js' => 'విడ్జెట్ మునుజూపు',
 	'Dashboard_Close_js' => 'మూసివేయి',
 	'Dashboard_TitleWidgetInDashboard_js' => 'విడ్జెట్ ఇప్పటికే డాష్‌బోర్డులో ఉంది',
@@ -244,7 +242,6 @@ $translations = array(
 	'Referers_DirectEntry' => 'నేరు సందర్శన',
 	'Referers_Websites' => 'జాలగూళ్ళు',
 	'Referers_Campaigns' => 'ప్రచారాలు',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (%2$s నుండి)',
 	'Referers_ColumnSearchEngine' => 'శోధనయంత్రం',
 	'Referers_ColumnWebsite' => 'జాలగూడు',
 	'Referers_ColumnWebsitePage' => 'జాలగూడు పుట',
