@@ -5,6 +5,7 @@ $translations = array(
 	'General_TranslatorEmail' => 'halfdan@xnorfz.de, dev@yazici.info, hello@emresaracoglu.com',
 	'General_EnglishLanguageName' => 'Turkish',
 	'General_OriginalLanguageName' => 'Türkçe',
+	'General_LayoutDirection' => 'ltr',
 	'General_HelloUser' => 'Merhaba, %s!',
 	'General_OpenSourceWebAnalytics' => 'Açık kaynak kodlu Web İstatistik Servisi',
 	'General_Dashboard' => 'Pano',
@@ -16,8 +17,10 @@ $translations = array(
 	'General_Settings' => 'Ayarlar',
 	'General_GiveUsYourFeedback' => 'Geri Bildirim Verin!',
 	'General_Unknown' => 'Bilinmeyen',
+	'General_Never' => 'Asla',
 	'General_Required' => '%s gerekli',
 	'General_NotValid' => '%s geçerli değil',
+	'General_NotDefined' => '%s tanımlı değil',
 	'General_Id' => 'No',
 	'General_Error' => 'Hata',
 	'General_Warning' => 'Uyarı',
@@ -26,18 +29,52 @@ $translations = array(
 	'General_No' => 'Hayır',
 	'General_Delete' => 'Sil',
 	'General_Report' => 'Raporla',
+	'General_Reports' => 'Raporlar',
 	'General_Edit' => 'Düzenle',
 	'General_Download' => 'İndir',
+	'General_Upload' => 'Yükle',
 	'General_Ok' => 'Tamam',
 	'General_Close' => 'Kapat',
+	'General_OrCancel' => 'veya %s İptal %s',
 	'General_Logout' => 'Oturumu Kapat',
 	'General_Username' => 'Kullanıcı adı',
 	'General_Description' => 'Açıklama',
 	'General_Done' => 'Yapıldı',
+	'General_PoweredBy' => 'Altyapı',
 	'General_Name' => 'İsim',
 	'General_Value' => 'Değer',
+	'General_Total' => 'Toplam',
+	'General_TotalVisitsActionsRevenue' => '(Toplam: %s ziyaretçi, %s eylem, %s kazanç)',
+	'General_AverageOrderValue' => 'Ortalama Sipariş Değeri',
+	'General_PurchasedProducts' => 'Satın Alınan Ürünler',
+	'General_EcommerceOrders' => 'ETicaret Siparişleri',
+	'General_TotalRevenue' => 'Toplam Kazanç',
+	'General_ProductRevenue' => 'Ürün Kazancı',
+	'General_AveragePrice' => 'Ortalama Fiyat',
+	'General_AverageQuantity' => 'Ortalama Ürün Adedi',
+	'General_UniquePurchases' => 'Tekil Satın Alımlar',
+	'General_ProductConversionRate' => 'Ürün Kuru',
+	'General_Quantity' => 'Miktar',
+	'General_Price' => 'Fiyat',
+	'General_Subtotal' => 'Ara toplam',
+	'General_Tax' => 'Vergi',
+	'General_Shipping' => 'Teslimat',
+	'General_Discount' => 'İndirim',
 	'General_Details' => 'Detaylar',
 	'General_Default' => 'Varsayılan',
+	'General_Visit' => 'Ziyaret',
+	'General_FromReferrer' => 'şuradan',
+	'General_VisitorIP' => 'Ziyaretçi IP',
+	'General_VisitorID' => 'Ziyaretçi ID',
+	'General_VisitType' => 'Ziyaretçi Türü',
+	'General_DaysSinceLastVisit' => 'Son ziyaretten bu yana geçen gün',
+	'General_DaysSinceFirstVisit' => 'İlk ziyaretten bu yana geçen gün',
+	'General_DaysSinceLastEcommerceOrder' => 'Son siparişten bu yana geçen gün',
+	'General_NumberOfVisits' => 'Ziyaret sayısı',
+	'General_NewVisitor' => 'Yeni Ziyaretçi',
+	'General_NewVisits' => 'Yeni ziyaret',
+	'General_ReturningVisitor' => 'Geri dönen ziyaretçi',
+	'General_Visitor' => 'Ziyaretçi',
 	'General_Date' => 'Tarih',
 	'General_Period' => 'Zaman aralığı',
 	'General_ChooseDate' => 'Tarih Seçimi',
@@ -47,29 +84,42 @@ $translations = array(
 	'General_CurrentMonth' => 'Bu ay',
 	'General_CurrentYear' => 'Bu yıl',
 	'General_DateRange' => 'Tarih aralığı:',
+	'General_DateRangeInPeriodList' => 'Tarih aralığı',
+	'General_DateRangeFromTo' => '%s tarihinden %s tarihine',
+	'General_ApplyDateRange' => 'Tarih Aralığını Uygula',
+	'General_InvalidDateRange_js' => 'Geçersiz Tarih Aralığı, Lütfen Tekrar Deneyin',
+	'General_DateRangeFrom_js' => 'Buradan',
+	'General_DateRangeTo_js' => 'Buraya',
+	'General_PreviousDays' => 'Önceki %s gün (bugün hariç)',
+	'General_LastDays' => 'Son %s gün (bugün dahil)',
 	'General_LoadingData' => 'Veri yükleniyor...',
 	'General_Loading_js' => 'Yükleniyor...',
 	'General_GoTo' => '%s\'e git',
 	'General_Next' => 'İleri',
 	'General_Previous' => 'Geri',
+	'General_First' => 'İlk',
 	'General_Search' => 'Arama',
 	'General_Others' => 'Diğerleri',
 	'General_Table' => 'Tablo',
 	'General_Piechart' => 'Pasta grafik',
 	'General_TagCloud' => 'Etiket bulutu',
 	'General_VBarGraph' => 'Dikey çubuk grafik',
+	'General_View' => 'Göster',
+	'General_OpenInNewWindow_js' => 'Yeni pencerede aç',
 	'General_SaveImageOnYourComputer_js' => 'Resmi bilgisayarınıza kaydetmek için, resme sağ tıklayıp "Farklı kaydet..." deyin',
 	'General_Refresh' => 'Sayfayı yenile',
 	'General_Visitors' => 'Ziyaretçiler',
 	'General_ExportThisReport' => 'Bu veri setini diğer formatlarda ihraç et',
 	'General_ExportAsImage_js' => 'Resim olarak dışa aktar',
 	'General_Export' => 'Dışa aktar',
+	'General_ParameterMustIntegerBetween' => '%s değeri %s ve %s arasında sayısal bir değer olmalıdır.',
 	'General_YourChangesHaveBeenSaved' => 'Değişiklikleriniz kaydedildi.',
 	'General_ErrorRequest' => 'Oops… istek sırasında problem meydana geldi, lütfen tekrar deneyin.',
 	'General_ColumnNbUniqVisitors' => 'Tekil ziyaretçiler',
 	'General_ColumnNbVisits' => 'Ziyaretler',
 	'General_ColumnPercentageVisits' => '% Ziyaretler',
 	'General_ColumnNbActions' => 'Eylemler',
+	'General_NbActions' => 'Eylem Sayısı',
 	'General_ColumnMaxActions' => 'Tek ziyarette maksimum eylem',
 	'General_ColumnSumVisitLength' => 'Ziyaretçiler tarafından harcanan toplam süre (saniye)',
 	'General_ColumnLabel' => 'Etiket',
@@ -77,21 +127,29 @@ $translations = array(
 	'General_ColumnActionsPerVisit' => 'Ziyaret başına eylemler',
 	'General_VisitDuration' => 'Ort. Ziyaret Süresi (saniye cinsinden)',
 	'General_ColumnAvgTimeOnSite' => 'Sitede geçirilen ortalama süre',
+	'General_ColumnAvgTimeOnSiteDocumentation' => 'Bir ziyaretin ortalama süresi.',
+	'General_ColumnVisitDuration' => 'Ziyaret Süresi (saniye bazında)',
 	'General_ColumnBounceRate' => 'Hemen çıkma oranı',
 	'General_ColumnExitRate' => 'Çıkış oranı',
 	'General_ColumnPageviews' => 'Sayfa gösterimleri',
+	'General_ColumnPageviewsDocumentation' => 'Bu sayfanın kaç defa ziyaret edildiği',
 	'General_ColumnUniquePageviews' => 'Tekil sayfa gösterimleri',
 	'General_ColumnBounces' => 'Sıçramalar',
+	'General_ColumnUniqueEntrances' => 'Tekil girişler',
 	'General_ColumnEntrances' => 'Girişler',
+	'General_ColumnEntrancesDocumentation' => 'Bu sayfadan başlayan ziyaret sayısı',
 	'General_ColumnExits' => 'Çıkışlar',
+	'General_ColumnUniqueExits' => 'Tekil çıkışlar',
+	'General_ColumnExitsDocumentation' => 'Bu sayfada biten ziyaret sayısı',
 	'General_ColumnAverageTimeOnPage' => 'Sayfada geçirilen ort. süre',
 	'General_ColumnValuePerVisit' => 'Ziyaret başına değer',
 	'General_ColumnVisitsWithConversions' => 'Sitenize gelen ve (alışveriş, mail listesine kayıt gibi) aktiviteler gösteren ziyaretçileri gör.',
+	'General_VisitsWith' => '%s ile Ziyaretler',
 	'General_YearsDays' => '%1$s yıl %2$s gün',
 	'General_DaysHours' => '%1$s gün %2$s saat',
 	'General_HoursMinutes' => '%1$s saat %2$s dak',
 	'General_MinutesSeconds' => '%1$s dak %2$ss',
-	'General_Seconds' => '%ss',
+	'General_Seconds' => '%ssn',
 	'General_Save' => 'Kaydet',
 	'General_ForExampleShort' => 'Örneğin',
 	'General_YouMustBeLoggedIn' => 'Bu işleve erişmek için oturumu açmış olmanız gerekmekte.',
@@ -109,6 +167,7 @@ $translations = array(
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s kullanılabilir durumda.. %2$s Lütfen şimdi güncelleyin!%3$s (%4$s değişiklikleri%5$s görün).',
 	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s mevcut. Lütfen site yöneticisine bildiriniz.',
 	'General_BackToPiwik' => 'Piwik\'e geri dön.',
+	'General_ClickHere' => 'Daha fazla bilgi için buraya tıklayın.',
 	'General_ShortMonth_1' => 'Oca',
 	'General_ShortMonth_2' => 'Şub',
 	'General_ShortMonth_3' => 'Mar',
@@ -133,13 +192,13 @@ $translations = array(
 	'General_LongMonth_10' => 'Ekim',
 	'General_LongMonth_11' => 'Kasım',
 	'General_LongMonth_12' => 'Aralık',
-	'General_ShortDay_1' => 'Pt',
+	'General_ShortDay_1' => 'Pzt',
 	'General_ShortDay_2' => 'Sa',
-	'General_ShortDay_3' => 'Ça',
-	'General_ShortDay_4' => 'Pe',
+	'General_ShortDay_3' => 'Çrş',
+	'General_ShortDay_4' => 'Prş',
 	'General_ShortDay_5' => 'Cu',
-	'General_ShortDay_6' => 'Ct',
-	'General_ShortDay_7' => 'Pa',
+	'General_ShortDay_6' => 'Cmt',
+	'General_ShortDay_7' => 'Pzr',
 	'General_LongDay_1' => 'Pazartesi',
 	'General_LongDay_2' => 'Salı',
 	'General_LongDay_3' => 'Çarşamba',
@@ -166,6 +225,7 @@ $translations = array(
 	'General_ExceptionUnreadableFileDisabledMethod' => 'Yapılandırma dosyası {%s} okunamadı. Sitenizi barındıran servis %s özelliğini devre dışı bırakmış olabilir.',
 	'General_ExceptionInvalidToken' => 'Güvenlik jetonu geçerli değil.',
 	'General_ExceptionLanguageFileNotFound' => '\'%s\' dil dosyası bulunamadı.',
+	'General_ExceptionUnableToStartSession' => 'Oturum başlatılamadı.',
 	'General_WarningFileIntegritySkipped' => 'Geliştirme Ortamı saptandı. Dosya bütünlük kontrolü gerçekleştirilmedi.',
 	'General_WarningFileIntegrityNoManifest' => 'manifest.inc.php dosyası bulunamadığı için dosya bütünlük kontrolü gerçekleştirilemedi.',
 	'General_WarningFileIntegrityNoMd5file' => 'md5_file() fonksiyonu bulunamadığı için dosya bütünlük kontrolü tamamlanamadı.',
@@ -187,6 +247,18 @@ $translations = array(
 	'General_Language' => 'Dil',
 	'General_PleaseUpdatePiwik' => 'Lütfen Piwik\'inizi güncelleyin',
 	'General_RequestTimedOut' => 'Veri isteği talebi %s süresi doldu. Lütfen tekrar deneyiniz.',
+	'General_Recommended' => '(önerilir)',
+	'General_Goal' => 'Hedef',
+	'General_Outlink' => 'Dış link',
+	'General_Help' => 'Yardım',
+	'General_DailySum' => 'günlük toplam',
+	'General_AfterEntry' => 'buraya girdikten sonra',
+	'General_Metadata' => 'Meta verisi',
+	'General_OneVisit' => '1 ziyaret',
+	'General_NVisits' => '%s ziyaret',
+	'General_OneDay' => '1 gün',
+	'General_NDays' => '%s gün',
+	'General_MainMetrics' => 'Ana ölçümler',
 	'Actions_PluginDescription' => 'Sayfa gösterimleri, dışarı linkler ve indirilenler hakkında raporlar. Dışarı linkler ve indirilenler otomatik.',
 	'Actions_Actions' => 'Eylemler',
 	'Actions_SubmenuPages' => 'Sayfalar',
@@ -199,14 +271,23 @@ $translations = array(
 	'Actions_ColumnUniqueClicks' => 'Tekil tıklamalar',
 	'Actions_ColumnDownloads' => 'İndirilenler',
 	'Actions_ColumnUniqueDownloads' => 'Tekil indirilenler',
+	'Actions_ColumnOutlinks' => 'Dış linkler',
+	'Actions_ColumnUniqueOutlinks' => 'Tekil dış linkler',
 	'Actions_ColumnPageName' => 'Sayfa isimleri',
 	'Actions_ColumnPageURL' => 'Sayfa URL\'leri',
 	'Actions_ColumnClickedURL' => 'Tıklanan URL\'ler',
 	'Actions_ColumnDownloadURL' => 'İndirilen URL\'ler',
+	'Actions_ColumnExitPageURL' => 'Çıkış URLsi',
+	'Actions_ColumnExitPageTitle' => 'Çıkış URL\'si ismi',
 	'AnonymizeIP_PluginDescription' => 'Yerel gizlilik kurallarına uymak için ziyaretçi IP adreslerini gizleyin.',
+	'API_PluginDescription' => 'Piwik içerisindeki tüm veriler basit APIlerle kullanılabilmektedir. Bu eklenti Web Istatistiklerinize xml, json, php, csv vb. yollarla erişebilmenizi sağlayan bir erişim noktasıdır.',
 	'API_QuickDocumentationTitle' => 'API hızlı belgeler',
+	'API_GenerateVisits' => 'Eğer bugün için bir veri yoksa öncelikle %s eklentisiyle biraz veri oluşturabilirsiniz. %s eklentisini aktifleştirin, sonrasında Piwik Yönetim alanından \'Ziyaretçi Oluşturucu\' menüsüne tıklayınız.',
+	'API_MoreInformation' => 'Piwik APIsi hakkında daha fazla bilgi için lütfen %s Piwik API Kullanımı %s ve %s Piwik API Referansına %s bakınız.',
 	'API_UserAuthentication' => 'Kullanıcı kimlik doğrulaması',
-	'API_LoadedAPIs' => 'API\'nin \'%s\' başarılı şekilde yüklendi',
+	'API_UsingTokenAuth' => 'Bir script, cron vb içerisinden %s verisi çağırmak isterseniz, %s kimlik doğrulama gerektiren API bağlantılarına %s parametresini eklemelisiniz.',
+	'API_KeepTokenSecret' => 'token_auth kullanıcı adı ve şifreniz kadar gizlidir, %s kimseyle paylaşmayınız%s!',
+	'API_LoadedAPIs' => '%s API başarılı şekilde yüklendi',
 	'CoreAdminHome_PluginDescription' => 'Piwik yönetici arenasi.',
 	'CoreAdminHome_MenuGeneralSettings' => 'Genel Ayarlar',
 	'CoreAdminHome_Administration' => 'Yönetici',
@@ -215,10 +296,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => 'Bu rapor için veri yok.',
 	'CoreHome_CategoryNoData' => 'Bu kategoride veri yok. "Eklenmiş tüm populasyon" deneyiniz.',
 	'CoreHome_ShowJSCode' => 'Eklenecek JavaScript kodu göster',
-	'CoreHome_IncludeAllPopulation_js' => 'Tüm popülasyonu içerir',
-	'CoreHome_ExcludeLowPopulation_js' => 'Hariç tutulan düşük populasyon',
 	'CoreHome_PageOf_js' => '%1$s nin %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => 'Gün',
 	'CoreHome_PeriodWeek' => 'Hafta',
 	'CoreHome_PeriodMonth' => 'Ay',
@@ -316,7 +394,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arşiv tamamlanmadı: bazı dosyalar kayıp (ör. %s).',
 	'Dashboard_PluginDescription' => 'Web istatistik panonuz. Panonuzu özelleştirebilirsiniz: yeni widget ekleyebilir, bileşen ayarlarınızı değiştirebilirsiniz. Her kullanıcı kendi panosuna ulaşır.',
 	'Dashboard_Dashboard' => 'Pano',
-	'Dashboard_AddWidget' => 'Bileşen ekle...',
 	'Dashboard_DeleteWidgetConfirm' => 'Bu Bileşenı panodan silmek istediğinize emin misiniz?',
 	'Dashboard_SelectWidget' => 'Panoya eklemek için bileşen seçiniz.',
 	'Dashboard_AddPreviewedWidget_js' => 'Görüntülenen Bileşenı panoya ekleyin.',
@@ -471,9 +548,7 @@ $translations = array(
 	'SecurityInfo_Result' => 'Sonuç',
 	'SEO_SeoRankings' => 'SEO Sıralamaları',
 	'SEO_AlexaRank' => 'Alexa Sırası',
-	'SEO_YahooIndexedPages' => 'Yahoo İndekslenen Sayfalar',
 	'SEO_DomainAge' => 'Alan Ad Yaşı',
-	'SEO_YahooBacklinks' => 'Yahoo Dönünen Linkler',
 	'SEO_Rank' => 'Sıralama',
 	'SEO_Backlinks' => 'Dönünen Linkler',
 	'SEO_Pages' => 'Sayfalar',
@@ -684,8 +759,8 @@ $translations = array(
 	'UserCountry_country_py' => 'Paraguay',
 	'UserCountry_country_qa' => 'Katar',
 	'UserCountry_country_ro' => 'Romanya',
-	'UserCountry_country_ru' => 'Rusya',
 	'UserCountry_country_rs' => 'Sırbistan',
+	'UserCountry_country_ru' => 'Rusya',
 	'UserCountry_country_sa' => 'Suudi Arabistan',
 	'UserCountry_country_sd' => 'Sudan',
 	'UserCountry_country_se' => 'İsveç',
