@@ -247,8 +247,6 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => '此报表沒有资料。',
 	'CoreHome_CategoryNoData' => '类别无数据！ 尝试使用 "包含所有个体"！',
 	'CoreHome_ShowJSCode' => '显示 Javascript 统计代码',
-	'CoreHome_IncludeAllPopulation_js' => '包含所有个体',
-	'CoreHome_ExcludeLowPopulation_js' => '排除非主要个体',
 	'CoreHome_PageOf_js' => '%s of %s',
 	'CoreHome_PeriodDay' => '日统计',
 	'CoreHome_PeriodWeek' => '周统计',
@@ -361,7 +359,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => '文件是不完整的：遗失某些文件（例如 %s）。',
 	'Dashboard_PluginDescription' => '您的网站分析控制台。您可以自动您的控制台：新增新的模組、变更您的模組排序。每位使用者可以存取他们自定义的控制台。',
 	'Dashboard_Dashboard' => '控制台',
-	'Dashboard_AddWidget' => '增加一个小工具...',
 	'Dashboard_DeleteWidgetConfirm' => '您确定要从控制台中删除此小工具吗？',
 	'Dashboard_SelectWidget' => '请选取小工具',
 	'Dashboard_Close_js' => '关闭',
@@ -584,7 +581,6 @@ $translations = array(
 	'Mobile_AccessUrlLabel' => 'Piwik 存取网址',
 	'Mobile_EnableGraphsLabel' => '显示图表',
 	'Mobile_MultiChartLabel' => '显示 sparklines',
-	'Mobile_MultiChartInfo' => '紧邻着每个网站的欢迎页面',
 	'Mobile_NetworkNotReachable' => '网络无法访问',
 	'Mobile_SaveSuccessError' => '请确认设置',
 	'Mobile_YouAreOffline' => '抱歉，您目前离线状态',
@@ -601,7 +597,6 @@ $translations = array(
 	'Referers_DirectEntry' => '直接链接',
 	'Referers_Websites' => '网站',
 	'Referers_Campaigns' => '广告活动',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (从 %2$s)',
 	'Referers_Evolution' => '此统计周期的发展趋势',
 	'Referers_Type' => '推介网站类型',
 	'Referers_ColumnRefererType' => '推荐网站类型',
@@ -636,9 +631,7 @@ $translations = array(
 	'SecurityInfo_Result' => '结果',
 	'SEO_SeoRankings' => 'SEO 评比',
 	'SEO_AlexaRank' => 'Alexa 排名',
-	'SEO_YahooIndexedPages' => 'Yahoo 索引页面',
 	'SEO_DomainAge' => '网域名称年龄',
-	'SEO_YahooBacklinks' => 'Yahoo 反向链接',
 	'SEO_Rank' => '评比',
 	'SEO_Backlinks' => '反向链接',
 	'SEO_Pages' => '页面',
@@ -908,8 +901,8 @@ $translations = array(
 	'UserCountry_country_qa' => '卡达',
 	'UserCountry_country_re' => '法属留尼旺岛',
 	'UserCountry_country_ro' => '罗马尼亚',
-	'UserCountry_country_ru' => '俄罗斯联邦',
 	'UserCountry_country_rs' => '俄罗斯',
+	'UserCountry_country_ru' => '俄罗斯联邦',
 	'UserCountry_country_rw' => '卢安达',
 	'UserCountry_country_sa' => '沙特阿拉伯',
 	'UserCountry_country_sb' => '索罗门群岛',
@@ -1098,7 +1091,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => '访客概述',
 	'VisitsSummary_NbVisits' => '%s 访客数',
 	'VisitsSummary_NbUniqueVisitors' => '%s 绝对唯一访客数',
-	'VisitsSummary_NbActions' => '%s 个活动数 (页面浏览)',
 	'VisitsSummary_NbActionsDescription' => '%s 个活动（检测网页、下载和离开链接）',
 	'VisitsSummary_AverageVisitDuration' => '%s 平均访问时间',
 	'VisitsSummary_MaxNbActions' => '%s 在一次会话中最大活动数',
