@@ -243,10 +243,7 @@ $translations = array(
 	'CoreHome_ThereIsNoDataForThisReport' => '此報告項目無資料！',
 	'CoreHome_CategoryNoData' => '無資料在此類別！ 嘗試使用 "包含所有個體"！',
 	'CoreHome_ShowJSCode' => '顯示 JavaScript 追蹤碼以供插入',
-	'CoreHome_IncludeAllPopulation_js' => '包含所有個體',
-	'CoreHome_ExcludeLowPopulation_js' => '排除非主要個體',
 	'CoreHome_PageOf_js' => '%1$s 之於 %2$s',
-	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 	'CoreHome_PeriodDay' => '日統計',
 	'CoreHome_PeriodWeek' => '週統計',
 	'CoreHome_PeriodMonth' => '月統計',
@@ -364,7 +361,6 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncomplete' => '檔案是不完整的：遺失某些檔案（例如 %s）。',
 	'Dashboard_PluginDescription' => '你的網站分析控制台。你可以自動你的控制台：新增新的模組、變更你的模組排序。每位使用者可以存取他們自訂的控制台。',
 	'Dashboard_Dashboard' => '展示板',
-	'Dashboard_AddWidget' => '新增一個組件...',
 	'Dashboard_DeleteWidgetConfirm' => '您確定要從展示板中刪除此組件嗎？',
 	'Dashboard_SelectWidget' => '請選取欲增加至展示板的組件',
 	'Dashboard_AddPreviewedWidget_js' => '增加已預覽的組件至展示板',
@@ -590,7 +586,6 @@ $translations = array(
 	'Mobile_AccessUrlLabel' => 'Piwik 存取網址',
 	'Mobile_EnableGraphsLabel' => '顯示圖表',
 	'Mobile_MultiChartLabel' => '顯示 sparklines',
-	'Mobile_MultiChartInfo' => '緊鄰著每個網站的歡迎畫面',
 	'Mobile_NetworkNotReachable' => '網路無法訪問',
 	'Mobile_SaveSuccessError' => '請確認設定',
 	'Mobile_YouAreOffline' => '抱歉，您目前為離線狀態',
@@ -607,7 +602,6 @@ $translations = array(
 	'Referers_DirectEntry' => '直接流量',
 	'Referers_Websites' => '網站',
 	'Referers_Campaigns' => '廣告活動',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1$s (從 %2$s)',
 	'Referers_Evolution' => '此統計期的發展趨勢',
 	'Referers_Type' => '推薦連結網站類型',
 	'Referers_ColumnRefererType' => '推薦連結網站類型',
@@ -642,9 +636,7 @@ $translations = array(
 	'SecurityInfo_Result' => '結果',
 	'SEO_SeoRankings' => 'SEO 評比',
 	'SEO_AlexaRank' => 'Alexa 排名',
-	'SEO_YahooIndexedPages' => 'Yahoo 索引頁面',
 	'SEO_DomainAge' => '網域名稱年齡',
-	'SEO_YahooBacklinks' => 'Yahoo 反向連結',
 	'SEO_Rank' => '評比',
 	'SEO_Backlinks' => '反向連結',
 	'SEO_Pages' => '頁面',
@@ -914,8 +906,8 @@ $translations = array(
 	'UserCountry_country_qa' => '卡達',
 	'UserCountry_country_re' => '法屬留尼旺島',
 	'UserCountry_country_ro' => '羅馬尼亞',
-	'UserCountry_country_ru' => '俄羅斯',
 	'UserCountry_country_rs' => '塞爾維亞',
+	'UserCountry_country_ru' => '俄羅斯',
 	'UserCountry_country_rw' => '盧安達',
 	'UserCountry_country_sa' => '沙烏地阿拉伯',
 	'UserCountry_country_sb' => '索羅門群島',
@@ -1104,7 +1096,6 @@ $translations = array(
 	'VisitsSummary_VisitsSummary' => '訪客總覽',
 	'VisitsSummary_NbVisits' => '%s 個造訪次數',
 	'VisitsSummary_NbUniqueVisitors' => '%s 個絕對不重複訪客',
-	'VisitsSummary_NbActions' => '%s 個活動數 (頁面瀏覽)',
 	'VisitsSummary_NbActionsDescription' => '%s 個活動（檢視網頁、下載和離開連結）',
 	'VisitsSummary_AverageVisitDuration' => '%s 平均訪問時間',
 	'VisitsSummary_MaxNbActions' => '%s 由單一次造訪所產生的最大活動數',
