@@ -11,7 +11,7 @@
  *  - CURL or STREAM extensions (to issue the http request to Piwik)
  *  
  * @license released under BSD License http://www.opensource.org/licenses/bsd-license.php
- * @version $Id: PiwikTracker.php 5203 2011-09-22 09:22:02Z matt $
+ * @version $Id: PiwikTracker.php 6450 2012-06-03 00:14:03Z matt $
  * @link http://piwik.org/docs/tracking-api/
  *
  * @category Piwik
@@ -85,10 +85,14 @@ class PiwikTracker
     	$this->ip = @$_SERVER['REMOTE_ADDR'];
     	$this->acceptLanguage = @$_SERVER['HTTP_ACCEPT_LANGUAGE'];
     	$this->userAgent = @$_SERVER['HTTP_USER_AGENT'];
-    	if(!empty($apiUrl)) {
+    	if(!empty($apiUrl)) 
+    	{
     		self::$URL = $apiUrl;
     	}
     	$this->visitorId = substr(md5(uniqid(rand(), true)), 0, self::LENGTH_VISITOR_ID);
+    	
+		// Allow debug while blocking the request
+    	$this->requestTimeout = 600;
     }
     
     /**
@@ -257,7 +261,7 @@ class PiwikTracker
      * Records a Goal conversion
      * 
      * @param int $idGoal Id Goal to record a conversion
-     * @param int $revenue Revenue for this conversion
+     * @param float $revenue Revenue for this conversion
      * @return string Response
      */
     public function doTrackGoal($idGoal, $revenue = false)
@@ -483,7 +487,7 @@ class PiwikTracker
     /**
      * @see doTrackGoal()
      * @param int $idGoal Id Goal to record a conversion
-     * @param int $revenue Revenue for this conversion
+     * @param float $revenue Revenue for this conversion
      * @return string URL to piwik.php with all parameters set to track the goal conversion
      */
     public function getUrlTrackGoal($idGoal, $revenue = false)
@@ -505,9 +509,7 @@ class PiwikTracker
     public function getUrlTrackAction($actionUrl, $actionType)
     {
     	$url = $this->getRequest( $this->idSite );
-		$url .= '&'.$actionType.'=' . $actionUrl .
-				'&redirect=0';
-		
+		$url .= '&'.$actionType.'=' . $actionUrl;
     	return $url;
     }
 
@@ -517,8 +519,6 @@ class PiwikTracker
      * to track visits in the past. All times are in UTC.
      * 
      * Allowed only for Super User, must be used along with setTokenAuth()
-	 * Set tracking_requests_require_authentication = 0 in config.ini.php [Tracker] section
-	 * to change this security constraint.
      * @see setTokenAuth()
      * @param string Date with the format 'Y-m-d H:i:s', or a UNIX timestamp
      */
@@ -531,8 +531,6 @@ class PiwikTracker
      * Overrides IP address
      * 
      * Allowed only for Super User, must be used along with setTokenAuth()
-	 * Set tracking_requests_require_authentication = 0 in config.ini.php [Tracker] section
-	 * to change this security constraint.
      * @see setTokenAuth()
      * @param string IP string, eg. 130.54.2.1
      */
@@ -548,8 +546,6 @@ class PiwikTracker
      * This is typically used with the Javascript getVisitorId() function.
      * 
      * Allowed only for Super User, must be used along with setTokenAuth().
-	 * Set tracking_requests_require_authentication = 0 in config.ini.php [Tracker] section
-	 * to change this security constraint.
      * @see setTokenAuth()
      * @param string $visitorId 16 hexadecimal characters visitor ID, eg. "33c31e01394bdc63"
      */
@@ -619,8 +615,6 @@ class PiwikTracker
 	 * - force the date & time of the tracking requests rather than track for the current datetime
 	 * - force Piwik to track the requests to a specific VisitorId rather than use the standard visitor matching heuristic
 	 *
-	 * Set tracking_requests_require_authentication = 0 in config.ini.php [Tracker] section
-	 * to change this security constraint.
 	 * @param string token_auth 32 chars token_auth string
 	 */
 	public function setTokenAuth($token_auth)
@@ -713,12 +707,36 @@ class PiwikTracker
     	$this->cookieSupport = false;
     }
     
+    /**
+     * Returns the maximum number of seconds the tracker will spend waiting for a response
+     * from Piwik. Defaults to 600 seconds.
+     */
+    public function getRequestTimeout()
+    {
+    	return $this->requestTimeout;
+    }
+	
+	/**
+	 * Sets the maximum number of seconds that the tracker will spend waiting for a response
+	 * from Piwik.
+	 * 
+	 * @param int $timeout
+	 */
+    public function setRequestTimeout( $timeout )
+    {
+    	if (!is_int($timeout) || $timeout < 0)
+    	{
+    		throw new Exception("Invalid value supplied for request timeout: $timeout");
+    	}
+    	
+    	$this->requestTimeout = $timeout;
+    }
+    
     /**
      * @ignore
      */
     protected function sendRequest($url)
     {
-		$timeout = 600; // Allow debug while blocking the request
 		$response = '';
 
 		if(!$this->cookieSupport)
@@ -732,7 +750,7 @@ class PiwikTracker
 				CURLOPT_URL => $url,
 				CURLOPT_USERAGENT => $this->userAgent,
 				CURLOPT_HEADER => true,
-				CURLOPT_TIMEOUT => $timeout,
+				CURLOPT_TIMEOUT => $this->requestTimeout,
 				CURLOPT_RETURNTRANSFER => true,
 				CURLOPT_HTTPHEADER => array(
 					'Accept-Language: ' . $this->acceptLanguage,
@@ -755,7 +773,7 @@ class PiwikTracker
 					'user_agent' => $this->userAgent,
 					'header' => "Accept-Language: " . $this->acceptLanguage . "\r\n" .
 					            "Cookie: ".$this->requestCookie. "\r\n" ,
-					'timeout' => $timeout, // PHP 5.2.1
+					'timeout' => $this->requestTimeout, // PHP 5.2.1
 				)
 			);
 			$ctx = stream_context_create($stream_options);
@@ -776,6 +794,7 @@ class PiwikTracker
 			{
 				$cookie = $cookie[1];
 			}
+			// XDEBUG is a PHP Debugger 
 			if(strpos($cookie, 'XDEBUG') === false)
 			{
 				$this->requestCookie = $cookie;
@@ -817,12 +836,11 @@ class PiwikTracker
 			'&apiv=' . self::VERSION . 
 	        '&r=' . substr(strval(mt_rand()), 2, 6) .
     	
-    		// PHP DEBUGGING: Optional since debugger can be triggered remotely
+    		// XDEBUG_SESSIONS_START and KEY are related to the PHP Debugger, this can be ignored in other languages
     		(!empty($_GET['XDEBUG_SESSION_START']) ? '&XDEBUG_SESSION_START=' . @$_GET['XDEBUG_SESSION_START'] : '') . 
 	        (!empty($_GET['KEY']) ? '&KEY=' . @$_GET['KEY'] : '') .
     	 
     		// Only allowed for Super User, token_auth required,
-			// except when tracking_requests_require_authentication = 0 in config.ini.php [Tracker] section
 			(!empty($this->ip) ? '&cip=' . $this->ip : '') .
     		(!empty($this->forcedVisitorId) ? '&cid=' . $this->forcedVisitorId : '&_id=' . $this->visitorId) . 
 			(!empty($this->forcedDatetime) ? '&cdt=' . urlencode($this->forcedDatetime) : '') .
