@@ -1,11 +1,11 @@
 <?php
 /**
- * Copyright 2009, 2010  Matthieu Aubry
+ * Copyright 2009, 2010  Matthieu Aubry & Piwik team
  * All rights reserved.
  *
  * @link http://dev.piwik.org/trac/browser/trunk/libs/UserAgentParser
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
- * @version $Id: UserAgentParser.php 5273 2011-10-08 17:15:06Z vipsoft $
+ * @version $Id: UserAgentParser.php 6362 2012-05-29 05:17:56Z capedfuzz $
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -85,8 +85,12 @@ class UserAgentParser
 			'cheshire'						=> 'CS',
 
 			// Chrome, Chromium, and ChromePlus
+			'crmo'							=> 'CH',
 			'chrome'						=> 'CH',
 
+			// Chrome Frame
+			'chromeframe'					=> 'CF',
+
 			'cometbird'						=> 'CO',
 			'dillo'							=> 'DI',
 			'elinks'						=> 'EL',
@@ -168,13 +172,13 @@ class UserAgentParser
 			'ie'	 => array('IE'),
 			'gecko'  => array('NS', 'PX', 'FF', 'FB', 'CA', 'GA', 'KM', 'MO', 'SM', 'CO', 'FE', 'KP', 'KZ'),
 			'khtml'  => array('KO'),
-			'webkit' => array('SF', 'CH', 'OW', 'AR', 'EP', 'FL', 'WO', 'AB', 'IR', 'CS', 'FD', 'HA', 'MI', 'GE', 'DF', 'BB', 'BP', 'TI'),
+			'webkit' => array('SF', 'CH', 'OW', 'AR', 'EP', 'FL', 'WO', 'AB', 'IR', 'CS', 'FD', 'HA', 'MI', 'GE', 'DF', 'BB', 'BP', 'TI', 'CF'),
 			'opera'  => array('OP'),
 		);
 
 	// WebKit version numbers to Apple Safari version numbers (if Version/X.Y.Z not present)
 	static protected $safariVersions = array(
-			'534.50'	=> array('5', '1'),
+			'534.48'	=> array('5', '1'),
 			'533.16'	=> array('5', '0'),
 			'533.4'		=> array('4', '1'),
 			'526.11.2'	=> array('4', '0'),
@@ -210,8 +214,12 @@ class UserAgentParser
 			'Maemo'					=> 'MAE',
 			'Linux'					=> 'LIN',
 
-			'WP7'					=> 'WP7',
+			// workaround for vendors who changed the WinPhone 7 user agent
+			'WP7'					=> 'WPH',
 
+			'CYGWIN_NT-6.2'			=> 'WI8',
+			'Windows NT 6.2'		=> 'WI8',
+			'Windows 8'				=> 'WI8',
 			'CYGWIN_NT-6.1'			=> 'WI7',
 			'Windows NT 6.1'		=> 'WI7',
 			'Windows 7'				=> 'WI7',
@@ -242,9 +250,14 @@ class UserAgentParser
 			'Win95'					=> 'W95',		
 			'Windows 95'			=> 'W95',
 
-			'Windows Phone OS 7.0'	=> 'WP7',
-			'Windows Mobile 6.5'	=> 'W65',
-			'Windows Mobile 6.1'	=> 'W61',
+			// Windows Phone OS 7 and above
+			'Windows Phone OS'		=> 'WPH',
+
+			// Windows Mobile 6.x and some later versions of Windows Mobile 5
+			'IEMobile'			=> 'WMO', // fallback
+			'Windows Mobile'		=> 'WMO',
+
+			// Windows CE, Pocket PC, and Windows Mobile 5 are indistinguishable without vendor/device specific detection
 			'Windows CE'			=> 'WCE',
 
 			'iPod'					=> 'IPD',
@@ -300,6 +313,23 @@ class UserAgentParser
 			'Amiga'					=> 'AMI',
 			'AmigaOS'				=> 'AMI',
 		);
+	
+	// os family
+	// NOTE: The keys in this array are used by plugins/UserSettings/functions.php . Any  changes
+	// made here should also be made in that file.
+	static protected $osType = array(
+			'Windows' => array('WI8', 'WI7', 'WVI', 'WS3', 'WXP', 'W2K', 'WNT', 'WME', 'W98', 'W95'),
+			'Linux' => array('LIN'),
+			'Mac' => array('MAC'),
+			'iOS' => array('IPD', 'IPA', 'IPH'),
+			'Android' => array('AND'),
+			'Windows Mobile' => array('WPH', 'WMO', 'WCE'),
+			'Gaming Console' => array('WII', 'PS3'),
+			'Mobile Gaming Console' => array('PSP', 'NDS', 'DSI'),
+			'Unix' => array('SOS', 'AIX', 'HP-UX', 'BSD', 'NBS', 'OBS', 'DFB', 'SYL', 'IRI', 'T64'),
+			'Other Mobile' => array('MAE', 'WOS', 'POS', 'BLB', 'QNX', 'SYM', 'SBA'),
+			'Other' => array('VMS', 'OS2', 'BEOS', 'AMI')
+		);
 
 	static protected $browserIdToName;
 	static protected $browserIdToShortName;
@@ -396,7 +426,11 @@ class UserAgentParser
 			$info['id'] = self::$browsers[strtolower($results[1][0])];
 
 			// sometimes there's a better match at the end
-			if(($info['id'] == 'IE' || $info['id'] == 'LX') && (count($results[0]) > 1)) {
+			if(strpos($userAgent, 'chromeframe') !== false) {
+				$count = count($results[0]) - 1;
+				$info['id'] = 'CF';
+			}
+			else if(($info['id'] == 'IE' || $info['id'] == 'LX') && (count($results[0]) > 1)) {
 				$count = count($results[0]) - 1;
 				$info['id'] = self::$browsers[strtolower($results[1][$count])];
 			}
@@ -509,6 +543,7 @@ class UserAgentParser
 		self::$browserIdToName['BB'] = 'BlackBerry';
 		self::$browserIdToName['BP'] = 'PlayBook';
 		self::$browserIdToName['BX'] = 'BrowseX';
+		self::$browserIdToName['CF'] = 'Chrome Frame';
 		self::$browserIdToName['CO'] = 'CometBird';
 		self::$browserIdToName['EL'] = 'ELinks';
 		self::$browserIdToName['FF'] = 'Firefox';
@@ -539,6 +574,13 @@ class UserAgentParser
 			'BEO' => 'BeOS',
 			'T64' => 'Tru64',
 			'NDS' => 'Nintendo DS',
+		
+			// These are for BC purposes only
+			'W75' => 'WinPhone 7.5', 
+			'WP7' => 'WinPhone 7', 
+			'W65' => 'WinMo 6.5', 
+			'W61' => 'WinMo 6.1', 
+	
 		));
 		self::$operatingSystemsIdToShortName = array_merge(self::$operatingSystemsIdToName, array(
 			'PS3' => 'PS3',
@@ -546,6 +588,7 @@ class UserAgentParser
 			'WII' => 'Wii',
 			'NDS' => 'DS',
 			'DSI' => 'DSi',
+			'WI8' => 'Win 8',
 			'WI7' => 'Win 7',
 			'WVI' => 'Win Vista',
 			'WS3' => 'Win S2003',
@@ -555,9 +598,8 @@ class UserAgentParser
 			'WNT' => 'Win NT',
 			'WME' => 'Win Me',
 			'W95' => 'Win 95',
-			'WP7' => 'WinPhone 7',
-			'W65' => 'WinMo 6.5',
-			'W61' => 'WinMo 6.1',
+			'WPH' => 'WinPhone',
+			'WMO' => 'WinMo',
 			'WCE' => 'Win CE',
 			'WOS' => 'webOS',
 			'UNK' => 'Unknown',
@@ -614,4 +656,22 @@ class UserAgentParser
 		}
 		return false;
 	}
+	
+	static public function getOperatingSystemIdFromName($osName)
+	{
+		return isset(self::$operatingSystems[$osName]) ? self::$operatingSystems[$osName] : false;
+	}
+	
+	static public function getOperatingSystemFamilyFromId($osId)
+	{
+		self::init();
+		foreach (self::$osType as $familyName => $aSystems)
+		{
+			if (in_array($osId, $aSystems))
+			{
+				return $familyName;
+			}
+		}
+		return 'unknown';
+	}
 }
