@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 5235 2011-09-27 07:20:45Z matt $
+ * @version $Id: API.php 6363 2012-05-29 05:50:06Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Actions
@@ -28,6 +28,9 @@ class Piwik_Actions_API
 {
 	static private $instance = null;
 	
+	/**
+	 * @return Piwik_Actions_API
+	 */
 	static public function getInstance()
 	{
 		if (self::$instance == null)
@@ -36,17 +39,79 @@ class Piwik_Actions_API
 		}
 		return self::$instance;
 	}
-	
+
 
 	/**
 	 * Backward compatibility. Fallsback to getPageTitles() instead.
 	 * @deprecated Deprecated since Piwik 0.5
 	 * @ignore
+	 *
+	 * @param int $idSite
+	 * @param string $period
+	 * @param $date
+	 * @param bool $segment
+	 * @param bool $expanded
+	 * @param bool|int $idSubtable
+	 * @return Piwik_DataTable
 	 */
 	public function getActions( $idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false )
 	{
 	    return $this->getPageTitles( $idSite, $period, $date, $segment, $expanded, $idSubtable );
 	}
+
+	/**
+	 * Returns the list of metrics (pages, downloads, outlinks)
+	 *
+	 * @param int $idSite
+	 * @param string $period
+	 * @param string $date
+	 * @param bool|string $segment
+	 * @param bool|array $columns
+	 * @return Piwik_DataTable
+	 */
+	public function get( $idSite, $period, $date, $segment = false, $columns = false)
+	{
+		Piwik::checkUserHasViewAccess( $idSite );
+		$archive = Piwik_Archive::build( $idSite, $period, $date, $segment );
+		
+		$metrics = array(
+			'Actions_nb_pageviews' => 'nb_pageviews',
+			'Actions_nb_uniq_pageviews' => 'nb_uniq_pageviews',
+			'Actions_nb_downloads' => 'nb_downloads',
+			'Actions_nb_uniq_downloads' => 'nb_uniq_downloads',
+			'Actions_nb_outlinks' => 'nb_outlinks',
+			'Actions_nb_uniq_outlinks' => 'nb_uniq_outlinks'
+		);
+		
+		// get requested columns
+		$columns = Piwik::getArrayFromApiParameter($columns);
+		if(!empty($columns))
+		{
+			// get the columns that are available and requested
+			$columns = array_intersect($columns, array_values($metrics));
+			$columns = array_values($columns); // make sure indexes are right
+			$nameReplace = array();
+			foreach ($columns as $i => $column)
+			{
+				$fullColumn = array_search($column, $metrics);
+				$columns[$i] = $fullColumn;
+				$nameReplace[$fullColumn] = $column;
+			}
+		}
+		else
+		{
+			// get all columns
+			$columns = array_keys($metrics);
+			$nameReplace = &$metrics;
+		}
+		
+		$table = $archive->getDataTableFromNumeric($columns);
+		
+		// replace labels (remove Actions_)
+		$table->filter('ReplaceColumnNames', array($nameReplace));
+		
+		return $table;
+	}
 	
 	public function getPageUrls( $idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false )
 	{
@@ -56,6 +121,28 @@ class Piwik_Actions_API
 		return $dataTable;
 	}
 	
+	/**
+	 * Returns a DataTable with analytics information for every unique entry page URL, for
+	 * the specified site, period & segment.
+	 */
+	public function getEntryPageUrls( $idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false )
+	{
+		$dataTable = $this->getPageUrls($idSite, $period, $date, $segment, $expanded, $idSubtable);
+		$this->filterNonEntryActions($dataTable);
+		return $dataTable;
+	}
+	
+	/**
+	 * Returns a DataTable with analytics information for every unique exit page URL, for
+	 * the specified site, period & segment.
+	 */
+	public function getExitPageUrls( $idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false )
+	{
+		$dataTable = $this->getPageUrls($idSite, $period, $date, $segment, $expanded, $idSubtable);
+		$this->filterNonExitActions($dataTable);
+		return $dataTable;
+	}
+	
 	public function getPageUrl( $pageUrl, $idSite, $period, $date, $segment = false)
 	{
 		$callBackParameters = array('Actions_actions_url', $idSite, $period, $date, $segment, $expanded = false, $idSubtable = false );
@@ -73,6 +160,30 @@ class Piwik_Actions_API
 		return $dataTable;
 	}
 	
+	/**
+	 * Returns a Piwik_DataTable with analytics information for every unique entry page title
+	 * for the given site, time period & segment.
+	 */
+	public function getEntryPageTitles( $idSite, $period, $date, $segment = false, $expanded = false,
+										$idSubtable = false )
+	{
+		$dataTable = $this->getPageTitles($idSite, $period, $date, $segment, $expanded, $idSubtable);
+		$this->filterNonEntryActions($dataTable);
+		return $dataTable;
+	}
+	
+	/**
+	 * Returns a Piwik_DataTable with analytics information for every unique exit page title
+	 * for the given site, time period & segment.
+	 */
+	public function getExitPageTitles( $idSite, $period, $date, $segment = false, $expanded = false,
+									   $idSubtable = false )
+	{
+		$dataTable = $this->getPageTitles($idSite, $period, $date, $segment, $expanded, $idSubtable);
+		$this->filterNonExitActions($dataTable);
+		return $dataTable;
+	}
+	
 	public function getPageTitle( $pageName, $idSite, $period, $date, $segment = false)
 	{
 		$callBackParameters = array('Actions_actions', $idSite, $period, $date, $segment, $expanded = false, $idSubtable = false );
@@ -166,6 +277,9 @@ class Piwik_Actions_API
 		return $this->doFilterPageDatatableSearch($callBackParameters, $table, $searchTree);
 	}
 
+	/**
+	 * This looks very similar to LabelFilter.php should it be refactored somehow? FIXME
+	 */
 	protected function doFilterPageDatatableSearch($callBackParameters, $table, $searchTree)
 	{
 		// filter a data table array
@@ -243,5 +357,25 @@ class Piwik_Actions_API
 		
 		$dataTable->queueFilter('ReplaceSummaryRowLabel');
 	}
+	
+	/**
+	 * Removes DataTable rows referencing actions that were never the first action of a visit.
+	 * 
+	 * @param Piwik_DataTable $dataTable
+	 */
+	private function filterNonEntryActions( $dataTable )
+	{
+		$dataTable->filter('ColumnCallbackDeleteRow', array('entry_nb_visits', 'strlen'));
+	}
+	
+	/**
+	 * Removes DataTable rows referencing actions that were never the last action of a visit.
+	 * 
+	 * @param Piwik_DataTable $dataTable
+	 */
+	private function filterNonExitActions( $dataTable )
+	{
+		$dataTable->filter('ColumnCallbackDeleteRow', array('exit_nb_visits', 'strlen'));
+	}
 }
 
