@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Actions.php 5152 2011-09-11 05:44:57Z matt $
+ * @version $Id: Actions.php 6363 2012-05-29 05:50:06Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Actions
@@ -24,7 +24,6 @@ class Piwik_Actions extends Piwik_Plugin
 	static protected $defaultActionName = null;
 	static protected $defaultActionNameWhenNotDefined = null;
 	static protected $defaultActionUrlWhenNotDefined = null;
-	static protected $limitLevelSubCategory = 10; // must be less than Piwik_DataTable::MAXIMUM_DEPTH_LEVEL_ALLOWED
 	protected $maximumRowsInDataTableLevelZero;
 	protected $maximumRowsInSubDataTable;
 	protected $columnToSortByBeforeTruncation;
@@ -40,7 +39,7 @@ class Piwik_Actions extends Piwik_Plugin
 		return $info;
 	}
 	
-	function getListHooksRegistered()
+	public function getListHooksRegistered()
 	{
 		$hooks = array(
 			'ArchiveProcessing_Day.compute' => 'archiveDay',
@@ -52,11 +51,14 @@ class Piwik_Actions extends Piwik_Plugin
 		);
 		return $hooks;
 	}
-	    
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getSegmentsMetadata($notification)
 	{
 		$segments =& $notification->getNotificationObject();
-		$sqlFilter = array($this, 'getIdActionFromString');
+		$sqlFilter = array($this, 'getIdActionFromSegment');
         
 		// entry and exit pages of visit
 		$segments[] = array(
@@ -112,55 +114,121 @@ class Piwik_Actions extends Piwik_Plugin
         );
 	}
 
-	function getIdActionFromString($string, $sqlField)
+	/**
+	 * Convert segment expression to an action ID or an SQL expression.
+	 *
+	 * This method is used as a sqlFilter-callback for the segments of this plugin.
+	 * Usually, these callbacks only return a value that should be compared to the
+	 * column in the database. In this case, that doesn't work since multiple IDs
+	 * can match an expression (e.g. "pageUrl=@foo").
+	 * @param string $string
+	 * @param string $sqlField
+	 * @param string $matchType
+	 * @throws Exception
+	 * @return array|int|string
+	 */
+	function getIdActionFromSegment($string, $sqlField, $matchType='==')
 	{
 		// Field is visit_*_idaction_url or visit_*_idaction_name
 		$actionType = strpos($sqlField, '_name') === false
 							? Piwik_Tracker_Action::TYPE_ACTION_URL
 							: Piwik_Tracker_Action::TYPE_ACTION_NAME;
-							 
-		$sql = Piwik_Tracker_Action::getSqlSelectActionId();
-		$bind = array($string, $string, $actionType);
 		
-		$idAction = Zend_Registry::get('db')->fetchOne($sql, $bind);
-		
-		// if the action is not found, we hack -1 to ensure it tries to match against an integer
-		// otherwise binding idaction_name to "false" returns some rows for some reasons (in case &segment=pageTitle==Větrnásssssss)
-		if(empty($idAction))
-		{
-			$idAction = -1;
-		}
-		return $idAction;
+        // exact matches work by returning the id directly
+        if ($matchType == Piwik_SegmentExpression::MATCH_EQUAL 
+			|| $matchType == Piwik_SegmentExpression::MATCH_NOT_EQUAL)
+        {
+            $sql = Piwik_Tracker_Action::getSqlSelectActionId();
+            $bind = array($string, $string, $actionType);
+            $idAction = Piwik_FetchOne($sql, $bind);
+            // if the action is not found, we hack -100 to ensure it tries to match against an integer
+            // otherwise binding idaction_name to "false" returns some rows for some reasons (in case &segment=pageTitle==Větrnásssssss)
+            if(empty($idAction))
+            {
+                $idAction = -100;
+            }
+            return $idAction;
+        }
+        
+        // now, we handle the cases =@ (contains) and !@ (does not contain)
+                
+        // build the expression based on the match type
+        $sql = 'SELECT idaction FROM '.Piwik_Common::prefixTable('log_action').' WHERE ';
+        switch ($matchType)
+        {
+            case '=@':
+                // use concat to make sure, no %s occurs because some plugins use %s in their sql
+                $sql .= '( name LIKE CONCAT("%", ?, "%") AND type = '.$actionType.' )';
+                break;
+            case '!@':
+                $sql .= '( name NOT LIKE CONCAT("%", ?, "%") AND type = '.$actionType.' )';
+                break;
+            default:
+                throw new Exception("This match type is not available for action-segments.");
+                break;
+        }
+        
+        return array(
+            // mark that the returned value is an sql-expression instead of a literal value
+            'SQL' => $sql,
+        	'bind' => $string
+        );
 	}
-	
+
+	/**
+	 * Returns metadata for available reports
+	 *
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getReportMetadata($notification)
 	{
 		$reports = &$notification->getNotificationObject();
         
-		$metrics = array(
-            'nb_visits' => Piwik_Translate('General_ColumnUniquePageviews'),
-            'nb_hits' => Piwik_Translate('General_ColumnPageviews'),
-            'entry_nb_visits' => Piwik_Translate('General_ColumnEntrances'),
-            'avg_time_on_page' => Piwik_Translate('General_ColumnAverageTimeOnPage'),
-            'bounce_rate' => Piwik_Translate('General_ColumnBounceRate'),
-            'exit_nb_visits' => Piwik_Translate('General_ColumnExits'),
-            'exit_rate' => Piwik_Translate('General_ColumnExitRate'),
-			// 'entry_bounce_count' => Piwik_Translate('General_ColumnBounces'),
-    	);
-    	
-		$documentation = array(
-			'nb_hits' => 'General_ColumnPageviewsDocumentation',
-			'nb_visits' => 'General_ColumnUniquePageviewsDocumentation',
-    		'bounce_rate' => 'General_ColumnPageBounceRateDocumentation',
-    		'avg_time_on_page' => 'General_ColumnAverageTimeOnPageDocumentation',
-			'exit_rate' => 'General_ColumnExitRateDocumentation'
-		);
-		$documentation = array_map('Piwik_Translate', $documentation);
-
-		// Page views URLs and Page titles have the full set of metrics
 		$reports[] = array(
 			'category' => Piwik_Translate('Actions_Actions'),
-			'name' => Piwik_Translate('Actions_SubmenuPages'),
+			'name' => Piwik_Translate('Actions_Actions') . ' - ' . Piwik_Translate('General_MainMetrics'),
+			'module' => 'Actions',
+			'action' => 'get',
+			'metrics' => array(
+				'nb_pageviews' => Piwik_Translate('General_ColumnPageviews'),
+				'nb_uniq_pageviews' => Piwik_Translate('General_ColumnUniquePageviews'),
+				'nb_downloads' => Piwik_Translate('Actions_ColumnDownloads'),
+				'nb_uniq_downloads' => Piwik_Translate('Actions_ColumnUniqueDownloads'),
+				'nb_outlinks' => Piwik_Translate('Actions_ColumnOutlinks'),
+				'nb_uniq_outlinks' => Piwik_Translate('Actions_ColumnUniqueOutlinks')
+			),
+			'metricsDocumentation' => array(
+				'nb_pageviews' => Piwik_Translate('General_ColumnPageviewsDocumentation'),
+				'nb_uniq_pageviews' => Piwik_Translate('General_ColumnUniquePageviewsDocumentation'),
+				'nb_downloads' => Piwik_Translate('Actions_ColumnClicksDocumentation'),
+				'nb_uniq_downloads' => Piwik_Translate('Actions_ColumnUniqueClicksDocumentation'),
+				'nb_outlinks' => Piwik_Translate('Actions_ColumnClicksDocumentation'),
+				'nb_uniq_outlinks' => Piwik_Translate('Actions_ColumnUniqueClicksDocumentation')
+			),
+			'processedMetrics' => false,
+			'order' => 1
+		);
+		
+		$metrics = array(
+			'nb_hits' => Piwik_Translate('General_ColumnPageviews'),
+			'nb_visits' => Piwik_Translate('General_ColumnUniquePageviews'),
+			'bounce_rate' => Piwik_Translate('General_ColumnBounceRate'),
+			'avg_time_on_page' => Piwik_Translate('General_ColumnAverageTimeOnPage'),
+			'exit_rate' => Piwik_Translate('General_ColumnExitRate')
+		);
+		
+		$documentation = array(
+			'nb_hits' => Piwik_Translate('General_ColumnPageviewsDocumentation'),
+			'nb_visits' => Piwik_Translate('General_ColumnUniquePageviewsDocumentation'),
+			'bounce_rate' => Piwik_Translate('General_ColumnPageBounceRateDocumentation'),
+			'avg_time_on_page' => Piwik_Translate('General_ColumnAverageTimeOnPageDocumentation'),
+			'exit_rate' => Piwik_Translate('General_ColumnExitRateDocumentation')
+		);
+		
+		// pages report
+		$reports[] = array(
+			'category' => Piwik_Translate('Actions_Actions'),
+			'name' => Piwik_Translate('Actions_PageUrls'),
 			'module' => 'Actions',
 			'action' => 'getPageUrls',
     		'dimension' => Piwik_Translate('Actions_ColumnPageURL'),
@@ -169,9 +237,56 @@ class Piwik_Actions extends Piwik_Plugin
 			'documentation' => Piwik_Translate('Actions_PagesReportDocumentation', '<br />')
 					.'<br />'.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
 			'processedMetrics' => false,
-			'order' => 1,
+			'order' => 2
 		);
-
+		
+		// entry pages report
+		$reports[] = array(
+			'category' => Piwik_Translate('Actions_Actions'),
+			'name' => Piwik_Translate('Actions_SubmenuPagesEntry'),
+			'module' => 'Actions',
+			'action' => 'getEntryPageUrls',
+    		'dimension' => Piwik_Translate('Actions_ColumnPageURL'),
+			'metrics' => array(
+				'entry_nb_visits' => Piwik_Translate('General_ColumnEntrances'),
+				'entry_bounce_count' => Piwik_Translate('General_ColumnBounces'),
+				'bounce_rate' => Piwik_Translate('General_ColumnBounceRate'),
+			),
+			'metricsDocumentation' => array(
+				'entry_nb_visits' => Piwik_Translate('General_ColumnEntrancesDocumentation'),
+				'entry_bounce_count' => Piwik_Translate('General_ColumnBouncesDocumentation'),
+				'bounce_rate' => Piwik_Translate('General_ColumnBounceRateForPageDocumentation')
+			),
+			'documentation' => Piwik_Translate('Actions_EntryPagesReportDocumentation', '<br />')
+					.' '.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
+			'processedMetrics' => false,
+			'order' => 3
+		);
+		
+		// exit pages report
+		$reports[] = array(
+			'category' => Piwik_Translate('Actions_Actions'),
+			'name' => Piwik_Translate('Actions_SubmenuPagesExit'),
+			'module' => 'Actions',
+			'action' => 'getExitPageUrls',
+    		'dimension' => Piwik_Translate('Actions_ColumnPageURL'),
+			'metrics' => array(
+				'exit_nb_visits' => Piwik_Translate('General_ColumnExits'),
+				'nb_visits' => Piwik_Translate('General_ColumnUniquePageviews'),
+				'exit_rate' => Piwik_Translate('General_ColumnExitRate')
+			),
+			'metricsDocumentation' => array(
+				'exit_nb_visits' => Piwik_Translate('General_ColumnExitsDocumentation'),
+				'nb_visits' => Piwik_Translate('General_ColumnUniquePageviewsDocumentation'),
+				'exit_rate' => Piwik_Translate('General_ColumnExitRateDocumentation')
+			),
+			'documentation' => Piwik_Translate('Actions_ExitPagesReportDocumentation', '<br />')
+					.' '.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
+			'processedMetrics' => false,
+			'order' => 4
+		);
+		
+		// page titles report
 		$reports[] = array(
 			'category' => Piwik_Translate('Actions_Actions'),
 			'name' => Piwik_Translate('Actions_SubmenuPageTitles'),
@@ -182,55 +297,108 @@ class Piwik_Actions extends Piwik_Plugin
 			'metricsDocumentation' => $documentation,
 			'documentation' => Piwik_Translate('Actions_PageTitlesReportDocumentation', array('<br />', htmlentities('<title>'))),
 			'processedMetrics' => false,
-			'order' => 3,
+			'order' => 5,
+			
 		);
 		
-		// Outlinks and downloads only report basic metrics
-		$metrics = array(	'nb_hits' => Piwik_Translate('General_ColumnPageviews'),
-            				'nb_visits',
-    	);
-    	
-    	$documentation = array(
-			'nb_hits' => Piwik_Translate('Actions_ColumnClicksDocumentation'),
-			'nb_visits' => Piwik_Translate('Actions_ColumnUniqueClicksDocumentation')
+		// entry page titles report
+		$reports[] = array(
+			'category' => Piwik_Translate('Actions_Actions'),
+			'name' => Piwik_Translate('Actions_EntryPageTitles'),
+			'module' => 'Actions',
+			'action' => 'getEntryPageTitles',
+			'dimension' => Piwik_Translate('Actions_ColumnPageName'),
+			'metrics' => array(
+				'entry_nb_visits' => Piwik_Translate('General_ColumnEntrances'),
+				'entry_bounce_count' => Piwik_Translate('General_ColumnBounces'),
+				'bounce_rate' => Piwik_Translate('General_ColumnBounceRate'),
+			),
+			'metricsDocumentation' => array(
+				'entry_nb_visits' => Piwik_Translate('General_ColumnEntrancesDocumentation'),
+				'entry_bounce_count' => Piwik_Translate('General_ColumnBouncesDocumentation'),
+				'bounce_rate' => Piwik_Translate('General_ColumnBounceRateForPageDocumentation')
+			),
+			'documentation' => Piwik_Translate('Actions_ExitPageTitlesReportDocumentation', '<br />')
+					.' '.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
+			'processedMetrics' => false,
+			'order' => 6
+		);
+		
+		// exit page titles report
+		$reports[] = array(
+			'category' => Piwik_Translate('Actions_Actions'),
+			'name' => Piwik_Translate('Actions_ExitPageTitles'),
+			'module' => 'Actions',
+			'action' => 'getExitPageTitles',
+			'dimension' => Piwik_Translate('Actions_ColumnPageName'),
+			'metrics' => array(
+				'exit_nb_visits' => Piwik_Translate('General_ColumnExits'),
+				'nb_visits' => Piwik_Translate('General_ColumnUniquePageviews'),
+				'exit_rate' => Piwik_Translate('General_ColumnExitRate')
+			),
+			'metricsDocumentation' => array(
+				'exit_nb_visits' => Piwik_Translate('General_ColumnExitsDocumentation'),
+				'nb_visits' => Piwik_Translate('General_ColumnUniquePageviewsDocumentation'),
+				'exit_rate' => Piwik_Translate('General_ColumnExitRateDocumentation')
+			),
+			'documentation' => Piwik_Translate('Actions_EntryPageTitlesReportDocumentation', '<br />')
+					.' '.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
+			'processedMetrics' => false,
+			'order' => 7
 		);
     	
+		$documentation = array(
+			'nb_visits' => Piwik_Translate('Actions_ColumnUniqueClicksDocumentation'),
+			'nb_hits' => Piwik_Translate('Actions_ColumnClicksDocumentation')
+		);
+		
+		// outlinks report
 		$reports[] = array(
 			'category' => Piwik_Translate('Actions_Actions'),
 			'name' => Piwik_Translate('Actions_SubmenuOutlinks'),
 			'module' => 'Actions',
 			'action' => 'getOutlinks',
 			'dimension' => Piwik_Translate('Actions_ColumnClickedURL'),
-			'metrics' => $metrics,
+			'metrics' => array(
+				'nb_visits' => Piwik_Translate('Actions_ColumnUniqueClicks'),
+				'nb_hits' => Piwik_Translate('Actions_ColumnClicks')
+			),
 			'metricsDocumentation' => $documentation,
 			'documentation' => Piwik_Translate('Actions_OutlinksReportDocumentation').' '
 					.Piwik_Translate('Actions_OutlinkDocumentation').'<br />'
 					.Piwik_Translate('General_UsePlusMinusIconsDocumentation'),
 			'processedMetrics' => false,
-			'order' => 5,
+			'order' => 8,
 		);
+		
+		// downloads report
 		$reports[] = array(
 			'category' => Piwik_Translate('Actions_Actions'),
 			'name' => Piwik_Translate('Actions_SubmenuDownloads'),
 			'module' => 'Actions',
 			'action' => 'getDownloads',
 			'dimension' => Piwik_Translate('Actions_ColumnDownloadURL'),
-			'metrics' => $metrics,
+			'metrics' => array(
+				'nb_visits' => Piwik_Translate('Actions_ColumnUniqueDownloads'),
+				'nb_hits' => Piwik_Translate('Actions_ColumnDownloads')
+			),
 			'metricsDocumentation' => $documentation,
 			'documentation' => Piwik_Translate('Actions_DownloadsReportDocumentation', '<br />'),
 			'processedMetrics' => false,
-			'order' => 7,
+			'order' => 9,
 		);
 	}
 	
 	function addWidgets()
 	{
-		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPagesEntry', 'Actions', 'getEntryPageUrls');
-		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPagesExit', 'Actions', 'getExitPageUrls');
 		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPages', 'Actions', 'getPageUrls');
 		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPageTitles', 'Actions', 'getPageTitles');
 		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuOutlinks', 'Actions', 'getOutlinks');
 		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuDownloads', 'Actions', 'getDownloads');
+		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPagesEntry', 'Actions', 'getEntryPageUrls');
+		Piwik_AddWidget( 'Actions_Actions', 'Actions_SubmenuPagesExit', 'Actions', 'getExitPageUrls');
+		Piwik_AddWidget( 'Actions_Actions', 'Actions_EntryPageTitles', 'Actions', 'getEntryPageTitles' );
+		Piwik_AddWidget( 'Actions_Actions', 'Actions_ExitPageTitles', 'Actions', 'getExitPageTitles' );
 	}
 	
 	function addMenus()
@@ -259,23 +427,30 @@ class Piwik_Actions extends Piwik_Plugin
 	public function __construct()
 	{
 		// for BC, we read the old style delimiter first (see #1067)
-		$actionDelimiter = Zend_Registry::get('config')->General->action_category_delimiter;
+		$actionDelimiter = @Piwik_Config::getInstance()->General['action_category_delimiter'];
 		if(empty($actionDelimiter))
 		{
-    		self::$actionUrlCategoryDelimiter =  Zend_Registry::get('config')->General->action_url_category_delimiter;
-    		self::$actionTitleCategoryDelimiter =  Zend_Registry::get('config')->General->action_title_category_delimiter;
+			self::$actionUrlCategoryDelimiter = Piwik_Config::getInstance()->General['action_url_category_delimiter'];
+			self::$actionTitleCategoryDelimiter = Piwik_Config::getInstance()->General['action_title_category_delimiter'];
 		}
 		else
 		{
 			self::$actionUrlCategoryDelimiter = self::$actionTitleCategoryDelimiter = $actionDelimiter;
 		}
 		
-		self::$defaultActionName = Zend_Registry::get('config')->General->action_default_name;
+		self::$defaultActionName = Piwik_Config::getInstance()->General['action_default_name'];
 		$this->columnToSortByBeforeTruncation = Piwik_Archive::INDEX_NB_VISITS;
-		$this->maximumRowsInDataTableLevelZero = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_actions;
-		$this->maximumRowsInSubDataTable = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_subtable_actions;
+		$this->maximumRowsInDataTableLevelZero = Piwik_Config::getInstance()->General['datatable_archiving_maximum_rows_actions'];
+		$this->maximumRowsInSubDataTable = Piwik_Config::getInstance()->General['datatable_archiving_maximum_rows_subtable_actions'];
+
+		// Piwik_DataTable::MAXIMUM_DEPTH_LEVEL_ALLOWED must be greater than the category level limit
+		Piwik_DataTable::setMaximumDepthLevelAllowedAtLeast(self::getSubCategoryLevelLimit() + 1);
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 * @return mixed
+	 */
 	function archivePeriod( $notification )
 	{
 		$archiveProcessing = $notification->getNotificationObject();
@@ -289,15 +464,24 @@ class Piwik_Actions extends Piwik_Plugin
 				'Actions_actions_url',
 		);
 		$archiveProcessing->archiveDataTable($dataTableToSum, self::$invalidSummedColumnNameToRenamedNameForPeriodArchive, $this->maximumRowsInDataTableLevelZero, $this->maximumRowsInSubDataTable, $this->columnToSortByBeforeTruncation);
+		
+		$archiveProcessing->archiveNumericValuesSum(array(
+			'Actions_nb_pageviews',
+			'Actions_nb_uniq_pageviews',
+			'Actions_nb_downloads',
+			'Actions_nb_uniq_downloads',
+			'Actions_nb_outlinks',
+			'Actions_nb_uniq_outlinks'
+		));
 	}
 	
 	/**
 	 * Compute all the actions along with their hierarchies.
 	 *
 	 * For each action we process the "interest statistics" :
-	 * visits, unique visitors, bouce count, sum visit length.
-	 *
+	 * visits, unique visitors, bounce count, sum visit length.
 	 *
+	 * @param Piwik_Event_Notification $notification  notification object
 	 */
 	public function archiveDay( $notification )
 	{
@@ -364,7 +548,7 @@ class Piwik_Actions extends Piwik_Plugin
 				count(*) as `". Piwik_Archive::INDEX_PAGE_ENTRY_NB_VISITS ."`,
 				sum(log_visit.visit_total_actions) as `". Piwik_Archive::INDEX_PAGE_ENTRY_NB_ACTIONS ."`,
 				sum(log_visit.visit_total_time) as `". Piwik_Archive::INDEX_PAGE_ENTRY_SUM_VISIT_LENGTH ."`,
-				sum(case log_visit.visit_total_actions when 1 then 1 else 0 end) as `". Piwik_Archive::INDEX_PAGE_ENTRY_BOUNCE_COUNT ."`";
+				sum(case log_visit.visit_total_actions when 1 then 1 when 0 then 1 else 0 end) as `". Piwik_Archive::INDEX_PAGE_ENTRY_BOUNCE_COUNT ."`";
 		
 		$from = "log_visit";
 		
@@ -432,7 +616,17 @@ class Piwik_Actions extends Piwik_Plugin
 		// Record the final datasets
 		$this->archiveDayRecordInDatabase($archiveProcessing);
 	}
-	
+
+	/**
+	 * @param $select
+	 * @param $from
+	 * @param $where
+	 * @param $orderBy
+	 * @param $groupBy
+	 * @param $sprintfField
+	 * @param Piwik_ArchiveProcessing $archiveProcessing
+	 * @return int
+	 */
 	protected function archiveDayQueryProcess($select, $from, $where, $orderBy, $groupBy,
 			$sprintfField, $archiveProcessing)
 	{
@@ -466,18 +660,24 @@ class Piwik_Actions extends Piwik_Plugin
 		$this->deleteInvalidSummedColumnsFromDataTable($dataTable);
 		$s = $dataTable->getSerialized( $this->maximumRowsInDataTableLevelZero, $this->maximumRowsInSubDataTable, $this->columnToSortByBeforeTruncation );
 		$archiveProcessing->insertBlobRecord('Actions_actions_url', $s);
+		$archiveProcessing->insertNumericRecord('Actions_nb_pageviews', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_PAGE_NB_HITS)));
+		$archiveProcessing->insertNumericRecord('Actions_nb_uniq_pageviews', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_NB_VISITS)));
 		destroy($dataTable);
 
 		$dataTable = Piwik_ArchiveProcessing_Day::generateDataTable($this->actionsTablesByType[Piwik_Tracker_Action::TYPE_DOWNLOAD]);
 		$this->deleteInvalidSummedColumnsFromDataTable($dataTable);
 		$s = $dataTable->getSerialized($this->maximumRowsInDataTableLevelZero, $this->maximumRowsInSubDataTable, $this->columnToSortByBeforeTruncation );
 		$archiveProcessing->insertBlobRecord('Actions_downloads', $s);
+		$archiveProcessing->insertNumericRecord('Actions_nb_downloads', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_PAGE_NB_HITS)));
+		$archiveProcessing->insertNumericRecord('Actions_nb_uniq_downloads', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_NB_VISITS)));
 		destroy($dataTable);
 
 		$dataTable = Piwik_ArchiveProcessing_Day::generateDataTable($this->actionsTablesByType[Piwik_Tracker_Action::TYPE_OUTLINK]);
 		$this->deleteInvalidSummedColumnsFromDataTable($dataTable);
 		$s = $dataTable->getSerialized( $this->maximumRowsInDataTableLevelZero, $this->maximumRowsInSubDataTable, $this->columnToSortByBeforeTruncation );
 		$archiveProcessing->insertBlobRecord('Actions_outlink', $s);
+		$archiveProcessing->insertNumericRecord('Actions_nb_outlinks', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_PAGE_NB_HITS)));
+		$archiveProcessing->insertNumericRecord('Actions_nb_uniq_outlinks', array_sum($dataTable->getColumn(Piwik_Archive::INDEX_NB_VISITS)));
 		destroy($dataTable);
 
 		$dataTable = Piwik_ArchiveProcessing_Day::generateDataTable($this->actionsTablesByType[Piwik_Tracker_Action::TYPE_ACTION_NAME]);
@@ -551,7 +751,7 @@ class Piwik_Actions extends Piwik_Plugin
 		{
 			$name = $urlPath;
 			
-			if( empty($name) || substr($name, -1) == '/' )
+			if( $name === '' || substr($name, -1) == '/' )
 			{
 				$name .= self::$defaultActionName;
 			}
@@ -571,7 +771,7 @@ class Piwik_Actions extends Piwik_Plugin
 			return array( trim($name) );
 		}
 
-		$split = explode($categoryDelimiter, $name, self::$limitLevelSubCategory);
+		$split = explode($categoryDelimiter, $name, self::getSubCategoryLevelLimit());
 		
 		// trim every category and remove empty categories
 		$split = array_map('trim', $split);
@@ -618,7 +818,12 @@ class Piwik_Actions extends Piwik_Plugin
 	const CACHE_PARSED_INDEX_NAME = 0;
 	const CACHE_PARSED_INDEX_TYPE = 1;
 	static $cacheParsedAction = array();
-	
+
+	/**
+	 * @param Zend_Db_Statement|PDOStatement $query
+	 * @param string|bool $fieldQueried
+	 * @return int
+	 */
 	protected function updateActionsTableWithRowQuery($query, $fieldQueried = false)
 	{
 		$rowsProcessed = 0;
@@ -758,5 +963,15 @@ class Piwik_Actions extends Piwik_Plugin
 		}
 		return $currentTable;
 	}
+	
+	/**
+	 * Returns the configured sub-category level limit.
+	 * 
+	 * @return int
+	 */
+	public static function getSubCategoryLevelLimit()
+	{
+		return Piwik_Config::getInstance()->General['action_category_level_limit'];
+	}
 }
 
