@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 4634 2011-05-05 08:56:37Z EZdesign $
+ * @version $Id: Controller.php 6366 2012-05-29 06:57:11Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Actions
@@ -19,20 +19,18 @@ class Piwik_Actions_Controller extends Piwik_Controller
 {
 	const ACTIONS_REPORT_ROWS_DISPLAY = 100;
 	
-	protected function getPageUrlsView($currentAction, $controllerActionSubtable)
+	protected function getPageUrlsView($currentAction, $controllerActionSubtable, $apiAction)
 	{
 		$view = Piwik_ViewDataTable::factory();
-		$view->init(  	$this->pluginName,
-						$currentAction,
-						'Actions.getPageUrls',
-						$controllerActionSubtable );
+		$view->init($this->pluginName, $currentAction, $apiAction, $controllerActionSubtable);
 		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageURL'));
 		return $view;
 	}
-	
-	
+
 	/**
 	 * PAGES
+	 * @param bool $fetch
+	 * @return string
 	 */
 	
 	public function indexPageUrls($fetch = false)
@@ -44,7 +42,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	
 	public function getPageUrls($fetch = false)
 	{
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getPageUrlsSubDataTable', 'Actions.getPageUrls');
 		$this->configureViewPages($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -52,7 +50,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	
 	public function getPageUrlsSubDataTable($fetch = false)
 	{
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getPageUrlsSubDataTable', 'Actions.getPageUrls');
 		$this->configureViewPages($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -62,10 +60,12 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	{
 		$view->setColumnsToDisplay( array('label','nb_hits','nb_visits', 'bounce_rate', 'avg_time_on_page', 'exit_rate') );
 	}
-	
-	
+
+
 	/**
 	 * ENTRY PAGES
+	 * @param bool $fetch
+	 * @return string|void
 	 */
 	
 	public function indexEntryPageUrls($fetch = false)
@@ -76,7 +76,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	}
 	
 	public function getEntryPageUrls($fetch = false) {
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getEntryPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getEntryPageUrlsSubDataTable', 'Actions.getEntryPageUrls');
 		$this->configureViewEntryPageUrls($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -84,7 +84,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	
 	public function getEntryPageUrlsSubDataTable($fetch = false)
 	{
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getEntryPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getEntryPageUrlsSubDataTable', 'Actions.getEntryPageUrls');
 		$this->configureViewEntryPageUrls($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -94,23 +94,18 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	{
 		$view->setSortedColumn('entry_nb_visits');
 		$view->setColumnsToDisplay( array('label','entry_nb_visits', 'entry_bounce_count', 'bounce_rate') );
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnEntryPageURL'));
 		$view->setColumnTranslation('entry_bounce_count', Piwik_Translate('General_ColumnBounces'));
 		$view->setColumnTranslation('entry_nb_visits', Piwik_Translate('General_ColumnEntrances'));
-		// remove pages that are not entry pages
-		$view->queueFilter('ColumnCallbackDeleteRow', array('entry_nb_visits', 'strlen'), $priorityFilter = true);
-		
-		$view->setMetricDocumentation('entry_nb_visits', Piwik_Translate('General_ColumnEntrancesDocumentation'));
-		$view->setMetricDocumentation('entry_bounce_count', Piwik_Translate('General_ColumnBouncesDocumentation'));
-		$view->setMetricDocumentation('bounce_rate', Piwik_Translate('General_ColumnBounceRateForPageDocumentation'));
-		$view->setReportDocumentation(Piwik_Translate('Actions_EntryPagesReportDocumentation', '<br />').' '
-				.Piwik_Translate('General_UsePlusMinusIconsDocumentation'));
+		$view->addRelatedReports(Piwik_Translate('Actions_SubmenuPagesEntry'), array(
+			'Actions.getEntryPageTitles' => Piwik_Translate('Actions_EntryPageTitles')
+		));
+		$view->setReportUrl('Actions', $this->getEntryPageUrlActionForLink());
 	}
 	
-	
-	/**
+	/*
 	 * EXIT PAGES
 	 */
-
 	public function indexExitPageUrls($fetch = false)
 	{
 		return Piwik_View::singleReport(
@@ -120,7 +115,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	
 	public function getExitPageUrls($fetch = false)
 	{
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getExitPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getExitPageUrlsSubDataTable', 'Actions.getExitPageUrls');
 		$this->configureViewExitPageUrls($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -128,7 +123,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	
 	public function getExitPageUrlsSubDataTable($fetch = false)
 	{
-		$view = $this->getPageUrlsView(__FUNCTION__, 'getExitPageUrlsSubDataTable');
+		$view = $this->getPageUrlsView(__FUNCTION__, 'getExitPageUrlsSubDataTable', 'Actions.getExitPageUrls');
 		$this->configureViewExitPageUrls($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -138,19 +133,15 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	{
 		$view->setSortedColumn('exit_nb_visits');
 		$view->setColumnsToDisplay( array('label', 'exit_nb_visits', 'nb_visits', 'exit_rate') );
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnExitPageURL'));
 		$view->setColumnTranslation('exit_nb_visits', Piwik_Translate('General_ColumnExits'));
-		// remove pages that are not exit pages
-		$view->queueFilter('ColumnCallbackDeleteRow', array('exit_nb_visits', 'strlen'), $priorityFilter = true);
-		
-		$view->setMetricDocumentation('exit_nb_visits', Piwik_Translate('General_ColumnExitsDocumentation'));
-		$view->setMetricDocumentation('nb_visits', Piwik_Translate('General_ColumnUniquePageviewsDocumentation'));
-		$view->setMetricDocumentation('exit_rate', Piwik_Translate('General_ColumnExitRateDocumentation'));
-		$view->setReportDocumentation(Piwik_Translate('Actions_ExitPagesReportDocumentation', '<br />').' '
-				.Piwik_Translate('General_UsePlusMinusIconsDocumentation'));
+		$view->addRelatedReports(Piwik_Translate('Actions_SubmenuPagesExit'), array(
+			'Actions.getExitPageTitles' => Piwik_Translate('Actions_ExitPageTitles')
+		));
+		$view->setReportUrl('Actions', $this->getExitPageUrlActionForLink());
 	}
 	
-	
-	/**
+	/*
 	 * PAGE TITLES
 	 */
 	
@@ -169,6 +160,11 @@ class Piwik_Actions_Controller extends Piwik_Controller
 						'Actions.getPageTitles',
 						'getPageTitlesSubDataTable' );
 		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageName'));
+		$view->addRelatedReports(Piwik_Translate('Actions_SubmenuPageTitles'), array(
+			'Actions.getEntryPageTitles' => Piwik_Translate('Actions_EntryPageTitles'),
+			'Actions.getExitPageTitles' => Piwik_Translate('Actions_ExitPageTitles'),
+		));
+		$view->setReportUrl('Actions', $this->getPageTitlesActionForLink());
 		$this->configureViewPages($view);
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
@@ -185,9 +181,61 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
 	}
-
 	
 	/**
+	 * Echos or returns a report displaying analytics data for every unique entry
+	 * page title.
+	 * 
+	 * @param bool $fetch True to return the view as a string, false to echo it.
+	 * @return string
+	 */
+	public function getEntryPageTitles( $fetch = false )
+	{
+		$view = Piwik_ViewDataTable::factory();
+		$view->init($this->pluginName, __FUNCTION__, 'Actions.getEntryPageTitles', __FUNCTION__);
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnEntryPageTitle'));
+		$view->setColumnTranslation('entry_bounce_count', Piwik_Translate('General_ColumnBounces'));
+		$view->setColumnTranslation('entry_nb_visits', Piwik_Translate('General_ColumnEntrances'));
+		$view->setColumnsToDisplay( array('label','entry_nb_visits', 'entry_bounce_count', 'bounce_rate') );
+		
+		$entryPageUrlAction = $this->getEntryPageUrlActionForLink();
+		$view->addRelatedReports(Piwik_Translate('Actions_EntryPageTitles'), array(
+			'Actions.getPageTitles' => Piwik_Translate('Actions_SubmenuPageTitles'),
+			"Actions.$entryPageUrlAction" => Piwik_Translate('Actions_SubmenuPagesEntry'),
+		));
+		
+		$this->configureViewActions($view);
+		
+		return $this->renderView($view, $fetch);
+	}
+	
+	/**
+	 * Echos or returns a report displaying analytics data for every unique exit
+	 * page title.
+	 * 
+	 * @param bool $fetch True to return the view as a string, false to echo it.
+	 * @return string
+	 */
+	public function getExitPageTitles( $fetch = false )
+	{
+		$view = Piwik_ViewDataTable::factory();
+		$view->init($this->pluginName, __FUNCTION__, 'Actions.getExitPageTitles', __FUNCTION__);
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnExitPageTitle'));
+		$view->setColumnTranslation('exit_nb_visits', Piwik_Translate('General_ColumnExits'));
+		$view->setColumnsToDisplay( array('label', 'exit_nb_visits', 'nb_visits', 'exit_rate') );
+		
+		$exitPageUrlAction = $this->getExitPageUrlActionForLink();
+		$view->addRelatedReports(Piwik_Translate('Actions_ExitPageTitles'), array(
+			'Actions.getPageTitles' => Piwik_Translate('Actions_SubmenuPageTitles'),
+			"Actions.$exitPageUrlAction" => Piwik_Translate('Actions_SubmenuPagesExit'),
+		));
+		
+		$this->configureViewActions($view);
+		
+		return $this->renderView($view, $fetch);
+	}
+	
+	/*
 	 * DOWNLOADS
 	 */
 	
@@ -222,7 +270,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 	}
 	
 	
-	/**
+	/*
 	 * OUTLINKS
 	 */
 
@@ -356,7 +404,6 @@ class Piwik_Actions_Controller extends Piwik_Controller
 				}
 			}
 			
-			$label = $row->getColumn('label');
 			$newRow = array(
 				'level' => $depth,
 				'columns' => $row->getColumns(),
@@ -371,4 +418,26 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		}
 		return $table;
 	}
+	
+	/** Returns action to use when linking to the exit page URLs report. */
+	private function getExitPageUrlActionForLink()
+	{
+		// link to the page not, just the report, but only if not a widget
+		return Piwik_Common::getRequestVar('widget', 0) == 0 ? 'indexExitPageUrls' : 'getExitPageUrls';
+	}
+
+	
+	/** Returns action to use when linking to the entry page URLs report. */
+	private function getEntryPageUrlActionForLink()
+	{
+		// link to the page not, just the report, but only if not a widget
+		return Piwik_Common::getRequestVar('widget', 0) == 0 ? 'indexEntryPageUrls' : 'getEntryPageUrls';
+	}
+	
+	/** Returns action to use when linking to the page titles report. */
+	private function getPageTitlesActionForLink()
+	{
+		// link to the page not, just the report, but only if not a widget
+		return Piwik_Common::getRequestVar('widget', 0) == 0 ? 'indexPageTitles' : 'getPageTitles';
+	}
 }
