@@ -5,12 +5,22 @@
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
 
-$('.but').bind('click', function(e)
+$('.but').on('click', function(e)
 {
 	if($('#websiteSearch').val() != '')
 		$('#websiteSearch').autocomplete('search', $('#websiteSearch').val() + '%%%');
 	return false;
 });
+
+function switchSite(id, name)
+{
+    $("#sitesSelectionSearch .custom_select_block").toggleClass("custom_select_block_show");
+    $('.custom_select_main_link').text(name);
+    $('.custom_select_main_link').addClass('custom_select_loading');
+    broadcast.propagateNewPage('idSite='+id );
+    return false;
+}
+
 $(function() {
 	if($('#websiteSearch').length == 0)
 	{
@@ -35,13 +45,12 @@ $(function() {
 		select: function(event, ui) {
 			if(piwik.idSite == ui.item.id)
 			{
-				hide();
 				$("#sitesSelectionSearch .custom_select_block").toggleClass("custom_select_block_show");
 			}
 			else
 			{
 				if(ui.item.id > 0) {
-					broadcast.propagateNewPage('idSite='+ui.item.id );
+				    switchSite(ui.item.id, ui.item.name);
 				} else {
 					reset();
 				}
@@ -80,11 +89,16 @@ $(function() {
 		$(ul).attr('id', 'siteSelect');
 		return $( "<li></li>" )
 		.data( "item.autocomplete", item )
-		.append( $( "<a></a>" ).html( item.label ).attr('href', piwikHelper.getCurrentQueryStringWithParametersModified('idSite='+item.id)+jQuery.historyCurrentHash.replace(/idSite=[0-9]+/, 'idSite='+item.id)) )
+		.append( $( "<a></a>" ).html( item.label )
+					.attr('href', piwikHelper.getCurrentQueryStringWithParametersModified('idSite='+item.id) 
+									+ (broadcast.isHashExists()
+												? broadcast.getHashFromUrl().replace(/idSite=[0-9]+/, 'idSite='+item.id) 
+												: ""
+									) ) )
 		.appendTo( ul );
 	};
 
-	$('body').bind('mouseup',function(e){ 
+	$('body').on('mouseup',function(e){ 
 		if(!$(e.target).parents('#sitesSelectionSearch').length && !$(e.target).is('#sitesSelectionSearch') && !$(e.target).parents('#siteSelect.ui-autocomplete').length) {
 			reset();
 			$('#sitesSelectionSearch .custom_select_block').removeClass('custom_select_block_show');
