@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 4856 2011-06-03 15:19:10Z peterb $
+ * @version $Id: Controller.php 5951 2012-03-04 22:04:41Z vipsoft $
  *
  * @category Piwik_Plugins
  * @package Piwik_CorePluginsAdmin
@@ -44,7 +44,7 @@ class Piwik_CorePluginsAdmin_Controller extends Piwik_Controller_Admin
 		$view->pluginsName = $plugins;
 		$this->setBasicVariablesView($view);
 		$view->menu = Piwik_GetAdminMenu();
-		if(!Zend_Registry::get('config')->isFileWritable())
+		if(!Piwik_Config::getInstance()->isFileWritable())
 		{
 			$view->configFileNotWritable = true;
 		}
