@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: CustomVariables.php 5235 2011-09-27 07:20:45Z matt $
+ * @version $Id: CustomVariables.php 6243 2012-05-02 22:08:23Z SteveG $
  *
  * @category Piwik_Plugins
  * @package Piwik_CustomVariables
@@ -23,7 +23,8 @@ class Piwik_CustomVariables extends Piwik_Plugin
 	public function getInformation()
 	{
 		$info = array(
-			'description' => Piwik_Translate('CustomVariables_PluginDescription'),
+			'description' => Piwik_Translate('CustomVariables_PluginDescription') 
+			. ' <br/>Required to use <a href="http://piwik.org/docs/ecommerce-analytics/">Ecommerce Analytics</a> feature!',
 			'author' => 'Piwik',
 			'author_homepage' => 'http://piwik.org/',
 			'version' => Piwik_Version::VERSION,
@@ -56,6 +57,11 @@ class Piwik_CustomVariables extends Piwik_Plugin
 		Piwik_AddMenu('General_Visitors', 'CustomVariables_CustomVariables', array('module' => 'CustomVariables', 'action' => 'index'), $display = true, $order = 50);
 	}
 
+	/**
+	 * Returns metadata for available reports
+	 *
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getReportMetadata($notification)
 	{
 		$reports = &$notification->getNotificationObject();
@@ -65,6 +71,7 @@ class Piwik_CustomVariables extends Piwik_Plugin
         			'name'   => Piwik_Translate('CustomVariables_CustomVariables'),
         			'module' => 'CustomVariables',
         			'action' => 'getCustomVariables',
+					'actionToLoadSubTables' => 'getCustomVariablesValuesFromNameId',
         			'dimension' => Piwik_Translate('CustomVariables_ColumnCustomVariableName'),
         			'documentation' => Piwik_Translate('CustomVariables_CustomVariablesReportDocumentation', array('<br />', '<a href="http://piwik.org/docs/custom-variables/" target="_blank">', '</a>')),
         			'order' => 10
@@ -72,6 +79,9 @@ class Piwik_CustomVariables extends Piwik_Plugin
 		));
 	}
 
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getSegmentsMetadata($notification)
 	{
 		$segments =& $notification->getNotificationObject();
@@ -114,6 +124,8 @@ class Piwik_CustomVariables extends Piwik_Plugin
 
 	/**
 	 * Adds Goal dimensions, so that the dimensions are displayed in the UI Goal Overview page
+	 *
+	 * @param Piwik_Event_Notification $notification  notification object
 	 */
 	function getReportsWithGoalMetrics( $notification )
 	{
@@ -129,8 +141,8 @@ class Piwik_CustomVariables extends Piwik_Plugin
 
 	function __construct()
 	{
-		$this->maximumRowsInDataTableLevelZero = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_referers;
-		$this->maximumRowsInSubDataTable = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_subtable_referers;
+		$this->maximumRowsInDataTableLevelZero = Piwik_Config::getInstance()->General['datatable_archiving_maximum_rows_referers'];
+		$this->maximumRowsInSubDataTable = Piwik_Config::getInstance()->General['datatable_archiving_maximum_rows_subtable_referers'];
 	}
 
 	protected $interestByCustomVariables = array();
@@ -139,7 +151,7 @@ class Piwik_CustomVariables extends Piwik_Plugin
 	/**
 	 * Hooks on daily archive to trigger various log processing
 	 *
-	 * @param Piwik_Event_Notification $notification
+	 * @param Piwik_Event_Notification $notification  notification object
 	 * @return void
 	 */
 	public function archiveDay( $notification )
@@ -214,7 +226,7 @@ class Piwik_CustomVariables extends Piwik_Plugin
 					if(substr($label, -2) != '"]') {
 						$label .= '"]';
 					}
-					$decoded = @json_decode($label);
+					$decoded = @Piwik_Common::json_decode($label);
 					if(is_array($decoded))
 					{
 						$count = 0;
@@ -279,7 +291,7 @@ class Piwik_CustomVariables extends Piwik_Plugin
 
 	protected function cleanCustomVarValue($value)
 	{
-		if(!empty($value))
+		if(strlen($value))
 		{
 			return $value;
 		} 
@@ -300,6 +312,10 @@ class Piwik_CustomVariables extends Piwik_Plugin
 		destroy($table);
 	}
 
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 * @return mixed
+	 */
 	function archivePeriod( $notification )
 	{
 		$archiveProcessing = $notification->getNotificationObject();
