@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: en.php 3565 2011-01-03 05:49:45Z matt $
+ * @version $Id: en.php 6348 2012-05-28 09:42:39Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_ExamplePlugin
@@ -14,9 +14,8 @@ $translations = array(
 	'ExamplePlugin_PluginDescription' => 'Example Plugin: This plugin shows how to create a very simple plugin, that exports two widgets in the Dashboard.',
 	'ExamplePlugin_exampleWidgets' => 'Example Widgets',
 	'ExamplePlugin_exampleWidget' => 'Example widget',
-	'ExamplePlugin_blogPiwikRss' => 'Blog Piwik RSS',
 	'ExamplePlugin_photostreamMatt' => 'Matt\'s Photos',
-	'ExamplePlugin_piwikDownloads' => 'Piwik Downloads',
-	'ExamplePlugin_PiwikHasBeenDownloaded' => 'On %s, Piwik was downloaded %s times.'
+	'ExamplePlugin_piwikForumVisits' => 'Piwik Forums visits',
+	'ExamplePlugin_PiwikForumReceivedVisits' => 'On %s, Piwik forums received %s visits.'
 	
 );
