@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 5245 2011-09-27 10:00:20Z matt $
+ * @version $Id: API.php 6243 2012-05-02 22:08:23Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_Goals
@@ -53,6 +53,8 @@ class Piwik_Goals_API
 	 */
 	public function getGoals( $idSite )
 	{
+		//TODO calls to this function could be cached as static
+		// would help UI at least, since some UI requests would call this 2-3 times..
 		if(!is_array($idSite))
 		{
 			$idSite = Piwik_Site::getIdSitesFromIdSitesString($idSite);
@@ -81,16 +83,16 @@ class Piwik_Goals_API
 
 	/**
 	 * Creates a Goal for a given website.
-	 * 
+	 *
 	 * @param int $idSite
 	 * @param string $name
 	 * @param string $matchAttribute 'url', 'title', 'file', 'external_website' or 'manually'
 	 * @param string $pattern eg. purchase-confirmation.htm
-	 * @param string $patternType 'regex', 'contains', 'exact' 
+	 * @param string $patternType 'regex', 'contains', 'exact'
 	 * @param bool $caseSensitive
-	 * @param float|string $revenue If set, default revenue to assign to conversions
+	 * @param bool|float $revenue If set, default revenue to assign to conversions
 	 * @param bool $allowMultipleConversionsPerVisit By default, multiple conversions in the same visit will only record the first conversion.
-	 * 						If set to true, multiple conversions will all be recorded within a visit (useful for Ecommerce goals)
+	 *                         If set to true, multiple conversions will all be recorded within a visit (useful for Ecommerce goals)
 	 * @return int ID of the new goal
 	 */
 	public function addGoal( $idSite, $name, $matchAttribute, $pattern, $patternType, $caseSensitive = false, $revenue = false, $allowMultipleConversionsPerVisit = false)
@@ -125,12 +127,21 @@ class Piwik_Goals_API
 		Piwik_Common::regenerateCacheWebsiteAttributes($idSite);
 		return $idGoal;
 	}
-	
+
 	/**
 	 * Updates a Goal description.
-	 * Will not update or re-process the conversions already recorded  
-	 * 
+	 * Will not update or re-process the conversions already recorded
+	 *
 	 * @see addGoal() for parameters description
+	 * @param int $idSite
+	 * @param int $idGoal
+	 * @param $name
+	 * @param $matchAttribute
+	 * @param string $pattern
+	 * @param string $patternType
+	 * @param bool $caseSensitive
+	 * @param bool|float $revenue
+	 * @param bool $allowMultipleConversionsPerVisit
 	 * @return void
 	 */
 	public function updateGoal( $idSite, $idGoal, $name, $matchAttribute, $pattern, $patternType, $caseSensitive = false, $revenue = false, $allowMultipleConversionsPerVisit = false)
@@ -189,7 +200,7 @@ class Piwik_Goals_API
 										WHERE idsite = ? 
 											AND idgoal = ?",
 									array($idSite, $idGoal));
-		Piwik_Query("DELETE FROM ".Piwik_Common::prefixTable("log_conversion")." WHERE idgoal = ?", $idGoal);
+		Piwik_DeleteAllRows(Piwik_Common::prefixTable("log_conversion"), "WHERE idgoal = ?", 100000, array($idGoal));
 		Piwik_Common::regenerateCacheWebsiteAttributes($idSite);
 	}
 	
@@ -340,13 +351,41 @@ class Piwik_Goals_API
 		return $this->getItems('Goals_ItemsCategory', $idSite, $period, $date, $abandonedCarts);
 	}
 	
+	/**
+	 * Helper function that checks for special string goal IDs and converts them to
+	 * their integer equivalents.
+	 *
+	 * Checks for the following values:
+	 * Piwik_Archive::LABEL_ECOMMERCE_ORDER
+	 * Piwik_Archive::LABEL_ECOMMERCE_CART
+	 *
+	 * @param string|int $idGoal The goal id as an integer or a special string.
+	 * @return int The numeric goal id.
+	 */
+	protected static function convertSpecialGoalIds( $idGoal )
+	{
+		if ($idGoal == Piwik_Archive::LABEL_ECOMMERCE_ORDER)
+		{
+			return Piwik_Tracker_GoalManager::IDGOAL_ORDER;
+		}
+		else if ($idGoal == Piwik_Archive::LABEL_ECOMMERCE_CART)
+		{
+			return Piwik_Tracker_GoalManager::IDGOAL_CART;
+		}
+		else
+		{
+			return $idGoal;
+		}
+	}
+
 	/**
 	 * Returns Goals data
-	 * 
+	 *
 	 * @param int $idSite
 	 * @param string $period
 	 * @param string $date
-	 * @param int $idGoal
+	 * @param bool $segment
+	 * @param bool|int $idGoal
 	 * @param array $columns Array of metrics to fetch: nb_conversions, conversion_rate, revenue
 	 * @return Piwik_DataTable
 	 */
@@ -357,11 +396,7 @@ class Piwik_Goals_API
 		$columns = Piwik::getArrayFromApiParameter($columns);
 		
 		// Mapping string idGoal to internal ID
-		$idGoal = ($idGoal == Piwik_Archive::LABEL_ECOMMERCE_ORDER) 
-						? Piwik_Tracker_GoalManager::IDGOAL_ORDER
-						: ($idGoal == Piwik_Archive::LABEL_ECOMMERCE_CART
-							? Piwik_Tracker_GoalManager::IDGOAL_CART
-							: $idGoal);
+		$idGoal = self::convertSpecialGoalIds($idGoal);
 							
 		if(empty($columns))
 		{
@@ -376,7 +411,7 @@ class Piwik_Goals_API
 		{
 			$columns[] = 'nb_conversions';
 			$columns[] = 'revenue';
-			$columns = array_unique($columns);
+			$columns = array_values(array_unique($columns));
 		}
 		$columnsToSelect = array();
 		foreach($columns as &$columnName)
@@ -464,4 +499,79 @@ class Piwik_Goals_API
 	{
 		return $this->getNumeric( $idSite, $period, $date, $segment, Piwik_Goals::getRecordName('revenue', $idGoal));
 	}
+
+	/**
+	 * Utility method that retrieve an archived DataTable for a specific site, date range,
+	 * segment and goal. If not goal is specified, this method will retrieve and sum the
+	 * data for every goal.
+	 *
+	 * @param string $recordName The archive entry name.
+	 * @param int|string $idSite The site(s) to select data for.
+	 * @param string $period The period type.
+	 * @param string $date The date type.
+	 * @param string $segment The segment.
+	 * @param int|bool $idGoal The id of the goal to get data for. If this is set to false,
+	 *                         data for every goal that belongs to $idSite is returned.
+	 */	
+	protected function getGoalSpecificDataTable($recordName, $idSite, $period, $date, $segment, $idGoal)
+	{
+		Piwik::checkUserHasViewAccess( $idSite );
+
+		$archive = Piwik_Archive::build($idSite, $period, $date, $segment );
+
+		// check for the special goal ids
+		$realGoalId = $idGoal != true ? false : self::convertSpecialGoalIds($idGoal);
+
+		// get the data table
+		$dataTable = $archive->getDataTable(Piwik_Goals::getRecordName($recordName, $realGoalId), $idSubtable = null);
+		$dataTable->queueFilter('ReplaceColumnNames');
+		
+		return $dataTable;
+	}
+
+	/**
+	 * Gets a DataTable that maps ranges of days to the number of conversions that occurred
+	 * within those ranges, for the specified site, date range, segment and goal.
+	 *
+	 * @param int $idSite The site to select data from.
+	 * @param string $period The period type.
+	 * @param string $date The date type.
+	 * @param string|bool $segment The segment.
+	 * @param int|bool $idGoal The id of the goal to get data for. If this is set to false,
+	 *                         data for every goal that belongs to $idSite is returned.
+	 */
+	public function getDaysToConversion($idSite, $period, $date, $segment = false, $idGoal = false)
+	{
+		$dataTable = $this->getGoalSpecificDataTable(
+			Piwik_Goals::DAYS_UNTIL_CONV_RECORD_NAME, $idSite, $period, $date, $segment, $idGoal);
+
+		$dataTable->queueFilter('Sort', array('label', 'asc', true));
+		$dataTable->queueFilter(
+			'BeautifyRangeLabels', array(Piwik_Translate('General_OneDay'), Piwik_Translate('General_NDays')));
+
+		return $dataTable;
+	}
+	
+	/**
+	 * Gets a DataTable that maps ranges of visit counts to the number of conversions that
+	 * occurred on those visits for the specified site, date range, segment and goal.
+	 *
+	 * @param int $idSite The site to select data from.
+	 * @param string $period The period type.
+	 * @param string $date The date type.
+	 * @param string|bool $segment The segment.
+	 * @param int|bool $idGoal The id of the goal to get data for. If this is set to false,
+	 *                         data for every goal that belongs to $idSite is returned.
+	 */
+	public function getVisitsUntilConversion($idSite, $period, $date, $segment = false, $idGoal = false)
+	{
+		$dataTable = $this->getGoalSpecificDataTable(
+			Piwik_Goals::VISITS_UNTIL_RECORD_NAME, $idSite, $period, $date, $segment, $idGoal);
+
+		$dataTable->queueFilter('Sort', array('label', 'asc', true));
+		$dataTable->queueFilter(
+			'BeautifyRangeLabels', array(Piwik_Translate('General_OneVisit'), Piwik_Translate('General_NVisits')));
+
+		return $dataTable;
+	}
 }
