@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 3581 2011-01-03 13:28:21Z matt $
+ * @version $Id: Controller.php 6370 2012-05-29 09:08:49Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_Login
@@ -17,6 +17,24 @@
  */
 class Piwik_Login_Controller extends Piwik_Controller
 {
+	/**
+	 * Generate hash on user info and password
+	 *
+	 * @param string $userinfo User name, email, etc
+	 * @param string $password
+	 * @return string
+	 */
+	private function generateHash($userInfo, $password)
+	{
+		// mitigate rainbow table attack
+		$passwordLen = strlen($password) / 2;
+		$hash = Piwik_Common::hash(
+			$userInfo . substr($password, 0, $passwordLen)
+			. Piwik_Common::getSalt() . substr($password, $passwordLen)
+		);
+		return $hash;
+	}
+
 	/**
 	 * Default action
 	 *
@@ -57,34 +75,38 @@ class Piwik_Login_Controller extends Piwik_Controller
 			}
 			else
 			{
-				$messageNoAccess = Piwik_Translate('Login_InvalidNonceOrReferer');
+				$messageNoAccess = $this->getMessageExceptionNoAccess();
 			}
 		}
 
 		$view = Piwik_View::factory('login');
 		$view->AccessErrorString = $messageNoAccess;
-		$view->nonce = Piwik_Nonce::getNonce('Piwik_Login.login');
 		$view->addForm( $form );
 		$this->configureView($view);
 		echo $view->render();
 	}
 
+	/**
+	 * Configure common view properties
+	 *
+	 * @param Piwik_View $view
+	 */
 	private function configureView($view)
 	{
-		$enableFramedLogins = Zend_Registry::get('config')->General->enable_framed_logins;
-		$view->enableFramedLogins = $enableFramedLogins;
-		if(!$enableFramedLogins)
-		{
-			$view->setXFrameOptions('sameorigin');
-		}
-		$view->forceSslLogin = Zend_Registry::get('config')->General->force_ssl_login;
+		$this->setBasicVariablesView($view);
+
 		$view->linkTitle = Piwik::getRandomTitle();
+
+		$view->forceSslLogin = Piwik_Config::getInstance()->General['force_ssl_login'];
+
+		// crsf token: don't trust the submitted value; generate/fetch it from session data
+		$view->nonce = Piwik_Nonce::getNonce('Piwik_Login.login');
 	}
-	
+
 	/**
 	 * Form-less login
-	 *
-	 * @param none
+	 * @see how to use it on http://piwik.org/faq/how-to/#faq_30
+	 * @throws Exception
 	 * @return void
 	 */
 	function logme()
@@ -98,12 +120,18 @@ class Piwik_Login_Controller extends Piwik_Controller
 		}
 
 		$login = Piwik_Common::getRequestVar('login', null, 'string');
-		if($login == Zend_Registry::get('config')->superuser->login)
-		{			
+		if($login == Piwik_Config::getInstance()->superuser['login'])
+		{
 			throw new Exception(Piwik_TranslateException('Login_ExceptionInvalidSuperUserAuthenticationMethod', array("logme")));
 		}
 
 		$currentUrl = 'index.php';
+
+		if(($idSite = Piwik_Common::getRequestVar('idSite', false, 'int')) !== false)
+		{
+			$currentUrl .= '?idSite='.$idSite;
+		}
+
 		$urlToRedirect = Piwik_Common::getRequestVar('url', $currentUrl, 'string');
 		$urlToRedirect = Piwik_Common::unsanitizeInputValue($urlToRedirect);
 
@@ -125,6 +153,7 @@ class Piwik_Login_Controller extends Piwik_Controller
 						'md5Password' => $md5Password,
 						'rememberMe' => $rememberMe,
 		);
+		Piwik_Nonce::discardNonce('Piwik_Login.login');
 		Piwik_PostEvent('Login.initSession', $info);
 		Piwik_Url::redirectToUrl($urlToRedirect);
 	}
@@ -144,8 +173,16 @@ class Piwik_Login_Controller extends Piwik_Controller
 		$form = new Piwik_Login_FormPassword();
 		if($form->validate())
 		{
-			$loginMail = $form->getSubmitValue('form_login');
-			$messageNoAccess = $this->lostPasswordFormValidated($loginMail);
+			$nonce = $form->getSubmitValue('form_nonce');
+			if(Piwik_Nonce::verifyNonce('Piwik_Login.login', $nonce))
+			{
+				$loginMail = $form->getSubmitValue('form_login');
+				$messageNoAccess = $this->lostPasswordFormValidated($loginMail);
+			}
+			else
+			{
+				$messageNoAccess = $this->getMessageExceptionNoAccess();
+			}
 		}
 
 		$view = Piwik_View::factory('lostPassword');
@@ -155,6 +192,13 @@ class Piwik_Login_Controller extends Piwik_Controller
 		echo $view->render();
 	}
 
+	protected function getMessageExceptionNoAccess()
+	{
+		$message = Piwik_Translate('Login_InvalidNonceOrHeadersOrReferer', array('<a href="?module=Proxy&action=redirect&url='.urlencode('http://piwik.org/faq/how-to-install/#faq_98').'" target="_blank">', '</a>'));
+		// Should mention trusted_hosts or link to FAQ
+		return $message;
+	}
+
 	/**
 	 * Validate user (by username or email address).
 	 *
@@ -163,6 +207,11 @@ class Piwik_Login_Controller extends Piwik_Controller
 	 */
 	protected function lostPasswordFormValidated($loginMail)
 	{
+		if( $loginMail === 'anonymous' )
+		{
+			return Piwik_Translate('Login_InvalidUsernameEmail');
+		}
+
 		$user = self::getUserInformation($loginMail);
 		if( $user === null )
 		{
@@ -177,8 +226,8 @@ class Piwik_Login_Controller extends Piwik_Controller
 		// construct a password reset token from user information
 		$resetToken = self::generatePasswordResetToken($user);
 
-		$ip = Piwik_Common::getIpString();
-		$url = Piwik_Url::getCurrentUrlWithoutQueryString() . "?module=Login&action=resetPassword&token=$resetToken";
+		$ip = Piwik_IP::getIpFromHeader();
+		$url = Piwik_Url::getCurrentUrlWithoutQueryString() . "?module=Login&action=resetPassword";
 
 		// send email with new password
 		try
@@ -194,8 +243,8 @@ class Piwik_Login_Controller extends Piwik_Controller
 			$mail->setBodyText($bodyText);
 
 
-			$fromEmailName = Zend_Registry::get('config')->General->login_password_recovery_email_name;
-			$fromEmailAddress = Zend_Registry::get('config')->General->login_password_recovery_email_address;
+			$fromEmailName = Piwik_Config::getInstance()->General['login_password_recovery_email_name'];
+			$fromEmailAddress = Piwik_Config::getInstance()->General['login_password_recovery_email_address'];
 			$mail->setFrom($fromEmailAddress, $fromEmailName);
 			@$mail->send();
 		}
@@ -205,7 +254,6 @@ class Piwik_Login_Controller extends Piwik_Controller
 		}
 		$this->configureView($view);
 		echo $view->render();
-
 		exit;
 	}
 
@@ -224,15 +272,23 @@ class Piwik_Login_Controller extends Piwik_Controller
 		$form = new Piwik_Login_FormResetPassword();
 		if($form->validate())
 		{
-			$loginMail = $form->getSubmitValue('form_login');
-			$token = $form->getSubmitValue('form_token');
-			$password = $form->getSubmitValue('form_password');
-			$messageNoAccess = $this->resetPasswordFormValidated($loginMail, $token, $password);
+			$nonce = $form->getSubmitValue('form_nonce');
+			if(Piwik_Nonce::verifyNonce('Piwik_Login.login', $nonce))
+			{
+				$loginMail = $form->getSubmitValue('form_login');
+				$token = $form->getSubmitValue('form_token');
+				$password = $form->getSubmitValue('form_password');
+				$messageNoAccess = $this->resetPasswordFormValidated($loginMail, $token, $password);
+			}
+			else
+			{
+				$messageNoAccess = $this->getMessageExceptionNoAccess();
+			}
 		}
 
 		$view = Piwik_View::factory('resetPassword');
 		$view->AccessErrorString = $messageNoAccess;
-		$view->forceSslLogin = Zend_Registry::get('config')->General->force_ssl_login;
+		$view->forceSslLogin = Piwik_Config::getInstance()->General['force_ssl_login'];
 		$view->addForm( $form );
 		$this->configureView($view);
 		echo $view->render();
@@ -244,6 +300,7 @@ class Piwik_Login_Controller extends Piwik_Controller
 	 * @param string $loginMail user name or email address
 	 * @param string $token password reset token
 	 * @param string $password new password
+	 * @throws Exception
 	 * @return string failure message
 	 */
 	protected function resetPasswordFormValidated($loginMail, $token, $password)
@@ -262,14 +319,16 @@ class Piwik_Login_Controller extends Piwik_Controller
 		$view = Piwik_View::factory('passwordchanged');
 		try
 		{
-			if( $user['email'] == Zend_Registry::get('config')->superuser->email )
+			if( $user['email'] == Piwik::getSuperUserEmail() )
 			{
-    			if(!Zend_Registry::get('config')->isFileWritable())
-    			{
-    				throw new Exception(Piwik_Translate('General_ConfigFileIsNotWritable', array("(config/config.ini.php)","<br/>")));
-    			}
+				if(!Piwik_Config::getInstance()->isFileWritable())
+				{
+					throw new Exception(Piwik_Translate('General_ConfigFileIsNotWritable', array("(config/config.ini.php)","<br/>")));
+				}
+
 				$user['password'] = md5($password);
-				Zend_Registry::get('config')->superuser = $user;
+				Piwik_Config::getInstance()->superuser = $user;
+				Piwik_Config::getInstance()->forceSave();
 			}
 			else
 			{
@@ -282,9 +341,7 @@ class Piwik_Login_Controller extends Piwik_Controller
 		}
 
 		$this->configureView($view);
-		
 		echo $view->render();
-
 		exit;
 	}
 
@@ -299,13 +356,13 @@ class Piwik_Login_Controller extends Piwik_Controller
 		Piwik::setUserIsSuperUser();
 
 		$user = null;
-		if( $loginMail == Zend_Registry::get('config')->superuser->email
-			|| $loginMail == Zend_Registry::get('config')->superuser->login )
+		if( $loginMail == Piwik::getSuperUserEmail()
+			|| $loginMail == Piwik_Config::getInstance()->superuser['login'] )
 		{
 			$user = array(
-					'login' => Zend_Registry::get('config')->superuser->login,
-					'email' => Zend_Registry::get('config')->superuser->email,
-					'password' => Zend_Registry::get('config')->superuser->password,
+					'login' => Piwik_Config::getInstance()->superuser['login'],
+					'email' => Piwik::getSuperUserEmail(),
+					'password' => Piwik_Config::getInstance()->superuser['password'],
 			);
 		}
 		else if( Piwik_UsersManager_API::getInstance()->userExists($loginMail) )
@@ -330,7 +387,7 @@ class Piwik_Login_Controller extends Piwik_Controller
 	protected function generatePasswordResetToken($user, $timestamp = null)
 	{
 		/*
-		 * Piwik does not stored the generated password reset token.
+		 * Piwik does not store the generated password reset token.
 		 * This avoids a database schema change and SQL queries to store, retrieve, and purge (expired) tokens.
 		 */
 		if(!$timestamp)
@@ -339,7 +396,10 @@ class Piwik_Login_Controller extends Piwik_Controller
 		}
 
 		$expiry = strftime('%Y%m%d%H', $timestamp); 
-		$token = md5($expiry . $user['login'] . $user['email'] . $user['password']);
+		$token = $this->generateHash(
+			$expiry . $user['login'] . $user['email'],
+			$user['password']
+		);
 		return $token;
 	}
 
@@ -376,12 +436,11 @@ class Piwik_Login_Controller extends Piwik_Controller
 	 */
 	static public function clearSession()
 	{
-		$authCookieName = Zend_Registry::get('config')->General->login_cookie_name;
+		$authCookieName = Piwik_Config::getInstance()->General['login_cookie_name'];
 		$cookie = new Piwik_Cookie($authCookieName);
 		$cookie->delete();
 
 		Piwik_Session::expireSessionCookie();
-		Piwik_Session::regenerateId();
 	}
 
 	/**
@@ -404,18 +463,15 @@ class Piwik_Login_Controller extends Piwik_Controller
 	 */
 	protected function checkForceSslLogin()
 	{
-		$forceSslLogin = Zend_Registry::get('config')->General->force_ssl_login;
-		if($forceSslLogin)
+		$forceSslLogin = Piwik_Config::getInstance()->General['force_ssl_login'];
+		if($forceSslLogin
+			&& !Piwik::isHttps())
 		{
-			$reverseProxy = Zend_Registry::get('config')->General->reverse_proxy;
-			if(!(Piwik_Url::getCurrentScheme() == 'https' || $reverseProxy))
-			{
-				$url = 'https://'
-					. Piwik_Url::getCurrentHost()
-					. Piwik_Url::getCurrentScriptName()
-					. Piwik_Url::getCurrentQueryString();
-				Piwik_Url::redirectToUrl($url);
-			}
+			$url = 'https://'
+				. Piwik_Url::getCurrentHost()
+				. Piwik_Url::getCurrentScriptName()
+				. Piwik_Url::getCurrentQueryString();
+			Piwik_Url::redirectToUrl($url);
 		}
 	}
 }
