@@ -15,7 +15,7 @@ function setRowData (idsite, visits, actions, revenue, name, url, visitsSummaryV
 	this.actions = actions;
 	this.visitsSummaryValue = parseFloat(visitsSummaryValue);
 	this.actionsSummaryValue = parseFloat(actionsSummaryValue);
-	this.revenueSummaryValue = parseFloat(revenueSummaryValue);
+	this.revenueSummaryValue = parseFloat(revenueSummaryValue) || 0;
 }
 
 function setOrderBy(self, allSites, params, mOrderBy)
@@ -94,11 +94,10 @@ function orderBy(allSites, params)
 	else if(params['mOrderBy'] == 'revenue')
 	{
 		allSites.sort(function (a,b) {
-			if (a['revenue'].replace(/[^0-9\.]+/g,"") == b['revenue'].replace(/[^0-9\.]+/g,"")) {
-				return 0;
-			}
-			return (parseFloat(a['revenue'].replace(/[^0-9\.]+/g,"")) 
-						< parseFloat(b['revenue'].replace(/[^0-9\.]+/g,""))) ? -1 : 1;
+			var lhs = parseFloat(a['revenue'].replace(/[^0-9\.]+/g,"")) || 0,
+				rhs = parseFloat(b['revenue'].replace(/[^0-9\.]+/g,"")) || 0;
+
+			return lhs === rhs ? 0 : ((lhs < rhs) ? -1 : 1);
 		});
 	}
 	else if(params['mOrderBy'] == 'revenueSummary')
@@ -191,7 +190,12 @@ function getSparklineImg(id, column, params)
 	if(column != 'revenue') {
 		column = 'nb_' + column;
 	}
-	return '<img class="sparkline" alt="" src="?module=MultiSites&action=getEvolutionGraph&period=' + params['period'] + '&date=' + params['dateSparkline']  + '&evolutionBy=' + params['evolutionBy'] + '&columns=' + column  + '&idSite=' + id + '&idsite=' + id + '&viewDataTable=sparkline" width="100" height="25" />';
+	var append = '';
+	var token_auth = broadcast.getValueFromUrl('token_auth');
+	if(token_auth.length) {
+		append = '&token_auth=' + token_auth;
+	}
+	return '<img class="sparkline" alt="" src="?module=MultiSites&action=getEvolutionGraph&period=' + params['period'] + '&date=' + params['dateSparkline']  + '&evolutionBy=' + params['evolutionBy'] + '&columns=' + column  + '&idSite=' + id + '&idsite=' + id + '&viewDataTable=sparkline'+ append +'" width="100" height="25" />';
 }
 
 function showPagination(allSites, params)
@@ -233,7 +237,7 @@ function getImageForSummary(value)
 {
 	if(value > 0)
 	{
-		return '<img src="plugins/MultiSites/images/arrow_up.png" alt="" /> <b style="color: green;">' + value + ' %</b>';
+		return '<img src="plugins/MultiSites/images/arrow_up.png" alt="" /> <b style="color: green;">' + value + '&nbsp;%</b>';
 	}
 	else if(value == 0)
 	{
@@ -241,7 +245,7 @@ function getImageForSummary(value)
 	}
 	else
 	{
-		return '<img src="plugins/MultiSites/images/arrow_down.png" alt="" /> <b style="color: red;">' + value +' %</b>';
+		return '<img src="plugins/MultiSites/images/arrow_down.png" alt="" /> <b style="color: red;">' + value +'&nbsp;%</b>';
 	}
 }
 
