@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 5296 2011-10-14 02:52:44Z matt $
+ * @version $Id: API.php 6243 2012-05-02 22:08:23Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_PDFReports
@@ -47,18 +47,23 @@ class Piwik_PDFReports_API
 	 * 
 	 * @param int $idSite 
 	 * @param string $description Report description
-	 * @param string $period Schedule frequency: day, week or month 
-	 * @param bool $sendToMe
-	 * @param string $additionalEmails Comma separated list of emails
+	 * @param string $period Schedule frequency: day, week or month
+	 * @param string $reportFormat 'pdf' or 'html'
+	 * @return int $displayFormat see Piwik_PDFReports_API::getDisplayFormats()
 	 * @param string $reports Comma separated list of reports
+	 * @param bool $emailMe
+	 * @param string $additionalEmails Comma separated list of emails
+	 *
 	 * @return int idReport generated
 	 */
-	public function addReport( $idSite, $description, $period, $reportFormat, $reports, $emailMe = true, $additionalEmails = false)
+	public function addReport( $idSite, $description, $period, $reportFormat, $displayFormat, $reports, $emailMe = true, $additionalEmails = false)
 	{
 		Piwik::checkUserIsNotAnonymous();
 		Piwik::checkUserHasViewAccess($idSite);
+
 		$this->checkPeriod($period);
 		$this->checkFormat($reportFormat);
+		$this->checkDisplayFormat($displayFormat);
 		$description = $this->checkDescription($description);
 		$currentUser = Piwik::getCurrentUserLogin();
 		$emailMe = (int)$emailMe;
@@ -83,6 +88,7 @@ class Piwik_PDFReports_API
 						'description' => $description,
 						'period' => $period,
 						'format' => $reportFormat,
+						'display_format' => $displayFormat,
 						'email_me' => $emailMe,
 						'additional_emails' => $additionalEmails,
 						'reports' => $reports,
@@ -106,15 +112,18 @@ class Piwik_PDFReports_API
 	 * 
 	 * @see addReport()
 	 */
-	public function updateReport( $idReport, $idSite, $description, $period, $reportFormat, $reports, $emailMe = true, $additionalEmails = false)
+	public function updateReport( $idReport, $idSite, $description, $period, $reportFormat, $displayFormat, $reports, $emailMe = true, $additionalEmails = false)
 	{
+		Piwik::checkUserIsNotAnonymous();
 		Piwik::checkUserHasViewAccess($idSite);
+
 		$pdfReports = $this->getReports($idSite, $periodSearch = false, $idReport);
 		$report = reset($pdfReports);
 		$idReport = $report['idreport'];
 		
 		$this->checkPeriod($period);
 		$this->checkFormat($reportFormat);
+		$this->checkDisplayFormat($displayFormat);
 		$description = $this->checkDescription($description);
 		$currentUser = Piwik::getCurrentUserLogin();
 		$emailMe = (int)$emailMe;
@@ -130,6 +139,7 @@ class Piwik_PDFReports_API
 						'description' => $description,
 						'period' => $period,
 						'format' => $reportFormat,
+						'display_format' => $displayFormat,
 						'email_me' => $emailMe,
 						'additional_emails' => $additionalEmails,
 						'reports' => $reports,
@@ -168,10 +178,13 @@ class Piwik_PDFReports_API
 	 * @param int $idSite If specified, will filter reports that belong to a specific idsite
 	 * @param string $period If specified, will filter reports that are scheduled for this period (day,week,month)
 	 * @param int $idReport If specified, will filter the report that has the given idReport 
+	 * @return array
 	 * @throws Exception if $idReport was specified but the report wasn't found
 	 */
 	public function getReports($idSite = false, $period = false, $idReport = false, $ifSuperUserReturnOnlySuperUserReports = false)
 	{
+		Piwik::checkUserIsNotAnonymous();
+
 		$cacheKey = (int)$idSite .'.'. (string)$period .'.'. (int)$idReport .'.'. (int)$ifSuperUserReturnOnlySuperUserReports;
 		if(isset(self::$cache[$cacheKey]))
 		{
@@ -209,14 +222,14 @@ class Piwik_PDFReports_API
 		
 		// Joining with the site table to work around pre-1.3 where reports could still be linked to a deleted site
 		$reports = Piwik_FetchAll("SELECT * 
-    							FROM ".Piwik_Common::prefixTable('pdf')." 
-    								JOIN ".Piwik_Common::prefixTable('site')."
-    								USING (idsite)
-    							WHERE deleted = 0
-    								$sqlWhere", $bind);
-    	// When a specific report was requested and not found, throw an error
-    	if($idReport !== false
-    		&& empty($reports))
+								FROM ".Piwik_Common::prefixTable('pdf')."
+									JOIN ".Piwik_Common::prefixTable('site')."
+									USING (idsite)
+								WHERE deleted = 0
+									$sqlWhere", $bind);
+		// When a specific report was requested and not found, throw an error
+		if($idReport !== false
+			&& empty($reports))
 		{
 			throw new Exception("Requested report couldn't be found.");
 		}
@@ -225,36 +238,38 @@ class Piwik_PDFReports_API
 		
 		return $reports;
 	}
-	
-    /**
+
+	/**
 	 * Generates a report file.
 	 *
-     * @param int $idReport ID of the report to generate. If idReport=0 it will generate a report containing all reports
+	 * @param int $idReport ID of the report to generate. If idReport=0 it will generate a report containing all reports
 	 * for the specified period & date
-     * @param string $date YYYY-MM-DD
-	 * @param int|false $idSite
-	 * @param string|false $language If not passed, will use default language.
-	 * @param int|false $outputType 1 = download report, 2 = save report to disk, defaults to download
-	 * @param string|false $period Defaults to 'day'. If not specified, will default to the report's period set when creating the report
-	 * @param string $reportFormat pdf, html
+	 * @param string $date YYYY-MM-DD
+	 * @param bool|false|int $idSite
+	 * @param bool|false|string $language If not passed, will use default language.
+	 * @param bool|false|int $outputType 1 = download report, 2 = save report to disk, defaults to download
+	 * @param bool|false|string $period Defaults to 'day'. If not specified, will default to the report's period set when creating the report
+	 * @param bool|string $reportFormat pdf, html
+	 * @param bool|false|int $displayFormat see Piwik_PDFReports_API::getDisplayFormats()
+	 * @return array
 	 */
-	public function generateReport($idReport, $date, $idSite = false, $language = false, $outputType = false, $period = false, $reportFormat = false)
+	public function generateReport($idReport, $date, $idSite = false, $language = false, $outputType = false, $period = false, $reportFormat = false, $displayFormat = false)
 	{
+		Piwik::checkUserIsNotAnonymous();
+
 		// Load specified language
 		if(empty($language))
 		{
 			$language = Piwik_Translate::getInstance()->getLanguageDefault();
 		}
-    	Piwik_Translate::getInstance()->reloadLanguage($language);
-		
-		// Available reports
-		static $reportMetadata = null;
-		if(is_null($reportMetadata))
-		{
-			//TODO here should pass $period and $date for graphs to display in metadata and then in Email reports. 
-			$reportMetadata = Piwik_API_API::getInstance()->getReportMetadata($idSite);
-		}
+		Piwik_Translate::getInstance()->reloadLanguage($language);
 
+		// Available reports
+		$reportMetadata = Piwik_API_API::getInstance()->getReportMetadata($idSite);
+
+		// User who created this report
+		$userLogin = false;
+		
 		// Test template: include all reports
 		if($idReport == 0)
 		{
@@ -266,7 +281,20 @@ class Piwik_PDFReports_API
 			{
 				$reportFormat = Piwik_PDFReports::DEFAULT_FORMAT;
 			}
-			$reports = $reportMetadata;
+			if(empty($displayFormat))
+			{
+				$displayFormat = Piwik_PDFReports::DEFAULT_DISPLAY_FORMAT;
+			}
+
+			$reports = array();
+			foreach($reportMetadata as $report)
+			{
+				if($report['category'] != 'API')
+				{
+					$reports[] = $report;
+				}
+			}
+
 			$description = Piwik_Translate('PDFReports_DefaultContainingAllReports');
 		}
 		// Template is a custom template
@@ -274,21 +302,23 @@ class Piwik_PDFReports_API
 		{
 			$pdfReports = $this->getReports($idSite, $_period = false, $idReport);
 			$pdfReport = reset($pdfReports);
+			
+			$userLogin = $pdfReport['login'];
 			$reportUniqueIds = explode(',', $pdfReport['reports']);
-			
-    		$description = $pdfReport['description'];
-			
-    		// If period wasn't specified, we shall default to the report's period
-    		if(empty($period))
-    		{
-    			$period = 'day';
-    			if($pdfReport['period'] != 'never')
+
+			$description = $pdfReport['description'];
+
+			// If period wasn't specified, we shall default to the report's period
+			if(empty($period))
+			{
+				$period = 'day';
+				if($pdfReport['period'] != 'never')
 				{
 					$period = $pdfReport['period'];
 				}
-    		}
+			}
 
-    		// If format wasn't specified, defaults to the report's format
+			// If format wasn't specified, defaults to the report's format
 			if(empty($reportFormat))
 			{
 				$reportFormat = $pdfReport['format'];
@@ -299,85 +329,166 @@ class Piwik_PDFReports_API
 				}
 			}
 
-    		// We need to lookup which reports metadata are registered in this report
-    		$reports = array();
-    		foreach($reportMetadata as $metadata)
-    		{
-    			if(in_array($metadata['uniqueId'], $reportUniqueIds))
-    			{
-    				$reports[] = $metadata;
-    			}
-    		}
+    		// If $displayFormat wasn't specified, defaults to the report configuration
+			if(empty($displayFormat))
+			{
+				$displayFormat = $pdfReport['display_format'];
+			}
+
+			// We need to lookup which reports metadata are registered in this report
+			$reports = array();
+			foreach($reportMetadata as $metadata)
+			{
+				if(in_array($metadata['uniqueId'], $reportUniqueIds))
+				{
+					$reports[] = $metadata;
+				}
+			}
+			
 		}
 
+		// prepare the report renderer
+		$reportRenderer = Piwik_ReportRenderer::factory($reportFormat);
+		$reportRenderer->setLocale($language);
+		$reportRenderer->setRenderImageInline($outputType == self::OUTPUT_DOWNLOAD ? true : false);
+
 		$description = str_replace(array("\r", "\n"), ' ', $description);
 
-		// The report will be rendered with the first 30 rows and will aggregate other rows in a summary row
-    	$filterTruncateGET = Piwik_Common::getRequestVar('filter_truncate', false);
-    	$_GET['filter_truncate'] = 30;
+		// The report will be rendered with the first 23 rows and will aggregate other rows in a summary row
+		$filterTruncateGET = Piwik_Common::getRequestVar('filter_truncate', false);
 
-    	$websiteName = $prettyDate = false;
-        $processedReports = array();
-        foreach ($reports as $action)
-        {
-        	$apiModule = $action['module'];
-        	$apiAction = $action['action'];
-        	$apiParameters = array();
-        	if(isset($action['parameters']))
-        	{
-        		$apiParameters = $action['parameters'];
-        	}
-        	$report = Piwik_API_API::getInstance()->getProcessedReport($idSite, $period, $date, $apiModule, $apiAction, $segment = false, $apiParameters, $idGoal = false, $language);
-        	$websiteName = $report['website'];
-        	$prettyDate = $report['prettyDate'];
-        	$processedReports[] = $report;
-        }
-        
-        // Restore values
-        if($filterTruncateGET !== false)
-        {
-        	$_GET['filter_truncate'] = $filterTruncateGET;
-        }
+		// 23 rows table fits in one portrait page
+		$reportTruncation = 23;
+		$_GET['filter_truncate'] = $reportTruncation;
 
-		if(empty($reportFormat))
+		$websiteName = $prettyDate = false;
+		$processedReports = array();
+		
+		foreach ($reports as $action)
 		{
-			$reportFormat = Piwik_PDFReports::DEFAULT_FORMAT;
+			$apiModule = $action['module'];
+			$apiAction = $action['action'];
+			$apiParameters = array();
+			if(isset($action['parameters']))
+			{
+				$apiParameters = $action['parameters'];
+			}
+			
+			$mustRestoreGET = false;
+			
+			// All Websites dashboard should not be truncated in the report
+			if($apiModule == 'MultiSites' && $apiAction == 'getAll')
+			{
+				$mustRestoreGET = $_GET;
+				$_GET['filter_truncate'] = false;
+				
+				// When a view/admin user created a report, workaround the fact that "Super User" 
+				// is enforced in Scheduled tasks, and ensure Multisites.getAll only return the websites that this user can access
+				if(!empty($userLogin)
+					&& $userLogin != Piwik_Config::getInstance()->superuser['login'])
+				{
+					$_GET['_restrictSitesToLogin'] = $userLogin;
+				}
+			}
+			$report = Piwik_API_API::getInstance()->getProcessedReport($idSite, $period, $date, $apiModule, $apiAction, $segment = false, $apiParameters, $idGoal = false, $language);
+			
+			if($mustRestoreGET)
+			{
+				$_GET = $mustRestoreGET;
+			}
+			$websiteName = $report['website'];
+			$prettyDate = $report['prettyDate'];
+
+			$reportMetadata = $report['metadata'];
+			$isAggregateReport = !empty($reportMetadata['dimension']);
+
+			$report['displayTable'] = $displayFormat != Piwik_PDFReports::DISPLAY_FORMAT_GRAPHS_ONLY;
+
+			$report['displayGraph'] =
+				($isAggregateReport ?
+					$displayFormat == Piwik_PDFReports::DISPLAY_FORMAT_GRAPHS_ONLY || $displayFormat == Piwik_PDFReports::DISPLAY_FORMAT_TABLES_AND_GRAPHS
+						:
+					$displayFormat != Piwik_PDFReports::DISPLAY_FORMAT_TABLES_ONLY)
+				&& Piwik::isGdExtensionEnabled()
+				&& Piwik_PluginsManager::getInstance()->isPluginActivated('ImageGraph')
+				&& !empty($reportMetadata['imageGraphUrl']);
+
+			$processedReports[] = $report;
 		}
 
-		// Generate the report
-		$reportRenderer = Piwik_ReportRenderer::factory($reportFormat);
-		$reportRenderer->setLocale($language);
-        $reportRenderer->renderFrontPage($websiteName, $prettyDate, $description, $reports );
+		// Restore values
+		if($filterTruncateGET !== false)
+		{
+			$_GET['filter_truncate'] = $filterTruncateGET;
+		}
+
+		// generate the report
+		$reportRenderer->renderFrontPage($websiteName, $prettyDate, $description, $reports );
 		array_walk($processedReports, array($reportRenderer, 'renderReport'));
 
-        switch($outputType)
-        { 
-        	case self::OUTPUT_SAVE_ON_DISK:
+		switch($outputType)
+		{
+			case self::OUTPUT_SAVE_ON_DISK:
 				$outputFilename = 'Email Report - ' . $idReport . '.' . $date . '.' . $idSite . '.' . $language;
 				$outputFilename = $reportRenderer->sendToDisk($outputFilename);
 
+				$additionalFiles = array();
+				if($reportFormat == 'html')
+				{
+					foreach ($processedReports as &$report) {
+						if($report['displayGraph'])
+						{
+							$additionalFile = array();
+							$additionalFile['filename'] = $report['metadata']['name'].'.png';
+							$additionalFile['cid'] = $report['metadata']['uniqueId'];
+							$additionalFile['content'] =
+									Piwik_ReportRenderer::getStaticGraph(
+										$report['metadata']['imageGraphUrl'],
+										Piwik_ReportRenderer_Html::IMAGE_GRAPH_WIDTH,
+										Piwik_ReportRenderer_Html::IMAGE_GRAPH_HEIGHT
+									);
+							$additionalFile['mimeType'] = 'image/png';
+							$additionalFile['encoding'] = Zend_Mime::ENCODING_BASE64;
+
+							$additionalFiles[] = $additionalFile;
+						}
+					}
+				}
+
 				return array(	$outputFilename,
 								$prettyDate,
 								$websiteName,
-								$reportFormat
+								$reportFormat,
+								$additionalFiles,
 				);
-    		break;
+			break;
 
 			default:
 			case self::OUTPUT_DOWNLOAD:
 				$reportRenderer->sendToBrowserDownload("$websiteName - $prettyDate - $description");
 				break;
-        }
+		}
 	}
 
-	public function sendEmailReport($idReport, $idSite)
+	public function sendEmailReport($idReport, $idSite, $period = false, $date = false)
 	{
-		$reports = $this->getReports($idSite, $period = false, $idReport);
+		Piwik::checkUserIsNotAnonymous();
+		$reports = $this->getReports($idSite, false, $idReport);
 		$report = reset($reports);
 		if($report['period'] == 'never')
 		{
 			$report['period'] = 'day';
 		}
+		if(!empty($period))
+		{
+			$report['period'] = $period;
+		}
+		if(empty($date))
+		{
+			$date = Piwik_Date::now()->subPeriod(1, $report['period'])->toString();
+		}
+		
+
 		// Get user emails and languages 
 		$emails = self::getEmailsFromString($report['additional_emails']);
 		if($report['email_me'] == 1)
@@ -386,7 +497,7 @@ class Piwik_PDFReports_API
 			{
 				$emails[] = Piwik::getCurrentUserEmail();
 			}
-			elseif($report['login'] == Zend_Registry::get('config')->superuser->login)
+			elseif($report['login'] == Piwik_Config::getInstance()->superuser['login'])
 			{
 				$emails[] = Piwik::getSuperUserEmail();
 			}
@@ -401,19 +512,20 @@ class Piwik_PDFReports_API
 			}
 		}
 		$language = Piwik_LanguagesManager_API::getInstance()->getLanguageForUser($report['login']);
-		list($outputFilename, $prettyDate, $websiteName, $reportFormat) =
+		list($outputFilename, $prettyDate, $websiteName, $reportFormat, $additionalFiles) =
 			$this->generateReport(
 					$idReport, 
-					Piwik_Date::now()->subPeriod(1, $report['period'])->toString(),
+					$date,
 					$idSite,
 					$language,
-					self::OUTPUT_SAVE_ON_DISK
+					self::OUTPUT_SAVE_ON_DISK,
+					$report['period']
 					);
 
-		$this->sendReportEmail($emails, $outputFilename, $prettyDate, $websiteName, $report, $reportFormat);
+		$this->sendReportEmail($emails, $outputFilename, $prettyDate, $websiteName, $report, $reportFormat, $additionalFiles);
 	}
 	
-	protected function sendReportEmail($emails, $outputFilename, $prettyDate, $websiteName, $report, $reportFormat)
+	protected function sendReportEmail($emails, $outputFilename, $prettyDate, $websiteName, $report, $reportFormat, $additionalFiles)
 	{
 		$periods = self::getPeriodToFrequency();
 		$message  = Piwik_Translate('PDFReports_EmailHello');
@@ -421,7 +533,7 @@ class Piwik_PDFReports_API
 
 		if(!file_exists($outputFilename))
 		{
-			throw new Exception("The PDF file wasn't found in $outputFilename");
+			throw new Exception("The report file wasn't found in $outputFilename");
 		}
 		$filename = basename($outputFilename);
 		$handle = fopen($outputFilename, "r");
@@ -430,14 +542,19 @@ class Piwik_PDFReports_API
 
 		$mail = new Piwik_Mail();
 		$mail->setSubject($subject);
-		$fromEmailName = Piwik_Translate('PDFReports_PiwikReports');
-		$fromEmailAddress = Zend_Registry::get('config')->General->noreply_email_address;
+		$fromEmailName = Piwik_Config::getInstance()->branding['use_custom_logo'] 
+							? Piwik_Translate('CoreHome_WebAnalyticsReports')
+							: Piwik_Translate('PDFReports_PiwikReports');
+		$fromEmailAddress = Piwik_Config::getInstance()->General['noreply_email_address'];
 		$attachmentName = $subject;
 		$mail->setFrom($fromEmailAddress, $fromEmailName);
 
 		switch ($reportFormat)
 		{
 			case 'html':
+
+				// Needed when using images as attachment with cid
+				$mail->setType(Zend_Mime::MULTIPART_RELATED);
 				$message .= "<br/>" . Piwik_Translate('PDFReports_PleaseFindBelow', array($periods[$report['period']], $websiteName));
 				$mail->setBodyHtml($message . "<br/><br/>". $contents);
 				break;
@@ -455,6 +572,21 @@ class Piwik_PDFReports_API
 				break;
 		}
 
+		foreach($additionalFiles as $additionalFile)
+		{
+			$fileContent = $additionalFile['content'];
+			$at = $mail->createAttachment(
+				$fileContent,
+				$additionalFile['mimeType'],
+				Zend_Mime::DISPOSITION_INLINE,
+				$additionalFile['encoding'],
+				$additionalFile['filename']
+			);
+			$at->id = $additionalFile['cid'];
+
+			unset($fileContent);
+		}
+
 		foreach ($emails as $email)
 		{
 			$mail->addTo($email);
@@ -467,8 +599,8 @@ class Piwik_PDFReports_API
 				if(!isset($GLOBALS['PIWIK_TRACKER_DEBUG']) || !$GLOBALS['PIWIK_TRACKER_DEBUG'])
 				{
 					throw new Exception("An error occured while sending '$filename' ".
-										" to ". implode(', ',$mail->getRecipients()). ".
-    								Error was '". $e->getMessage()."'");
+										" to ". implode(', ',$mail->getRecipients()). 
+									". Error was '". $e->getMessage()."'");
 				}
 			}
 			$mail->clearRecipients();
@@ -566,6 +698,21 @@ class Piwik_PDFReports_API
 		}
 	}
 
+	private function checkDisplayFormat($format)
+	{
+		$availableDisplayFormats = array_keys(Piwik_PDFReports_API::getDisplayFormats());
+		if(!in_array($format, $availableDisplayFormats))
+		{
+			throw new Exception(
+				Piwik_TranslateException(
+					// General_ExceptionInvalidAggregateReportsFormat should be named General_ExceptionInvalidDisplayFormat
+					'General_ExceptionInvalidAggregateReportsFormat',
+					array($format, implode(', ', $availableDisplayFormats))
+				)
+			);
+		}
+	}
+
 	/**
 	 * @ignore
 	 */
@@ -575,6 +722,24 @@ class Piwik_PDFReports_API
 			'day' => Piwik_Translate('General_Daily'),
 			'week' => Piwik_Translate('General_Weekly'),
 			'month' => Piwik_Translate('General_Monthly'),
+			'range' => Piwik_Translate('General_DateRangeInPeriodList'),
+		);
+		return $periods;
+	}
+
+	/**
+	 * @ignore
+	 */
+	static public function getDisplayFormats()
+	{
+		$periods = array(
+			// PDFReports_AggregateReportsFormat_TablesOnly should be named PDFReports_DisplayFormat_GraphsOnlyForKeyMetrics
+			Piwik_PDFReports::DISPLAY_FORMAT_GRAPHS_ONLY_FOR_KEY_METRICS => Piwik_Translate('PDFReports_AggregateReportsFormat_TablesOnly'),
+			// PDFReports_AggregateReportsFormat_GraphsOnly should be named PDFReports_DisplayFormat_GraphsOnly
+			Piwik_PDFReports::DISPLAY_FORMAT_GRAPHS_ONLY => Piwik_Translate('PDFReports_AggregateReportsFormat_GraphsOnly'),
+			// PDFReports_AggregateReportsFormat_TablesAndGraphs should be named PDFReports_DisplayFormat_TablesAndGraphs
+			Piwik_PDFReports::DISPLAY_FORMAT_TABLES_AND_GRAPHS => Piwik_Translate('PDFReports_AggregateReportsFormat_TablesAndGraphs'),
+			Piwik_PDFReports::DISPLAY_FORMAT_TABLES_ONLY => Piwik_Translate('PDFReports_DisplayFormat_TablesOnly'),
 		);
 		return $periods;
 	}
