@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: PDFReports.php 5277 2011-10-10 04:41:52Z vipsoft $
+ * @version $Id: PDFReports.php 6243 2012-05-02 22:08:23Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_PDFReports
@@ -18,6 +18,12 @@ class Piwik_PDFReports extends Piwik_Plugin
 {
 	const DEFAULT_FORMAT = 'pdf';
 
+	const DISPLAY_FORMAT_GRAPHS_ONLY_FOR_KEY_METRICS = 1; // Display Tables Only (Graphs only for key metrics)
+	const DISPLAY_FORMAT_GRAPHS_ONLY = 2; // Display Graphs Only for all reports
+	const DISPLAY_FORMAT_TABLES_AND_GRAPHS = 3; // Display Tables and Graphs for all reports
+	const DISPLAY_FORMAT_TABLES_ONLY = 4; // Display only tables for all reports
+	const DEFAULT_DISPLAY_FORMAT = Piwik_PDFReports::DISPLAY_FORMAT_GRAPHS_ONLY_FOR_KEY_METRICS;
+
 	public function getInformation()
 	{
 		return array(
@@ -42,7 +48,7 @@ class Piwik_PDFReports extends Piwik_Plugin
 	/**
 	 * Delete reports for the website
 	 *
-	 * @param Event_Notification $notification
+	 * @param Piwik_Event_Notification $notification  notification object
 	 */
 	function deleteSiteReport( $notification )
 	{
@@ -56,13 +62,19 @@ class Piwik_PDFReports extends Piwik_Plugin
 			Piwik_PDFReports_API::getInstance()->deleteReport($idReport);
 		}
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	function getJsFiles( $notification )
 	{
 		$jsFiles = &$notification->getNotificationObject();
 		$jsFiles[] = "plugins/PDFReports/templates/pdf.js";
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	function getScheduledTasks ( $notification )
 	{
 		// Reports have to be sent when the period ends for all websites
@@ -133,7 +145,10 @@ class Piwik_PDFReports extends Piwik_Plugin
     {
     	Piwik_AddTopMenu( 'PDFReports_EmailReports', array('module' => 'PDFReports', 'action' => 'index'), true, 13);
     }
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
     function deleteUserReport($notification)
 	{
 		$userLogin = $notification->getNotificationObject();
@@ -150,6 +165,7 @@ class Piwik_PDFReports extends Piwik_Plugin
 					description VARCHAR(255) NOT NULL,
 					period VARCHAR(10) NULL,
 					format VARCHAR(10),
+					display_format TINYINT(1) NOT NULL,
 					email_me TINYINT NULL,
 					additional_emails TEXT NULL,
 					reports TEXT NOT NULL,
