@@ -20,17 +20,17 @@ $(document).ready(function() {
 				$('#SeoRanks').html(response);
 			},
 			data: { 
-					module: 'SEO',
-					action :'getRank',
-					url: encodeURIComponent( $('#seoUrl').val() ), 
-					idSite: piwik.idSite
-				}
+				module: 'SEO',
+				action :'getRank',
+				url: encodeURIComponent( $('#seoUrl').val() ), 
+				idSite: piwik.idSite
+			}
 		};
 		piwikHelper.queueAjaxRequest( $.ajax( ajaxRequest ) );
 	}  
 	
 	// click on Rank button
-	$('#rankbutton').bind('click', function() {
+	$('#rankbutton').on('click', function() {
 		getRank();
 		return false ;
 	});
