@@ -26,13 +26,13 @@ class PhpSecInfo_Test_Application_Php extends PhpSecInfo_Test_Application
 	var $recommended_value = null;
 
 	function _retrieveCurrentValue() {
-		$this->current_value = phpversion();;
+		$this->current_value = PHP_VERSION;
 
 		$url = 'http://php.net/releases/?serialize=1&version=5';
 		$timeout = Piwik_UpdateCheck::SOCKET_TIMEOUT;
 		try {
 			$latestVersion = Piwik_Http::sendHttpRequest($url, $timeout);
-			$versionInfo = Piwik_Common::unserialize_array($latestVersion);
+			$versionInfo = safe_unserialize($latestVersion);
 			$this->recommended_value = $versionInfo['version'];
 		} catch(Exception $e) {
 			$this->recommended_value = '';
@@ -58,7 +58,10 @@ class PhpSecInfo_Test_Application_Php extends PhpSecInfo_Test_Application
 	function _setMessages() {
 		parent::_setMessages();
 
-		$this->setMessageForResult(PHPSECINFO_TEST_RESULT_OK, 'en', "You are running PHP ".$this->recommended_value." (the latest version).");
+		$this->setMessageForResult(PHPSECINFO_TEST_RESULT_OK, 'en', "You are running PHP ".$this->current_value.
+			($this->current_value == $this->recommended_value
+			? " (the latest version)."
+			: ".  The latest version is ".$this->recommended_value."."));
 		$this->setMessageForResult(PHPSECINFO_TEST_RESULT_NOTICE, 'en', "You are running PHP ".$this->current_value.".  The latest version of PHP is ".$this->recommended_value.".");
 		$this->setMessageForResult(PHPSECINFO_TEST_RESULT_WARN, 'en', "You are running PHP ".$this->current_value." which is really old. We recommend running the latest (stable) version of PHP which includes numerous bug fixes and security fixes.");
 		$this->setMessageForResult(PHPSECINFO_TEST_RESULT_ERROR, 'en', "Unable to determine the latest version of PHP available.");
