@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: UserCountry.php 5138 2011-09-07 15:25:57Z EZdesign $
+ * @version $Id: UserCountry.php 6243 2012-05-02 22:08:23Z SteveG $
  *
  * @category Piwik_Plugins
  * @package Piwik_UserCountry
@@ -26,7 +26,7 @@ class Piwik_UserCountry extends Piwik_Plugin
 		);
 		return $info;
 	}
-	
+
 	function getListHooksRegistered()
 	{
 		$hooks = array(
@@ -36,7 +36,7 @@ class Piwik_UserCountry extends Piwik_Plugin
 			'Menu.add' => 'addMenu',
 			'Goals.getReportsWithGoalMetrics' => 'getReportsWithGoalMetrics',
 			'API.getReportMetadata' => 'getReportMetadata',
-		    'API.getSegmentsMetadata' => 'getSegmentsMetadata',
+			'API.getSegmentsMetadata' => 'getSegmentsMetadata',
 		);
 		return $hooks;
 	}
@@ -46,106 +46,131 @@ class Piwik_UserCountry extends Piwik_Plugin
 		Piwik_AddWidget( 'General_Visitors', 'UserCountry_WidgetContinents', 'UserCountry', 'getContinent');
 		Piwik_AddWidget( 'General_Visitors', 'UserCountry_WidgetCountries', 'UserCountry', 'getCountry');
 	}
-	
+
 	function addMenu()
 	{
 		Piwik_AddMenu('General_Visitors', 'UserCountry_SubmenuLocations', array('module' => 'UserCountry', 'action' => 'index'));
 	}
-	
 
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getSegmentsMetadata($notification)
 	{
 		$segments =& $notification->getNotificationObject();
 		$segments[] = array(
-		        'type' => 'dimension',
-		        'category' => 'Visit',
-		        'name' => Piwik_Translate('UserCountry_Country'),
-		        'segment' => 'country',
-		        'sqlSegment' => 'log_visit.location_country',
-				'acceptedValues' => 'de, us, fr, in, es, etc.'
-       );
-       $segments[] = array(
-		        'type' => 'dimension',
-		        'category' => 'Visit',
-		        'name' => Piwik_Translate('UserCountry_Continent'),
-		        'segment' => 'continent',
-		        'sqlSegment' => 'log_visit.location_continent',
-				'acceptedValues' => 'eur, asi, amc, amn, ams, afr, ant, oce'
+			'type' => 'dimension',
+			'category' => 'Visit',
+			'name' => Piwik_Translate('UserCountry_Country'),
+			'segment' => 'country',
+			'sqlSegment' => 'log_visit.location_country',
+			'acceptedValues' => 'de, us, fr, in, es, etc.',
+		);
+		$segments[] = array(
+			'type' => 'dimension',
+			'category' => 'Visit',
+			'name' => Piwik_Translate('UserCountry_Continent'),
+			'segment' => 'continent',
+			'sqlSegment' => 'log_visit.location_continent',
+			'acceptedValues' => 'eur, asi, amc, amn, ams, afr, ant, oce',
 		);
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	public function getReportMetadata($notification)
 	{
+		$metrics = array(
+			'nb_visits' => Piwik_Translate('General_ColumnNbVisits'),
+			'nb_uniq_visitors' => Piwik_Translate('General_ColumnNbUniqVisitors'),
+			'nb_actions' => Piwik_Translate('General_ColumnNbActions'),
+		);
+
 		$reports = &$notification->getNotificationObject();
+
 		$reports[] = array(
 			'category' => Piwik_Translate('General_Visitors'),
 			'name' => Piwik_Translate('UserCountry_Country'),
 			'module' => 'UserCountry',
 			'action' => 'getCountry',
 			'dimension' => Piwik_Translate('UserCountry_Country'),
-        	'order' => 5,
+			'metrics' => $metrics,
+			'order' => 5,
 		);
-		
+
 		$reports[] = array(
 			'category' => Piwik_Translate('General_Visitors'),
 			'name' => Piwik_Translate('UserCountry_Continent'),
 			'module' => 'UserCountry',
 			'action' => 'getContinent',
-        	'dimension' => Piwik_Translate('UserCountry_Continent'),
-        	'order' => 6,
+			'dimension' => Piwik_Translate('UserCountry_Continent'),
+			'metrics' => $metrics,
+			'order' => 6,
 		);
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 */
 	function getReportsWithGoalMetrics( $notification )
 	{
 		$dimensions =& $notification->getNotificationObject();
 		$dimensions = array_merge($dimensions, array(
-        		array(	'category'  => Piwik_Translate('General_Visit'),
-            			'name'   => Piwik_Translate('UserCountry_Country'),
-            			'module' => 'UserCountry',
-            			'action' => 'getCountry',
-        		),
-        		array(	'category'  => Piwik_Translate('General_Visit'),
-            			'name'   => Piwik_Translate('UserCountry_Continent'),
-            			'module' => 'UserCountry',
-            			'action' => 'getContinent',
-        		),
-    	));
+			array(	'category'  => Piwik_Translate('General_Visit'),
+				'name'   => Piwik_Translate('UserCountry_Country'),
+				'module' => 'UserCountry',
+				'action' => 'getCountry',
+			),
+			array(	'category'  => Piwik_Translate('General_Visit'),
+				'name'   => Piwik_Translate('UserCountry_Continent'),
+				'module' => 'UserCountry',
+				'action' => 'getContinent',
+			),
+		));
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 * @return mixed
+	 */
 	function archivePeriod( $notification )
 	{
 		/**
 		 * @param Piwik_ArchiveProcessing_Period  $archiveProcessing
 		 */
 		$archiveProcessing = $notification->getNotificationObject();
-		
+
 		if(!$archiveProcessing->shouldProcessReportsForPlugin($this->getPluginName())) return;
-		
+
 		$dataTableToSum = array(
-				'UserCountry_country',
-				'UserCountry_continent',
+			'UserCountry_country',
+			'UserCountry_continent',
 		);
-		
+
 		$nameToCount = $archiveProcessing->archiveDataTable($dataTableToSum);
 		$archiveProcessing->insertNumericRecord('UserCountry_distinctCountries',
 												$nameToCount['UserCountry_country']['level0']);
 	}
-	
+
+	/**
+	 * @param Piwik_Event_Notification $notification  notification object
+	 * @return mixed
+	 */
 	function archiveDay($notification)
 	{
 		/**
 		 * @var Piwik_ArchiveProcessing
 		 */
 		$archiveProcessing = $notification->getNotificationObject();
-		
+
 		if(!$archiveProcessing->shouldProcessReportsForPlugin($this->getPluginName())) return;
-		
+
 		$this->archiveDayAggregateVisits($archiveProcessing);
 		$this->archiveDayAggregateGoals($archiveProcessing);
 		$this->archiveDayRecordInDatabase($archiveProcessing);
 	}
-	
+
 	/**
 	 * @param Piwik_ArchiveProcessing_Day $archiveProcessing
 	 */
@@ -153,11 +178,11 @@ class Piwik_UserCountry extends Piwik_Plugin
 	{
 		$labelSQL = "log_visit.location_country";
 		$this->interestByCountry = $archiveProcessing->getArrayInterestForLabel($labelSQL);
-		
+
 		$labelSQL = "log_visit.location_continent";
 		$this->interestByContinent = $archiveProcessing->getArrayInterestForLabel($labelSQL);
 	}
-	
+
 	/**
 	 * @param Piwik_ArchiveProcessing_Day $archiveProcessing
 	 */
@@ -166,7 +191,7 @@ class Piwik_UserCountry extends Piwik_Plugin
 		$query = $archiveProcessing->queryConversionsByDimension(array("location_continent","location_country"));
 
 		if($query === false) return;
-		
+
 		while($row = $query->fetch() )
 		{
 			if(!isset($this->interestByCountry[$row['location_country']][Piwik_Archive::INDEX_GOALS][$row['idgoal']])) $this->interestByCountry[$row['location_country']][Piwik_Archive::INDEX_GOALS][$row['idgoal']] = $archiveProcessing->getNewGoalRow($row['idgoal']);
@@ -177,7 +202,7 @@ class Piwik_UserCountry extends Piwik_Plugin
 		$archiveProcessing->enrichConversionsByLabelArray($this->interestByCountry);
 		$archiveProcessing->enrichConversionsByLabelArray($this->interestByContinent);
 	}
-	
+
 	/**
 	 * @param Piwik_ArchiveProcessing_Day $archiveProcessing
 	 */
@@ -187,10 +212,9 @@ class Piwik_UserCountry extends Piwik_Plugin
 		$archiveProcessing->insertBlobRecord('UserCountry_country', $tableCountry->getSerialized());
 		$archiveProcessing->insertNumericRecord('UserCountry_distinctCountries', $tableCountry->getRowsCount());
 		destroy($tableCountry);
-		
+
 		$tableContinent = $archiveProcessing->getDataTableFromArray($this->interestByContinent);
 		$archiveProcessing->insertBlobRecord('UserCountry_continent', $tableContinent->getSerialized());
 		destroy($tableContinent);
 	}
-
 }
