@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: API.php 4643 2011-05-05 21:26:21Z matt $
+ * @version $Id: API.php 6243 2012-05-02 22:08:23Z SteveG $
  * 
  * @category Piwik_Plugins
  * @package Piwik_UsersManager
@@ -26,14 +26,15 @@
 class Piwik_UsersManager_API 
 {
 	static private $instance = null;
-	
+
 	/**
-	 * You can create your own Users Plugin to override this class. 
+	 * You can create your own Users Plugin to override this class.
 	 * Example of how you would overwrite the UsersManager_API with your own class:
 	 * Call the following in your plugin __construct() for example:
-	 * 
+	 *
 	 * Zend_Registry::set('UsersManager_API',Piwik_MyCustomUsersManager_API::getInstance());
-	 * 
+	 *
+	 * @throws Exception
 	 * @return Piwik_UsersManager_API
 	 */
 	static public function getInstance()
@@ -67,13 +68,12 @@ class Piwik_UsersManager_API
 		Piwik::checkUserIsSuperUserOrTheUser($userLogin);
 		Piwik_SetOption($this->getPreferenceId($userLogin, $preferenceName), $preferenceValue);
 	}
-	
+
 	/**
 	 * Gets a user preference
 	 * @param string $userLogin
 	 * @param string $preferenceName
-	 * @param string $preferenceValue
-	 * @return void
+	 * @return bool|string
 	 */
 	public function getUserPreference($userLogin, $preferenceName)
 	{
@@ -89,7 +89,7 @@ class Piwik_UsersManager_API
 	/**
 	 * Returns the list of all the users
 	 * 
-	 * @param string Comma separated list of users to select. If not specified, will return all users
+	 * @param string $userLogins  Comma separated list of users to select. If not specified, will return all users
 	 * @return array the list of all the users
 	 */
 	public function getUsers( $userLogins = '' )
@@ -400,6 +400,8 @@ class Piwik_UsersManager_API
 		// we reload the access list which doesn't yet take in consideration this new user
 		Zend_Registry::get('access')->reloadAccess();
 		Piwik_Common::deleteTrackerCache();
+
+		Piwik_PostEvent('UsersManager.addUser', $userLogin);
 	}
 	
 	/**
@@ -416,7 +418,7 @@ class Piwik_UsersManager_API
 		$this->checkUserIsNotAnonymous( $userLogin );
 		$this->checkUserIsNotSuperUser($userLogin);
 		$userInfo = $this->getUser($userLogin);
-				
+
 		if(empty($password))
 		{
 			$password = $userInfo['password'];
@@ -458,14 +460,16 @@ class Piwik_UsersManager_API
 					"login = '$userLogin'"
 			);		
 		Piwik_Common::deleteTrackerCache();
+
+		Piwik_PostEvent('UsersManager.updateUser', $userLogin);
 	}
 	
 	/**
 	 * Delete a user and all its access, given its login.
 	 * 
-	 * @param string the user login.
+	 * @param string $userLogin the user login.
 	 * 
-	 * @exception if the user doesn't exist
+	 * @throws Exception if the user doesn't exist
 	 * 
 	 * @return bool true on success
 	 */
@@ -504,10 +508,10 @@ class Piwik_UsersManager_API
 	 */
 	public function userEmailExists( $userEmail )
 	{
-		Piwik::checkUserHasSomeAdminAccess();
+		Piwik::checkUserIsNotAnonymous();
 		$count = Piwik_FetchOne("SELECT count(*) 
-													FROM ".Piwik_Common::prefixTable("user"). " 
-													WHERE email = ?", $userEmail);
+								FROM ".Piwik_Common::prefixTable("user"). " 
+								WHERE email = ?", $userEmail);
 		return $count != 0;	
 	}
 	
@@ -516,15 +520,15 @@ class Piwik_UsersManager_API
 	 * 
 	 * If access = 'noaccess' the current access (if any) will be deleted.
 	 * If access = 'view' or 'admin' the current access level is deleted and updated with the new value.
-	 *  
-	 * @param string Access to grant. Must have one of the following value : noaccess, view, admin
-	 * @param string The user login 
-	 * @param int|array The array of idSites on which to apply the access level for the user. 
+	 *
+	 * @param string $userLogin The user login
+	 * @param string $access Access to grant. Must have one of the following value : noaccess, view, admin
+	 * @param int|array $idSites The array of idSites on which to apply the access level for the user.
 	 *       If the value is "all" then we apply the access level to all the websites ID for which the current authentificated user has an 'admin' access.
 	 * 
-	 * @exception if the user doesn't exist
-	 * @exception if the access parameter doesn't have a correct value
-	 * @exception if any of the given website ID doesn't exist
+	 * @throws Exception if the user doesn't exist
+	 * @throws Exception if the access parameter doesn't have a correct value
+	 * @throws Exception if any of the given website ID doesn't exist
 	 * 
 	 * @return bool true on success
 	 */
@@ -583,8 +587,8 @@ class Piwik_UsersManager_API
 	/**
 	 * Throws an exception is the user login doesn't exist
 	 * 
-	 * @param string user login
-	 * @exception if the user doesn't exist
+	 * @param string $userLogin user login
+	 * @throws Exception if the user doesn't exist
 	 */
 	private function checkUserExists( $userLogin )
 	{
@@ -597,8 +601,8 @@ class Piwik_UsersManager_API
 	/**
 	 * Throws an exception is the user email cannot be found
 	 * 
-	 * @param string user email
-	 * @exception if the user doesn't exist
+	 * @param string $userEmail user email
+	 * @throws Exception if the user doesn't exist
 	 */
 	private function checkUserEmailExists( $userEmail )
 	{
@@ -618,7 +622,7 @@ class Piwik_UsersManager_API
 	
 	private function checkUserIsNotSuperUser( $userLogin )
 	{
-		if($userLogin == Zend_Registry::get('config')->superuser->login)
+		if($userLogin == Piwik_Config::getInstance()->superuser['login'])
 		{
 			throw new Exception(Piwik_TranslateException("UsersManager_ExceptionSuperUser"));
 		}
@@ -683,12 +687,14 @@ class Piwik_UsersManager_API
 			}
 		}
 	}
-	
+
 	/**
 	 * Generates a unique MD5 for the given login & password
-	 * 
-	 * @param string Login
-	 * @param string MD5ied string of the password
+	 *
+	 * @param string $userLogin Login
+	 * @param string $md5Password MD5ied string of the password
+	 * @throws Exception
+	 * @return string
 	 */
 	public function getTokenAuth($userLogin, $md5Password)
 	{
