@@ -4,7 +4,7 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 4480 2011-04-16 06:24:33Z matt $
+ * @version $Id: Controller.php 5465 2011-11-23 05:15:59Z matt $
  * 
  * @category Piwik_Plugins
  * @package Piwik_VisitTime
@@ -26,17 +26,10 @@ class Piwik_VisitTime_Controller extends Piwik_Controller
 		
 	public function getVisitInformationPerServerTime( $fetch = false)
 	{
-		$view = Piwik_ViewDataTable::factory( 'graphVerticalBar');
-		$view->init( $this->pluginName,  __FUNCTION__, "VisitTime.getVisitInformationPerServerTime" );
+		$view = $this->getGraph(__FUNCTION__, 'VisitTime.getVisitInformationPerServerTime',
+				'VisitTime_ColumnServerTime');
+		
 		$view->setCustomParameter('hideFutureHoursWhenToday', 1);
-		$view->setColumnsToDisplay( array('label','nb_visits') );
-		$view->setSortedColumn( 'label', 'asc' );		
-		$view->setColumnTranslation('label', Piwik_Translate('VisitTime_ColumnServerTime'));
-		$view->setLimit( 24 );
-		$view->setGraphLimit( 24 );
-		$view->disableSearchBox();
-		$view->disableExcludeLowPopulation();
-		$view->disableOffsetInformationAndPaginationControls();
 		$view->enableShowGoals();
 		
 		return $this->renderView($view, $fetch);
@@ -44,17 +37,29 @@ class Piwik_VisitTime_Controller extends Piwik_Controller
 	
 	public function getVisitInformationPerLocalTime( $fetch = false)
 	{
-		$view = Piwik_ViewDataTable::factory( 'graphVerticalBar');
-		$view->init( $this->pluginName,  __FUNCTION__, "VisitTime.getVisitInformationPerLocalTime" );
-		$view->setColumnTranslation('label', Piwik_Translate('VisitTime_ColumnLocalTime'));
-		$view->setColumnsToDisplay( array('label','nb_visits') );
+		$view = $this->getGraph(__FUNCTION__, 'VisitTime.getVisitInformationPerLocalTime',
+					'VisitTime_ColumnLocalTime');
+		
+		return $this->renderView($view, $fetch);
+	}
+	
+	private function getGraph( $controllerMethod, $apiMethod, $labelTranslation )
+	{
+		$view = Piwik_ViewDataTable::factory('graphVerticalBar');
+		$view->init($this->pluginName, $controllerMethod, $apiMethod);
+		
+		
+		$view->setColumnTranslation('label', Piwik_Translate($labelTranslation));
 		$view->setSortedColumn( 'label', 'asc' );
+		
 		$view->setLimit( 24 );
 		$view->setGraphLimit( 24 );
 		$view->disableSearchBox();
 		$view->disableExcludeLowPopulation();
 		$view->disableOffsetInformationAndPaginationControls();
+		$this->setMetricsVariablesView($view);
 		
-		return $this->renderView($view, $fetch);
+		return $view;
 	}
+	
 }
