@@ -4,7 +4,7 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Controller.php 4634 2011-05-05 08:56:37Z EZdesign $
+ * @version $Id: Controller.php 6076 2012-03-20 21:52:15Z matt $
  *
  * @category Piwik_Plugins
  * @package Piwik_VisitsSummary
@@ -33,17 +33,15 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 		echo $view->render();
 	}
 
-	public function getEvolutionGraph( $fetch = false, $columns = false)
+	public function getEvolutionGraph( $fetch = false, $columns = false )
 	{
-		$view = $this->getLastUnitGraph($this->pluginName, __FUNCTION__, "VisitsSummary.get");
 		if(empty($columns))
 		{
 			$columns = Piwik_Common::getRequestVar('columns');
+			$columns = Piwik::getArrayFromApiParameter($columns);
 		}
-		$columns = !is_array($columns) ? array($columns) : $columns;
-		$view->setColumnsToDisplay($columns);
 		
-		$doc = Piwik_Translate('VisitsSummary_VisitsSummaryDocumentation').'<br />'
+		$documentation = Piwik_Translate('VisitsSummary_VisitsSummaryDocumentation').'<br />'
 		     . Piwik_Translate('General_BrokenDownReportDocumentation').'<br /><br />'
 		     
 		     . '<b>'.Piwik_Translate('General_ColumnNbVisits').':</b> '
@@ -58,7 +56,26 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 		     . '<b>'.Piwik_Translate('General_ColumnActionsPerVisit').':</b> '
 		     . Piwik_Translate('General_ColumnActionsPerVisitDocumentation');
 		
-		$view->setReportDocumentation($doc);
+		$selectableColumns = array(
+			// columns from VisitsSummary.get
+			'nb_visits',
+			'nb_uniq_visitors',
+			'avg_time_on_site',
+			'bounce_rate',
+			'nb_actions_per_visit',
+			'max_actions',
+			'nb_visits_converted',
+			// columns from Actions.get
+			'nb_pageviews',
+			'nb_uniq_pageviews',
+			'nb_downloads',
+			'nb_uniq_downloads',
+			'nb_outlinks',
+			'nb_uniq_outlinks'
+		);
+		
+		$view = $this->getLastUnitGraphAcrossPlugins($this->pluginName, __FUNCTION__, $columns, 
+							$selectableColumns, $documentation);
 		
 		return $this->renderView($view, $fetch);
 	}
@@ -85,8 +102,10 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 	
 	protected function setSparklinesAndNumbers($view)
 	{
-		$view->urlSparklineNbVisits 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_visits')));
-		$view->urlSparklineNbActions 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_actions')));
+		$view->urlSparklineNbVisits 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => $view->displayUniqueVisitors ? array('nb_visits', 'nb_uniq_visitors') : array('nb_visits')));
+		$view->urlSparklineNbPageviews 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_pageviews', 'nb_uniq_pageviews')));
+		$view->urlSparklineNbDownloads 	    = $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_downloads', 'nb_uniq_downloads')));
+		$view->urlSparklineNbOutlinks 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_outlinks', 'nb_uniq_outlinks')));
 		$view->urlSparklineAvgVisitDuration = $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('avg_time_on_site')));
 		$view->urlSparklineMaxActions 		= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('max_actions')));
 		$view->urlSparklineActionsPerVisit 	= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_actions_per_visit')));
@@ -94,15 +113,36 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 		
 		$dataTableVisit = self::getVisitsSummary();
 		$dataRow = $dataTableVisit->getFirstRow();
-		$view->urlSparklineNbUniqVisitors 	= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_uniq_visitors')));
-		$view->nbUniqVisitors = $dataRow->getColumn('nb_uniq_visitors');
-		$nbVisits = $dataRow->getColumn('nb_visits');
+		
+		$dataTableActions = Piwik_Actions_API::getInstance()->get(Piwik_Common::getRequestVar('idSite'), Piwik_Common::getRequestVar('period'), Piwik_Common::getRequestVar('date'), Piwik_Common::getRequestVar('segment',false));
+		$dataActionsRow = $dataTableActions->getFirstRow();
+		
+		$view->nbUniqVisitors = (int)$dataRow->getColumn('nb_uniq_visitors');
+		$nbVisits = (int)$dataRow->getColumn('nb_visits');
 		$view->nbVisits = $nbVisits;
-		$view->nbActions = $dataRow->getColumn('nb_actions');
+		$view->nbPageviews = (int)$dataActionsRow->getColumn('nb_pageviews');
+		$view->nbUniquePageviews = (int)$dataActionsRow->getColumn('nb_uniq_pageviews');
+		$view->nbDownloads = (int)$dataActionsRow->getColumn('nb_downloads');
+		$view->nbUniqueDownloads = (int)$dataActionsRow->getColumn('nb_uniq_downloads');
+		$view->nbOutlinks = (int)$dataActionsRow->getColumn('nb_outlinks');
+		$view->nbUniqueOutlinks = (int)$dataActionsRow->getColumn('nb_uniq_outlinks');
 		$view->averageVisitDuration = $dataRow->getColumn('avg_time_on_site');
 		$nbBouncedVisits = $dataRow->getColumn('bounce_count');
 		$view->bounceRate = Piwik::getPercentageSafe($nbBouncedVisits, $nbVisits);
-		$view->maxActions = $dataRow->getColumn('max_actions');
+		$view->maxActions = (int)$dataRow->getColumn('max_actions');
 		$view->nbActionsPerVisit = $dataRow->getColumn('nb_actions_per_visit');
+		
+		// backward compatibility:
+		// show actions if the finer metrics are not archived
+		$view->showOnlyActions = false;
+		if (  $dataActionsRow->getColumn('nb_pageviews') 
+			+ $dataActionsRow->getColumn('nb_downloads')
+			+ $dataActionsRow->getColumn('nb_outlinks') == 0 
+			&& $dataRow->getColumn('nb_actions') > 0)
+		{
+			$view->showOnlyActions = true;
+			$view->nbActions = $dataRow->getColumn('nb_actions');
+			$view->urlSparklineNbActions = $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_actions')));
+		}
 	}
 }
